/**
 * AuditResultData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.audit;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

import com.smartmatic.waffle.domain.device.VotingDeviceData;
import com.smartmatic.waffle.domain.general.BaseGeneralInfo;

/**
 * Entity class that represents auditory results.
 */
@Entity
@org.hibernate.annotations.Entity(mutable = false)
@Table(name = "audit_result", uniqueConstraints = { @UniqueConstraint(columnNames = "audit_result_custom_code") })
public class AuditResultData extends BaseGeneralInfo {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The audit object. */
	private AuditData audit;

	/** The voting device data. */
	private VotingDeviceData device;

	/** The deviation. */
	private float deviation;

	/**
	 * Full constructor.
	 * 
	 * @param audit
	 *            the audit
	 * @param device
	 *            the device
	 * @param deviation
	 *            the deviation
	 */
	public AuditResultData(AuditData audit, VotingDeviceData device,
			float deviation) {
		this.audit = audit;
		this.device = device;
		this.deviation = deviation;
	}

	/**
	 * Getter for the audit attribute.
	 * 
	 * @return the audit
	 */
	@ManyToOne
	@JoinColumn(name = "audit_code", nullable = false)
	public AuditData getAudit() {
		return this.audit;
	}

	/**
	 * Setter for the audit attribute.
	 * 
	 * @param audit
	 *            the audit to set
	 */
	public void setAudit(AuditData audit) {
		this.audit = audit;
	}

	/**
	 * Getter for the device attribute.
	 * 
	 * @return the device
	 */
	@ManyToOne
	@JoinColumn(name = "voting_device_code", nullable = false)
	public VotingDeviceData getDevice() {
		return this.device;
	}

	/**
	 * Setter for the device attribute.
	 * 
	 * @param device
	 *            the device to set
	 */
	public void setDevice(VotingDeviceData device) {
		this.device = device;
	}

	/**
	 * Getter for the deviation attribute.
	 * 
	 * @return the deviation
	 */
	@Column(name = "audit_result_deviation", nullable = false)
	public float getDeviation() {
		return this.deviation;
	}

	/**
	 * Setter for the deviation attribute.
	 * 
	 * @param deviation
	 *            the deviation to set
	 */
	public void setDeviation(float deviation) {
		this.deviation = deviation;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCode()
	 */
	@Id
	@Column(name = "audit_result_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_audit_result")
	@SequenceGenerator(name = "s_audit_result", sequenceName = "s_audit_result", allocationSize = 1, initialValue = 1)
	@Override
	public long getCode() {
		return super.getCode();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCustomCode()
	 */
	@Column(name = "audit_result_custom_code", nullable = false)
	@Override
	public String getCustomCode() {
		return super.getCustomCode();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCode(long)
	 */
	@Override
	public void setCode(long code) {
		super.setCode(code);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCustomCode(
	 * java.lang.String)
	 */
	@Override
	public void setCustomCode(String customCode) {
		super.setCustomCode(customCode);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.domain.BaseDataObject#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object anObject) {
		if (anObject instanceof AuditResultData) {
			AuditResultData otherAuditResult = (AuditResultData) anObject;
			return otherAuditResult.customCode.equals(this.customCode);
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.domain.BaseDataObject#hashCode()
	 */
	@Override
	public int hashCode() {
		return (int) this.code;
	}

}
