/**
 * BallotOptionData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.ballot;

import java.util.ArrayList;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;

import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionRoleData;
import com.smartmatic.waffle.domain.eligibleoption.PartyData;
import com.smartmatic.waffle.domain.general.BaseGeneralInfo;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamConverter;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import com.thoughtworks.xstream.converters.enums.EnumConverter;

/**
 * JavaBean that represents a single voting possibility conformed by the
 * combination of one political party with one eligible option.
 */
@Entity
@Table(name = "ballot_option", uniqueConstraints = { @UniqueConstraint(columnNames = "ballot_option_custom_code") })
@XStreamAlias("ballot-option")
public class BallotOptionData extends BaseGeneralInfo {

	/** The Constant serialVersionUID. */
	@XStreamOmitField
	private static final long serialVersionUID = -3502168608023417471L;

	/** The type. */
	@XStreamAlias("type")
	@XStreamAsAttribute
	@Enumerated(EnumType.ORDINAL)
	Type type;

	/**
	 * The Enum Type.
	 */
	@XStreamConverter(EnumConverter.class)
	public enum Type {

		/** The screen. */
		SCREEN,
		/** The pad. */
		PAD,
		/** The vtv. */
		VTV,
		/** The pad with screen status. */
		PAD_WITH_SCREEN_STATUS
	}

	/** The additional pad position group. */
	@XStreamOmitField
	Set<Integer> additionalPadPositionGroup;

	/** The image file name. */
	@XStreamAlias("image-file-name")
	@XStreamAsAttribute
	String imageFileName;

	/** The tally position. */
	@XStreamAlias("tally-position")
	@XStreamAsAttribute
	int tallyPosition;

	/** The party. */
	@XStreamAlias("party")
	PartyData party;

	/** The pad position. */
	@XStreamOmitField
	int padPosition;

	/** The order. */
	@XStreamOmitField
	int order;

	/** The tabulation arrange. */
	@XStreamOmitField
	int tabulationArrange;

	/** The automated arrange. */
	@XStreamOmitField
	int automatedArrange;

	/** The manual arrange. */
	@XStreamOmitField
	int manualArrange;

	/** The is initialized. */
	@XStreamOmitField
	private boolean isInitialized = false;

	/** The eligible option. */
	@XStreamOmitField
	private EligibleOptionData eligibleOption;

	/** The category. */
	@XStreamAlias("category")
	@XStreamAsAttribute
	private BallotOptionCategoryEnum category;

	/** The ballot option parent. */
	@XStreamOmitField
	private BallotOptionData ballotOptionParent;

	/**
	 * Gets the category.
	 * 
	 * @return the category
	 */
	@Transient
	public BallotOptionCategoryEnum getCategory() {

		ArrayList<EligibleOptionRoleData> eligibleOptionRoleDataList = null;

		if (this.eligibleOption != null) {
			eligibleOptionRoleDataList = new ArrayList<EligibleOptionRoleData>(
					this.eligibleOption.getEligibleOptionRoleData());

			if (eligibleOptionRoleDataList.size() == 1) {
				for (EligibleOptionRoleData eligibleOptionRoleData : eligibleOptionRoleDataList) {

					if (eligibleOptionRoleData.getRole() == EligibleOptionRoleData.Role.CHIEF) {
						this.category = BallotOptionCategoryEnum.PRINCIPAL;
					}

					if (eligibleOptionRoleData.getRole() == EligibleOptionRoleData.Role.STANDIN) {
						this.category = BallotOptionCategoryEnum.STAND_IN;
					}
				}
			} else {
				this.category = BallotOptionCategoryEnum.PRINCIPAL;
			}
		}
		return this.category;
	}

	/**
	 * Setter for the <code>category</code> attribute.
	 * 
	 * @param category
	 *            the category to set
	 * @see BallotOptionData#category
	 */
	public void setCategory(BallotOptionCategoryEnum category) {
		this.category = category;
	}

	/**
	 * Getter of <code>additionalPadPositionGroup</code> property.
	 * 
	 * @return <code>additionalPadPositionGroup</code> property value.
	 * @see #additionalPadPositionGroup
	 */
	@Transient
	public Set<Integer> getAdditionalPadPositionGroup() {
		return this.additionalPadPositionGroup;
	}

	/**
	 * Setter of <code>additionalPadPositionGroup</code> property.
	 * 
	 * @param additionalPadPositionGroup
	 *            The <code>additionalPadPositionGroup</code> to set.
	 * @see #additionalPadPositionGroup
	 */
	public void setAdditionalPadPositionGroup(
			Set<Integer> additionalPadPositionGroup) {
		this.additionalPadPositionGroup = additionalPadPositionGroup;
	}

	/**
	 * Getter of <code>imageFileName</code> property.
	 * 
	 * @return <code>imageFileName</code> property value.
	 * @see #imageFileName
	 */
	@Column(name = "image_file_name")
	public String getImageFileName() {
		return this.imageFileName;
	}

	/**
	 * Setter of <code>imageFileName</code> property.
	 * 
	 * @param imageFileName
	 *            The <code>imageFileName</code> to set.
	 * @see #imageFileName
	 */
	public void setImageFileName(String imageFileName) {
		this.imageFileName = imageFileName;
	}

	/**
	 * Getter of <code>tallyPosition</code> property.
	 * 
	 * @return <code>tallyPosition</code> property value.
	 * @see #tallyPosition
	 */
	@Column(name = "tally_position")
	public int getTallyPosition() {
		return this.tallyPosition;
	}

	/**
	 * Setter of <code>tallyPosition</code> property.
	 * 
	 * @param tallyPosition
	 *            The <code>tallyPosition</code> to set.
	 * @see #tallyPosition
	 */
	public void setTallyPosition(int tallyPosition) {
		this.tallyPosition = tallyPosition;
	}

	/**
	 * Getter of <code>party</code> property.
	 * 
	 * @return <code>party</code> property value.
	 * @see #party
	 */
	@ManyToOne(optional = false, targetEntity = PartyData.class)
	@JoinColumn(name = "party_code", nullable = false, updatable = true)
	public PartyData getParty() {
		return this.party;
	}

	/**
	 * Setter of <code>party</code> property.
	 * 
	 * @param party
	 *            The <code>party</code> to set.
	 * @see #party
	 */
	public void setParty(PartyData party) {
		this.party = party;
	}

	/**
	 * Getter of <code>padPosition</code> property.
	 * 
	 * @return <code>padPosition</code> property value.
	 * @see #padPosition
	 */
	@Column(name = "pad_position")
	public int getPadPosition() {
		return this.padPosition;
	}

	/**
	 * Setter of <code>padPosition</code> property.
	 * 
	 * @param padPosition
	 *            The <code>padPosition</code> to set.
	 * @see #padPosition
	 */
	public void setPadPosition(int padPosition) {
		this.padPosition = padPosition;
	}

	/**
	 * Sets the party name.
	 * 
	 * @param PartyName
	 *            the new party name
	 */
	@Transient
	public void setPartyName(String PartyName) {
		this.getParty().setName(PartyName);
	}

	/**
	 * Gets the party name.
	 * 
	 * @return the party name
	 */
	@Transient
	public String getPartyName() {
		return this.getParty().getName();
	}

	/**
	 * Getter of <code>order</code> property.
	 * 
	 * @return <code>order</code> property value.
	 * @see #order
	 */
	@Transient
	public int getOrder() {
		return this.order;
	}

	/**
	 * Setter of <code>order</code> property.
	 * 
	 * @param order
	 *            The <code>order</code> to set.
	 * @see #order
	 */
	public void setOrder(int order) {
		this.order = order;
	}

	/**
	 * Getter of <code>tabulationArrange</code> property.
	 * 
	 * @return <code>tabulationArrange</code> property value.
	 * @see #tabulationArrange
	 */
	@Column(name = "totalization_order")
	public int getTabulationArrange() {
		return this.tabulationArrange;
	}

	/**
	 * Setter of <code>tabulationArrange</code> property.
	 * 
	 * @param tabulationArrange
	 *            The <code>tabulationArrange</code> to set.
	 * @see #tabulationArrange
	 */
	public void setTabulationArrange(int tabulationArrange) {
		this.tabulationArrange = tabulationArrange;
	}

	/**
	 * Getter of <code>automatedArrange</code> property.
	 * 
	 * @return <code>automatedArrange</code> property value.
	 * @see #automatedArrange
	 */
	@Column(name = "automatic_order")
	public int getAutomatedArrange() {
		return this.automatedArrange;
	}

	/**
	 * Setter of <code>automatedArrange</code> property.
	 * 
	 * @param automatedArrange
	 *            The <code>automatedArrange</code> to set.
	 * @see #automatedArrange
	 */
	public void setAutomatedArrange(int automatedArrange) {
		this.automatedArrange = automatedArrange;
	}

	/**
	 * Getter of <code>manualArrange</code> property.
	 * 
	 * @return <code>manualArrange</code> property value.
	 * @see #manualArrange
	 */
	@Column(name = "manual_order")
	public int getManualArrange() {
		return this.manualArrange;
	}

	/**
	 * Setter of <code>manualArrange</code> property.
	 * 
	 * @param manualArrange
	 *            The <code>manualArrange</code> to set.
	 * @see #manualArrange
	 */
	public void setManualArrange(int manualArrange) {
		this.manualArrange = manualArrange;
	}

	/**
	 * Initialize.
	 * 
	 * @param eligibleOption
	 *            the eligible option
	 */
	public void initialize(EligibleOptionData eligibleOption) {
		if (this.isInitialized) {
			return;
		}
		this.eligibleOption = eligibleOption;
		this.isInitialized = true;
	}

	/**
	 * Getter of <code>isInitialized</code> property.
	 * 
	 * @return <code>isInitialized</code> property value.
	 * @see #isInitialized
	 */
	@Transient
	public boolean isInitialized() {
		return this.isInitialized;
	}

	/**
	 * Getter of <code>EligibleOptionData</code> property.
	 * 
	 * @return <code>EligibleOptionData</code> property value.
	 * @see #EligibleOptionData
	 */
	@ManyToOne(optional = false, targetEntity = EligibleOptionData.class)
	@JoinColumn(name = "eligible_option_code", nullable = false, updatable = true)
	public EligibleOptionData getEligibleOption() {
		return this.eligibleOption;
	}

	/**
	 * Setter for the <code>EligibleOptionData</code> attribute.
	 * 
	 * @param EligibleOptionData
	 *            the EligibleOptionData to set
	 * @see BallotOptionData#EligibleOptionData
	 */
	public void setEligibleOption(EligibleOptionData EligibleOptionData) {
		this.eligibleOption = EligibleOptionData;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {

		return this.party.getName() + " - "
				+ this.eligibleOption.getBallotName();

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCode()
	 */
	@Id
	@Column(name = "ballot_option_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_ballot_option")
	@SequenceGenerator(name = "s_ballot_option", sequenceName = "s_ballot_option", allocationSize = 1, initialValue = 1)
	@Override
	public long getCode() {
		return super.getCode();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCustomCode()
	 */
	@CustomCodeAnnotation
	@Column(name = "ballot_option_custom_code", nullable = false, unique = true)
	@Override
	public String getCustomCode() {
		return super.getCustomCode();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCode(long)
	 */
	@Override
	public void setCode(long code) {
		super.setCode(code);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCustomCode(
	 * java.lang.String)
	 */
	@Override
	public void setCustomCode(String customCode) {
		super.setCustomCode(customCode);
	}

	/**
	 * Getter of <code>ballotOptionParent</code> property.
	 * 
	 * @return <code>ballotOptionParent</code> property value.
	 * @see #ballotOptionParent
	 */
	@ManyToOne
	@JoinColumn(name = "ballot_option_parent_code", nullable = true, updatable = true)
	public BallotOptionData getBallotOptionParent() {
		return this.ballotOptionParent;
	}

	/**
	 * Setter of <code>ballotOptionParent</code> property.
	 * 
	 * @param ballotOptionParent
	 *            The <code>ballotOptionParent</code> to set.
	 * @see #ballotOptionParent
	 */
	public void setBallotOptionParent(BallotOptionData ballotOptionParent) {
		this.ballotOptionParent = ballotOptionParent;
	}

	/**
	 * Gets the type.
	 * 
	 * @return the type
	 */
	@Column(name = "ballot_option_type")
	public Type getType() {
		return this.type;
	}

	/**
	 * Sets the type.
	 * 
	 * @param type
	 *            the type to set
	 */
	public void setType(Type type) {
		this.type = type;
	}
}
