/**
 * CategoryData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.demographics;

import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;
import javax.persistence.Version;

import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.general.GeneralInfo;
import com.smartmatic.waffle.lang.annotations.basic.ValidatorListener;
import com.smartmatic.waffle.persistence.metadata.MultilingualPropertyAnnotation;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamOmitField;

/**
 * This class represents the category of a {@link RegionData}.
 */
@Entity
@Table(name = "category", uniqueConstraints = {
		@UniqueConstraint(columnNames = "category_custom_code"),
		@UniqueConstraint(columnNames = { "category_name" }) })
@ValidatorListener(name = "com.smartmatic.waffle.validator.demographics.CategoryDataValidator")
@XStreamAlias("category")
public class CategoryData extends GeneralInfo {

	/**
	 * The Enum Level.
	 */
	public enum Level {

		/** The first level. */
		FIRST_LEVEL // Country,
		/** The second level. */
		, SECOND_LEVEL // Region
		/** The third level. */
		, THIRD_LEVEL // Province
		/** The fourth level. */
		, FOURTH_LEVEL // Arrondissement
		/** The fifth level. */
		, FIFTH_LEVEL // Province District (only for locals elections)
		/** The sixth level. */
		, SIXTH_LEVEL // Canton
		/** The seventh level. */
		, SEVENTH_LEVEL // Commune
		/** The eighth level. */
		, EIGHTH_LEVEL // District
	}

	/** The Constant serialVersionUID. */
	@XStreamOmitField
	private static final long serialVersionUID = -6401548220800645531L;

	/** The region. */
	@XStreamAlias("region")
	private RegionData region;

	/** The parent. */
	@XStreamOmitField
	private Set<CategoryData> parent;

	/** The category. */
	private CategoryData category;

	/** The category level. */
	@XStreamAlias("category-level")
	@XStreamAsAttribute
	@Enumerated(EnumType.ORDINAL)
	private Level categoryLevel;

	/** The category name. */
	@XStreamAlias("name-key")
	@XStreamAsAttribute
	String categoryName;

	/**
	 * All paths related to this category.
	 * 
	 * @see PathData
	 */
	@XStreamOmitField
	private Set<PathData> paths;

	/**
	 * Field that indicates if a category is a last level category. This field
	 * means that the regions which has this value in true allows to map the
	 * Polling place to those regions because is a last level region (Does not
	 * have any child)
	 */
	@XStreamOmitField
	private boolean lastLevelCategory;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCode()
	 */
	@Override
	@Id
	@Column(name = "category_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_category")
	@SequenceGenerator(name = "s_category", sequenceName = "s_category", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCode(long)
	 */
	@Override
	public void setCode(long code) {
		this.code = code;
	}

	/**
	 * Gets the parent.
	 * 
	 * @return the parent
	 */
	@ManyToMany(fetch = FetchType.LAZY)
	@JoinTable(name = "category_parent", inverseJoinColumns = @JoinColumn(name = "category_parent_code", referencedColumnName = "category_code"), joinColumns = @JoinColumn(name = "category_child_code", referencedColumnName = "category_code"))
	public Set<CategoryData> getParent() {
		return this.parent;
	}

	/**
	 * Setter of <code>parent</code> property.
	 * 
	 * @param parent
	 *            The <code>parent</code> to set
	 */
	public void setParent(Set<CategoryData> parent) {
		this.parent = parent;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCustomCode()
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "category_custom_code", nullable = false)
	public String getCustomCode() {
		return this.customCode;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCustomCode(
	 * java.lang.String)
	 */
	@Override
	public void setCustomCode(String customCode) {
		this.customCode = customCode;
	}

	/**
	 * Gets the category name.
	 * 
	 * @return the category name
	 */
	@MultilingualPropertyAnnotation
	@Column(name = "category_name", nullable = false)
	public String getCategoryName() {
		return this.categoryName;
	}

	/**
	 * Setter of <code>categoryName</code> property.
	 * 
	 * @param categoryName
	 *            The <code>categoryName</code> to set
	 */
	public void setCategoryName(String categoryName) {
		this.categoryName = categoryName;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getVersion()
	 */
	@Override
	@Column(name = "version")
	@Version
	public int getVersion() {
		return this.version;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.domain.BaseDataObject#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object anObject) {
		if (anObject instanceof CategoryData) {
			CategoryData otherCategory = (CategoryData) anObject;
			return otherCategory.code == this.code;
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.domain.BaseDataObject#hashCode()
	 */
	@Override
	public int hashCode() {
		return (int) this.code;
	}

	/**
	 * Getter of <code>region</code> property.
	 * 
	 * @return <code>region</code> property value.
	 * @see #region
	 */
	@Transient
	public RegionData getRegion() {
		return this.region;
	}

	/**
	 * Setter of <code>region</code> property.
	 * 
	 * @param region
	 *            The <code>region</code> to set.
	 * @see #region
	 */
	public void setRegion(RegionData region) {
		this.region = region;
	}

	/**
	 * Getter of <code>lastLevelCategory</code> property.
	 * 
	 * @return <code>lastLevelCategory</code> property value.
	 * @see #lastLevelCategory
	 */
	@Column(name = "last_level", nullable = false)
	public boolean isLastLevelCategory() {
		return this.lastLevelCategory;
	}

	/**
	 * Setter of <code>lastLevelCategory</code> property.
	 * 
	 * @param lastLevelCategory
	 *            The <code>lastLevelCategory</code> to set.
	 * @see #lastLevelCategory
	 */
	public void setLastLevelCategory(boolean lastLevelCategory) {
		this.lastLevelCategory = lastLevelCategory;
	}

	/**
	 * Getter of <code>paths</code> property.
	 * 
	 * @return <code>paths</code> property value.
	 * @see #paths
	 */
	@ManyToMany(fetch = FetchType.LAZY)
	@JoinTable(name = "category_path", inverseJoinColumns = @JoinColumn(name = "path_code", referencedColumnName = "path_code"), joinColumns = @JoinColumn(name = "category_code", referencedColumnName = "category_code"))
	public Set<PathData> getPaths() {
		return this.paths;
	}

	/**
	 * Setter of <code>paths</code> property.
	 * 
	 * @param paths
	 *            The <code>paths</code> to set.
	 * @see #paths
	 */
	public void setPaths(Set<PathData> paths) {
		this.paths = paths;
	}

	/**
	 * Getter of <code>categoryLevel</code> property.
	 * 
	 * @return <code>categoryLevel</code> property value.
	 * @see #categoryLevel
	 */
	@Column(name = "category_level", nullable = false)
	public Level getCategoryLevel() {
		return this.categoryLevel;
	}

	/**
	 * Setter of <code>categoryLevel</code> property.
	 * 
	 * @param categoryLevel
	 *            The <code>categoryLevel</code> to set.
	 * @see #categoryLevel
	 */
	public void setCategoryLevel(Level categoryLevel) {
		this.categoryLevel = categoryLevel;
	}

	/**
	 * Getter of <code>category</code> property.
	 * 
	 * @return <code>category</code> property value.
	 * @see #category
	 */
	@Transient
	public CategoryData getCategory() {
		return this.category;
	}

	/**
	 * Setter of <code>category</code> property.
	 * 
	 * @param category
	 *            The <code>category</code> to set.
	 * @see #category
	 */
	public void setCategory(CategoryData category) {
		this.category = category;
	}
}
