/**
 * DistrictData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.demographics;

import java.util.List;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;

import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.general.GeneralInfo;
import com.smartmatic.waffle.lang.annotations.basic.ValidatorListener;
import com.smartmatic.waffle.persistence.metadata.MultilingualPropertyAnnotation;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamOmitField;

/**
 * Represents clearly defined territory and its population into which a city,
 * town, state, country or any administrative entity is divided for voting
 * purposes.
 */
@XStreamAlias("district")
@Entity
@Table(name = "district", uniqueConstraints = { @UniqueConstraint(columnNames = "district_custom_code") })
@ValidatorListener(name = "com.smartmatic.waffle.validator.demographics.DistrictDataValidator")
public class DistrictData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	@XStreamOmitField
	private static final long serialVersionUID = -7739247474759078696L;

	/** The regions. */
	@XStreamOmitField
	Set<RegionData> regions;

	/** The region. */
	@XStreamAlias("regions")
	List<RegionCodeData> region;

	/** The number. */
	@XStreamAlias("number")
	@XStreamAsAttribute
	int number;

	/** The description. */
	@XStreamAlias("description-key")
	@XStreamAsAttribute
	String description;

	/** The path. */
	@XStreamAlias("region-hierarchy-code")
	@XStreamAsAttribute
	long path;

	/**
	 * Corresponds to the category path to which this district is related.
	 * 
	 * @see PathData
	 */
	@XStreamOmitField
	private Set<PathData> paths;

	/** The contests. */
	@XStreamOmitField
	Set<ContestData> contests;

	/** The district name. */
	@XStreamAlias("name-key")
	@XStreamAsAttribute
	String districtName;

	/** The district name traslated. */
	@XStreamOmitField
	String districtNameTraslated;

	/**
	 * Gets the corresponds to the category path to which this district is
	 * related.
	 * 
	 * @return the paths
	 */
	@ManyToMany(targetEntity = PathData.class)
	@JoinTable(name = "district_path", joinColumns = @JoinColumn(name = "district_code", referencedColumnName = "district_code"), inverseJoinColumns = @JoinColumn(name = "path_code", referencedColumnName = "path_code"))
	public Set<PathData> getPaths() {
		return this.paths;
	}

	/**
	 * Setter of <code>paths</code> property.
	 * 
	 * @param paths
	 *            the paths to set
	 */
	public void setPaths(Set<PathData> paths) {
		this.paths = paths;
	}

	/**
	 * Getter of <code>number</code> property.
	 * 
	 * @return <code>number</code> property value.
	 * @see #number
	 */
	@Column(name = "district_number")
	public int getNumber() {
		return this.number;
	}

	/**
	 * Setter of <code>number</code> property.
	 * 
	 * @param number
	 *            The <code>number</code> to set.
	 * @see #number
	 */
	public void setNumber(int number) {
		this.number = number;
	}

	/**
	 * Getter of <code>description</code> property.
	 * 
	 * @return <code>description</code> property value.
	 * @see #description
	 */
	@MultilingualPropertyAnnotation
	@Column(name = "district_description", nullable = false)
	public String getDescription() {
		return this.description;
	}

	/**
	 * Setter of <code>description</code> property.
	 * 
	 * @param description
	 *            The <code>description</code> to set.
	 * @see #description
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * Getter of <code>path</code> property.
	 * 
	 * @return <code>path</code> property value.
	 * @see #path
	 */
	@Transient
	public long getPath() {
		return this.path;
	}

	/**
	 * Setter of <code>path</code> property.
	 * 
	 * @param path
	 *            The <code>path</code> to set.
	 * @see #path
	 */
	public void setPath(long path) {
		this.path = path;
	}

	/**
	 * Gets the region code inner data.
	 * 
	 * @return the region code inner data
	 */
	@Transient
	public RegionCodeData getRegionCodeInnerData() {
		return new RegionCodeData();
	}

	/**
	 * The Class RegionCodeData.
	 */
	@XStreamAlias("region")
	public static class RegionCodeData extends GeneralInfo {

		/** The Constant serialVersionUID. */
		private static final long serialVersionUID = -1780778070115771757L;

		/**
		 * Getter of <code>code</code> property.
		 * 
		 * @return <code>code</code> property value.
		 * @see #code
		 */
		@Override
		public long getCode() {
			return this.code;
		}

		/**
		 * Setter of <code>code</code> property.
		 * 
		 * @param code
		 *            The <code>code</code> to set.
		 * @see #code
		 */
		@Override
		public void setCode(long code) {
			this.code = code;
		}
	}

	/**
	 * Getter of <code>regions</code> property.
	 * 
	 * @return <code>regions</code> property value.
	 * @see #regions
	 */
	@ManyToMany(targetEntity = RegionData.class)
	@JoinTable(name = "region_district", joinColumns = @JoinColumn(name = "district_code", referencedColumnName = "district_code"), inverseJoinColumns = @JoinColumn(name = "region_code", referencedColumnName = "region_code"))
	public Set<RegionData> getRegions() {
		return this.regions;
	}

	/**
	 * Getter of {@link #region} field.
	 * 
	 * @return {@link #region} value.
	 */
	@Transient
	public List<RegionCodeData> getRegion() {
		return this.region;
	}

	/**
	 * Setter of {@link #region} field.
	 * 
	 * @param region
	 *            The List<RegionCodeData> to set.
	 */
	public void setRegion(List<RegionCodeData> region) {
		this.region = region;
	}

	/**
	 * Setter of <code>regions</code> property.
	 * 
	 * @param regions
	 *            The <code>regions</code> to set.
	 * @see #regions
	 */
	public void setRegions(Set<RegionData> regions) {
		this.regions = regions;
	}

	/**
	 * Gets the district name.
	 * 
	 * @return the districtName
	 */
	@MultilingualPropertyAnnotation
	@Column(name = "district_name", nullable = false)
	public String getDistrictName() {
		return this.districtName;
	}

	/**
	 * Sets the district name.
	 * 
	 * @param districtName
	 *            the districtName to set
	 */
	public void setDistrictName(String districtName) {
		this.districtName = districtName;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCode()
	 */
	@Id
	@Column(name = "district_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_district")
	@SequenceGenerator(name = "s_district", sequenceName = "s_district", allocationSize = 1, initialValue = 1)
	@Override
	public long getCode() {
		return super.getCode();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCustomCode()
	 */
	@CustomCodeAnnotation
	@Column(name = "district_custom_code", nullable = false)
	@Override
	public String getCustomCode() {
		return super.getCustomCode();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCode(long)
	 */
	@Override
	public void setCode(long code) {
		super.setCode(code);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCustomCode(
	 * java.lang.String)
	 */
	@Override
	public void setCustomCode(String customCode) {
		super.setCustomCode(customCode);
	}

	/**
	 * Getter for the contests attribute.
	 * 
	 * @return the contests
	 */
	@OneToMany(mappedBy = "district", targetEntity = ContestData.class)
	public Set<ContestData> getContests() {
		return this.contests;
	}

	/**
	 * Setter for the contests attribute.
	 * 
	 * @param contests
	 *            the contests to set
	 */
	public void setContests(Set<ContestData> contests) {
		this.contests = contests;
	}

	/**
	 * Gets the district name traslated.
	 * 
	 * @return the district name traslated
	 */
	@Transient
	public String getDistrictNameTraslated() {
		return this.districtNameTraslated;
	}

	/**
	 * Setter of the districtNameTraslated attribute.
	 * 
	 * @param districtNameTraslated
	 *            the districtNameTraslated to set
	 */
	public void setDistrictNameTraslated(String districtNameTraslated) {
		this.districtNameTraslated = districtNameTraslated;
	}

	/**
	 * Hash code.
	 * 
	 * @return the int
	 * @inheritDoc
	 */
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = super.hashCode();
		result = prime * result
				+ ((this.customCode == null) ? 0 : this.customCode.hashCode());
		return result;
	}

	/**
	 * Equals.
	 * 
	 * @param obj
	 *            the obj
	 * @return true, if successful
	 * @inheritDoc
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (!super.equals(obj)) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		DistrictData other = (DistrictData) obj;
		if (this.customCode == null) {
			if (other.customCode != null) {
				return false;
			}
		} else if (!this.customCode.equals(other.customCode)) {
			return false;
		}
		return true;
	}

}
