/**
 * PollingPlaceData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.demographics;

import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;

import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.general.GeneralInfo;
import com.smartmatic.waffle.lang.annotations.basic.ValidatorListener;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamOmitField;

// TODO: Auto-generated Javadoc
/**
 * Class that represents a physical location inside a Polling Place where the
 * voters are required to go in order to vote and where the election
 * administrators assigns officials who monitor the voting procedures and assist
 * voters with the election process.
 */
@XStreamAlias("polling-place")
@Entity
@Table(name = "polling_place", uniqueConstraints = { @UniqueConstraint(columnNames = "polling_place_code") })
@ValidatorListener(name = "com.smartmatic.waffle.validator.demographics.PollingPlaceDataValidator")
public class PollingPlaceData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -4269635523742794695L;

	/** The region nis code. */
	@XStreamOmitField
	private String regionNisCode;

	/** The zip code. */
	@XStreamOmitField
	private String zipCode;

	/**
	 * Description given by the user to the Polling Place. This is the the field
	 * used by the user to maintain some useful information about the polling
	 * place. In this field the user can store some user code or any information
	 * that he requires.
	 */
	private String description;

	/** Address where the polling place is located. */
	@XStreamAlias("address")
	@XStreamAsAttribute
	private String address;

	/**
	 * Region where the polling place is located.
	 */
	@XStreamOmitField
	private RegionData region;

	/** City where teh polling place is located. */
	@XStreamOmitField
	private String city;

	/**
	 * Total amount of voters that could vote in the polling place. This is the
	 * maximum amount of people that can vote and that are registered to vote
	 * but this amount does not take into account provisional ballots
	 */
	@XStreamAlias("registered-electors")
	@XStreamAsAttribute
	private int amountVoters;

	/**
	 * Set of polling stations located in the polling place. A Polling place
	 * needs to be formed by one or more polling stations.
	 */
	@XStreamOmitField
	private Set<PollingStationData> pollingStations;

	/** The custom code. */
	@XStreamOmitField
	private String customCode;

	/** Indicates if this polling place was generated automatically. */
	@XStreamOmitField
	private boolean generated = false;

	/** Polling Place Number for sort the reports generated. */
	@XStreamOmitField
	public int pollingPlaceNumber;

	/** The cantonNis Code, used for totalization. */
	@XStreamOmitField
	private String cantonNisCode;

	/**
	 * Getter of <code>name</code> property.
	 * 
	 * @return <code>name</code> property value.
	 * @see #name
	 */
	@Override
	@Column(name = "polling_place_name", nullable = false, length = 320)
	public String getName() {
		return this.name;
	}

	/**
	 * Getter of <code>description</code> property.
	 * 
	 * @return <code>description</code> property value.
	 * @see #description
	 */
	@Column(name = "description", length = 2080)
	public String getDescription() {
		return this.description;
	}

	/**
	 * Setter of <code>description</code> property.
	 * 
	 * @param description
	 *            The <code>description</code> to set.
	 * @see #description
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * Getter of <code>address</code> property.
	 * 
	 * @return <code>address</code> property value.
	 * @see #address
	 */
	@Column(name = "polling_place_address", nullable = false, length = 1120)
	public String getAddress() {
		return this.address;
	}

	/**
	 * Setter of <code>address</code> property.
	 * 
	 * @param address
	 *            The <code>address</code> to set.
	 * @see #address
	 */
	public void setAddress(String address) {
		this.address = address;
	}

	/**
	 * Getter of <code>region</code> property.
	 * 
	 * @return <code>region</code> property value.
	 * @see #region
	 */
	@ManyToOne(optional = false, targetEntity = RegionData.class)
	@JoinColumn(name = "region_code", nullable = false, updatable = true)
	public RegionData getRegion() {
		return this.region;
	}

	/**
	 * Setter of <code>region</code> property.
	 * 
	 * @param region
	 *            The <code>region</code> to set.
	 * @see #region
	 */
	public void setRegion(RegionData region) {
		this.region = region;
	}

	/**
	 * Getter of <code>city</code> property.
	 * 
	 * @return <code>city</code> property value.
	 * @see #city
	 */
	@Column(name = "city", nullable = false, length = 160)
	public String getCity() {
		return this.city;
	}

	/**
	 * Setter of <code>city</code> property.
	 * 
	 * @param city
	 *            The <code>city</code> to set.
	 * @see #city
	 */
	public void setCity(String city) {
		this.city = city;
	}

	/**
	 * Getter of <code>amountVoters</code> property.
	 * 
	 * @return <code>amountVoters</code> property value.
	 * @see #amountVoters
	 */
	@Column(name = "voter_number", nullable = false)
	public int getAmountVoters() {
		return this.amountVoters;
	}

	/**
	 * Setter of <code>amountVoters</code> property.
	 * 
	 * @param amountVoters
	 *            The <code>amountVoters</code> to set.
	 * @see #amountVoters
	 */
	public void setAmountVoters(int amountVoters) {
		this.amountVoters = amountVoters;
	}

	/**
	 * Getter of <code>pollingStations</code> property.
	 * 
	 * @return <code>pollingStations</code> property value.
	 * @see #pollingStations
	 */
	@OneToMany(mappedBy = "pollingPlace")
	public Set<PollingStationData> getPollingStations() {
		return this.pollingStations;
	}

	/**
	 * Setter of <code>pollingStations</code> property.
	 * 
	 * @param pollingStations
	 *            The <code>pollingStations</code> to set.
	 * @see #pollingStations
	 */
	public void setPollingStations(Set<PollingStationData> pollingStations) {
		this.pollingStations = pollingStations;
	}

	/**
	 * Getter of <code>code</code> property.
	 * 
	 * @return <code>code</code> property value.
	 * @see #code
	 */
	@Override
	@Id
	@Column(name = "polling_place_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_polling_place")
	@SequenceGenerator(name = "s_polling_place", sequenceName = "s_polling_place", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/**
	 * Getter of <code>customCode</code> property.
	 * 
	 * @return <code>customCode</code> property value.
	 * @see #customCode
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "polling_place_custom_code", nullable = false, unique = true, length = 80)
	public String getCustomCode() {
		return this.customCode;
	}

	/**
	 * Setter of <code>customCode</code> property.
	 * 
	 * @param customCode
	 *            The <code>customCode</code> to set.
	 * @see #customCode
	 */
	@Override
	public void setCustomCode(String customCode) {
		this.customCode = customCode;
	}

	/**
	 * Getter of <code>generated</code> property.
	 * 
	 * @return <code>generated</code> property value.
	 * @see #generated
	 */
	@Column(name = "generated", nullable = false)
	public boolean isGenerated() {
		return this.generated;
	}

	/**
	 * Setter of <code>generated</code> property.
	 * 
	 * @param generated
	 *            The <code>generated</code> to set.
	 * @see #generated
	 */
	public void setGenerated(boolean generated) {
		this.generated = generated;
	}

	/**
	 * Getter of <code>version</code> property.
	 * 
	 * @return <code>version</code> property value.
	 * @see #version
	 */
	@Override
	@Transient
	public int getVersion() {
		return 0;
	}

	/**
	 * Gets the region nis code.
	 * 
	 * @return the region nis code
	 */
	@Transient
	public String getRegionNisCode() {
		return this.regionNisCode;
	}

	/**
	 * Gets the zip code.
	 * 
	 * @return the zip code
	 */
	@Column(name = "zip_code")
	public String getZipCode() {
		return this.zipCode;
	}

	/**
	 * Sets the zip code.
	 * 
	 * @param zipCode
	 *            the new zip code
	 */
	public void setZipCode(String zipCode) {
		this.zipCode = zipCode;
	}

	/**
	 * Sets the region nis code.
	 * 
	 * @param regionNisCode
	 *            the new region nis code
	 */
	public void setRegionNisCode(String regionNisCode) {
		this.regionNisCode = regionNisCode;
	}

	/**
	 * Gets the polling place number.
	 *
	 * @return the polling place number
	 */
	@Column(name = "polling_place_number")
	public int getPollingPlaceNumber() {
		return this.pollingPlaceNumber;
	}

	/**
	 * Sets the polling place number.
	 *
	 * @param pollingPlaceNumber
	 *            the new polling place number
	 */
	public void setPollingPlaceNumber(int pollingPlaceNumber) {
		this.pollingPlaceNumber = pollingPlaceNumber;
	}

	/**
	 * Gets the canton nis code.
	 *
	 * @return the canton nis code.
	 */
	@Column(name = "canton_nis_code", nullable = true)
	public String getCantonNisCode() {
		return this.cantonNisCode;
	}

	/**
	 * Sets the canton nis code.
	 *
	 * @param cantonNisCoder
	 *            the canton nis code.
	 */
	public void setCantonNisCode(String cantonNisCode) {
		this.cantonNisCode = cantonNisCode;
	}
}
