/**
 * OperationModeData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.device;

import java.util.Date;
import java.util.Set;

import com.smartmatic.waffle.domain.general.GeneralInfo;
import com.smartmatic.waffle.domain.util.ISO8601DateUtil;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamOmitField;

/**
 * JavaBean representing a Voting Operation Mode. A voting operation mode is a
 * way in that a Logical Voting Group execute the vote.
 */
@XStreamAlias("operation-mode")
public class OperationModeData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	@XStreamOmitField
	private static final long serialVersionUID = 7934564358796488168L;

	/** The operation mode name. */
	@XStreamAlias("name-key")
	@XStreamAsAttribute
	String operationModeName;

	/** The roles. */
	@XStreamAlias("roles")
	Set<RoleData> roles;

	/** The folder name. */
	@XStreamAlias("folder-name")
	@XStreamAsAttribute
	String folderName;

	/** The description. */
	@XStreamAlias("description-key")
	@XStreamAsAttribute
	String description;

	/** The is default. */
	@XStreamAlias("default")
	@XStreamAsAttribute
	boolean isDefault;

	/** The unblocking key. */
	@XStreamAlias("unblocking-key")
	@XStreamAsAttribute
	String unblockingKey;

	/** The audio unblocking key. */
	@XStreamAlias("audio-unblocking-key")
	@XStreamAsAttribute
	int audioUnblockingKey;

	/** The opening date time string. */
	@XStreamAlias("opening-date-time")
	@XStreamAsAttribute
	String openingDateTimeString;

	/** The opening date time. */
	@XStreamOmitField
	Date openingDateTime;

	/** The closing date time string. */
	@XStreamAlias("closing-date-time")
	@XStreamAsAttribute
	String closingDateTimeString;

	/** The closing date time. */
	@XStreamOmitField
	Date closingDateTime;

	/** The scanner unblocking key. */
	@XStreamAlias("scanner-unblocking-key")
	@XStreamAsAttribute
	int scannerUnblockingKey;

	/** The synchronization unblocking key. */
	@XStreamAlias("synchronization-unblocking-key")
	@XStreamAsAttribute
	int synchronizationUnblockingKey;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getVersion()
	 */
	@Override
	public int getVersion() {
		return 0;
	}

	/**
	 * Getter of <code>description</code> property.
	 * 
	 * @return <code>description</code> property value
	 */
	public String getDescription() {
		return this.description;
	}

	/**
	 * Setter of <code>description</code> property.
	 * 
	 * @param description
	 *            <code>description</code> to set
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * Getter of <code>scannerUnblockingKey</code> property.
	 * 
	 * @return <code>scannerUnblockingKey</code> property value
	 */
	public int getScannerUnblockingKey() {
		return this.scannerUnblockingKey;
	}

	/**
	 * Setter of <code>scannerUnblockingKey</code>.
	 * 
	 * @param scannerUnblockingKey
	 *            <code>scannerUnblockingKey</code> to set
	 */
	public void setScannerUnblockingKey(int scannerUnblockingKey) {
		this.scannerUnblockingKey = scannerUnblockingKey;
	}

	/**
	 * Getter of <code>synchronizationUnblockingKey</code> property.
	 * 
	 * @return <code>synchronizationUnblockingKey</code> property value
	 */
	public int getSynchronizationUnblockingKey() {
		return this.synchronizationUnblockingKey;
	}

	/**
	 * Setter of <code>synchronizationUnblockingKey</code> property.
	 * 
	 * @param synchronizationUnblockingKey
	 *            <code>synchronizationUnblockingKey</code> to set
	 */
	public void setSynchronizationUnblockingKey(int synchronizationUnblockingKey) {
		this.synchronizationUnblockingKey = synchronizationUnblockingKey;
	}

	/**
	 * Getter of <code>operationModeName</code> property.
	 * 
	 * @return <code>operationModeName</code> property value
	 */
	public String getOperationModeName() {
		return this.operationModeName;
	}

	/**
	 * Setter of <code>operationModeName</code> property.
	 * 
	 * @param name
	 *            <code>operationModeName</code> to set
	 */
	public void setOperationModeName(String name) {
		this.operationModeName = name;
	}

	/**
	 * Setter of <code>openingDateTimeString</code> property.
	 * 
	 * @param openingDateTimeString
	 *            <code>openingDateTimeString</code> to set
	 */
	public void setOpeningDateTimeString(String openingDateTimeString) {
		this.openingDateTimeString = openingDateTimeString;
	}

	/**
	 * Setter of <code>closingDateTimeString</code> property.
	 * 
	 * @param closingDateTimeString
	 *            <code>closingDateTimeString</code> to set
	 */
	public void setClosingDateTimeString(String closingDateTimeString) {
		this.closingDateTimeString = closingDateTimeString;
	}

	/**
	 * Returns the <code>openingDateTime</code> property as string.
	 * 
	 * @return <code>openingDateTime</code> string value
	 */
	public String getOpeningDateTimeString() {
		if (this.openingDateTime != null) {
			this.openingDateTimeString = ISO8601DateUtil
					.fullFormat(this.openingDateTime);
			return this.openingDateTimeString;
		}
		return this.openingDateTimeString;
	}

	/**
	 * Returns the <code>closingDateTime</code> property as string.
	 * 
	 * @return <code>closingDateTime</code> string value
	 */
	public String getClosingDateTimeString() {
		if (this.closingDateTime != null) {
			this.closingDateTimeString = ISO8601DateUtil
					.fullFormat(this.closingDateTime);
		}
		return this.closingDateTimeString;
	}

	/**
	 * Getter of <code>roles</code> property.
	 * 
	 * @return <code>roles</code> property value.
	 * @see #roles
	 */

	public Set<RoleData> getRoles() {
		return this.roles;
	}

	/**
	 * Setter of <code>roles</code> property.
	 * 
	 * @param roles
	 *            The <code>roles</code> to set.
	 * @see #roles
	 */
	public void setRoles(Set<RoleData> roles) {
		this.roles = roles;
	}

	/**
	 * Getter of <code>folderName</code> property.
	 * 
	 * @return <code>folderName</code> property value.
	 * @see #folderName
	 */

	public String getFolderName() {
		return this.folderName;
	}

	/**
	 * Setter of <code>folderName</code> property.
	 * 
	 * @param folderName
	 *            The <code>folderName</code> to set.
	 * @see #folderName
	 */
	public void setFolderName(String folderName) {
		this.folderName = folderName;
	}

	/**
	 * Getter of <code>isDefault</code> property.
	 * 
	 * @return <code>isDefault</code> property value.
	 * @see #isDefault
	 */

	public boolean isDefault() {
		return this.isDefault;
	}

	/**
	 * Setter of <code>isDefault</code> property.
	 * 
	 * @param isDefault
	 *            The <code>isDefault</code> to set.
	 * @see #isDefault
	 */
	public void setDefault(boolean isDefault) {
		this.isDefault = isDefault;
	}

	/**
	 * Getter of <code>unblockingKey</code> property.
	 * 
	 * @return <code>unblockingKey</code> property value.
	 * @see #unblockingKey
	 */

	public String getUnblockingKey() {
		return this.unblockingKey;
	}

	/**
	 * Setter of <code>unblockingKey</code> property.
	 * 
	 * @param unblockingKey
	 *            The <code>unblockingKey</code> to set.
	 * @see #unblockingKey
	 */
	public void setUnblockingKey(String unblockingKey) {
		this.unblockingKey = unblockingKey;
	}

	/**
	 * Getter of <code>audioUnblockingKey</code> property.
	 * 
	 * @return <code>audioUnblockingKey</code> property value.
	 * @see #audioUnblockingKey
	 */

	public int getAudioUnblockingKey() {
		return this.audioUnblockingKey;
	}

	/**
	 * Setter of <code>audioUnblockingKey</code> property.
	 * 
	 * @param audioUnblockingKey
	 *            The <code>audioUnblockingKey</code> to set.
	 * @see #audioUnblockingKey
	 */
	public void setAudioUnblockingKey(int audioUnblockingKey) {
		this.audioUnblockingKey = audioUnblockingKey;
	}

	/**
	 * Getter of <code>openingDateTime</code> property.
	 * 
	 * @return <code>openingDateTime</code> property value.
	 * @see #openingDateTime
	 */

	public Date getOpeningDateTime() {
		return this.openingDateTime;
	}

	/**
	 * Setter of <code>openingDateTime</code> property.
	 * 
	 * @param openingDateTime
	 *            The <code>openingDateTime</code> to set.
	 * @see #openingDateTime
	 */
	public void setOpeningDateTime(Date openingDateTime) {
		this.openingDateTime = openingDateTime;
	}

	/**
	 * Getter of <code>closingDateTime</code> property.
	 * 
	 * @return <code>closingDateTime</code> property value.
	 * @see #closingDateTime
	 */

	public Date getClosingDateTime() {
		return this.closingDateTime;
	}

	/**
	 * Setter of <code>closingDateTime</code> property.
	 * 
	 * @param closingDateTime
	 *            The <code>closingDateTime</code> to set.
	 * @see #closingDateTime
	 */
	public void setClosingDateTime(Date closingDateTime) {
		this.closingDateTime = closingDateTime;
	}
}
