/**
 * EligibleOptionData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.eligibleoption;

import java.util.ArrayList;
import java.util.Set;
import java.util.SortedSet;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;

import org.apache.commons.lang.StringUtils;
import org.hibernate.annotations.Sort;
import org.hibernate.annotations.SortType;

import com.smartmatic.waffle.domain.ballot.BallotOptionData;
import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionRoleData.OrderComparator;
import com.smartmatic.waffle.domain.general.GeneralInfo;
import com.smartmatic.waffle.domain.xstream.converters.HibernateCollectionConverter;
import com.smartmatic.waffle.lang.annotations.basic.ValidatorListener;
import com.smartmatic.waffle.persistence.metadata.MultilingualPropertyAnnotation;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamConverter;
import com.thoughtworks.xstream.annotations.XStreamOmitField;

/**
 * Class that represents a nomination is the condition of having been proposed
 * as a suitable candidate for appointment to a contest.
 */
@Entity
@XStreamAlias("eligible-option")
@Table(name = "eligible_option", uniqueConstraints = { @UniqueConstraint(columnNames = "eligible_option_code") })
@ValidatorListener(name = "com.smartmatic.waffle.validator.eligibleoption.EligibleOptionDataValidator")
public class EligibleOptionData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	@XStreamOmitField
	private static final long serialVersionUID = 5877003597326613632L;

	/** The ballot options. */
	@XStreamAlias("ballot-options")
	@XStreamConverter(HibernateCollectionConverter.class)
	Set<BallotOptionData> ballotOptions;

	/** The ballot name. */
	@XStreamAlias("ballot-name-key")
	@XStreamAsAttribute
	String ballotName;

	/** The eligible option rol data. */
	@XStreamOmitField
	SortedSet<EligibleOptionRoleData> eligibleOptionRoleData;

	/** The candidate id. */
	@XStreamAlias("candidate-id")
	@XStreamAsAttribute
	String candidateId;

	/** The contest. */
	@XStreamOmitField
	ContestData contest;

	/** The eligible option parent. */
	@XStreamOmitField
	EligibleOptionData eligibleOptionParent;

	/** The parent code. */
	@XStreamAlias("parent-code")
	@XStreamAsAttribute
	String parentCode;

	/** The is initialized. */
	@XStreamOmitField
	private boolean isInitialized = false;

	/** The contest data parent. */
	@XStreamOmitField
	private ContestData contestDataParent;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getVersion()
	 */
	@Override
	@Transient
	public int getVersion() {
		return 0;
	}

	/**
	 * Getter of <code>code</code> property.
	 * 
	 * @return <code>code</code> property value.
	 * @see #code
	 */
	@Override
	@Id
	@Column(name = "eligible_option_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_eligible_option")
	@SequenceGenerator(name = "s_eligible_option", sequenceName = "s_eligible_option", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/**
	 * Getter of <code>customCode</code> property.
	 * 
	 * @return <code>customCode</code> property value.
	 * @see #customCode
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "eligible_option_custom_code", nullable = false, unique = true, length = 80)
	public String getCustomCode() {
		return this.customCode;
	}

	/**
	 * Getter of <code>candidateId</code> property.
	 * 
	 * @return <code>candidateId</code> property value.
	 * @see #candidateId
	 */
	@Transient
	public String getCandidateId() {

		if (this.parentCode != null && this.parentCode.equals("")) {
			this.setCandidateId("");
		} else {
			ArrayList<EligibleOptionRoleData> eligibleOptionRoleDataList = null;

			if (this.eligibleOptionRoleData != null) {
				eligibleOptionRoleDataList = new ArrayList<EligibleOptionRoleData>(
						this.eligibleOptionRoleData);

				if (eligibleOptionRoleDataList.size() == 1) {
					for (EligibleOptionRoleData eligibleOptionRoleData : eligibleOptionRoleDataList) {
						this.setCandidateId(eligibleOptionRoleData
								.getCandidate().getIdentification());
					}
				} else {
					this.setCandidateId("");
				}
			}
		}
		return this.candidateId;
	}

	/**
	 * Setter of <code>candidateId</code> property.
	 * 
	 * @param candidateId
	 *            The <code>candidateId</code> to set.
	 * @see #candidateId
	 */
	public void setCandidateId(String candidateId) {
		this.candidateId = candidateId;
	}

	/**
	 * Getter of <code>contest</code> property.
	 * 
	 * @return <code>contest</code> property value.
	 * @see #contest
	 */
	@ManyToOne(optional = false, targetEntity = ContestData.class)
	@JoinColumn(name = "contest_code", referencedColumnName = "contest_code")
	public ContestData getContest() {
		return this.contest;
	}

	/**
	 * Setter of <code>contest</code> property.
	 * 
	 * @param contest
	 *            The <code>contest</code> to set.
	 * @see #contest
	 */
	public void setContest(ContestData contest) {
		this.contest = contest;
	}

	/**
	 * Getter of <code>ballotOptions</code> property.
	 * 
	 * @return <code>ballotOptions</code> property value.
	 * @see #ballotOptions
	 */
	@OneToMany(mappedBy = "eligibleOption")
	public Set<BallotOptionData> getBallotOptions() {
		return this.ballotOptions;
	}

	/**
	 * Setter of <code>ballotOptions</code> property.
	 * 
	 * @param ballotOptions
	 *            The <code>ballotOptions</code> to set.
	 * @see #ballotOptions
	 */
	public void setBallotOptions(Set<BallotOptionData> ballotOptions) {
		this.ballotOptions = ballotOptions;
	}

	/**
	 * Getter of <code>ballotName</code> property.
	 * 
	 * @return <code>ballotName</code> property value.
	 * @see #ballotName
	 */
	@MultilingualPropertyAnnotation
	@Column(name = "ballot_name", nullable = true, length = 80)
	public String getBallotName() {

		this.ballotName = StringUtils.chomp(this.ballotName, "null");

		return this.ballotName;
	}

	/**
	 * Setter of <code>ballotName</code> property.
	 * 
	 * @param ballotName
	 *            The <code>ballotName</code> to set.
	 * @see #ballotName
	 */
	public void setBallotName(String ballotName) {
		this.ballotName = ballotName;
	}

	/**
	 * Getter of <code>eligibleOptionParent</code> property.
	 * 
	 * @return <code>eligibleOptionParent</code> property value.
	 * @see #eligibleOptionParent
	 */
	@ManyToOne
	@JoinColumn(name = "eligible_option_parent_code", nullable = true, updatable = true)
	public EligibleOptionData getEligibleOptionParent() {
		return this.eligibleOptionParent;
	}

	/**
	 * Setter of <code>eligibleOptionParent</code> property.
	 * 
	 * @param eligibleOptionParent
	 *            The <code>eligibleOptionParent</code> to set.
	 * @see #eligibleOptionParent
	 */
	public void setEligibleOptionParent(EligibleOptionData eligibleOptionParent) {
		this.eligibleOptionParent = eligibleOptionParent;

		if (eligibleOptionParent != null) {
			this.setParentCode(String.valueOf(eligibleOptionParent.getCode()));
		} else {
			this.setParentCode("");
		}
	}

	/**
	 * Getter of <code>isInitialized</code> property.
	 * 
	 * @return <code>isInitialized</code> property value.
	 * @see #isInitialized
	 */
	@Transient
	public boolean isInitialized() {
		return this.isInitialized;
	}

	/**
	 * Initilize.
	 * 
	 * @param contestData
	 *            the contest data
	 */
	public void initilize(ContestData contestData) {
		if (this.isInitialized) {
			return;
		}
		this.contestDataParent = contestData;
		for (BallotOptionData ballotOption : this.getBallotOptions()) {
			// ballotOption.initialize(this);
		}
		this.isInitialized = true;

	}

	/**
	 * Getter of <code>candidates</code> property.
	 * 
	 * @return <code>candidates</code> property value.
	 * @see #eligibleOptionRoleData
	 */
	@OneToMany(mappedBy = "eligibleOption", targetEntity = EligibleOptionRoleData.class)
	@Sort(type = SortType.COMPARATOR, comparator = OrderComparator.class)
	public SortedSet<EligibleOptionRoleData> getEligibleOptionRoleData() {
		return this.eligibleOptionRoleData;
	}

	/**
	 * Setter of <code>candidates</code> property.
	 * 
	 * @param eligibleOptionRoleData
	 *            the new eligible option role data
	 * @see #eligibleOptionRoleData
	 */
	public void setEligibleOptionRoleData(
			SortedSet<EligibleOptionRoleData> eligibleOptionRoleData) {
		this.eligibleOptionRoleData = eligibleOptionRoleData;
	}

	/**
	 * Getter of <code>contestDataParent</code> property.
	 * 
	 * @return <code>contestDataParent</code> property value.
	 * @see #contestDataParent
	 */
	@Transient
	public ContestData getContestDataParent() {
		return this.contestDataParent;
	}

	/**
	 * Getter of <code>parentCode</code> property.
	 * 
	 * @return <code>parentCode</code> property value.
	 * @see #parentCode
	 */
	@Transient
	public String getParentCode() {
		return this.parentCode;
	}

	/**
	 * Setter of <code>parentCode</code> property.
	 * 
	 * @param parentCode
	 *            The <code>parentCode</code> to set.
	 * @see #parentCode
	 */
	public void setParentCode(String parentCode) {
		this.parentCode = parentCode;
	}

	/**
	 * Gets the ballot option by code.
	 * 
	 * @param ballotOptionCode
	 *            the ballot option code
	 * @return the ballot option by code
	 */
	public BallotOptionData getBallotOptionByCode(String ballotOptionCode) {
		if (this.getBallotOptions() != null) {
			for (BallotOptionData ballotOption : this.getBallotOptions()) {
				if (Long.toString(ballotOption.getCode()).equals(
						ballotOptionCode)) {
					return ballotOption;
				}
			}
		}
		return null;
	}
}
