/**
 * EligibleOptionRoleData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.eligibleoption;

import java.io.Serializable;
import java.util.Comparator;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;

import org.apache.commons.lang.builder.CompareToBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;

import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.general.GeneralInfo;

/**
 * Class that represents is a single nomination is a kind of Nomination where
 * there is only one candidate and possibly its substitute for a specified
 * contest.
 */
@Entity
@Table(name = "eligible_option_role", uniqueConstraints = {
		@UniqueConstraint(columnNames = "eligible_option_code"),
		@UniqueConstraint(columnNames = "candidate_code") })
public class EligibleOptionRoleData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 2787803678102872668L;

	/**
	 * The candidate role in this eligible option.
	 */
	public enum Role {

		/** The principal candidate. */
		CHIEF,

		/** The candidate elected if the principal cannot confront the contest. */
		STANDIN
	}

	/** The candidate role in this eligible option. */
	@Enumerated(EnumType.ORDINAL)
	private Role role;

	/** The candidate order in this eligible option. */

	private int order;

	/** The candidate votes in this eligible option. */

	private int votes;

	/** The eligible option this role is related to. */
	private EligibleOptionData eligibleOption;

	/** The candidate this role is related to. */
	private CandidateData candidate;

	/**
	 * Getter of <code>customCode</code> property.
	 * 
	 * @return <code>customCode</code> property value.
	 * @see #customCode
	 */
	@CustomCodeAnnotation
	@Column(name = "custom_code", nullable = false, unique = true, length = 255)
	@Override
	public String getCustomCode() {
		return this.customCode;
	}

	/**
	 * Getter of <code>code</code> property.
	 * 
	 * @return <code>code</code> property value.
	 * @see #code
	 */
	@Override
	@Id
	@Column(name = "eligible_option_role_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_eligible_option_role")
	@SequenceGenerator(name = "s_eligible_option_role", sequenceName = "s_eligible_option_role", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/**
	 * Generates a descriptive name of Role.
	 * 
	 * @return The descriptive name of role
	 */
	@Override
	@Transient
	public String getName() {
		if (this.getCandidate() != null) {
			return this.getCandidate().getName() + "-" + this.role.name() + "-"
					+ this.order;
		}
		return null;
	}

	/**
	 * Getter of <code>order</code> property.
	 * 
	 * @return <code>order</code> property value.
	 * @see #order
	 */
	@Column(name = "eligible_option_order")
	public int getOrder() {
		return this.order;
	}

	/**
	 * Setter of <code>order</code> property.
	 * 
	 * @param theOrder
	 *            The <code>order</code> to set.
	 * @see #order
	 */
	public void setOrder(int theOrder) {
		this.order = theOrder;
	}

	/**
	 * Getter of <code>role</code> property.
	 * 
	 * @return <code>role</code> property value.
	 * @see #role
	 */
	@Column(name = "eligible_option_role")
	public Role getRole() {
		return this.role;
	}

	/**
	 * Setter of <code>role</code> property.
	 * 
	 * @param theRole
	 *            The <code>role</code> to set.
	 * @see #role
	 */
	public void setRole(Role theRole) {
		this.role = theRole;

		return;
	}

	/**
	 * Getter of <code>candidate</code> property.
	 * 
	 * @return <code>candidate</code> property value.
	 * @see #candidate
	 */
	@ManyToOne(optional = false, targetEntity = CandidateData.class)
	@JoinColumn(name = "candidate_code", nullable = false, updatable = true)
	public CandidateData getCandidate() {
		return this.candidate;
	}

	/**
	 * Setter of <code>candidate</code> property.
	 * 
	 * @param candidate
	 *            The <code>candidate</code> to set.
	 * @see #candidate
	 */
	public void setCandidate(CandidateData candidate) {
		this.candidate = candidate;
	}

	/**
	 * Getter of <code>eligibleOption</code> property.
	 * 
	 * @return <code>eligibleOption</code> property value.
	 * @see #eligibleOption
	 */
	@ManyToOne(optional = false, targetEntity = EligibleOptionData.class)
	@JoinColumn(name = "eligible_option_code", nullable = false, updatable = true)
	public EligibleOptionData getEligibleOption() {
		return this.eligibleOption;
	}

	/**
	 * Setter of <code>eligibleOption</code> property.
	 * 
	 * @param eligibleOption
	 *            The <code>eligibleOption</code> to set.
	 * @see #eligibleOption
	 */
	public void setEligibleOption(EligibleOptionData eligibleOption) {
		this.eligibleOption = eligibleOption;
	}

	/**
	 * Void setter of name.
	 * 
	 * @param name
	 *            The descriptive name of role
	 */
	@Override
	public void setName(String name) {
		return;
	}

	/**
	 * String representation of this object.
	 * 
	 * @return String representation of this object.
	 */
	@Override
	public String toString() {
		return new ToStringBuilder(this).append("identification",
				this.candidate.getIdentification()).toString();
	}

	/**
	 * Gets the candidate votes in this eligible option.
	 * 
	 * @return the candidate votes in this eligible option
	 */
	@Transient
	public int getVotes() {
		return this.votes;
	}

	/**
	 * Sets the candidate votes in this eligible option.
	 * 
	 * @param theVotes
	 *            the new candidate votes in this eligible option
	 */
	public void setVotes(int theVotes) {
		this.votes = theVotes;
	}

	/**
	 * Compares two roles using its order field as criteria sort.
	 */
	public static class OrderComparator implements Serializable,
			Comparator<EligibleOptionRoleData> {

		/** The Constant serialVersionUID. */
		private static final long serialVersionUID = 1812292906607738120L;

		/**
		 * Implementation of the compare method, using the category level of the
		 * region, the region's name and the region's code.
		 * 
		 * @param o1
		 *            The role 1 to be compared
		 * @param o2
		 *            The role 2 to be compared
		 * @return the int
		 */
		@Override
		public int compare(EligibleOptionRoleData o1, EligibleOptionRoleData o2) {
			return new CompareToBuilder().append(o1.order, o2.order)
					.append(o1.role, o2.role)
					.append(o1.getCandidate(), o2.getCandidate())
					.toComparison();
		}

	}
}
