/**
 * PartyData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.eligibleoption;

import java.util.Collection;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;

import com.smartmatic.waffle.domain.ballot.BallotOptionData;
import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.general.BaseGeneralInfo;
import com.smartmatic.waffle.lang.annotations.basic.ValidatorListener;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamConverter;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import com.thoughtworks.xstream.converters.enums.EnumConverter;

/**
 * Class that represents an organization that typically seeks to attain and
 * maintain political power within the government.
 */
@XStreamAlias("party")
@Entity
@Table(name = "party", uniqueConstraints = { @UniqueConstraint(columnNames = "party_code") })
@ValidatorListener(name = "com.smartmatic.waffle.validator.eligibleoption.PartyDataValidator")
public class PartyData extends BaseGeneralInfo {

	/** The Constant serialVersionUID. */
	@XStreamOmitField
	private static final long serialVersionUID = 2738446269871346787L;

	/** The image file name. */
	@XStreamAlias("image-file-name")
	@XStreamAsAttribute
	String imageFileName;

	/** The image. */
	@XStreamOmitField
	private ImageWrapper image;

	/** The lazy ballot options. */
	@XStreamOmitField
	private Map<ContestData, Collection<BallotOptionData>> lazyBallotOptions;

	/** The type. */
	@XStreamAsAttribute
	@Enumerated(EnumType.ORDINAL)
	Type type;

	/** The ballot options. */
	@XStreamOmitField
	Set<BallotOptionData> ballotOptions = new HashSet<BallotOptionData>();

	/**
	 * The Enum Type.
	 */
	@XStreamAlias("type")
	@XStreamConverter(EnumConverter.class)
	public enum Type {

		/** Cross Filled Options. */
		CFO,

		/** a citizen's group. */
		CITIZEN,

		/** a indian's community. */
		COMMUNITY,
		/**
		 * Dummy party for non-partisan and issue classes of contests.
		 */
		DUMMY,

		/** Elector groups. */
		GROUP,

		/** An idependent nomination. */
		I,

		/** A real political party. */
		PARTY

	}

	/** The name. */
	@XStreamAlias("name")
	@XStreamAsAttribute
	String name;

	/** The abbreviation. */
	@XStreamAlias("abbreviation")
	@XStreamAsAttribute
	String abbreviation;

	/** The college code. */
	@XStreamOmitField
	long collegeCode;

	/**
	 * Getter of <code>code</code> property.
	 * 
	 * @return <code>code</code> property value.
	 * @see #code
	 */
	@Override
	@Id
	@Column(name = "party_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_party")
	@SequenceGenerator(name = "s_party", sequenceName = "s_party", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/**
	 * Getter of <code>customCode</code> property.
	 * 
	 * @return <code>customCode</code> property value.
	 * @see #customCode
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "party_custom_code", nullable = false, unique = true, length = 255)
	public String getCustomCode() {
		return this.customCode;
	}

	/**
	 * Gets the image.
	 * 
	 * @return the image
	 */
	@Column(name = "party_image_file", nullable = true)
	public ImageWrapper getImage() {
		return this.image;
	}

	/**
	 * Sets the image.
	 * 
	 * @param image
	 *            the new image
	 */
	public void setImage(ImageWrapper image) {
		this.image = image;
	}

	/**
	 * Getter for the <code>imageFileName</code> attribute.
	 * 
	 * @return <code>imageFileName</code> attribute value.
	 * @see PartyData#imageFileName
	 */
	@Column(name = "party_image_file_name", nullable = true)
	public String getImageFileName() {
		return this.imageFileName;
	}

	/**
	 * Setter for the <code>imageFileName</code> attribute.
	 * 
	 * @param imageFileName
	 *            the imageFileName to set
	 * @see PartyData#imageFileName
	 */
	public void setImageFileName(String imageFileName) {
		this.imageFileName = imageFileName;
	}

	/**
	 * Getter of <code>type</code> property.
	 * 
	 * @return the type
	 * @see #type
	 */
	@Column(name = "type")
	public Type getType() {
		return this.type;
	}

	/**
	 * Setter of <code>type</code> property.
	 * 
	 * @param type
	 *            the new type
	 * @return <code>type</code> property value.
	 * @see #type
	 */
	public void setType(Type type) {
		this.type = type;
	}

	/**
	 * Getter of <code>abbreviation</code> property.
	 * 
	 * @return the abbreviation
	 * @see #abbreviation
	 */
	@Column(name = "party_abbreviation", length = 100)
	public String getAbbreviation() {
		return this.abbreviation;
	}

	/**
	 * Setter of <code>abbreviation</code> property.
	 * 
	 * @param abbreviation
	 *            the new abbreviation
	 * @return <code>abbreviation</code> property value.
	 * @see #abbreviation
	 */
	public void setAbbreviation(String abbreviation) {
		this.abbreviation = abbreviation;
	}

	/**
	 * Getter of <code>collegeCode</code> property.
	 * 
	 * @return the college code
	 * @see #collegeCode
	 */
	@Transient
	public long getCollegeCode() {
		return this.collegeCode;
	}

	/**
	 * Setter of <code>collegeCode</code> property.
	 * 
	 * @param collegeCode
	 *            the new college code
	 * @return <code>collegeCode</code> property value.
	 * @see #collegeCode
	 */
	public void setCollegeCode(long collegeCode) {
		this.collegeCode = collegeCode;
	}

	/**
	 * Getter of <code>name</code> property.
	 * 
	 * @return <code>name</code> property value.
	 * @see #name
	 */
	@Column(name = "party_name", length = 100)
	public String getName() {
		return this.name;
	}

	/**
	 * Setter of <code>name</code> property.
	 * 
	 * @param name
	 *            The <code>name</code> to set.
	 * @see #name
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * Gets the ballot options by contest.
	 * 
	 * @param contest
	 *            the contest
	 * @return the ballot options by contest
	 */
	public Collection<BallotOptionData> getBallotOptionsByContest(
			ContestData contest) {
		if (this.lazyBallotOptions == null) {
			return null;
		}

		return this.lazyBallotOptions.get(contest);
	}

	/**
	 * Getter for the ballotOptions attribute.
	 * 
	 * @return the ballotOptions
	 */
	@OneToMany(mappedBy = "party")
	public Set<BallotOptionData> getBallotOptions() {
		return this.ballotOptions;
	}

	/**
	 * Setter for the ballotOptions attribute.
	 * 
	 * @param ballotOptions
	 *            the ballotOptions to set
	 */
	public void setBallotOptions(Set<BallotOptionData> ballotOptions) {
		this.ballotOptions = ballotOptions;
	}

	/**
	 * Equals.
	 * 
	 * @param obj
	 *            the obj
	 * @return true, if successful
	 * @see java.lang.Object#equals(java.lang.Object)
	 * @author Fernando Alvarez (fernando.alvarez@smartmatic.com)
	 * @since Mar 26, 2009
	 */

	@Override
	public boolean equals(Object obj) {
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}

		PartyData party = (PartyData) obj;

		if (this.code != party.code) {
			return false;
		}
		return true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.domain.BaseDataObject#hashCode()
	 */
	@Override
	public int hashCode() {
		return super.hashCode();
	}
}
