/**
 * KeystoreData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.general;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Lob;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.eligibleoption.ImageWrapper;
import com.smartmatic.waffle.lang.annotations.basic.ValidatorListener;

/**
 * This class presents a security file in PKSC12 format used to store private
 * keys with accompanying public key certificates, protected with a
 * password-based symmetric key.
 */
@Entity
@Table(name = "keystore")
@ValidatorListener(name = "com.smartmatic.waffle.validator.demographics.KeystoreDataValidation")
public class KeystoreData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 5646827969660769418L;

	/** The alias. */
	private String alias;

	/** The password. */
	private String password;

	/** The pkcs12. */
	private ImageWrapper pkcs12;

	/** The default key. */
	private boolean defaultKey;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCustomCode()
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "keystore_custom_code")
	public String getCustomCode() {
		return this.customCode;
	}

	/**
	 * Getter of <code>code</code> property.
	 * 
	 * @return <code>code</code> property value.
	 * @see #code
	 */

	@Override
	@Id
	@Column(name = "keystore_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_keystore")
	@SequenceGenerator(name = "s_keystore", sequenceName = "s_keystore", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/**
	 * Gets the alias.
	 * 
	 * @return the alias
	 */
	@Column(name = "alias", nullable = false)
	public String getAlias() {
		return this.alias;
	}

	/**
	 * Sets the alias.
	 * 
	 * @param alias
	 *            the alias to set
	 */
	public void setAlias(String alias) {
		this.alias = alias;
	}

	/**
	 * Gets the password.
	 * 
	 * @return the password
	 */
	@Column(name = "password", nullable = false)
	public String getPassword() {
		return this.password;
	}

	/**
	 * Sets the password.
	 * 
	 * @param password
	 *            the password to set
	 */
	public void setPassword(String password) {
		this.password = password;
	}

	/**
	 * Gets the pkcs12.
	 * 
	 * @return the pkcs12
	 */
	@Lob
	@Column(name = "keystore_file", nullable = true)
	public ImageWrapper getPkcs12() {
		return this.pkcs12;
	}

	/**
	 * Sets the pkcs12.
	 * 
	 * @param pkcs12
	 *            the pkcs12 to set
	 */
	public void setPkcs12(ImageWrapper pkcs12) {
		this.pkcs12 = pkcs12;
	}

	/**
	 * Checks if is default key.
	 * 
	 * @return the defaultKey
	 */
	@Column(name = "is_default")
	public boolean isDefaultKey() {
		return this.defaultKey;
	}

	/**
	 * Sets the default key.
	 * 
	 * @param defaultKey
	 *            the defaultKey to set
	 */
	public void setDefaultKey(boolean defaultKey) {
		this.defaultKey = defaultKey;
	}

}
