/**
 * ReportTemplateData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.general;

import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.Lob;
import javax.persistence.ManyToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.demographics.RegionData;
import com.smartmatic.waffle.domain.eligibleoption.ImageWrapper;

/**
 * This class represents the templates of reports used by the system in
 * different stages of the process.
 */
@Entity
@Table(name = "report_template", uniqueConstraints = { @UniqueConstraint(columnNames = "report_template_code") })
public class ReportTemplateData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -4272528285382454006L;

	/**
	 * The Enum Application.
	 */
	public enum Application {

		/** The ecm. */
		ECM,
		/** The pm. */
		PM,
		/** The rts. */
		RTS
	}

	/**
	 * The Enum Type.
	 */
	public enum Type {

		/** The close election sumary votes. */
		CLOSE_ELECTION_SUMARY_VOTES("close_election_sub_report_sumary_votes"),
		/** The close election acount. */
		CLOSE_ELECTION_ACOUNT("closeElectionAccounts_subreport"),
		/** The close election. */
		CLOSE_ELECTION("closeElectionReport"),
		/** The receipt. */
		RECEIPT("rts_pen_reception_no_pwd"),
		/** The estimates of registrations report. */
		ESTIMATES_OF_REGISTRATIONS_REPORT("Report1"),
		/** The annex report. */
		ANNEX_REPORT("Report3"),
		/** The list and white report. */
		LIST_AND_WHITE_REPORT("Report2"),
		/** The sub report. */
		SUB_REPORT(""),
		/** The resource. */
		RESOURCE(""),
		/** The pm pswd report. */
		PM_PSWD_REPORT(""),
		/** The rc pswd report. */
		RC_PSWD_REPORT(""),
		/** The rts pswd report. */
		RTS_PSWD_REPORT(""),

		/** Defines if the type of the resources is a common audio resource. **/
		AUDIO_RESOURCE("");

		/** The file name. */
		private String fileName;

		/**
		 * Instantiates a new type.
		 * 
		 * @param fileName
		 *            the file name
		 */
		Type(String fileName) {
			this.fileName = fileName;
		}

		/**
		 * Gets the file name.
		 * 
		 * @return the fileName
		 */
		public String getFileName() {
			return this.fileName;
		}
	}

	/** The type. */
	@Enumerated(EnumType.ORDINAL)
	private Type type;

	/** The app. */
	@Enumerated(EnumType.ORDINAL)
	private Application app;

	/** The jrxml. */
	private ImageWrapper jrxml;

	/** The language. */
	private String language;

	/** The exported name. */
	private String exportedName;

	/** The regions. */
	private Set<RegionData> regions;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCode()
	 */
	@Override
	@Id
	@Column(name = "report_template_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_report_template")
	@SequenceGenerator(name = "s_report_template", sequenceName = "s_report_template", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCustomCode()
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "report_template_custom_code", nullable = false, unique = true, length = 255)
	public String getCustomCode() {
		return this.customCode;
	}

	/**
	 * Gets the name.
	 * 
	 * @return the name
	 */
	@Override
	@Column(name = "report_template_name", nullable = false)
	public String getName() {
		return this.name;
	}

	/**
	 * Sets the name.
	 * 
	 * @param name
	 *            the name to set
	 */
	@Override
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * Gets the type.
	 * 
	 * @return the type
	 */
	@Column(name = "report_template_type", nullable = false)
	public Type getType() {
		return this.type;
	}

	/**
	 * Sets the type.
	 * 
	 * @param type
	 *            the type to set
	 */
	public void setType(Type type) {
		this.type = type;
	}

	/**
	 * Gets the app.
	 * 
	 * @return the app
	 */
	@Column(name = "report_template_application", nullable = false)
	public Application getApp() {
		return this.app;
	}

	/**
	 * Sets the app.
	 * 
	 * @param app
	 *            the app to set
	 */
	public void setApp(Application app) {
		this.app = app;
	}

	/**
	 * Gets the jrxml.
	 * 
	 * @return the jrxml
	 */
	@Lob
	@Column(name = "jrxml_file", nullable = false)
	public ImageWrapper getJrxml() {
		return this.jrxml;
	}

	/**
	 * Sets the jrxml.
	 * 
	 * @param jrxml
	 *            the jrxml to set
	 */
	public void setJrxml(ImageWrapper jrxml) {
		this.jrxml = jrxml;
	}

	/**
	 * Gets the language.
	 * 
	 * @return the language
	 */
	@Column(name = "language")
	public String getLanguage() {
		return this.language;
	}

	/**
	 * Sets the language.
	 * 
	 * @param language
	 *            the language to set
	 */
	public void setLanguage(String language) {
		this.language = language;
	}

	/**
	 * Gets the regions.
	 * 
	 * @return the region
	 */
	@ManyToMany(targetEntity = RegionData.class)
	@JoinTable(name = "report_template_region", joinColumns = @JoinColumn(name = "report_template_code", referencedColumnName = "report_template_code"), inverseJoinColumns = @JoinColumn(name = "region_code", referencedColumnName = "region_code"))
	public Set<RegionData> getRegions() {
		return this.regions;
	}

	/**
	 * Sets the regions.
	 * 
	 * @param regions
	 *            the new regions
	 */
	public void setRegions(Set<RegionData> regions) {
		this.regions = regions;
	}

	/**
	 * Gets the exported name.
	 * 
	 * @return the exportedReportName
	 */
	@Column(name = "exported_name")
	public String getExportedName() {
		return this.exportedName;
	}

	/**
	 * Sets the exported name.
	 * 
	 * @param exportedName
	 *            the new exported name
	 */
	public void setExportedName(String exportedName) {
		this.exportedName = exportedName;
	}

}
