/**
 * TranslationKeyData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.multiLanguage;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;

import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.general.GeneralInfo;
import com.smartmatic.waffle.domain.i18n.LanguageData;

/**
 * Class that represents a translation from a "translatable" entry. A
 * MultilingualKeyData is a translatable entity and holds a list of
 * TranslationKeyData with the translation of the entry to all the supported
 */
@Entity
@Table(name = "translation_key", uniqueConstraints = { @UniqueConstraint(columnNames = "custom_code") })
public class TranslationKeyData extends GeneralInfo {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/**
	 * The language for this translation key.
	 * 
	 * {@link LanguageData}
	 */

	private LanguageData electionLanguage;

	/**
	 * The "tranlatable" item of this translation.
	 * 
	 * {@link MultiLingualKeyData}
	 */

	private MultiLingualKeyData multilingualKey;

	/**
	 * The translated text from the translatable item in the configured election
	 * language.
	 */
	private String translationText;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCustomCode()
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "custom_code", nullable = false)
	public String getCustomCode() {
		return super.getCustomCode();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCustomCode(
	 * java.lang.String)
	 */
	@Override
	public void setCustomCode(String customCode) {
		super.setCustomCode(customCode);
	}

	/**
	 * Getter of <code>code</code> property.
	 * 
	 * @return <code>code</code> property value.
	 * @see #code
	 */
	@Override
	@Id
	@Column(name = "translation_key_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_translation_key")
	@SequenceGenerator(name = "s_translation_key", sequenceName = "s_translation_key", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/**
	 * Setter of <code>code</code> property.
	 * 
	 * @param theCode
	 *            The <code>code</code> to set.
	 * @see #code
	 */
	@Override
	public void setCode(long theCode) {
		this.code = theCode;
	}

	/**
	 * Getter of <code>electionLanguage</code> property.
	 * 
	 * @return <code>electionLanguage</code> property value.
	 * @see #electionLanguage
	 */
	@ManyToOne(optional = false, targetEntity = LanguageData.class)
	@JoinColumn(name = "election_language_code", nullable = false, updatable = true)
	public LanguageData getElectionLanguage() {
		return this.electionLanguage;
	}

	/**
	 * Setter of <code>electionLanguage</code> property.
	 * 
	 * @param theElectionLanguage
	 *            The <code>electionLanguage</code> to set.
	 * @see #electionLanguage
	 */
	public void setElectionLanguage(LanguageData theElectionLanguage) {
		this.electionLanguage = theElectionLanguage;
	}

	/**
	 * Getter of <code>multilingualKey</code> property.
	 * 
	 * @return <code>multilingualKey</code> property value.
	 * @see #multilingualKey
	 * 
	 */

	@ManyToOne(optional = false, targetEntity = MultiLingualKeyData.class)
	@JoinColumn(name = "multilingual_key_code", nullable = false, updatable = true)
	public MultiLingualKeyData getMultilingualKey() {
		return this.multilingualKey;
	}

	/**
	 * Setter of <code>multilingualKey</code> property.
	 * 
	 * @param theMultilingualKey
	 *            The <code>multilingualKey</code> to set.
	 * @see #multilingualKey
	 */
	public void setMultilingualKey(MultiLingualKeyData theMultilingualKey) {
		this.multilingualKey = theMultilingualKey;
	}

	/**
	 * Getter of <code>translationText</code> property.
	 * 
	 * @return <code>translationText</code> property value.
	 * @see #translationText
	 */
	@Column(name = "translation_text", nullable = true)
	public String getTranslationText() {
		return this.translationText;
	}

	/**
	 * Setter of <code>translationText</code> property.
	 * 
	 * @param theTranslationText
	 *            The <code>translationText</code> to set.
	 * @see #translationText
	 */
	public void setTranslationText(String theTranslationText) {
		this.translationText = theTranslationText;
	}

	/**
	 * Overrrides equal method with specific semantics to the Translation key
	 * object.
	 * 
	 * @param o
	 *            the o
	 * @return true if is the same object or false otherwise
	 */

	@Override
	public boolean equals(Object o) {
		if (o instanceof TranslationKeyData) {
			TranslationKeyData a = (TranslationKeyData) o;
			return new EqualsBuilder().append(this.code, a.code).isEquals();
		}
		return false;
	}

	/**
	 * Overrrides the hashCode method with specific semantics to the Translation
	 * Key object.
	 * 
	 * @return a hashcode value from this object instance
	 */
	@Override
	public int hashCode() {
		return new HashCodeBuilder().append(this.code).toHashCode();
	}

}