/**
 * FunctionalityData.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.domain.security;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;

import com.smartmatic.waffle.domain.bulk.CustomCodeAnnotation;
import com.smartmatic.waffle.domain.general.BaseGeneralInfo;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamOmitField;

/**
 * Represents a functionality in a given application.
 */
@Entity
@Table(name = "functionality", uniqueConstraints = { @UniqueConstraint(columnNames = "functionality_code") })
public class FunctionalityData extends BaseGeneralInfo {

	/** The Constant serialVersionUID. */
	@XStreamOmitField
	private static final long serialVersionUID = -3518937517014178229L;

	/**
	 * Action supported by the FunctionalityDefinition that creates a different
	 * "working" mode for the basic functionality.
	 */
	@XStreamOmitField
	private IActionData action;

	/**
	 * The definition of the actual functionality.
	 */
	@XStreamAlias("type")
	@XStreamAsAttribute
	private FunctionalityDefinitionEnum functionalityDefinition;

	/** The profile data. */
	@XStreamOmitField
	private ProfileData profileData;

	/** The functionality name. */
	private String functionalityName;

	/**
	 * Getter for the <code>code</code> attribute.
	 * 
	 * @return <code>code</code> attribute value.
	 * @see FunctionalityData#code
	 */
	@Override
	@Id
	@Column(name = "functionality_code")
	@GeneratedValue(strategy = GenerationType.AUTO, generator = "s_function")
	@SequenceGenerator(name = "s_function", sequenceName = "s_function", allocationSize = 1, initialValue = 1)
	public long getCode() {
		return this.code;
	}

	/**
	 * Setter for the <code>code</code> attribute.
	 * 
	 * @param code
	 *            the code to set
	 * @see FunctionalityData#code
	 */
	@Override
	public void setCode(long code) {
		this.code = code;
	}

	/**
	 * Getter for the <code>action</code> attribute.
	 * 
	 * @return <code>action</code> attribute value.
	 * @see FunctionalityData#action
	 */
	@Transient
	public IActionData getAction() {
		return this.action;
	}

	/**
	 * Setter for the <code>action</code> attribute.
	 * 
	 * @param action
	 *            the action to set
	 * @see FunctionalityData#action
	 */
	public void setAction(IActionData action) {
		this.action = action;
	}

	/**
	 * Getter for the <code>functionalityDefinition</code> attribute.
	 * 
	 * @return <code>functionalityDefinition</code> attribute value.
	 * @see FunctionalityData#functionalityDefinition
	 */
	@Column(name = "func_definition", nullable = false)
	public FunctionalityDefinitionEnum getFunctionalityDefinition() {
		return this.functionalityDefinition;
	}

	/**
	 * Setter for the <code>functionalityDefinition</code> attribute.
	 * 
	 * @param functionalityDefinition
	 *            the functionalityDefinition to set
	 * @see FunctionalityData#functionalityDefinition
	 */
	public void setFunctionalityDefinition(
			FunctionalityDefinitionEnum functionalityDefinition) {
		this.functionalityDefinition = functionalityDefinition;
	}

	/**
	 * Getter of <code>profile</code> property.
	 * 
	 * @return <code>profile</code> property value.
	 * @see #profile
	 */
	@Transient
	public ProfileData getProfileData() {
		return this.profileData;
	}

	/**
	 * Setter of <code>profile</code> property.
	 * 
	 * @param profile
	 *            The <code>profile</code> to set.
	 * @see #profile
	 */
	public void setProfileData(ProfileData profile) {
		this.profileData = profile;

		return;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getVersion()
	 */
	@Override
	public int getVersion() {
		return this.version;
	}

	/**
	 * Sets the functionality name.
	 * 
	 * @param functionalityName
	 *            the new functionality name
	 */
	public void setFunctionalityName(String functionalityName) {
		this.functionalityName = functionalityName;
	}

	/**
	 * Gets the functionality name.
	 * 
	 * @return the functionality name
	 */
	@Column(name = "functionality_name")
	public String getFunctionalityName() {
		return this.functionalityName;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#getCustomCode()
	 */
	@Override
	@CustomCodeAnnotation
	@Column(name = "custom_code", nullable = false, unique = true, length = 255)
	public String getCustomCode() {
		return super.getCustomCode();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.domain.general.BaseGeneralInfo#setCustomCode(
	 * java.lang.String)
	 */
	@Override
	public void setCustomCode(String customCode) {
		super.setCustomCode(customCode);
	}

}