/**
 * ECMServiceProvider.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import javax.ejb.EJBTransactionRolledbackException;

import net.sf.jasperreports.engine.JasperPrint;

import org.apache.commons.lang.StringUtils;
import org.jboss.remoting.CannotConnectException;

import com.smartmatic.waffle.domain.authority.ElectoralAuthorityData;
import com.smartmatic.waffle.domain.ballot.BallotOptionData;
import com.smartmatic.waffle.domain.contest.ContestClassData;
import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.contest.ContestGroupData;
import com.smartmatic.waffle.domain.demographics.CategoryData;
import com.smartmatic.waffle.domain.demographics.DistrictData;
import com.smartmatic.waffle.domain.demographics.ElectionData;
import com.smartmatic.waffle.domain.demographics.PollingPlaceData;
import com.smartmatic.waffle.domain.demographics.RegionData;
import com.smartmatic.waffle.domain.device.DeviceParameterData;
import com.smartmatic.waffle.domain.device.LogicalVotingGroupData;
import com.smartmatic.waffle.domain.device.VotingDeviceData;
import com.smartmatic.waffle.domain.eligibleoption.CandidateData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionRoleData;
import com.smartmatic.waffle.domain.eligibleoption.PartyData;
import com.smartmatic.waffle.domain.general.ParameterData;
import com.smartmatic.waffle.domain.general.ReportTemplateData;
import com.smartmatic.waffle.domain.i18n.ContestLanguagesPairData;
import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum;
import com.smartmatic.waffle.domain.user.UserData;
import com.smartmatic.waffle.ecm.client.lang.ConnectionException;
import com.smartmatic.waffle.ecm.data.transfer.objects.ActiveContestForElectionDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.BulkResultDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.ContestClassTranslationsDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.DataTestGenerationDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.ElectionXmlComponentsDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.ElectoralAuthoritySecurityComponentsDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.EntityRecordsQuantitiesDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.ProgrammingUnitLastLevelRegionDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.QueryResultDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.VotingDeviceDTO;
import com.smartmatic.waffle.ecm.data.transfer.objects.VotingDeviceSecurityComponentsDTO;
import com.smartmatic.waffle.ecm.data.transfer.type.EMLFileType;
import com.smartmatic.waffle.ecm.data.transfer.type.SmttFileType;
import com.smartmatic.waffle.ecm.service.lang.BackupDatabaseGenerationExeption;
import com.smartmatic.waffle.ecm.service.lang.BulkDataLoadException;
import com.smartmatic.waffle.ecm.service.lang.DemographyException;
import com.smartmatic.waffle.ecm.service.lang.ElectoralDemographyException;
import com.smartmatic.waffle.ecm.service.lang.ElectoralOrganizationOperationException;
import com.smartmatic.waffle.ecm.service.lang.ElectoralPhysicalLocationsRegistryException;
import com.smartmatic.waffle.ecm.service.lang.MasterUSBGenerationException;
import com.smartmatic.waffle.ecm.service.lang.NominationException;
import com.smartmatic.waffle.ecm.service.lang.UtilitiesException;
import com.smartmatic.waffle.ecm.service.lang.XmlGenerationException;
import com.smartmatic.waffle.ecm.service.spec.IECMBulkDataLoadService;
import com.smartmatic.waffle.ecm.service.spec.IECMDemographyService;
import com.smartmatic.waffle.ecm.service.spec.IECMElectoralDemographyService;
import com.smartmatic.waffle.ecm.service.spec.IECMElectoralOrganizationService;
import com.smartmatic.waffle.ecm.service.spec.IECMElectoralPhysicalLocationsRegistryService;
import com.smartmatic.waffle.ecm.service.spec.IECMMasterUSBGenerationService;
import com.smartmatic.waffle.ecm.service.spec.IECMNominationService;
import com.smartmatic.waffle.ecm.service.spec.IECMService;
import com.smartmatic.waffle.ecm.service.spec.IECMUtilitiesService;
import com.smartmatic.waffle.ecm.service.spec.IECMWorkflowService;
import com.smartmatic.waffle.ecm.service.workflow.ECMWorkflowStatus;
import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Wrapper class that encapsulates all the service calls to the server.
 */
public class ECMServiceProvider {

	/**
	 * ECM Server's services for general purpose.
	 */
	private static IECMService ecmService;

	/**
	 * ECM Server's services for workflow control.
	 */
	private static IECMWorkflowService ecmWorkflowService;

	/**
	 * ECM Server's services for usb generation.
	 */
	private static IECMMasterUSBGenerationService ecmMasterUSBGenerationService;

	/**
	 * ECM Server's services for Electoral Organization operations.
	 */
	private static IECMElectoralOrganizationService ecmElectoralOrganizationService;

	/**
	 * ECM Server's services for Electoral Physical Locations Registry
	 * operations.
	 */
	private static IECMElectoralPhysicalLocationsRegistryService ecmElectoralPhysicalLocationsRegistryService;

	/**
	 * ECM Server's services for demography operations.
	 */
	private static IECMDemographyService ecmDemographyService;

	/**
	 * ECM Server's utilities services.
	 */
	private static IECMUtilitiesService ecmUtilitiesService;

	/**
	 * ECM Server's services for bulk upload operations.
	 */
	private static IECMBulkDataLoadService ecmBulkDataLoadService;

	/**
	 * ECM Server's services for nomination operations.
	 */
	private static IECMNominationService ecmNominationService;

	/**
	 * ECM Server's services for electoral demography operation.
	 */
	private static IECMElectoralDemographyService ecmElectoralDemographyService;

	/**
	 * Object for logger purpose.
	 */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(ECMServiceProvider.class);

	/**
	 * Method that initializes <code>IECMElectoralOrganizationService</code> for
	 * Electoral Organization operations.
	 * 
	 * @param ecmElectoralOrganizationService
	 *            IECMElectoralOrganizationService instance
	 */
	public static void initializeECMElectoralOrganizationService(
			IECMElectoralOrganizationService ecmElectoralOrganizationService) {

		if (ECMServiceProvider.ecmElectoralOrganizationService != null) {
			synchronized (ECMServiceProvider.ecmElectoralOrganizationService) {

				ECMServiceProvider.ecmElectoralOrganizationService = ecmElectoralOrganizationService;
			}
		} else {
			ECMServiceProvider.ecmElectoralOrganizationService = ecmElectoralOrganizationService;

		}
	}

	/**
	 * Method that initializes
	 * <code>IECMElectoralPhysicalLocationsRegistryService</code> for Electoral
	 * Organization operations.
	 * 
	 * @param ecmElectoralPhysicalLocationsRegistryService
	 *            IECMElectoralPhysicalLocationsRegistryService instance
	 */
	public static void initializeElectoralPhysicalLocationsRegistryService(
			IECMElectoralPhysicalLocationsRegistryService ecmElectoralPhysicalLocationsRegistryService) {

		if (ECMServiceProvider.ecmElectoralPhysicalLocationsRegistryService != null) {
			synchronized (ECMServiceProvider.ecmElectoralPhysicalLocationsRegistryService) {

				ECMServiceProvider.ecmElectoralPhysicalLocationsRegistryService = ecmElectoralPhysicalLocationsRegistryService;
			}
		} else {
			ECMServiceProvider.ecmElectoralPhysicalLocationsRegistryService = ecmElectoralPhysicalLocationsRegistryService;
		}
	}

	/**
	 * Method that initializes <code>IECMDemographyService</code> for demography
	 * operations.
	 * 
	 * @param ecmDemographyService
	 *            IECMDemographyService instance
	 */
	public static void initializeDemographyService(
			IECMDemographyService ecmDemographyService) {

		if (ECMServiceProvider.ecmDemographyService != null) {
			synchronized (ECMServiceProvider.ecmDemographyService) {

				ECMServiceProvider.ecmDemographyService = ecmDemographyService;
			}
		} else {
			ECMServiceProvider.ecmDemographyService = ecmDemographyService;
		}
	}

	/**
	 * Method that initializes <code>IECMUtilitiesService</code> bean.
	 * 
	 * @param ecmServiceUtilitiesService
	 *            IECMUtilitiesService
	 */
	public static void initializeUtilitiesService(
			IECMUtilitiesService ecmServiceUtilitiesService) {

		if (ECMServiceProvider.ecmUtilitiesService != null) {
			synchronized (ECMServiceProvider.ecmUtilitiesService) {

				ECMServiceProvider.ecmUtilitiesService = ecmServiceUtilitiesService;
			}
		} else {
			ECMServiceProvider.ecmUtilitiesService = ecmServiceUtilitiesService;
		}
	}

	/**
	 * Method that initializes <code>IECMBulkDataLoadService</code> for bulk
	 * upload operations.
	 * 
	 * @param ecmBulkDataLoadService
	 *            IECMBulkDataLoadService instance
	 */
	public static void initializeBulkDataLoadService(
			IECMBulkDataLoadService ecmBulkDataLoadService) {

		if (ECMServiceProvider.ecmBulkDataLoadService != null) {
			synchronized (ECMServiceProvider.ecmBulkDataLoadService) {

				ECMServiceProvider.ecmBulkDataLoadService = ecmBulkDataLoadService;
			}
		} else {
			ECMServiceProvider.ecmBulkDataLoadService = ecmBulkDataLoadService;
		}
	}

	/**
	 * Method that initializes <code>IECMNominationService</code> for nomination
	 * operations.
	 * 
	 * @param ecmNominationService
	 *            IECMNominationService instance
	 */
	public static void initializeNominationService(
			IECMNominationService ecmNominationService) {

		if (ECMServiceProvider.ecmNominationService != null) {
			synchronized (ECMServiceProvider.ecmNominationService) {

				ECMServiceProvider.ecmNominationService = ecmNominationService;
			}
		} else {
			ECMServiceProvider.ecmNominationService = ecmNominationService;
		}
	}

	/**
	 * Method that initializes <code>IECMElectoralDemographyService</code> for
	 * nomination operations.
	 * 
	 * @param ecmElectoralDemographyService
	 *            IECMElectoralDemographyService instance
	 */
	public static void initializeElectoralDemographyService(
			IECMElectoralDemographyService ecmElectoralDemographyService) {

		if (ECMServiceProvider.ecmElectoralDemographyService != null) {
			synchronized (ECMServiceProvider.ecmElectoralDemographyService) {

				ECMServiceProvider.ecmElectoralDemographyService = ecmElectoralDemographyService;
			}
		} else {
			ECMServiceProvider.ecmElectoralDemographyService = ecmElectoralDemographyService;
		}
	}

	/**
	 * Method to retrieve the active election in a <code>ElectionData</code>
	 * object.
	 * 
	 * @return <code>ElectionData</code> object with the active election
	 * 
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred.
	 * 
	 * @throws ElectoralOrganizationOperationException
	 *             signals that any problem occurred.
	 */
	public static ElectionData retrieveActiveElection()
			throws ConnectionException, ElectoralOrganizationOperationException {
		try {
			return ecmElectoralOrganizationService.retrieveActiveElection();
		} catch (ElectoralOrganizationOperationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to retrieve the the voting devices amount loaded in database.
	 * 
	 * @return devices amount loaded in database
	 * 
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred.
	 * 
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             signals that any problem occurred.
	 */
	public static int retrieveVotingDevicesAmount() throws ConnectionException,
			ElectoralPhysicalLocationsRegistryException {
		try {
			return ecmElectoralPhysicalLocationsRegistryService
					.retrieveVotingDevicesAmount();
		} catch (ElectoralPhysicalLocationsRegistryException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to retrieve the the voting devices amount loaded in database.
	 * 
	 * @return devices amount loaded in database
	 * 
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred.
	 * 
	 * @throws DemographyException
	 *             signals that any problem occurred.
	 */
	public static int retrieveProgrammingUnitAmount()
			throws ConnectionException, DemographyException {
		try {
			return ecmDemographyService.retrieveProgrammingUnitsAmount();
		} catch (DemographyException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that sets the protection key to programming unit and update the
	 * object in database.
	 * 
	 * @param pageNumber
	 *            Current page number
	 * @param pageSize
	 *            Page size
	 * 
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred.
	 * 
	 * @throws DemographyException
	 *             signals that an exception has occurred updating the
	 *             Programming Units Protection Key.
	 */
	public static void setProtectionKeyToProgrammingUnit(int pageNumber,
			int pageSize) throws ConnectionException, DemographyException {
		try {
			ecmDemographyService.setProtectionKeyToProgrammingUnit(pageNumber,
					pageSize);
		} catch (DemographyException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Retrieves the security components of a number of voting devices stored in
	 * database.
	 * 
	 * The security components will be retrieved from the database by chunks, or
	 * pages, of <code>pageSize</code>, and the method will set the components
	 * for page number <code>pageNumber</code>.
	 * 
	 * @param pageNumber
	 *            Page number to process
	 * @param pageSize
	 *            Total page size
	 * 
	 * @return DTO list with security components of a number of voting devices
	 * 
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             signals that an exception has occurred retrieving some voting
	 *             device security components.
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred.
	 */
	public static List<VotingDeviceSecurityComponentsDTO> retrieveVotingDeviceSecurityComponents(
			int pageNumber, int pageSize)
			throws ElectoralPhysicalLocationsRegistryException,
			ConnectionException {
		try {
			return ecmElectoralPhysicalLocationsRegistryService
					.retrieveVotingDeviceSecurityComponents(pageNumber,
							pageSize);
		} catch (ElectoralPhysicalLocationsRegistryException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Retrieves the security components stored for the electoral authorities
	 * 
	 * @param pageNumber
	 *            page number to process
	 * @param pageSize
	 *            the total page size
	 * @return a list of the electoral authorities components objects
	 * @throws ConnectionException
	 *             Signals that a connection problem has occurred.
	 * @throws ElectoralOrganizationOperationException
	 *             Signal that an error occurred performing an operation
	 */
	public static List<ElectoralAuthoritySecurityComponentsDTO> retrieveElectoralAuthoritiesSecurityComponents(
			int pageNumber, int pageSize) throws ConnectionException,
			ElectoralOrganizationOperationException {
		try {
			return ecmElectoralOrganizationService
					.retrieveElectoralAuthoritiesSecurityComponents(pageNumber,
							pageSize);
		} catch (ElectoralOrganizationOperationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method used to generate the security components for a number of voting
	 * devices stored in database.
	 * 
	 * These security components are: Voting device transmission key, Voting
	 * device protection key, Voting device asymmetric key, Voting device
	 * president key, Voting device recounter key, Voting device numeric key 1
	 * and Voting device numeric key 2.
	 * 
	 * Sets the security components of a number of voting devices. The voting
	 * devices will be retrieved from the database by chunks, or pages, of
	 * <code>pageSize</code>, and the method will set the components for page
	 * number <code>pageNumber</code>.
	 * 
	 * @param pageNumber
	 *            Page number to process
	 * @param pageSize
	 *            Total page size
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred.
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             signals that an exception has occurred setting security
	 *             components to some voting device.
	 * @throws ElectoralOrganizationOperationException
	 *             signals that an exception has occurred retrieving the active
	 *             election
	 */
	public static void setSecurityComponentsToVotingDevices(int pageNumber,
			int pageSize) throws ConnectionException,
			ElectoralPhysicalLocationsRegistryException,
			ElectoralOrganizationOperationException {
		try {
			ecmElectoralPhysicalLocationsRegistryService
					.setSecurityComponentsToVotingDevices(pageNumber, pageSize);
		} catch (ElectoralPhysicalLocationsRegistryException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Sets the security components of a number of electoral authorities stored
	 * in database.
	 * 
	 * These security components are: protection key, alias, asymmetric key,
	 * user name and symmetric key.
	 * 
	 * The electoral authorities will be retrieved from the database by chunks,
	 * or pages, of <code>pageSize</code>, and the method will set the
	 * components for page number <code>pageNumber</code>.
	 * 
	 * @param pageNumber
	 *            the page to process
	 * @param pageSize
	 *            the total size
	 * @throws ConnectionException
	 *             Signals that a connection problem has occurred.
	 * @throws ElectoralOrganizationOperationException
	 *             Signal that an exception has occurred setting the security
	 *             components.
	 */
	public static void setSecurityComponentsToElectoralAuthorities(
			int pageNumber, int pageSize) throws ConnectionException,
			ElectoralOrganizationOperationException {
		try {
			ecmElectoralOrganizationService
					.setSecurityComponentsToElectoralAuthorities(pageNumber,
							pageSize);
		} catch (ElectoralOrganizationOperationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Deletes voting device security components.
	 * 
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred.
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             signals that an exception has occurred deleting voting device
	 *             security information.
	 */
	public static void deleteVotingDeviceSecurityComponents()
			throws ConnectionException,
			ElectoralPhysicalLocationsRegistryException {
		try {
			ecmElectoralPhysicalLocationsRegistryService
					.deleteVotingDeviceSecurityComponents();
		} catch (ElectoralPhysicalLocationsRegistryException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Deletes programming unit security components.
	 * 
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred.
	 * @throws DemographyException
	 *             signals that a exception has occurred deleting
	 */
	public static void deleteProgrammingUnitSecurityComponents()
			throws ConnectionException, DemographyException {
		try {
			ecmDemographyService.deleteProgrammingUnitSecurityComponents();
		} catch (DemographyException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Deletes the security components stored for the electoral authorities.
	 * 
	 * @throws ConnectionException
	 *             Signals that a connection problem has occurred.
	 * @throws ElectoralOrganizationOperationException
	 *             signal that an error occurred deleting the security
	 *             components
	 */
	public static void deleteElectoralAuthoritiesSecurityComponents()
			throws ConnectionException, ElectoralOrganizationOperationException {
		try {
			ecmElectoralOrganizationService
					.deleteElectoralAuthoritiesSecurityComponents();
		} catch (ElectoralOrganizationOperationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Executes bulk upload of smartmatic files into database.
	 * 
	 * @param fileToUploadName
	 *            Name of file to upload
	 * @param fileToUploadContent
	 *            Content of file to upload
	 * @param resourceFileContent
	 *            Content of resources needed by file to upload
	 * 
	 * @return List of DTO with the result of bulk upload generation.
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred executing bulk upload
	 * 
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static BulkResultDTO uploadSmttFileIntoDataBase(
			String fileToUploadName, byte[] fileToUploadContent,
			SmttFileType fileType, byte[] resourceFileContent)
			throws BulkDataLoadException, ConnectionException {
		try {
			return ecmBulkDataLoadService.uploadSmttFileIntoDataBase(
					fileToUploadName, fileToUploadContent, fileType,
					resourceFileContent);
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Executes bulk upload of EML and csv sites files into database.
	 * 
	 * @param fileToUploadName
	 *            Name of file to upload
	 * @param fileToUploadContent
	 *            Content of file to upload
	 * @param emlFileType
	 *            Type of file to upload
	 * @param resourceFileContent
	 *            Content of resources needed by file to upload
	 * 
	 * @return List of DTO with the result of bulk upload generation.
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred executing bulk upload
	 * 
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static BulkResultDTO uploadEMLFileIntoDataBase(
			String fileToUploadName, byte[] fileToUploadContent,
			EMLFileType emlFileType, byte[] resourceFileContent)
			throws BulkDataLoadException, ConnectionException {
		try {
			return ecmBulkDataLoadService.uploadEMLFilesIntoDataBase(
					fileToUploadName, fileToUploadContent, emlFileType,
					resourceFileContent);
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Executes a SQL query and returns the result data.
	 * 
	 * @param sqlQuery
	 *            SQL Query to execute.
	 * 
	 * @return DTO with query result.
	 * 
	 * @throws UtilitiesException
	 *             Thrown in case a failure occurs during the query execution.
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred.
	 */
	public static QueryResultDTO executeQuery(String sqlQuery)
			throws UtilitiesException, ConnectionException {
		try {
			return ecmUtilitiesService.executeQuery(sqlQuery);
		} catch (UtilitiesException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}

	}

	/**
	 * Gets the amount of records stored in database for each entity type.
	 * 
	 * @return List with the amount of records stored in database for each
	 *         entities
	 * 
	 * @throws BulkDataLoadException
	 *             signals that a problem occurred retrieving entities records
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static List<EntityRecordsQuantitiesDTO> getEntityRecordsQuantities()
			throws BulkDataLoadException, ConnectionException {
		try {
			return ecmUtilitiesService.getEntityRecordsQuantities();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}

	}

	/**
	 * Retrieves the number of multilingual keys loaded in database.
	 * 
	 * @return number of multilingual keys loaded in database
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred retrieving the
	 *             multilingual keys amount
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static int retrieveMultilingualKeysAmount()
			throws BulkDataLoadException, ConnectionException {
		try {
			return ecmUtilitiesService.retrieveMultilingualKeysAmount();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to get the multilingual keys for each language needed to export
	 * the translations file.
	 * 
	 * @param pageNumber
	 *            Current page number
	 * @param pageSize
	 *            Page size
	 * 
	 * @return list of strings, each holding the lines used to export the
	 *         translations file
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred retrieving the
	 *             multilingual keys to export the translations file
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static List<String> getTranslationkeysToDownload(int pageNumber,
			int pageSize) throws BulkDataLoadException, ConnectionException {
		try {
			return ecmUtilitiesService.getTranslationkeysToDownload(pageNumber,
					pageSize);
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to clear all records of translation_key, multilingual_key,
	 * region_election_language, election_language tables.
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred removing the records
	 *             in some table
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static void truncateLanguageTables() throws BulkDataLoadException,
			ConnectionException {
		try {
			ecmUtilitiesService.truncateLanguageTables();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to clear all records of region_contest_group,
	 * contest_group_contest, contest_group, contest, contest_class,
	 * region_district, district, ballot_layout, candidate and party
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred removing the records
	 *             in some table
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static void truncateNominationTables() throws BulkDataLoadException,
			ConnectionException {
		try {
			ecmUtilitiesService.truncateNominationTables();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to clear all records of user, profile_function, profile and
	 * electoral_authority
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred removing the records
	 *             in some table
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static void truncateUserTables() throws BulkDataLoadException,
			ConnectionException {
		try {
			ecmUtilitiesService.truncateUserTables();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to clear all records of voting_booth, voting_device,
	 * polling_station and polling_place
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred removing the records
	 *             in some table
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static void truncatePhysicalLocationsTables()
			throws BulkDataLoadException, ConnectionException {
		try {
			ecmUtilitiesService.truncatePhysicalLocationsTables();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to clear all records of category_path, category_parent,
	 * region_programming_unit, programming_unit, region_all_parent,
	 * region_parent, region, category, path and election
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred removing the records
	 *             in some table
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static void truncateDemographyTables() throws BulkDataLoadException,
			ConnectionException {
		try {
			ecmUtilitiesService.truncateDemographyTables();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to clear all records of report_template_region and
	 * report_template. This method also deletes the report templates and
	 * compiled reports saved in the filesystem.
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred removing the records
	 *             in some table
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static void truncateReportTemplatesTables()
			throws BulkDataLoadException, ConnectionException {
		try {
			ecmUtilitiesService.truncateReportTemplatesTables();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to clear all records of logical_voting_group_voting_booth
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred removing data for some
	 *             table
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static void truncateLogicalVotingGroup()
			throws BulkDataLoadException, ConnectionException {
		try {
			ecmUtilitiesService.truncateLogicalVotingGroup();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to clear all records of ballot_option and eligible_option_role
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred removing data for some
	 *             table
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static void truncateEligibleOption() throws BulkDataLoadException,
			ConnectionException {
		try {
			ecmUtilitiesService.truncateEligibleOption();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to clear all records of eligible_option, party and candidate
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred removing data for some
	 *             table
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static void truncateCodiNominationTables()
			throws BulkDataLoadException, ConnectionException {
		try {
			ecmUtilitiesService.truncateCodiNominationTables();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to remove EML files from the server.
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred removing EML files
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static void deleteEMLFiles() throws BulkDataLoadException,
			ConnectionException {
		try {
			ecmUtilitiesService.deleteEMLFiles();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to remove voice files in server side
	 * 
	 * @throws BulkDataLoadException
	 *             signals that an exception has occurred removing voice files
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static void deleteVoiceFiles() throws BulkDataLoadException,
			ConnectionException {
		try {
			ecmUtilitiesService.deleteVoiceFiles();
		} catch (BulkDataLoadException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to check if all certificate were generated.
	 * 
	 * @return True if all certificate were generated
	 * 
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             signals that some problem happened checking if the security
	 *             components are generated
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static boolean checkIfSecurityComponentsAreGenerated()
			throws ElectoralPhysicalLocationsRegistryException,
			ConnectionException {
		try {
			return ecmUtilitiesService.checkIfSecurityComponentsAreGenerated();
		} catch (ElectoralPhysicalLocationsRegistryException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method used to get a boolean property from config-properties.xml.
	 * 
	 * @param key
	 *            The key of the property to search.
	 * 
	 * @return The boolean value of the property with key:<code>key</code>
	 */
	public static Boolean getServerPropertyAsBoolean(String key) {
		try {
			return ecmUtilitiesService.getServerPropertyAsBoolean(key);
		} catch (CannotConnectException e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new RuntimeException(
					StringUtils.defaultString(e.getMessage()), e);
		} catch (EJBTransactionRolledbackException e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new RuntimeException(
					StringUtils.defaultString(e.getMessage()), e);
		}
	}

	/**
	 * Method used to get a string property from config-properties.xml.
	 * 
	 * @param key
	 *            The key of the property to search.
	 * 
	 * @return The string value of the property with key:<code>key</code>
	 */
	public static String getServerPropertyAsString(String key) {
		try {
			return ecmUtilitiesService.getServerPropertyAsString(key);
		} catch (CannotConnectException e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new RuntimeException(
					StringUtils.defaultString(e.getMessage()), e);
		} catch (EJBTransactionRolledbackException e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new RuntimeException(
					StringUtils.defaultString(e.getMessage()), e);
		}
	}

	/**
	 * Retrieves the district sent with its name translated to the specified
	 * language.
	 * 
	 * @param districtToTranslate
	 *            the district to translate
	 * 
	 * @param language
	 *            Language to translate the district
	 * 
	 * @return the district with the name translated
	 * 
	 * @throws UtilitiesException
	 *             signals that some problem occurred searching the district
	 *             translation
	 * 
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static DistrictData translateDistrictName(
			DistrictData districtToTranslate, LanguageData language)
			throws UtilitiesException, ConnectionException {
		try {
			return ecmUtilitiesService.translateDistrictName(
					districtToTranslate, language);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Retrieves a DTO with the contests, languages, and languages resources
	 * (needed to generate the election.xml)
	 * 
	 * @param lastLevelRegions
	 *            last level region list selected by user to generate Master
	 *            USB.
	 * @param appLanguage
	 *            current language with which the application is running.
	 * 
	 * @return DTO with components needed to build the election.xml.
	 * 
	 * @throws MasterUSBGenerationException
	 *             signals that something happened generating election.xml
	 *             components
	 * 
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static ActiveContestForElectionDTO getActiveContestForElection(
			List<RegionData> lastLevelRegions, LanguageData appLanguage)
			throws MasterUSBGenerationException, ConnectionException {
		try {
			return ecmMasterUSBGenerationService.getActiveContestForElection(
					lastLevelRegions, appLanguage);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that generate an election object with all electoral information to
	 * create the election.xml for a list of contests
	 * 
	 * @param contestList
	 *            the contest list to generate the election.
	 * @param objectCodePrefix
	 *            the prefix used for object's codes when generating election
	 *            objects.
	 * @param election
	 *            the election object reference
	 * @param resourcesLanguages
	 *            the resources languages translations object
	 * @return the election xml components object
	 * @throws MasterUSBGenerationException
	 *             signals that something happened generating election
	 *             components
	 */
	public static ElectionXmlComponentsDTO generateElectionForContest(
			List<ContestData> contestList, int objectCodePrefix,
			ElectionData election,
			Map<String, Map<String, String>> resourcesLanguages,
			List<ContestGroupData> contestGroups)
			throws MasterUSBGenerationException, ConnectionException {
		try {
			return ecmMasterUSBGenerationService.generateElectionForContest(
					contestList, objectCodePrefix, election,
					resourcesLanguages, contestGroups);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		} catch (OutOfMemoryError e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Gets only last level region data objects(but only region code and region
	 * name of each matched object) from a list of region data if provided, if
	 * not it will return all last level region data objects stored in database.
	 * 
	 * This method will load faster than <code>getLastLevelRegions</code> method
	 * but use only in cases that you do not need more fields that the ones
	 * indicated above.
	 * 
	 * @param regionsFilterList
	 *            the region data list to filter the search
	 * @return the last level region data list.
	 * @throws DemographyException
	 *             Signal that an error has occurred getting the last level
	 *             region data objects.
	 */
	public static List<RegionData> getLastLevelRegionsLight(
			List<RegionData> selectedRegions) throws DemographyException,
			ConnectionException {
		try {
			return ecmDemographyService
					.getLastLevelRegionsLight(selectedRegions);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Gets a set of programming units DTO from a list of regions.
	 * 
	 * @param regionList
	 *            the region data list to filter the search
	 * @return the set of programming units DTO
	 * @throws DemographyException
	 *             Signal that an error has occurred getting the last level
	 *             region data objects.
	 */
	public static Set<ProgrammingUnitLastLevelRegionDTO> getProgrammingUnitsByRegions(
			List<RegionData> selectedRegions) throws DemographyException,
			ConnectionException {
		try {
			return ecmDemographyService
					.getProgrammingUnitsByRegions(selectedRegions);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * This method is used to get a map which the key is the lower electoral
	 * authority defined by the region category level and the value a collection
	 * of electoral authorities which belong to the last level region provided.
	 * 
	 * @param lastLevelRegion
	 *            the last level region the get the electoral authorities
	 * @return a map of the lower electoral authority as key and a collection as
	 *         value
	 * @throws ElectoralOrganizationOperationException
	 *             signal than an error has occurred getting the electoral
	 *             authorities.
	 */
	public static Map<ElectoralAuthorityData, Collection<ElectoralAuthorityData>> getElectoralAuthoritiesByLastLevelRegion(
			RegionData lastLevelRegion)
			throws ElectoralOrganizationOperationException, ConnectionException {
		try {
			return ecmElectoralOrganizationService
					.getElectoralAuthoritiesByLastLevelRegion(lastLevelRegion);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Return a list of voting devices filtered by an specific region.
	 * 
	 * @param region
	 *            the region to obtain the voting devices list
	 * @return the voting devices list
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             Signal that an exception has occurred getting the voting
	 *             devices list.
	 */
	public static List<VotingDeviceData> getVotingDevicesByRegion(
			RegionData region) throws ConnectionException,
			ElectoralPhysicalLocationsRegistryException {
		try {
			return ecmElectoralPhysicalLocationsRegistryService
					.getVotingDevicesByRegion(region);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Return a list of voting devices filtered by an specific polling place.
	 * 
	 * @param pollingPlace
	 *            the polling place to obtain the voting devices list
	 * @return the voting devices list
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             Signal that an exception has occurred getting the voting
	 *             devices list.
	 */
	public static List<VotingDeviceData> getVotingDevicesByPollingPlace(
			PollingPlaceData pollingPlace) throws ConnectionException,
			ElectoralPhysicalLocationsRegistryException {
		try {
			return ecmElectoralPhysicalLocationsRegistryService
					.getVotingDevicesByPollingPlace(pollingPlace);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that generates an voting device object with all the voting device
	 * information to create the voting-device.xml for a region. This file is
	 * loaded by the voting machine to display the election data.
	 * 
	 * @param votingDevice
	 *            the voting device object which contains data to create the
	 *            voting device file
	 * @param region
	 *            the region in which the voting devices are located
	 * @param contestGroup
	 *            the contest group for which the voting device must be
	 *            generated
	 * @param resourcesLanguages
	 *            the resources languages object reference
	 * @param generateDummyVotingDevice
	 *            true if the voting device must be created with dummy data,
	 *            this is required when generating a master USB for the
	 *            screenshots functionality.
	 * @param election
	 *            the current active election
	 * @param audioVotingEnabled
	 *            The audio voting flag
	 * @return the voting device DTO object
	 * @throws MasterUSBGenerationException
	 *             A signal that an error has occurred generating the voting
	 *             device object.
	 */
	public static VotingDeviceDTO generateVotingDeviceForRegion(
			VotingDeviceData votingDevice, RegionData region,
			List<ContestGroupData> contestGroup,
			Map<String, Map<String, String>> resourcesLanguages,
			boolean generateDummyVotingDevice, ElectionData election,
			boolean audioVotingEnabled) throws MasterUSBGenerationException,
			ConnectionException {
		try {
			return ecmMasterUSBGenerationService.generateVotingDeviceForRegion(
					votingDevice, region, contestGroup, resourcesLanguages,
					generateDummyVotingDevice, election, audioVotingEnabled);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that returns a list of eligible option data objects filtered by
	 * contest.
	 * 
	 * @param contestData
	 *            the contest data object to filter the search
	 * @return a list of eligible options that matched the search
	 * @throws NominationException
	 *             a signal that an error has occurred getting the eligible
	 *             options by contest.
	 * 
	 **/
	public static List<EligibleOptionData> getEligibleOptionsByContest(
			ContestData contestData) throws ConnectionException,
			NominationException {
		try {
			return ecmNominationService
					.getEligibleOptionsByContest(contestData);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		} catch (OutOfMemoryError e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that returns a list of eligible options data objects with the
	 * information of its corresponding role data.
	 * 
	 * @param eligibleOptionsList
	 *            the eligible option list to fill the role data.
	 * @return a list of eligible options with its role data set.
	 * @throws NominationException
	 *             A signal that an error has occurred getting the eligible
	 *             option roles data list.
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static List<EligibleOptionData> getEligibleOptionRoleByEligibleOption(
			List<EligibleOptionData> eligibleOptionsList)
			throws ConnectionException, NominationException {
		try {
			return ecmNominationService
					.getEligibleOptionRoleByEligibleOption(eligibleOptionsList);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that returns a list of eligible options data objects with the
	 * information of its corresponding ballot option data.
	 * 
	 * @param eligibleOptionsList
	 *            the eligible option list to fill the ballot option data.
	 * @return a list of eligible options with its ballot option data set.
	 * @throws NominationException
	 *             A signal that an error has occurred getting the ballot
	 *             options data list.
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static List<EligibleOptionData> getBallotOptionByEligibleOption(
			List<EligibleOptionData> eligibleOptionsList)
			throws NominationException, ConnectionException {
		try {
			return ecmNominationService
					.getBallotOptionByEligibleOptions(eligibleOptionsList);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that returns a list of contest data objects given a list of
	 * contest codes to search.
	 * 
	 * @param constestsCodesList
	 *            a contest codes list to search
	 * @param pageNumber
	 *            the page to process
	 * @param pageSize
	 *            the total size of the resultset
	 * @return the contest data objects list that matched the search.
	 * @throws NominationException
	 *             A signal that an error has occurred getting the contests
	 *             list.
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static List<ContestData> getContests(List<Long> contestCodes,
			int pageNumber, int pageSize) throws NominationException,
			ConnectionException {
		try {
			return ecmNominationService.getContests(contestCodes, pageNumber,
					pageSize);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Returns a list of all available regions to fill the regions widget.
	 * 
	 * @return a list of region data objects only with the code set, to load
	 *         faster.
	 * @throws DemographyException
	 *             A signal that an error has occurred getting the available
	 *             regions.
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static List<RegionData> getAvailableRegionsForWidget()
			throws DemographyException, ConnectionException {
		try {
			return ecmDemographyService.getAvailableRegionsForWidget();
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that returns a set of language data objects stored in the database
	 * and used for the current election.
	 * 
	 * @return a set of language data objects
	 * @throws MasterUSBGenerationException
	 *             A signal that an error has occurred getting the language data
	 *             set.
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static Set<LanguageData> getLanguages()
			throws MasterUSBGenerationException, ConnectionException {
		try {
			return ecmMasterUSBGenerationService.getLanguages();
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method used to return a list of electoral authorities data objects given
	 * a list of regions.
	 * 
	 * @param selectedRegions
	 *            the list of regions to get the electoral authorities
	 * @return the list of electoral authorities that match the criteria
	 * @throws ElectoralOrganizationOperationException
	 *             Signal that an error has occurred getting the electoral
	 *             authorities
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static List<ElectoralAuthorityData> getElectoralAuthoritiesByRegion(
			List<RegionData> selectedRegions)
			throws ElectoralOrganizationOperationException, ConnectionException {
		try {
			return ecmElectoralOrganizationService
					.getElectoralAuthoritiesByRegion(selectedRegions);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that return from all the parent regions of the contest the list of
	 * languages
	 * 
	 * @param contest
	 *            the contest to search its parent languages
	 * @return a list of languages
	 * @throws UtilitiesException
	 *             signal that an error occurred getting the parent languages
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static List<LanguageData> getParentLanguages(ContestData contest)
			throws ConnectionException, UtilitiesException {
		try {

			return ecmUtilitiesService.getParentLanguages(contest);

		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that return from all the children regions of the contest the list
	 * of languages
	 * 
	 * @param contest
	 *            the contest to search its children languages
	 * @return a list of languages
	 * @throws UtilitiesException
	 *             signal that an error occurred getting the children languages
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 * 
	 */
	public static List<LanguageData> getChildrenLanguages(ContestData contest)
			throws ConnectionException, UtilitiesException {
		try {

			return ecmUtilitiesService.getChildrenLanguages(contest);

		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Returns a list of contest language pair objects for a given contest
	 * 
	 * @param contest
	 *            the contest to search its languages combinations
	 * @return a list of combination objects
	 * @throws UtilitiesException
	 *             signal that an error occurred getting the language
	 *             combinations
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static List<ContestLanguagesPairData> getLanguageCombinationsByContest(
			ContestData contest) throws ConnectionException, UtilitiesException {
		try {
			return ecmUtilitiesService
					.getLanguageCombinationsByContest(contest);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that returns a list of contest given a contest class
	 * 
	 * @param contestClass
	 *            the contest class to fetch all of its contests
	 * @param language
	 *            the language to translate contest classes and its contests
	 * @return the list of contest
	 * @throws NominationException
	 *             a signal that an error occurred getting the contests
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static List<ContestData> getContestByContestClass(
			String contestClass, LanguageData language)
			throws NominationException, ConnectionException {
		try {
			return ecmNominationService.getContestsByContestClass(contestClass,
					language);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Return the amount of processed contests while generating the election
	 * data.
	 * 
	 * @return the amount of processed contests.
	 * @throws ConnectionException
	 *             signals that a connection problem has occurred
	 */
	public static int getProcessedContests() throws ConnectionException {
		try {
			return ecmMasterUSBGenerationService.getProcessedContests();
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Reset the processed contest counter.
	 */
	public static void resetProcessedContests() throws ConnectionException {
		try {
			ecmMasterUSBGenerationService.resetProcessedContests();
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Return a list of report templates used by the PM/VM
	 * 
	 * @param regionCode
	 *            the region to get the reports
	 * @return a list of report template data
	 * @throws UtilitiesException
	 *             if an error has occurred getting the templates
	 * @throws ConnectionException
	 *             if a connection error occurred
	 */
	public static List<ReportTemplateData> getReportsTemplatesByRegion(
			long regionCode) throws UtilitiesException, ConnectionException {
		try {
			return ecmUtilitiesService.getReportsTemplatesByRegion(regionCode);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Returns a list of common audio resources XML files, which are loaded as
	 * resources.
	 * 
	 * @return the list of audio resources.
	 * @throws UtilitiesException
	 *             if an error occurs loading the files from the database.
	 * @throws ConnectionException
	 *             if a connection error occurs during the bean invocation.
	 */
	public static List<ReportTemplateData> getCommonAudioResources()
			throws UtilitiesException, ConnectionException {
		try {
			return ecmUtilitiesService.getCommonAudioResources();
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Gets the EML files from the server into a hashMap.
	 * 
	 * @return A HashMap with the inputStreams
	 * @throws ConnectionException
	 * @throws UtilitiesException
	 * @throws IOException
	 *             signals that an I/O exception of some sort has occurred.
	 */
	public static Map<String, byte[]> getEMLFiles() throws ConnectionException,
			UtilitiesException {
		try {
			return ecmUtilitiesService.getEMLFiles();
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Return a list of language data from a district custom code
	 * 
	 * @param customCode
	 *            the custom code of the district to search
	 * @return the list of language data
	 * @throws ElectoralDemographyException
	 *             if an error occurred getting the district languages
	 * @throws ConnectionException
	 *             if a connection error occurred
	 */
	public static List<LanguageData> getDistrictLanguages(String customCode)
			throws ElectoralDemographyException, ConnectionException {
		try {
			return ecmElectoralDemographyService
					.getDistrictLanguages(customCode);

		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}

	}

	/**
	 * Return a contest data object with its name translated
	 * 
	 * @param contest
	 *            the contest object to translate
	 * @param language
	 *            the language to translate the contest
	 * @return the contest object
	 * @throws UtilitiesException
	 *             if an error occurred translating the contest name
	 * @throws ConnectionException
	 *             if a connection error occurred
	 */
	public static ContestData getContestNameTranslated(ContestData contest,
			LanguageData language) throws UtilitiesException,
			ConnectionException {
		try {
			return ecmUtilitiesService.translateContestName(contest, language);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}

	}

	/**
	 * Return a district data object with its name translated
	 * 
	 * @param district
	 *            the district object to translate
	 * @param language
	 *            the language to translate the district
	 * @return the district object
	 * @throws UtilitiesException
	 *             if an error occurred translating the district name
	 * @throws ConnectionException
	 *             if a connection error occurred
	 */
	public static DistrictData getDistrictNameTranslated(DistrictData district,
			LanguageData language) throws ConnectionException,
			UtilitiesException {

		try {
			return ecmUtilitiesService
					.translateDistrictName(district, language);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to return the amount of candidates fetched given the filter
	 * parameters.
	 * 
	 * @param candidateName
	 *            Candidates search text
	 * @param regions
	 *            The regions list to filter the search
	 * @param contests
	 *            The contests list to filter the search
	 * @param parties
	 *            The parties list to filter the search.
	 * @return The amount of candidates matching the search parameters.
	 * @throws NominationException
	 *             A signal that an error occurred retrieving candidates amount.
	 * @throws ConnectionException
	 *             A signal that an error occurred during the server connection.
	 */
	public static int retrieveNumberOfCandidates(String candidateName,
			List<RegionData> regions, List<ContestData> contests,
			List<PartyData> parties) throws NominationException,
			ConnectionException {
		try {
			return ecmNominationService.retrieveNumberOfCandidates(
					candidateName, regions, contests, parties);
		} catch (NominationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to get the candidate information to be modified.
	 * 
	 * @param pageNumber
	 *            Page number to search.
	 * @param numberOfPages
	 *            Number of pages to search.
	 * @param candidateName
	 *            the candidate name
	 * @param selectedRegions
	 *            Selected Region.
	 * @param selectedContests
	 *            Selected contest.
	 * @param selectedParties
	 *            Selected parties.
	 * @param language
	 *            Application language.
	 * @return EligibleOptionData list with candidate information.
	 * @throws NominationException
	 *             A signal that an error occurred retrieving candidates list.
	 * @throws ConnectionException
	 *             the connection exception
	 */
	public static List<EligibleOptionData> getCandidates(int pageNumber,
			int numberOfPages, String candidateName,
			List<RegionData> selectedRegions,
			List<ContestData> selectedContests,
			List<PartyData> selectedParties, LanguageData language)
			throws NominationException, ConnectionException {
		try {
			return ecmNominationService.getCandidates(pageNumber,
					numberOfPages, candidateName, selectedRegions,
					selectedContests, selectedParties, language);
		} catch (NominationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to return the amount of parties fetched given the filter
	 * parameters.
	 * 
	 * @param candidateName
	 *            Candidates search text
	 * @param regions
	 *            The regions list to filter the search
	 * @param contests
	 *            The contests list to filter the search
	 * @return The amount of parties matching the search parameters.
	 * @throws NominationException
	 *             A signal that an error occurred retrieving parties amount.
	 * @throws ConnectionException
	 *             A signal that an error occurred during the server connection.
	 */
	public static int retrieveNumberOfParties(String partyName,
			List<RegionData> regions, List<ContestData> contests)
			throws NominationException, ConnectionException {
		try {
			return ecmNominationService.retrieveNumberOfParties(partyName,
					regions, contests);
		} catch (NominationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to retrieve the parties matching the filter parameters.
	 * 
	 * @param pageNumber
	 *            page number to process.
	 * @param numberOfPages
	 *            the total of pages to retrieve.
	 * @param partyName
	 *            parties search text
	 * @param regions
	 *            The regions list to filter the search
	 * @param contests
	 *            The contest list to filter the search
	 * @param language
	 *            The selected language
	 * @return A list of parties matching the search parameters.
	 * @throws NominationException
	 *             A signal that an error occurred retrieving parties.
	 * @throws ConnectionException
	 *             the connection exception
	 */
	public static List<EligibleOptionData> getParties(int pageNumber,
			int numberOfPages, String partyName,
			List<RegionData> selectedRegions,
			List<ContestData> selectedContests, LanguageData language)
			throws NominationException, ConnectionException {
		try {
			return ecmNominationService.getParties(pageNumber, numberOfPages,
					partyName, selectedRegions, selectedContests, language);
		} catch (NominationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that updates an eligible option data.
	 * 
	 * @param eligibleOption
	 *            The eligible option to update
	 * @return the updated object
	 * @throws NominationException
	 *             A signal that an error occurred updating the data.
	 */
	public static EligibleOptionData updateEligibleOption(
			EligibleOptionData eligibleOption) throws NominationException,
			ConnectionException {
		try {
			return ecmNominationService.updateEligibleOption(eligibleOption);
		} catch (NominationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method that updates an eligible option and party name.
	 * 
	 * @param eligibleOption
	 *            The eligible option to update
	 * @return the updated object
	 * @throws NominationException
	 *             A signal that an error occurred updating the data.
	 * @throws ConnectionException
	 */
	public static PartyData updateEligibleOptionAndParty(
			EligibleOptionData eligibleOption) throws NominationException,
			ConnectionException {
		try {
			return ecmNominationService
					.updateEligibleOptionAndParty(eligibleOption);
		} catch (NominationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}

	}

	/**
	 * Method to retrieve a list of contests given the filter parameters.
	 * 
	 * @param regions
	 *            The regions list to filter the search
	 * @param parties
	 *            The parties list to filter the search
	 * @param language
	 *            The selected language
	 * @return A list of contests matching the search parameters.
	 * @throws NominationException
	 *             A signal that an error occurred retrieving contests.
	 */
	public static List<ContestData> getContests(List<RegionData> regions,
			List<PartyData> parties, LanguageData language)
			throws NominationException, ConnectionException {
		try {
			return ecmNominationService.getContests(regions, parties, language);
		} catch (NominationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Method to retrieve a list of parties given the filter parameters.
	 * 
	 * @param regions
	 *            The regions list to filter the search
	 * @param contests
	 *            The contests list to filter the search
	 * @return A list of parties matching the search parameters.
	 * @throws NominationException
	 *             A signal that an error occurred retrieving parties.
	 */
	public static List<PartyData> getParties(List<RegionData> regions,
			List<ContestData> parties) throws ConnectionException,
			NominationException {
		try {
			return ecmNominationService.getParties(regions, parties);
		} catch (NominationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * From a region this method return the parent languages
	 * 
	 * @param region
	 *            the region to get its parent languages
	 * @return the list of languages
	 * @throws UtilitiesException
	 *             if an error has occurred getting the languages
	 * @throws ConnectionException
	 *             A signal that an error occurred during the server connection.
	 */
	public static List<LanguageData> getParentLanguages(RegionData region)
			throws UtilitiesException, ConnectionException {
		try {
			return ecmUtilitiesService.getParentLanguages(region);

		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Return an object that contains the contest class translations for a
	 * region
	 * 
	 * @param region
	 * @param languages
	 *            the language list to translate the contest classes
	 * @param translations
	 *            the translations object reference when iterating multiple
	 *            regions
	 * @return the contest class translation object
	 * @throws UtilitiesException
	 *             an error occurred translating the contest classes
	 * @throws ConnectionException
	 *             A signal that an error occurred during the server connection.
	 * 
	 */
	public static ContestClassTranslationsDTO getContestClassTranslations(
			RegionData region, List<LanguageData> languages,
			Map<String, ContestClassData> translations)
			throws UtilitiesException, ConnectionException {

		try {
			return ecmUtilitiesService.getContestClassTranslations(region,
					languages, translations);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Return a list of the official languages loaded
	 * 
	 * @return the list of languages
	 * @throws ConnectionException
	 *             A signal that an error occurred during the server connection.
	 * @throws UtilitiesException
	 *             if an error occurred getting the languages
	 */
	public static List<LanguageData> getOfficialLanguages()
			throws ConnectionException, UtilitiesException {
		try {
			return ecmUtilitiesService.getOfficialLanguages();

		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Generates the reports for voting devices and recount machines.
	 * 
	 * @param language
	 *            the language for the report
	 * @param votingDevices
	 *            the list of voting devices
	 * @param isVotingDeviceReport
	 *            true if the reports if for voting devices, otherwise false
	 * @param printReportWithoutPassword
	 *            true if the reports with password should be printed, otherwise
	 *            false
	 * @return the list of generated reports
	 * @throws UtilitiesException
	 *             if an error has occurred generating the reports
	 * @throws ConnectionException
	 *             A signal that an error occurred during the server connection.
	 */
	public static List<JasperPrint> generateReports(LanguageData language,
			List<VotingDeviceData> votingDevices, boolean isVotingDeviceReport,
			boolean printReportWithoutPassword) throws UtilitiesException,
			ConnectionException {
		try {
			return ecmUtilitiesService.generatePasswordReports(language,
					votingDevices, isVotingDeviceReport,
					printReportWithoutPassword);
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}

	}

	/**
	 * Generates the reports for totalization machines
	 * 
	 * @param language
	 *            the language for the report
	 * @param electoralAuthorities
	 *            the set of electoral authorities
	 * @return the list of generated reports
	 * @throws UtilitiesException
	 *             if an error has occurred generating the reports
	 * @throws ConnectionException
	 *             A signal that an error occurred during the server connection.
	 */
	public static List<JasperPrint> generateTotalizationReports(
			LanguageData language,
			Set<ElectoralAuthorityData> electoralAuthorities)
			throws UtilitiesException, ConnectionException {

		try {

			return ecmUtilitiesService.generateTotalizationReports(language,
					electoralAuthorities);

		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}

	}

	/**
	 * Gets the application key.
	 *
	 * @return the application key
	 */
	public static String getApplicationKey() {
		try {
			return ecmUtilitiesService.getApplicationKey();
		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new RuntimeException(
					StringUtils.defaultString(e.getMessage()), e);
		}
	}

	/**
	 * Sets the default application key.
	 *
	 * @throws ConnectionException
	 *             the connection exception
	 * @throws ElectoralOrganizationOperationException
	 *             the electoral organization operation exception
	 * @throws BaseException
	 *             the base exception
	 */
	public static void setDefaultApplicationKey() throws ConnectionException,
			ElectoralOrganizationOperationException, BaseException {
		try {
			ecmUtilitiesService.setDefaultApplicationKey();
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Generates a random application key.
	 *
	 * @throws ConnectionException
	 *             the connection exception
	 * @throws ElectoralOrganizationOperationException
	 *             the electoral organization operation exception
	 * @throws BaseException
	 *             the base exception
	 */
	public static void generateRandomApplicationKey()
			throws ConnectionException,
			ElectoralOrganizationOperationException, BaseException {
		try {
			ecmUtilitiesService.generateRandomApplicationKey();
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * ECMService constructor.
	 * 
	 * @param ecmService
	 *            ecmService instance
	 */
	public static void setEcmService(IECMService ecmService) {

		if (ECMServiceProvider.ecmService != null) {
			synchronized (ECMServiceProvider.ecmMasterUSBGenerationService) {

				ECMServiceProvider.ecmService = ecmService;
			}
		} else {
			ECMServiceProvider.ecmService = ecmService;

		}

	}

	/**
	 * ECMMasterUSBGenerationService constructor.
	 * 
	 * @param ecmMasterUSBGenerationService
	 *            ecmMasterUSBGenerationService instance
	 */
	public static void setEcmMasterUSBGenerationService(
			IECMMasterUSBGenerationService ecmMasterUSBGenerationService) {

		if (ECMServiceProvider.ecmMasterUSBGenerationService != null) {
			synchronized (ECMServiceProvider.ecmMasterUSBGenerationService) {

				ECMServiceProvider.ecmMasterUSBGenerationService = ecmMasterUSBGenerationService;
			}
		} else {
			ECMServiceProvider.ecmMasterUSBGenerationService = ecmMasterUSBGenerationService;

		}

	}

	/**
	 * ECMWorkflowService ecmWorkflowService constructor.
	 * 
	 * @param ecmWorkflowService
	 *            ecmWorkflowService instance
	 */
	public static void setEcmWorkflowService(
			IECMWorkflowService ecmWorkflowService) {

		if (ECMServiceProvider.ecmWorkflowService != null) {
			synchronized (ECMServiceProvider.ecmWorkflowService) {

				ECMServiceProvider.ecmWorkflowService = ecmWorkflowService;
			}
		} else {
			ECMServiceProvider.ecmWorkflowService = ecmWorkflowService;

		}

	}

	/**
	 * Method used to get the integer value of a parameter in the database.
	 * 
	 * @param key
	 *            The key of the parameter.
	 * @return The integer value of the parameter.
	 * @throws IllegalStateException
	 *             the illegal state exception
	 * @throws BaseException
	 *             If an exception occurs interacting with the database.
	 */
	public static Integer getIntParameter(String key)
			throws IllegalStateException, BaseException {
		try {
			return ecmService.getIntParameter(key);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Method used to get the value of a parameter in the database.
	 * 
	 * @param key
	 *            The key of the parameter.
	 * 
	 * @return The value of the parameter.
	 * 
	 * @throws BaseException
	 *             If an exception occurs interacting with the database.
	 */
	public static String getStringParameter(String key) throws BaseException {
		try {
			return ecmService.getStringParameter(key);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Updates an instance into the database.
	 * 
	 * @param parameter
	 *            the parameter
	 * @throws XmlGenerationException
	 *             Wrapper of Exception to notify the client that a problem
	 *             occurred
	 * @throws ConnectionException
	 *             the connection exception
	 */
	public static void updateParameter(ParameterData parameter)
			throws XmlGenerationException,
			com.smartmatic.waffle.ecm.client.exception.ConnectionException {
		try {
			ecmService.updateParameter(parameter);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Method to set or create a new parameter key - value.
	 * 
	 * @param key
	 *            The key of the parameter.
	 * @param value
	 *            The value of the parameter.
	 * @throws BaseException
	 *             the base exception
	 */
	public static void setParameter(String key, String value)
			throws BaseException {
		try {
			ecmService.setParameter(key, value);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Gets the list of parameters and its values that can be configured by the
	 * user.
	 * 
	 * @return List of configurable parameters
	 * @throws XmlGenerationException
	 *             Wrapper of Exception to notify the client that a problem
	 *             occurred
	 * @throws ConnectionException
	 *             the connection exception
	 */
	public static List<ParameterData> getParameters()
			throws XmlGenerationException,
			com.smartmatic.waffle.ecm.client.exception.ConnectionException {
		try {
			return ecmService.getParameters();
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Executes the generation process of logical voting groups after the main
	 * data load has ended.
	 * 
	 * @param region
	 *            Region of the logical voting groups that will be generated
	 * @return List of logical voting groups with its associated region
	 * @throws BaseException
	 *             Abstract base class to notify the client that a problem
	 *             occurred
	 */
	public static Map<String, LogicalVotingGroupData> postLoadProcess(
			RegionData region) throws Exception {
		try {
			return ecmService.postLoadProcess(region);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Stores a list of logical voting groups in the database, keeping their
	 * relationship with the respective regions.
	 * 
	 * @param logicalVotingGroupsData
	 *            List of logical voting groups and their respective regions
	 * @throws BaseException
	 *             Abstract base class to notify the client that a problem
	 *             occurred
	 * @throws ElectoralDemographyException
	 */
	public static void persistLogicalVotingGroup(
			Map<String, LogicalVotingGroupData> logicalVotingGroupsData)
			throws BaseException, ElectoralDemographyException {
		try {
			ecmService.persistLogicalVotingGroup(logicalVotingGroupsData);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Generates a backup of the database.
	 * 
	 * @param databaseIp
	 *            ip address to reach the database to extract the dump
	 * 
	 * @return Backup of the database
	 * @throws BackupDatabaseGenerationExeption
	 *             Abstract base class to notify the client that a problem
	 *             generating backup occurred
	 * @throws ConnectionException
	 *             the connection exception
	 */
	public static byte[] generateBackupDatabase(String databaseIp)
			throws BackupDatabaseGenerationExeption,
			com.smartmatic.waffle.ecm.client.exception.ConnectionException {
		try {
			return ecmService.dumpDatabase(databaseIp);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Gets all the polling places of a given region.
	 * 
	 * @param region
	 *            Region of the polling places
	 * @return List of polling places of the given region
	 * @throws XmlGenerationException
	 *             the xml generation exception
	 * @throws ConnectionException
	 *             the connection exception
	 */
	public static List<PollingPlaceData> getPollingPlacesPerRegion(
			RegionData region) throws XmlGenerationException,
			com.smartmatic.waffle.ecm.client.exception.ConnectionException {
		try {
			return ecmService.getPollingPlacesPerRegion(region);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			return null;

		}
	}

	public static int retrieveElectoralAuthoritiesAmount()
			throws ConnectionException, ElectoralOrganizationOperationException {
		try {
			return ecmElectoralOrganizationService
					.retrieveElectoralAuthoritiesAmount();
		} catch (ElectoralOrganizationOperationException e) {
			throw e;
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * Generate a parties information for test generation Data.
	 * 
	 * @param contest
	 *            - The contest in which the parties belong.
	 * 
	 * @param numbersParty
	 *            - number of parties to generate.
	 * 
	 * @return - The information of parties that have been created.
	 */
	public static List<DataTestGenerationDTO> generateDataForParties(
			ContestData contest, long numbersParty) {
		List<DataTestGenerationDTO> dataTestList = new ArrayList<DataTestGenerationDTO>();
		for (long indexParty = 1; indexParty <= numbersParty; indexParty++) {
			PartyData partyTest = generatePartyObject(contest, indexParty);

			EligibleOptionData eligibleOptiontest = generateEligibleOptionObject(
					contest, partyTest.getCustomCode(), null,
					partyTest.getName());

			BallotOptionData ballotOptionTest = generateBallotOptionObject(
					eligibleOptiontest, partyTest, null, indexParty);

			DataTestGenerationDTO dataTest = new DataTestGenerationDTO();
			dataTest.setParty(partyTest);
			dataTest.setBallotOption(ballotOptionTest);
			dataTest.setEligibleOption(eligibleOptiontest);
			dataTestList.add(dataTest);
		}
		return dataTestList;
	}

	/***
	 * Generate a candidate information for test generation Data.
	 * 
	 * @param contest
	 *            - The contest in which the candidates belong.
	 * @param dataTestList
	 *            - the parties list in which the candidates belong.
	 * @param numberOfCandidatesChief
	 *            - number of chief candidates that must be created
	 * @param numberOfCandidatesStandin
	 *            - number of standin candidates that must be created
	 * 
	 * @return - The information of candidates that have been created.
	 */
	public static List<DataTestGenerationDTO> generateDataForCandidates(
			ContestData contest,
			Collection<DataTestGenerationDTO> dataTestList,
			int numberOfCandidatesChief, int numberOfCandidatesStandin) {
		List<DataTestGenerationDTO> dataTestCandidateList = new ArrayList<DataTestGenerationDTO>();
		for (DataTestGenerationDTO index : dataTestList) {
			for (int i = 1; i <= numberOfCandidatesChief; i++) {
				DataTestGenerationDTO dataTestCandidate = generateDataCandidateByRol(
						contest, index, EligibleOptionRoleData.Role.CHIEF, i);
				dataTestCandidateList.add(dataTestCandidate);
			}
			for (int i = 1; i <= numberOfCandidatesStandin; i++) {
				DataTestGenerationDTO dataTestCandidate = generateDataCandidateByRol(
						contest, index, EligibleOptionRoleData.Role.STANDIN, i);
				dataTestCandidateList.add(dataTestCandidate);
			}
		}
		return dataTestCandidateList;
	}

	/**
	 * * Generate a party object for test generation Data.
	 * 
	 * @param contest
	 *            - The contest in which the party belong.
	 * @param indexParty
	 *            the index party
	 * @return - The party object generated.
	 */
	public static PartyData generatePartyObject(ContestData contest,
			long indexParty) {
		PartyData partyTest = new PartyData();
		partyTest.setCustomCode(contest.getCustomCode() + "_" + indexParty);
		partyTest.setType(PartyData.Type.PARTY);
		partyTest.setName(contest.getCustomCode() + " (" + indexParty + ")");
		partyTest.setAbbreviation("abbreviation");
		return partyTest;
	}

	/**
	 * * Generate a candidate information by rol for test generation Data.
	 * 
	 * @param contest
	 *            - The contest in which the candidates belong.
	 * @param partyInfo
	 *            -the party in which the candidate belong.
	 * @param role
	 *            -The rol of the candidate.
	 * @param indexCandidate
	 *            the index candidate
	 * @return -The information of candidate that has been created.
	 */
	public static DataTestGenerationDTO generateDataCandidateByRol(
			ContestData contest, DataTestGenerationDTO partyInfo,
			EligibleOptionRoleData.Role role, int indexCandidate) {
		CandidateData candidateTest = generateCandidateObject(
				partyInfo.getParty(), role, contest, indexCandidate);

		EligibleOptionData eligibleOptionTest = generateEligibleOptionObject(
				contest, candidateTest.getCustomCode(),
				partyInfo.getEligibleOption(), "firstName");

		EligibleOptionRoleData eligibleOptionRolTestByCandidate = generateEligibleOptionRolObject(
				eligibleOptionTest, candidateTest,
				/*** se debe agregar una secuencia indexRol ***/
				indexCandidate, role);

		EligibleOptionRoleData eligibleOptionRolTestByParty = generateEligibleOptionRolObject(
				partyInfo.getEligibleOption(), candidateTest,
				/*** se debe agregar una secuencia indexRol ***/
				indexCandidate, role);

		BallotOptionData balloOptionTest = generateBallotOptionObject(
				eligibleOptionTest, partyInfo.getParty(),
				partyInfo.getBallotOption(), /***
				 * 
				 * indexTallyPosition se debe
				 * generar una secuencia
				 ***/
				3);
		DataTestGenerationDTO dataTestCandidate = new DataTestGenerationDTO(
				candidateTest, balloOptionTest, eligibleOptionTest,
				eligibleOptionRolTestByCandidate, eligibleOptionRolTestByParty);
		return dataTestCandidate;
	}

	/**
	 * * Generate a candidate object for test generation Data.
	 * 
	 * @param party
	 *            the party
	 * @param rol
	 *            - candidate role.
	 * @param contest
	 *            -The contest in which the candidate belong.
	 * @param indexCandidate
	 *            the index candidate
	 * @return -The candidate object generated.
	 */
	private static CandidateData generateCandidateObject(PartyData party,
			EligibleOptionRoleData.Role rol, ContestData contest,
			int indexCandidate) {
		CandidateData candidateTest = new CandidateData();

		candidateTest.setCustomCode(party.getCustomCode() + "_"
				+ indexCandidate + rol);
		candidateTest.setIdentification(candidateTest.getCustomCode());
		return candidateTest;
	}

	/**
	 * Generate a Eligible Option Role object for test generation Data.
	 * 
	 * @param eligibleOptionTest
	 *            Eligible Option generated.
	 * @param candidateTest
	 *            Candidate generated.
	 * @param indexRol
	 *            Index Role.
	 * @param rol
	 *            Candidate Role
	 * @return the eligible option rol data
	 */
	private static EligibleOptionRoleData generateEligibleOptionRolObject(
			EligibleOptionData eligibleOptionTest, CandidateData candidateTest,
			long indexRol, EligibleOptionRoleData.Role rol) {
		EligibleOptionRoleData eligibleOptionRolTest = new EligibleOptionRoleData();
		eligibleOptionRolTest.setCustomCode(eligibleOptionTest.getCustomCode()
				+ candidateTest.getCustomCode());
		eligibleOptionRolTest.setCandidate(candidateTest);
		eligibleOptionRolTest.setEligibleOption(eligibleOptionTest);
		eligibleOptionRolTest.setOrder((int) indexRol);
		eligibleOptionRolTest.setRole(rol);
		return eligibleOptionRolTest;
	}

	/**
	 * Generate a Ballot Option for test generation Data.
	 * 
	 * @param eligibleOptionTest
	 *            Eligible Option test generated.
	 * @param partyTest
	 *            Party test generated.
	 * @param ballotOptionTestParent
	 *            Ballot Option test generated.
	 * @param indexTallyPosition
	 *            Tally position index.
	 * 
	 * @return Ballot Option object.
	 */
	private static BallotOptionData generateBallotOptionObject(
			EligibleOptionData eligibleOptionTest, PartyData partyTest,
			BallotOptionData ballotOptionTestParent, long indexTallyPosition) {

		BallotOptionData ballotOptionTest = new BallotOptionData();
		ballotOptionTest.setParty(partyTest);
		ballotOptionTest.setEligibleOption(eligibleOptionTest);
		ballotOptionTest.setCustomCode(eligibleOptionTest.getCustomCode());
		ballotOptionTest.setTallyPosition((int) indexTallyPosition);
		ballotOptionTest.setPadPosition(0);
		ballotOptionTest.setTabulationArrange(0);
		ballotOptionTest.setAutomatedArrange(0);
		ballotOptionTest.setManualArrange(0);
		ballotOptionTest.setType(BallotOptionData.Type.SCREEN);
		ballotOptionTest.setBallotOptionParent(ballotOptionTestParent);

		return ballotOptionTest;
	}

	/**
	 * Generate a Eligible Option object for test generation Data.
	 * 
	 * @param contest
	 *            Contest generated.
	 * @param customCode
	 *            Custom Code for Eligible Option.
	 * @param parent
	 *            Eligible Option Parent.
	 * @param ballotName
	 *            Ballot name.
	 * @return Eligible Option generated.
	 */
	private static EligibleOptionData generateEligibleOptionObject(
			ContestData contest, String customCode, EligibleOptionData parent,
			String ballotName) {
		EligibleOptionData eligibleOptiontest = new EligibleOptionData();
		eligibleOptiontest.setCustomCode(customCode);
		eligibleOptiontest.setContest(contest);
		eligibleOptiontest.setEligibleOptionParent(parent);
		eligibleOptiontest.setBallotName(ballotName);
		return eligibleOptiontest;
	}

	/**
	 * Method that return the server IP.
	 * 
	 * @return True if the database is working of false in otherwise.
	 * @throws BaseException
	 *             Abstract base class to notify the client that a problem
	 *             occurred
	 */
	public static String getServerIP() throws BaseException {
		try {
			return ecmService.getServerIP();
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}

	}

	/**
	 * Enable or disable the workflow buttons.
	 * 
	 * @param newStatus
	 *            true to block the buttons, false to unblock
	 */
	public static void setWorkflowButtonsEnabled(boolean newStatus) {
		ECMApp.getApplication().setWorkflowButtonsEnabled(newStatus);
	}

	/**
	 * Method that block tabs by functionality.
	 * 
	 * @param funcs
	 *            Functionality list
	 * @param block
	 *            Indicate if the tab will be locked or unlocked
	 */
	public static void blockOtherTabsByFunctionality(
			HashSet<FunctionalityDefinitionEnum> funcs, boolean block) {
		ECMApp.getApplication().blockOtherTabsByFunctionality(funcs, block);
	}

	/**
	 * Method to set tab focus.
	 * 
	 * @param func
	 *            Functionality to set focus
	 */
	public static void focusTab(FunctionalityDefinitionEnum func) {
		ECMApp.getApplication().focusTab(func);
	}

	/**
	 * * Get a list of regions by category.
	 * 
	 * @param categoryLevel
	 *            - The category level.
	 * @param codesOfRegionsAvailables
	 *            - List of region codes available to search.
	 * @param language
	 *            - Language used to translate the region name.
	 * @return - The region list.
	 * @throws XmlGenerationException
	 *             the xml generation exception
	 * @throws ConnectionException
	 *             the connection exception
	 */
	public static List<RegionData> getRegionsByCategoryLevel(
			CategoryData.Level categoryLevel,
			List<Long> codesOfRegionsAvailables, LanguageData language)
			throws XmlGenerationException,
			com.smartmatic.waffle.ecm.client.exception.ConnectionException {
		try {
			return ecmService.getRegionsByCategoryLevel(categoryLevel,
					codesOfRegionsAvailables, language);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * * Get the regions children by region.
	 * 
	 * @param parent
	 *            - The parent region.
	 * @param codesOfRegionsAvailables
	 *            -List of region codes available to search.
	 * @param language
	 *            -Language used to translate the region name.
	 * @return regions children.
	 * @throws XmlGenerationException
	 *             the xml generation exception
	 * @throws ConnectionException
	 *             the connection exception
	 */
	public static List<RegionData> getChildrenRegions(RegionData parent,
			List<Long> codesOfRegionsAvailables, LanguageData language)
			throws XmlGenerationException,
			com.smartmatic.waffle.ecm.client.exception.ConnectionException {
		try {
			return ecmService.getChildrenRegions(parent,
					codesOfRegionsAvailables, language);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Retrieves all the data of a specific user from the server. It uses an
	 * user id to determine which user data to retrieve.
	 * 
	 * @param user
	 *            Id of the user
	 * 
	 * @return User's data stored in the database as an hibernate object
	 * 
	 * @throws BaseException
	 *             Abstract base class to notify the client that a problem
	 *             occurred
	 */
	public static UserData getUserById(String user) throws BaseException {

		return ecmWorkflowService.getUserById(user);
	}

	/***
	 * Advance to the next node in the workflow. returns the current status of
	 * the node.
	 * 
	 * @return the current status of the node.
	 */
	public static ECMWorkflowStatus gotoNext() {

		synchronized (ECMServiceProvider.ecmWorkflowService) {

			return ecmWorkflowService.gotoNext();
		}
	}

	/***
	 * Rewinds to the last node executed.
	 */
	public static void goBack() {

		synchronized (ECMServiceProvider.ecmWorkflowService) {

			ecmWorkflowService.goBack();
		}
	}

	/**
	 * Increments one step the workflow and updates the database.
	 */
	public static void moveForward() {
		synchronized (ECMServiceProvider.ecmWorkflowService) {
			ecmWorkflowService.moveForward();
		}
	}

	/**
	 * Decrements one step the workflow and updates the database.
	 */
	public static void moveBackward() {
		synchronized (ECMServiceProvider.ecmWorkflowService) {
			ecmWorkflowService.moveBackward();
		}
	}

	/**
	 * Returns the name of the node that the workflow is.
	 * 
	 * @return Node name
	 */
	public static String getStepName() {

		synchronized (ECMServiceProvider.ecmWorkflowService) {

			return ecmWorkflowService.getActualNodeName();
		}
	}

	/***
	 * Method to get the current user logged into app.
	 * 
	 * @return the current user logged into app
	 */
	public static UserData getActualUser() {
		synchronized (ECMServiceProvider.ecmWorkflowService) {
			return ecmWorkflowService.getActualUser();
		}
	}

	/**
	 * Returns the value of the specific process instance's variable.
	 * 
	 * @param name
	 *            the name
	 * @return the variable value
	 */
	public static Object getWorkflowVariable(String name) {
		synchronized (ECMServiceProvider.ecmWorkflowService) {
			return ecmWorkflowService.getVariable(name);
		}
	}

	/***
	 * checks if admin user is already configured.
	 * 
	 * @return true if admin user is already configured otherwise returns false.
	 * @throws BaseException
	 *             -If there is an error
	 */
	public static boolean isAdminUserConfigured() throws BaseException {
		synchronized (ECMServiceProvider.ecmWorkflowService) {
			return ecmWorkflowService.isAdminUserConfigured();
		}
	}

	/**
	 * Updates user password.
	 * 
	 * @param user
	 * @param password
	 * @return
	 * @throws BaseException
	 */
	public static UserData updateUser(String user, String password)
			throws BaseException {
		synchronized (ECMServiceProvider.ecmWorkflowService) {
			return ecmWorkflowService.updateUser(user, password);
		}
	}

	/**
	 * Method to fill the language combinations table.
	 * 
	 * @throws BaseException
	 *             - The exception is thrown when there is an error executing
	 *             the post load process.
	 */
	public static void fillLanguageCombinations() throws Exception {
		try {
			ecmService.fillLanguageCombinations();
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Method to download ECM report from database to server file system.
	 * 
	 * @throws BaseException
	 *             The exception is thrown when there is an error executing the
	 *             post load process.
	 */
	public static void downloadECMReports() throws BaseException {
		try {
			ecmService.downloadECMReports();
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Method used to set the server date and time.
	 * 
	 * @param datePicked
	 *            The date to set.
	 * @param scriptPath
	 *            The path of the script
	 * @param machineDate
	 *            The command to execute
	 * @throws BaseException
	 *             The exception is thrown when there is an error executing the
	 *             post load process.
	 */
	public static void setServerDateTime(Date datePicked, String scriptPath,
			String machineDate) throws BaseException {
		try {
			ecmService.setServerDateTime(datePicked, scriptPath, machineDate);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Gets the server date time.
	 * 
	 * @param scriptPath
	 *            the script path
	 * @param machineDateTime
	 *            the machine date time
	 * @return the server date time
	 * @throws BaseException
	 *             The exception is thrown when there is an error executing the
	 *             post load process.
	 */
	public static String getServerDateTime(String scriptPath,
			String machineDateTime) throws BaseException {
		try {
			return ecmService.getServerDateTime(scriptPath, machineDateTime);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Gets log files from the server into a hashMap.
	 * 
	 * @return A HashMap with the inputStreams
	 * @throws IOException
	 *             signals that an I/O exception of some sort has occurred.
	 */
	public static Map<String, byte[]> getLogFiles() throws IOException {
		return ecmService.getLogFiles();
	}

	/**
	 * Method used to get a string property from config.properties.
	 * 
	 * @param key
	 *            The key of the property to search.
	 * 
	 * @return The string value of the property with key:<code>key</code>
	 */
	public static String getECMProperty(String key) {
		try {
			return ecmUtilitiesService.getECMProperty(key);
		} catch (CannotConnectException e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new RuntimeException(
					StringUtils.defaultString(e.getMessage()), e);
		} catch (EJBTransactionRolledbackException e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new RuntimeException(
					StringUtils.defaultString(e.getMessage()), e);
		}
	}

	/**
	 * Gets the voice_files from the server into a byte array.
	 * 
	 * @return The inputStreams
	 * @throws ConnectionException
	 * @throws UtilitiesException
	 * @throws IOException
	 *             signals that an I/O exception of some sort has occurred.
	 */
	public static byte[] getVoiceFiles() throws ConnectionException,
			UtilitiesException {
		try {
			return ecmUtilitiesService.getVoiceFiles();
		} catch (CannotConnectException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSED,
					StringUtils.defaultString(e.getMessage()));
		} catch (EJBTransactionRolledbackException e) {
			throw new ConnectionException(
					e,
					ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					StringUtils.defaultString(e.getMessage()));
		}
	}

	/**
	 * * Get the regions parents by region.
	 * 
	 * @param child
	 *            - The child region.
	 * @return region with parents.
	 * @throws XmlGenerationException
	 *             the xml generation exception
	 * @throws ConnectionException
	 *             the connection exception
	 */
	public static RegionData getParentRegions(RegionData child)
			throws XmlGenerationException,
			com.smartmatic.waffle.ecm.client.exception.ConnectionException {
		try {
			return ecmDemographyService.getAllRegionParentsWithDistricts(child);
		} catch (CannotConnectException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_REFUSE,
					e);
		} catch (EJBTransactionRolledbackException e) {
			throw new com.smartmatic.waffle.ecm.client.exception.ConnectionException(
					com.smartmatic.waffle.ecm.client.exception.ConnectionException.ConnectionExceptionInfo.CONNECTION_TIME_OUT,
					e);
		}
	}

	/**
	 * Validate that the language of the regions with audio voting enabled is
	 * configured correctly.
	 */
	public static void checkConfiguredRegionLaguages()
			throws BulkDataLoadException {
		ecmBulkDataLoadService.checkConfiguredRegionLaguages();
	}


    /**
     * Retrieves from the persistence layer any persisted device parameter.
     *
     * @return
     *      {@code List<}DeviceParameterData>} (never {@code null})
     */
    public static List<DeviceParameterData> retrieveDeviceParameters() {
        return ecmService.retrieveDeviceParameters();
    }


    /**
     * Truncates and deletes the content of the table: {@code device_parameter}.
     */
    public static void truncateDeviceParametersTable()
    throws BulkDataLoadException {
        ecmUtilitiesService.truncateDeviceParametersTable();
    }
}
