/**
 * ECMConnectionDataBaseCheckListener.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.core.monitoring;

import javax.swing.SwingUtilities;

import com.smartmatic.waffle.ecm.client.ECMApp;
import com.smartmatic.waffle.ecm.core.monitoring.spec.IConnectionCheckListener;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * The listener interface for receiving ECMConnectionDataBaseCheck events. The
 * class that is interested in processing a ECMConnectionDataBaseCheck event
 * implements this interface, and the object created with that class is
 * registered with a component using the component's
 * <code>addECMConnectionDataBaseCheckListener<code> method. When
 * the ECMConnectionDataBaseCheck event occurs, that object's appropriate
 * method is invoked.
 * 
 * @see ECMConnectionDataBaseCheckEvent
 */
public class ECMConnectionDataBaseCheckListener implements
		IConnectionCheckListener {

	/**
	 * Field used for logging purpose.
	 */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(ECMConnectionDataBaseCheckListener.class);

	/**
	 * {@inheritDoc} <br>
	 * No implemented yet.
	 */
	@Override
	public void hostConnected() {
		ECMApp.getApplication().hideResourceDisconnectedScreen(
				MonitoringResourceType.DATABASE);
	}

	/**
	 * {@inheritDoc}<br>
	 * This implementation shows a blocking pop-up to indicate there is a
	 * problem with connection to the database server
	 */
	@Override
	public void hostDisconnected() {

		logger.info("Data Base Server disconnected");

		SwingUtilities.invokeLater(new Runnable() {

			@Override
			public void run() {
				ECMApp.getApplication().showResourceDisconnectedScreen(
						MonitoringResourceType.DATABASE,
						"fatal.connectiondb.failure.message");
			}
		});
	}

}
