/**
 * CloseButtonActionListener.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.func;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;

import org.jdesktop.application.ResourceMap;

import com.smartmatic.waffle.ecm.client.ECMApp;
import com.smartmatic.waffle.ecm.ui.core.i18n.controller.LanguageController;
import com.smartmatic.waffle.ecm.ui.util.ECMOptionPane;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Provides the action to be performed when the logout confirmation message is
 * accepted.
 * 
 * @see CloseButtonActionEvent
 */

public class CloseButtonActionListener implements ActionListener {

	/***
	 * Object for logger purpose.
	 */
	private SMTTLogger logger = SMTTLogger
			.getLogger(CloseButtonActionListener.class);

	/** The resource message bundle. */
	private ResourceMap resourceMap = LanguageController.getInstance()
			.getApplicationContext().getResourceMap();

	/** * Reference to the main class of the ECM application. */
	private ECMApp ecm;

	/**
	 * * Class constructor.
	 */
	public CloseButtonActionListener() {
		this.ecm = null;
	}

	/***
	 * Class constructor.
	 * 
	 * @param ecmapp
	 *            -Reference to the main class of the ECM application
	 */
	public CloseButtonActionListener(ECMApp ecmapp) {
		this.ecm = ecmapp;
	}

	/**
	 * {@inheritDoc}<br>
	 * This implementation shows a popup message to ask if the user want close
	 * the app, and close the app if necessary
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		Component parent = ECMApp.getApplication().getMainFrame();
		if (e.getSource() instanceof JButton) {

			JButton button = (JButton) e.getSource();
			if (button.getParent() != null
					&& button.getParent().getParent() != null
					&& button.getParent().getParent().getParent() != null) {
				parent = button.getParent();
				parent = button.getParent().getParent().getParent();
			}
		}

		int option = ECMOptionPane.showConfirmDialog(parent, this.resourceMap
				.getString("workflow.leave.app.question.text"),
				this.resourceMap
						.getString("workflow.leave.app.question_title.text"),
				ECMOptionPane.YES_NO_OPTION, ECMOptionPane.CONFIRM_DIALOG);

		if (option == ECMOptionPane.YES_OPTION) {
			if (this.ecm == null) {
				System.exit(0);
			} else {
				this.ecm.restartUI();
			}
		} else {
			return;
		}
	}
}