/**
 * BulkUploadClearDatabaseController.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener;
import com.smartmatic.waffle.ecm.client.worker.BulkUploadClearDatabaseWorker;
import com.smartmatic.waffle.ecm.ui.util.ECMOptionPane;

/**
 * Controller class that creates and starts the worker thread to execute the
 * database data removal
 */
public class BulkUploadClearDatabaseController implements IAwtOperationListener {

	/**
	 * Instantiates a new BulkUploadClearDatabaseController
	 * 
	 * @param bulkUploadAbstractPanel
	 *            bulkUploadAbstractPanel instance
	 */
	public BulkUploadClearDatabaseController(
			BulkUploadAbstractPanel bulkUploadAbstractPanel,
			boolean deleteOnlyCodiData) {
		this.bulkUploadAbstractPanel = bulkUploadAbstractPanel;
		this.deleteOnlyCodiData = deleteOnlyCodiData;
	}

	/**
	 * Method that starts the worker that does the real backend functionality
	 * work.
	 */
	public void startWorker() {

		this.bulkUploadClearDatabaseWorker = new BulkUploadClearDatabaseWorker(
				this.deleteOnlyCodiData);

		this.bulkUploadClearDatabaseWorker.addListener(this);

		Thread bulkUploadClearDatabaseThread = new Thread(
				this.bulkUploadClearDatabaseWorker,
				"bulkUploadClearDatabaseThread");

		bulkUploadClearDatabaseThread.start();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener#awtOperation
	 * (com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType)
	 */
	@Override
	public void awtOperation(AwtOperationType awtOperationType) {

		switch (awtOperationType) {

		case REFRESH_LABEL:

			if (this.bulkUploadClearDatabaseWorker.getProgressMessage().equals(
					StringUtils.EMPTY)) {
				this.bulkUploadAbstractPanel
						.updateStatusMessage(StringUtils.EMPTY);
			} else {
				this.bulkUploadAbstractPanel
						.updateStatusMessage("BulkUploadSmttFilesPanel.message.delete."
								+ this.bulkUploadClearDatabaseWorker
										.getProgressMessage());
			}

			break;

		case UPDATE_PROGRESS_BAR: {

			this.bulkUploadAbstractPanel
					.updateProgressBar(this.bulkUploadClearDatabaseWorker
							.getProgressValue());
		}
			break;

		case SHOW_RESULT_MESSAGE: {

			this.bulkUploadAbstractPanel.showMessage(
					"BulkUploadSmttFilesPanel.message.clean.database.success",
					ECMOptionPane.INFORMATION_MESSAGE);

			this.bulkUploadAbstractPanel.setProgressBarMaximumValue(100);

			this.bulkUploadAbstractPanel.finishDatabaseClearingProcess(false);
		}
			break;

		case SHOW_ERROR_MESSAGE: {

			this.bulkUploadAbstractPanel.showMessage(
					"BulkUploadSmttFilesPanel.message.clean.database.error",
					ECMOptionPane.ERROR_MESSAGE);

			this.bulkUploadAbstractPanel.setProgressBarMaximumValue(100);

			this.bulkUploadAbstractPanel.finishDatabaseClearingProcess(true);
		}
			break;

		default: {
			this.bulkUploadAbstractPanel
					.setProgressBarMaximumValue(this.bulkUploadClearDatabaseWorker
							.getNumberOfTruncateProcess());
		}
			break;
		}

	}

	/** The instance of BulkUploadClearDatabaseWorker. */
	private BulkUploadClearDatabaseWorker bulkUploadClearDatabaseWorker;

	/** The instance of BulkUploadAbstractPanel. */
	private BulkUploadAbstractPanel bulkUploadAbstractPanel;

	/**
	 * Variable to hold with data will be removed
	 */
	private boolean deleteOnlyCodiData;
}
