/**
 * BulkUploadDownloadTraslationsTemplateController.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import java.io.File;

import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener;
import com.smartmatic.waffle.ecm.client.worker.BulkUploadDownloadTranslationsTemplateWorker;
import com.smartmatic.waffle.ecm.ui.util.ECMOptionPane;

/**
 * Controller class that creates and starts the worker thread to download the
 * translation template file
 */
public class BulkUploadDownloadTranslationsTemplateController implements
		IAwtOperationListener {

	/**
	 * Instantiates a new BulkUploadDownloadTranslationsTemplateController
	 * 
	 * @param bulkUploadSmttFilesPanel
	 *            BulkUploadSmttFilesPanel reference
	 * @param fileSelected
	 *            the file selected to save the template
	 */
	public BulkUploadDownloadTranslationsTemplateController(
			BulkUploadSmttFilesPanel bulkUploadSmttFilesPanel, File fileSelected) {
		this.bulkUploadSmttFilesPanel = bulkUploadSmttFilesPanel;
		this.fileToExportFile = fileSelected;
	}

	/**
	 * Validates the file permissions
	 */
	public void startDownloadProcess() {

		if (validateFolderPermission()) {
			startWorker();
		} else {
			this.bulkUploadSmttFilesPanel
					.showMessage(
							"BulkUploadSmttFilesPanel.generate.translations.message.permission.error",
							ECMOptionPane.ERROR_MESSAGE);
			this.bulkUploadSmttFilesPanel
					.finishTranslationsFileDownloadProcess();
		}

	}

	/**
	 * Method that starts the worker that does the real backend functionality
	 * work.
	 */
	public void startWorker() {
		this.bulkUploadDownloadTraslationsTemplateWorker = new BulkUploadDownloadTranslationsTemplateWorker(
				this.fileToExportFile);

		this.bulkUploadDownloadTraslationsTemplateWorker.addListener(this);

		Thread bulkUploadDownloadTranslationsTemplateThread = new Thread(
				this.bulkUploadDownloadTraslationsTemplateWorker,
				"bulkUploadDownloadTraslationsTemplateThread");

		bulkUploadDownloadTranslationsTemplateThread.start();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener#awtOperation
	 * (com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType)
	 */
	@Override
	public void awtOperation(AwtOperationType awtOperationType) {
		switch (awtOperationType) {

		case UPDATE_COMPONENTS:
			this.bulkUploadSmttFilesPanel
					.setProgressBarMaximum(this.bulkUploadDownloadTraslationsTemplateWorker
							.getMultilingualKeysPagesAmount());
			break;

		case UPDATE_PROGRESS_BAR:
			this.bulkUploadSmttFilesPanel
					.updateProgressBar(this.bulkUploadDownloadTraslationsTemplateWorker
							.getProcessedElements());
			break;

		case SHOW_RESULT_MESSAGE: {
			this.bulkUploadSmttFilesPanel
					.showMessage(
							"BulkUploadSmttFilesPanel.generate.translations.message.success",
							ECMOptionPane.INFORMATION_MESSAGE);

			this.bulkUploadSmttFilesPanel
					.finishTranslationsFileDownloadProcess();
		}

			break;

		case SHOW_ERROR_MESSAGE: {
			this.bulkUploadSmttFilesPanel
					.showMessage(
							"BulkUploadSmttFilesPanel.generate.translations.message.error",
							ECMOptionPane.ERROR_MESSAGE);

			this.bulkUploadSmttFilesPanel
					.finishTranslationsFileDownloadProcess();
		}
			break;

		}
	}

	/**
	 * Validates the folder permission.
	 * 
	 * @return true, if the folder selected has write permissions
	 */
	private boolean validateFolderPermission() {
		if (this.fileToExportFile.getParentFile().canWrite()) {
			return true;
		} else {
			return false;
		}
	}

	/** The file to export the template file. */
	private File fileToExportFile;

	/** BulkUploadSmttFilesPanel instance. */
	private BulkUploadSmttFilesPanel bulkUploadSmttFilesPanel;

	/** BulkUploadDownloadTranslationsTemplateWorker instance. */
	private BulkUploadDownloadTranslationsTemplateWorker bulkUploadDownloadTraslationsTemplateWorker;

}
