/**
 * BulkUploadFileFilter.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import java.io.File;

import javax.swing.filechooser.FileFilter;

import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.ecm.client.ECMClientSideConstants;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Class to define the filter used to select files to execute bulk upload.
 */
public class BulkUploadFileFilter extends FileFilter {

	/**
	 * Constant to hold the maximum length in bytes allowed for bulk data
	 * uploaded files.
	 */
	private static final long MAX_LENGTH_ALLOWED = ECMClientSideConstants.MAX_LENGTH_ALLOWED_FOR_FILES_TO_UPLOAD;

	/** The logger. */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(BulkUploadFileFilter.class);

	/**
	 * Object to define filters types
	 */
	enum FilterType {
		FILES_TO_UPLOAD, VALIDATION_CERTIFICATE;
	}

	/**
	 * Defines the filter type to do
	 */
	private FilterType filterType;

	/**
	 * Filter description for the File chooser GUI component.
	 */
	private String filterDescription;

	/**
	 * Instantiates a new BulkUploadFileFilter
	 * 
	 * @param filterDescription
	 *            the filter description
	 * @param filterType
	 *            the filter type
	 */
	public BulkUploadFileFilter(String filterDescription, FilterType filterType) {
		this.filterDescription = filterDescription;
		this.filterType = filterType;

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.filechooser.FileFilter#accept(java.io.File)
	 */
	@Override
	public boolean accept(File consideredFile) {
		try {

			if (consideredFile.isDirectory()) {
				return true;
			}

			boolean fileSize = consideredFile.length() <= MAX_LENGTH_ALLOWED;

			boolean fileExt = false;

			if (!consideredFile.getName().isEmpty()) {
				String[] exts = StringUtils
						.split(consideredFile.getName(), '.');
				String ext = exts[exts.length - 1].toLowerCase();
				switch (this.filterType) {
				case FILES_TO_UPLOAD:
					if (ext.length() == 2 || ext.equals("txt")
							|| ext.equals("csv") || ext.equals("zip")
							|| ext.equals("eml")) {
						fileExt = true;
					} else {
						fileExt = false;
					}
					break;

				case VALIDATION_CERTIFICATE:
					if (ext.equals("crt")) {
						fileExt = true;
					} else {
						fileExt = false;
					}
					break;
				}
			}

			return fileSize && fileExt;

		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.filechooser.FileFilter#getDescription()
	 */
	@Override
	public String getDescription() {
		return this.filterDescription;
	}

}
