/**
 * CodiFormatterDetailPanel.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Map;
import java.util.ResourceBundle;

import javax.swing.JDialog;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;

import org.apache.commons.io.FileUtils;

import com.smartmatic.waffle.localpersistence.SAESCommonDestinations;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Front-End for CODI Format functionality.
 */
public class CodiFormatterDetailPanel extends javax.swing.JPanel {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 5943688814950085162L;

	/** The logger. */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(CodiFormatterDetailPanel.class);

	/** The parent of this container. */
	JDialog parent;

	/**
	 * Language bundle. Resource bundle for languages
	 */
	static ResourceBundle languageBundle = ResourceBundle
			.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp");

	/**
	 * Creates new form CodiFormatterDetailPanel.
	 * 
	 * @param _parent
	 *            the _parent
	 */
	public CodiFormatterDetailPanel(JDialog _parent) {
		initComponents();
		this.parent = _parent;
		this.formatResultsTree
				.setModel(new DefaultTreeModel(
						new DefaultMutableTreeNode(
								languageBundle
										.getString("CodiFormatterDetailPanel.processing_codi.message"))));
	}

	/**
	 * Paints the error Tree.
	 * 
	 * @param currentErrorMap
	 *            , the map with the content
	 */
	public void paintErrorsTree(Map<File, List<String>> currentErrorMap) {
		DefaultMutableTreeNode root = new DefaultMutableTreeNode(
				languageBundle.getString("CodiFormatterDetailPanel.root_title"));
		DefaultTreeModel model = new DefaultTreeModel(root);
		this.formatResultsTree.setModel(model);
		DefaultMutableTreeNode error = null, subError = null;
		StringBuilder lines = new StringBuilder();
		/* Fill the list of files */
		InputStream fileInputStream = null;
		try {
			int fileCount = 0;
			for (File codiFile : currentErrorMap.keySet()) {
				fileInputStream = new FileInputStream(codiFile);
				String fileInfo = codiFile.getName()
						+ " - SHA-256: "
						+ org.apache.commons.codec.digest.DigestUtils
								.sha256Hex(fileInputStream);
				lines.append(fileInfo + System.getProperty("line.separator"));
				error = new DefaultMutableTreeNode(fileInfo);

				model.insertNodeInto(error, root, fileCount++);

				/* Fill the errors of the file */
				int subFileCount = 0;
				for (String errorLine : currentErrorMap.get(codiFile)) {
					lines.append(errorLine
							+ System.getProperty("line.separator"));
					subError = new DefaultMutableTreeNode(errorLine);
					model.insertNodeInto(subError, error, subFileCount++);
				}
			}
		} catch (FileNotFoundException e) {
			logger.error(e, e.getMessage());
		} catch (IOException e) {
			logger.error(e, e.getMessage());
		} finally {
			if (fileInputStream != null) {
				try {
					fileInputStream.close();
				} catch (IOException e) {
					logger.error(e, e.getMessage());
				}
			}
		}
		try {
			File fileOFResult = new File(
					SAESCommonDestinations.getInstance().confDir, "result.txt");
			FileUtils.writeStringToFile(fileOFResult, lines.toString());
			logger.info("an file with the result is in: "
					+ fileOFResult.getAbsolutePath());
		} catch (Exception e) {
			logger.error(e, "there is an error saving the result file");
		}
		this.formatResultsTree.expandRow(0);
	}

	/**
	 * Set the default 'no errors were found' state to the errors Tree.
	 */
	public void paintNoErrorsInTheTree() {
		this.formatResultsTree
				.setModel(new DefaultTreeModel(
						new DefaultMutableTreeNode(
								languageBundle
										.getString("CodiFormatterDetailPanel.no_files_in_error"))));
	}

	/**
	 * Set the progress bar value.
	 * 
	 * @param value
	 *            , the value to be set
	 */
	public synchronized void setProgressBarValue(int value) {
		this.validationProgressBar.setValue(value);
		this.validationProgressBar.setString(String.valueOf(value) + "%");
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	@SuppressWarnings("unchecked")
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// desc="Generated Code">//GEN-BEGIN:initComponents
	private void initComponents() {

		this.mainPanel = new javax.swing.JPanel();
		this.jScrollPane1 = new javax.swing.JScrollPane();
		this.formatResultsTree = new javax.swing.JTree();
		this.closeButton = new javax.swing.JButton();
		this.validationProgressBar = new javax.swing.JProgressBar();
		this.informationTitle = new javax.swing.JLabel();

		setMaximumSize(new java.awt.Dimension(800, 600));
		setMinimumSize(new java.awt.Dimension(800, 600));

		this.mainPanel
				.setBorder(javax.swing.BorderFactory.createEtchedBorder());
		this.mainPanel.setName("mainPanel"); // NOI18N

		this.jScrollPane1.setName("jScrollPane1"); // NOI18N

		this.formatResultsTree.setName("formatResultsTree"); // NOI18N
		this.jScrollPane1.setViewportView(this.formatResultsTree);

		java.util.ResourceBundle bundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp"); // NOI18N
		this.closeButton.setText(bundle
				.getString("CodiFormatterDetailPanel.closeButton.text")); // NOI18N
		this.closeButton.setName("closeButton"); // NOI18N
		this.closeButton.addActionListener(new java.awt.event.ActionListener() {
			@Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				closeButtonActionPerformed(evt);
			}
		});

		this.validationProgressBar.setName("validationProgressBar"); // NOI18N
		this.validationProgressBar.setStringPainted(true);

		javax.swing.GroupLayout mainPanelLayout = new javax.swing.GroupLayout(
				this.mainPanel);
		this.mainPanel.setLayout(mainPanelLayout);
		mainPanelLayout
				.setHorizontalGroup(mainPanelLayout
						.createParallelGroup(
								javax.swing.GroupLayout.Alignment.LEADING)
						.addGroup(
								mainPanelLayout
										.createSequentialGroup()
										.addGroup(
												mainPanelLayout
														.createParallelGroup(
																javax.swing.GroupLayout.Alignment.LEADING)
														.addGroup(
																mainPanelLayout
																		.createSequentialGroup()
																		.addContainerGap()
																		.addComponent(
																				this.jScrollPane1,
																				javax.swing.GroupLayout.DEFAULT_SIZE,
																				748,
																				Short.MAX_VALUE))
														.addGroup(
																mainPanelLayout
																		.createSequentialGroup()
																		.addGap(226,
																				226,
																				226)
																		.addComponent(
																				this.closeButton,
																				javax.swing.GroupLayout.PREFERRED_SIZE,
																				297,
																				javax.swing.GroupLayout.PREFERRED_SIZE))
														.addGroup(
																mainPanelLayout
																		.createSequentialGroup()
																		.addContainerGap()
																		.addComponent(
																				this.validationProgressBar,
																				javax.swing.GroupLayout.DEFAULT_SIZE,
																				748,
																				Short.MAX_VALUE)))
										.addContainerGap()));
		mainPanelLayout
				.setVerticalGroup(mainPanelLayout
						.createParallelGroup(
								javax.swing.GroupLayout.Alignment.LEADING)
						.addGroup(
								mainPanelLayout
										.createSequentialGroup()
										.addContainerGap()
										.addComponent(
												this.jScrollPane1,
												javax.swing.GroupLayout.PREFERRED_SIZE,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												javax.swing.GroupLayout.PREFERRED_SIZE)
										.addPreferredGap(
												javax.swing.LayoutStyle.ComponentPlacement.RELATED)
										.addComponent(
												this.validationProgressBar,
												javax.swing.GroupLayout.PREFERRED_SIZE,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												javax.swing.GroupLayout.PREFERRED_SIZE)
										.addPreferredGap(
												javax.swing.LayoutStyle.ComponentPlacement.RELATED,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												Short.MAX_VALUE)
										.addComponent(this.closeButton)
										.addContainerGap()));

		this.informationTitle
				.setIcon(new javax.swing.ImageIcon(
						getClass()
								.getResource(
										"/com/smartmatic/waffle/ecm/client/resources/cancel.png"))); // NOI18N
		this.informationTitle.setText(bundle
				.getString("CodiFormatterDetailPanel.informationTitle.text")); // NOI18N
		this.informationTitle.setName("informationTitle"); // NOI18N

		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
		this.setLayout(layout);
		layout.setHorizontalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						layout.createSequentialGroup()
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.LEADING)
												.addGroup(
														layout.createSequentialGroup()
																.addGap(38, 38,
																		38)
																.addComponent(
																		this.informationTitle,
																		javax.swing.GroupLayout.PREFERRED_SIZE,
																		726,
																		javax.swing.GroupLayout.PREFERRED_SIZE))
												.addGroup(
														layout.createSequentialGroup()
																.addContainerGap()
																.addComponent(
																		this.mainPanel,
																		javax.swing.GroupLayout.DEFAULT_SIZE,
																		javax.swing.GroupLayout.DEFAULT_SIZE,
																		Short.MAX_VALUE)))
								.addContainerGap()));
		layout.setVerticalGroup(layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGroup(
				javax.swing.GroupLayout.Alignment.TRAILING,
				layout.createSequentialGroup()
						.addContainerGap()
						.addComponent(this.informationTitle,
								javax.swing.GroupLayout.DEFAULT_SIZE,
								javax.swing.GroupLayout.DEFAULT_SIZE,
								Short.MAX_VALUE)
						.addGap(18, 18, 18)
						.addComponent(this.mainPanel,
								javax.swing.GroupLayout.PREFERRED_SIZE,
								javax.swing.GroupLayout.DEFAULT_SIZE,
								javax.swing.GroupLayout.PREFERRED_SIZE)
						.addGap(16, 16, 16)));
	}// </editor-fold>//GEN-END:initComponents

	/**
	 * Close button action performed.
	 * 
	 * @param evt
	 *            the evt
	 */
	private void closeButtonActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_closeButtonActionPerformed
		this.setVisible(false);
		this.parent.setVisible(false);
	}// GEN-LAST:event_closeButtonActionPerformed

	// Variables declaration - do not modify//GEN-BEGIN:variables
	/** The close button. */
	private javax.swing.JButton closeButton;

	/** The format results tree. */
	private javax.swing.JTree formatResultsTree;

	/** The information title. */
	private javax.swing.JLabel informationTitle;

	/** The j scroll pane1. */
	private javax.swing.JScrollPane jScrollPane1;

	/** The main panel. */
	private javax.swing.JPanel mainPanel;

	/** The validation progress bar. */
	private javax.swing.JProgressBar validationProgressBar;
	// End of variables declaration//GEN-END:variables

}
