/**
 * EligibleOptionCandidateEditorDialog.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.ecm.client.ui;

import java.awt.Component;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.util.Calendar;
import java.util.ResourceBundle;

import javax.swing.GroupLayout.Alignment;
import javax.swing.JDialog;

import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.domain.ballot.BallotOptionData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionData;
import com.smartmatic.waffle.ecm.client.ECMClientSideConstants;
import com.smartmatic.waffle.ecm.client.ui.controller.EligibleOptionEditorLogger;
import com.smartmatic.waffle.ecm.ui.util.ECMOptionPane;
import com.smartmatic.waffle.ecm.ui.util.UnicodeTextField;

/**
 * The Class is used to load and draw the components for Eligible Option Editor
 * Dialog.
 */
public class EligibleOptionCandidateEditorDialog extends javax.swing.JPanel {

	/**
	 * Creates new form EligibleOptionCandidateEditorDialog.
	 * 
	 * @param eligibleOptionToEdit
	 *            the eligibleOptionToEdit the eligible option object to edit
	 * @param eligibleOptionEditorPanel
	 *            the eligible options main panel
	 * @param rowToEdit
	 *            the row to edit
	 */
	public EligibleOptionCandidateEditorDialog(
			EligibleOptionData eligibleOptionToEdit,
			EligibleOptionEditorPanel eligibleOptionEditorPanel, int rowToEdit) {
		this.eligibleOptionToEdit = eligibleOptionToEdit;
		this.eligibleOptionEditorPanel = eligibleOptionEditorPanel;
		this.rowToEdit = rowToEdit;

		this.resourceBundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp"); // NOI18N

		initComponents();
	}

	/**
	 * Method to return the eligible option object to edit.
	 * 
	 * @return the eligible option object.
	 */
	public EligibleOptionData getEligibleOption() {
		return this.eligibleOptionToEdit;
	}

	/**
	 * Gets the ballot option name to be saved in DB from the values in the
	 * form.
	 * 
	 * @return the ballot option name
	 */
	public String buildBallotOptionName() {

		String emptyFieldValue = (ECMClientSideConstants.ADD_SPACE_TO_CANDIDATE_NAME_EMPTY_FIELDS) ? " "
				: StringUtils.EMPTY;

		String ballotOptionName = StringUtils.EMPTY;

		if (this.lastNameTextField.getText().isEmpty()
				&& this.nameTextField.getText().isEmpty()) {
			return null;
		}

		if (!this.lastNameTextField.getText().equals(StringUtils.EMPTY)) {
			ballotOptionName = this.lastNameTextField.getText();
		} else {
			ballotOptionName = ballotOptionName + emptyFieldValue;
		}

		ballotOptionName = ballotOptionName + "#";

		if (!this.nameTextField.getText().equals(StringUtils.EMPTY)) {
			ballotOptionName = ballotOptionName
					+ this.nameTextField.getText().trim();
		} else {
			ballotOptionName = ballotOptionName + emptyFieldValue;
		}

		ballotOptionName = ballotOptionName + "#";

		if (!this.initialTextField.getText().equals(StringUtils.EMPTY)) {
			ballotOptionName = ballotOptionName
					+ this.initialTextField.getText().trim();
		} else {
			ballotOptionName = ballotOptionName + emptyFieldValue;
		}

		return ballotOptionName;
	}

	/**
	 * Updates the eligible option.
	 * 
	 * @param row
	 *            the row
	 * @param eligibleOptionToEdit
	 *            the eligibleOptionToEdit
	 * @param ballotName
	 *            the ballot name
	 */
	public void updateEligibleOption(int row,
			EligibleOptionData eligibleOptionToEdit, String ballotName) {

		String oldBallotName = eligibleOptionToEdit.getBallotName();

		eligibleOptionToEdit.setBallotName(ballotName);

		UpdateEligibleOptionController updateEligibleOptionController = new UpdateEligibleOptionController(
				this);
		updateEligibleOptionController.startWorker();

		EligibleOptionEditorLogger.printMessageTologger(System
				.getProperty("line.separator")
				+ "Updating candidate name"
				+ System.getProperty("line.separator")

				+ "ID: "
				+ eligibleOptionToEdit.getCustomCode()
				+ System.getProperty("line.separator")
				+ "Old value: "
				+ oldBallotName.replace("#", " ")
				+ System.getProperty("line.separator")

				+ "New value: "
				+ ballotName.replace("#", " ")
				+ System.getProperty("line.separator")

				+ "Updating date: " + Calendar.getInstance().getTime());

		this.eligibleOptionEditorPanel.updateRow(row, eligibleOptionToEdit,
				true);
	}

	/**
	 * Shows an error message to the user.
	 */
	public void showErrorMessage() {
		ECMOptionPane
				.showMessageDialog(
						this,
						this.resourceBundle
								.getString("EligibleOptionEditorPanel.updateEligibleOption.error.message"),
						this.resourceBundle.getString("ErrorMessage.title"),
						ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);
	}

	/**
	 * Initialize the dialog fields.
	 */
	private void initValues() {
		BallotOptionData ballotOptionData = (BallotOptionData) this.eligibleOptionToEdit
				.getBallotOptions().toArray()[0];

		this.contestLabel.setText("<html>"
				+ this.eligibleOptionToEdit.getContest().getName() + "</html>");

		this.partyLabel.setText("<html>" + ballotOptionData.getPartyName()
				+ "</html>");

		this.tallyPositionLabel.setText("<html><br/>"
				+ ballotOptionData.getTallyPosition() + "</html>");

		String[] options = this.eligibleOptionToEdit.getBallotName().split("#");

		if (options.length > 1 && options[1] != null) {
			this.nameTextField.setText(options[1].trim());
		} else {
			this.nameTextField.setText(StringUtils.EMPTY);
		}

		if (options.length > 0 && options[0] != null) {
			this.lastNameTextField.setText(options[0].trim());
		} else {
			this.lastNameTextField.setText(StringUtils.EMPTY);
		}

		if (options.length > 2 && options[2] != null) {
			this.initialTextField.setText(options[2].trim());
		} else {
			this.initialTextField.setText(StringUtils.EMPTY);
		}

		this.candidateActualNameLabel.setText("<html>"
				+ this.nameTextField.getText() + " "
				+ this.lastNameTextField.getText() + " "
				+ this.initialTextField.getText() + "</html>");
	}

	/**
	 * Enable/Disable the update button.
	 * 
	 * @param enable
	 *            true to enable or false to disable
	 */
	private void enableUpdateButton(boolean enabled) {
		this.updateButton.setEnabled(enabled);
	}

	/**
	 * Updates the eligible option according to the user selection.
	 */
	private void updateCandidateActionPerformed() {
		int op = ECMOptionPane.CANCEL_OPTION;
		if (buildBallotOptionName() == null) {
			ECMOptionPane
					.showMessageDialog(
							this,
							this.resourceBundle
									.getString("EligibleOptionEditorPanel.updateEligibleOption.candidate.empty.message"),
							this.resourceBundle.getString("ErrorMessage.title"),
							ECMOptionPane.ERROR_MESSAGE,
							ECMOptionPane.ERROR_DIALOG);
		} else {

			op = ECMOptionPane
					.showConfirmDialog(
							this,
							this.resourceBundle
									.getString("EligibleOptionCandidateEditorDialog.updateConfirmationDialog.message"),
							this.resourceBundle
									.getString("ConfirmationMessage.title"),
							ECMOptionPane.YES_NO_OPTION,
							ECMOptionPane.CONFIRM_DIALOG);

			Component parent = this.getParent();
			while (!parent.getClass().equals(JDialog.class)) {
				parent = parent.getParent();
			}

			parent.setVisible(false);

			if (op == ECMOptionPane.OK_OPTION) {
				this.updateEligibleOption(this.rowToEdit,
						this.eligibleOptionToEdit, buildBallotOptionName());
			}
		}
	}

	/**
	 * Cancels the update dialog.
	 */
	private void cancelActionPerformed() {
		Component parent = this.getParent();
		while (!parent.getClass().equals(JDialog.class)) {
			parent = parent.getParent();
		}

		parent.setVisible(false);
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	private void initComponents() {

		this.candidateActualNameInfoLabel = new javax.swing.JLabel();
		this.candidateActualNameLabel = new javax.swing.JLabel();
		this.contestInfoLabel = new javax.swing.JLabel();
		this.contestLabel = new javax.swing.JLabel();
		this.partyInfoLabel = new javax.swing.JLabel();
		this.partyLabel = new javax.swing.JLabel();
		this.tallyPositionInfoLabel = new javax.swing.JLabel();
		this.tallyPositionLabel = new javax.swing.JLabel();
		this.nameLabel = new javax.swing.JLabel();
		this.lastNameLabel = new javax.swing.JLabel();
		this.initialLabel = new javax.swing.JLabel();
		this.updateButton = new javax.swing.JButton();
		this.cancelButton = new javax.swing.JButton();

		this.nameTextField = new UnicodeTextField(
				ECMClientSideConstants.MAX_CHARACTERS_ELIGIBLE_OPTION_NAME);

		this.lastNameTextField = new UnicodeTextField(
				ECMClientSideConstants.MAX_CHARACTERS_ELIGIBLE_OPTION_LASTNAME);

		this.initialTextField = new UnicodeTextField(
				ECMClientSideConstants.MAX_CHARACTERS_ELIGIBLE_OPTION_NAME);

		setMaximumSize(new java.awt.Dimension(500, 800));

		java.util.ResourceBundle bundle = java.util.ResourceBundle
				.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp"); // NOI18N

		this.eligibleOptionEditorPanel.setName("panelEligibleOptionEditor");
		this.candidateActualNameInfoLabel
				.setText(bundle
						.getString("EligibleOptionCandidateEditorDialog.candidateLabel.text")); // NOI18N
		this.candidateActualNameInfoLabel.setName("labelCandidate"); // NOI18N

		this.contestInfoLabel
				.setText(bundle
						.getString("EligibleOptionCandidateEditorDialog.contestLabel.text")); // NOI18N
		this.contestInfoLabel.setName("labelInfoContest"); // NOI18N
		this.contestLabel.setName("labelContest"); // NOI18N

		this.partyInfoLabel
				.setText(bundle
						.getString("EligibleOptionCandidateEditorDialog.partyLabel.text")); // NOI18N
		this.partyInfoLabel.setName("labelInfoParty"); // NOI18N
		this.partyLabel.setName("labelParty"); // NOI18N

		this.tallyPositionInfoLabel
				.setText("<html>"
						+ bundle.getString("EligibleOptionCandidateEditorDialog.tallyPositionLabel.text")
						+ "</html>"); // NOI18N
		this.tallyPositionInfoLabel.setName("labelTallyInfoPosition"); // NOI18N
		this.tallyPositionLabel.setName("labelTallyPosition"); // NOI18N

		this.updateButton
				.setText(bundle
						.getString("EligibleOptionCandidateEditorDialog.okButton.text")); // NOI18N
		this.updateButton.setName("buttonUpdateCandidate"); // NOI18N
		this.updateButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						updateCandidateActionPerformed();
					}
				});

		this.cancelButton
				.setText(bundle
						.getString("EligibleOptionCandidateEditorDialog.cancelButton.text")); // NOI18N
		this.cancelButton.setName("buttonCancelCandidate"); // NOI18N
		this.cancelButton
				.addActionListener(new java.awt.event.ActionListener() {
					@Override
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						cancelActionPerformed();
					}
				});

		this.nameLabel
				.setText(bundle
						.getString("EligibleOptionCandidateEditorDialog.eligibleOption1.text")); // NOI18N
		this.nameLabel.setName("labelBallotOption1"); // NOI18N

		this.lastNameLabel
				.setText(bundle
						.getString("EligibleOptionCandidateEditorDialog.eligibleOption2.text")); // NOI18N
		this.lastNameLabel.setName("labelBallotOption2"); // NOI18N

		this.initialLabel
				.setText(bundle
						.getString("EligibleOptionCandidateEditorDialog.eligibleOption3.text")); // NOI18N
		this.initialLabel.setName("labelBallotOption3"); // NOI18N

		this.nameTextField.setText(" ");
		this.nameTextField.setMaximumSize(new java.awt.Dimension(150,
				2147483647));
		this.nameTextField.setName("textFieldBallotName1"); // NOI18N
		this.nameTextField.addKeyListener(new KeyListener() {

			@Override
			public void keyTyped(KeyEvent e) {
				UnicodeTextField unicodeTextField = (UnicodeTextField) e
						.getSource();

				enableUpdateButton(unicodeTextField.isReadyToSave());
			}

			@Override
			public void keyPressed(KeyEvent e) {

			}

			@Override
			public void keyReleased(KeyEvent e) {
				UnicodeTextField unicodeTextField = (UnicodeTextField) e
						.getSource();
				enableUpdateButton(unicodeTextField.isReadyToSave());
			}
		});

		this.lastNameTextField.setText(" ");
		this.lastNameTextField.setMaximumSize(new java.awt.Dimension(250,
				2147483647));
		this.lastNameTextField.setName("textFieldBallotName2"); // NOI18N
		this.lastNameTextField.addKeyListener(new KeyListener() {

			@Override
			public void keyTyped(KeyEvent e) {
				UnicodeTextField unicodeTextField = (UnicodeTextField) e
						.getSource();
				enableUpdateButton(unicodeTextField.isReadyToSave());
			}

			@Override
			public void keyPressed(KeyEvent e) {

			}

			@Override
			public void keyReleased(KeyEvent e) {
				UnicodeTextField unicodeTextField = (UnicodeTextField) e
						.getSource();
				enableUpdateButton(unicodeTextField.isReadyToSave());
			}
		});

		this.initialTextField.setText(" ");
		this.initialTextField.setMaximumSize(new java.awt.Dimension(250,
				2147483647));
		this.initialTextField.setName("textFieldBallotName3"); // NOI18N
		this.initialTextField.addKeyListener(new KeyListener() {

			@Override
			public void keyTyped(KeyEvent e) {
				UnicodeTextField unicodeTextField = (UnicodeTextField) e
						.getSource();

				enableUpdateButton(unicodeTextField.isReadyToSave());
			}

			@Override
			public void keyPressed(KeyEvent e) {

			}

			@Override
			public void keyReleased(KeyEvent e) {
				UnicodeTextField unicodeTextField = (UnicodeTextField) e
						.getSource();
				enableUpdateButton(unicodeTextField.isReadyToSave());
			}
		});

		initValues();

		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
		this.setLayout(layout);
		layout.setHorizontalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						layout.createSequentialGroup()
								.addGap(20, 20, 20)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.TRAILING,
												false)
												.addGroup(
														javax.swing.GroupLayout.Alignment.LEADING,
														layout.createSequentialGroup()
																.addGroup(
																		layout.createParallelGroup(
																				javax.swing.GroupLayout.Alignment.LEADING,
																				false)
																				.addComponent(
																						this.tallyPositionInfoLabel,
																						javax.swing.GroupLayout.Alignment.LEADING,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						150,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.candidateActualNameInfoLabel,
																						javax.swing.GroupLayout.Alignment.LEADING,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						150,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.contestInfoLabel,
																						javax.swing.GroupLayout.Alignment.LEADING,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						150,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.partyInfoLabel,
																						javax.swing.GroupLayout.Alignment.LEADING,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						150,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.lastNameLabel,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						150,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.nameLabel,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						150,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.initialLabel,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						150,
																						javax.swing.GroupLayout.PREFERRED_SIZE))
																.addPreferredGap(
																		javax.swing.LayoutStyle.ComponentPlacement.RELATED)
																.addGroup(
																		layout.createParallelGroup(
																				javax.swing.GroupLayout.Alignment.LEADING)
																				.addComponent(
																						this.tallyPositionLabel,
																						javax.swing.GroupLayout.Alignment.LEADING,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						350,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.candidateActualNameLabel,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						350,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.contestLabel,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						350,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.partyLabel,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						350,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.lastNameTextField,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						350,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.nameTextField,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						350,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addComponent(
																						this.initialTextField,
																						javax.swing.GroupLayout.PREFERRED_SIZE,
																						350,
																						javax.swing.GroupLayout.PREFERRED_SIZE)
																				.addGroup(
																						javax.swing.GroupLayout.Alignment.TRAILING,
																						layout.createSequentialGroup()
																								.addComponent(
																										this.updateButton)
																								.addPreferredGap(
																										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
																								.addComponent(
																										this.cancelButton)))))
								.addContainerGap(13, Short.MAX_VALUE)));
		layout.setVerticalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addGroup(
						layout.createSequentialGroup()
								.addGap(20, 20, 20)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(
														this.candidateActualNameInfoLabel)
												.addComponent(
														this.candidateActualNameLabel,
														javax.swing.GroupLayout.PREFERRED_SIZE,
														30,
														javax.swing.GroupLayout.PREFERRED_SIZE))
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(
														this.tallyPositionInfoLabel,
														Alignment.BASELINE)
												.addComponent(
														this.tallyPositionLabel,
														Alignment.BASELINE,
														javax.swing.GroupLayout.PREFERRED_SIZE,
														30,
														javax.swing.GroupLayout.PREFERRED_SIZE))
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(
														this.contestInfoLabel)
												.addComponent(
														this.contestLabel,
														javax.swing.GroupLayout.PREFERRED_SIZE,
														30,
														javax.swing.GroupLayout.PREFERRED_SIZE))
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(
														this.partyInfoLabel)
												.addComponent(
														this.partyLabel,
														javax.swing.GroupLayout.PREFERRED_SIZE,
														30,
														javax.swing.GroupLayout.PREFERRED_SIZE))
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(this.nameLabel)
												.addComponent(
														this.nameTextField,
														javax.swing.GroupLayout.PREFERRED_SIZE,
														javax.swing.GroupLayout.DEFAULT_SIZE,
														javax.swing.GroupLayout.PREFERRED_SIZE))
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(
														this.lastNameLabel)
												.addComponent(
														this.lastNameTextField,
														javax.swing.GroupLayout.PREFERRED_SIZE,
														javax.swing.GroupLayout.DEFAULT_SIZE,
														javax.swing.GroupLayout.PREFERRED_SIZE))
								.addPreferredGap(
										javax.swing.LayoutStyle.ComponentPlacement.RELATED)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(this.initialLabel)
												.addComponent(
														this.initialTextField,
														javax.swing.GroupLayout.PREFERRED_SIZE,
														javax.swing.GroupLayout.DEFAULT_SIZE,
														javax.swing.GroupLayout.PREFERRED_SIZE))
								.addGap(18, 18, 18)
								.addGroup(
										layout.createParallelGroup(
												javax.swing.GroupLayout.Alignment.BASELINE)
												.addComponent(this.cancelButton)
												.addComponent(this.updateButton))
								.addContainerGap(20, Short.MAX_VALUE)));
	}

	private static final long serialVersionUID = -4032670741135729071L;

	private EligibleOptionData eligibleOptionToEdit;

	private EligibleOptionEditorPanel eligibleOptionEditorPanel = null;

	private int rowToEdit;

	private ResourceBundle resourceBundle;

	private javax.swing.JLabel candidateActualNameInfoLabel;

	private javax.swing.JLabel candidateActualNameLabel;

	private javax.swing.JLabel contestInfoLabel;

	private javax.swing.JLabel contestLabel;

	private javax.swing.JLabel partyInfoLabel;

	private javax.swing.JLabel partyLabel;

	private javax.swing.JLabel tallyPositionInfoLabel;

	private javax.swing.JLabel tallyPositionLabel;

	private javax.swing.JLabel nameLabel;

	private javax.swing.JLabel lastNameLabel;

	private javax.swing.JLabel initialLabel;

	private UnicodeTextField nameTextField;

	private UnicodeTextField lastNameTextField;

	private UnicodeTextField initialTextField;

	private javax.swing.JButton updateButton;

	private javax.swing.JButton cancelButton;

}
