/**
 * ImagesUploadHashGetterController.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import java.io.File;

import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener;
import com.smartmatic.waffle.ecm.client.worker.HashGetterWorker;
import com.smartmatic.waffle.localpersistence.SAESCommonDestinations;

/**
 * Controller class that creates and starts the worker thread to calculate the
 * sha256sum for OS images.
 */
public class ImagesUploadHashGetterController implements IAwtOperationListener {

	/** HashGetterWorker reference. */
	private HashGetterWorker hashGetterWorker;

	/** ImagesUploadPanel reference. */
	private ImagesUploadPanel imagesUploadPanel;

	/** File object to hold the abstract representation of image. */
	private File imageToGetHash;

	/** ImagesUploadGUIComponents reference. */
	private ImagesUploadGUIComponents imagesUploadGUIComponents;

	/**
	 * Instantiates a new ImagesUploadHashGetterController.
	 * 
	 * @param imagesUploadPanel
	 *            ImagesUploadPanel reference
	 * @param defaultDestinations
	 *            SAESCommonDestinations reference
	 * @param imagesUploadGUIComponents
	 *            ImagesUploadGUIComponents reference
	 */
	public ImagesUploadHashGetterController(
			ImagesUploadPanel imagesUploadPanel,
			SAESCommonDestinations defaultDestinations,
			ImagesUploadGUIComponents imagesUploadGUIComponents) {
		this.imagesUploadPanel = imagesUploadPanel;
		this.imagesUploadGUIComponents = imagesUploadGUIComponents;

		switch (this.imagesUploadGUIComponents.getImageType()) {
		case OFFICIAL:
			this.imageToGetHash = defaultDestinations.votingDeviceImage;
			break;
		case SCREEN_GENERATION:
			this.imageToGetHash = defaultDestinations.votingDeviceScreenShotImage;
			break;
		case CANVASSING_STATION:
			this.imageToGetHash = defaultDestinations.canvassingStationImage;
			break;
		}
	}

	/**
	 * Method that starts the worker that does the real backend functionality
	 * work.
	 */
	public void startWorker() {
		this.hashGetterWorker = new HashGetterWorker(this.imageToGetHash);

		this.hashGetterWorker.addListener(this);

		Thread hashGetterWorkerThread = new Thread(this.hashGetterWorker,
				"HashGetterWorker");

		hashGetterWorkerThread.start();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener#awtOperation
	 * (com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType)
	 */
	@Override
	public void awtOperation(AwtOperationType awtOperationType) {
		this.imagesUploadPanel.updateImageStatus(
				this.hashGetterWorker.getImageHash(),
				this.imagesUploadGUIComponents);
	}

}
