/**
 * IntegrityValidationController.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui;

import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener;
import com.smartmatic.waffle.ecm.client.worker.IntegrityValidationExecutorWorker;

/**
 * Class used to create and start the worker thread to perform the query
 * execution process.
 */
public class IntegrityValidationExecutorController implements
		IAwtOperationListener {

	IntegrityValidationExecutorWorker integrityValidationExecutorWorker;

	IntegrityPanel integrityPanel;

	/** The SQL query to execute. */
	String sqlQuery;

	/**
	 * Constructor.
	 * 
	 * @param integrityPanel
	 *            The integrity panel reference.
	 * @param sqlQuery
	 *            The SQL Query to execute.
	 */
	public IntegrityValidationExecutorController(IntegrityPanel integrityPanel,
			String sqlQuery) {
		this.integrityPanel = integrityPanel;
		this.sqlQuery = sqlQuery;
	}

	/**
	 * Method that starts the worker thread to perform the operations.
	 */
	public void startWorker() {
		this.integrityValidationExecutorWorker = new IntegrityValidationExecutorWorker();
		this.integrityValidationExecutorWorker.addListener(this);
		this.integrityValidationExecutorWorker.setSqlQuery(this.sqlQuery);

		Thread integrityValidationWorkerThread = new Thread(
				this.integrityValidationExecutorWorker,
				"IntegrityValidationWorker");
		integrityValidationWorkerThread.start();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener#awtOperation
	 * (com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType)
	 */
	@Override
	public void awtOperation(AwtOperationType awtOperationType) {
		switch (awtOperationType) {

		case SHOW_RESULT_MESSAGE:
			this.integrityPanel
					.showResult(this.integrityValidationExecutorWorker
							.getQueryResult());
			break;

		case SHOW_ERROR_MESSAGE:
			this.integrityPanel
					.showErrorMessage(this.integrityValidationExecutorWorker
							.getErrorBundleKey());
			break;

		case DISABLE_COMPONENTS:
			this.integrityPanel.blockControls();
			this.integrityPanel.activateStatusBar();
			break;

		case ENABLE_COMPONENTS:
			this.integrityPanel.unBlockControls();
			this.integrityPanel.deactivateStatusBar();
			break;
		}
	}

}
