package com.smartmatic.waffle.ecm.client.ui;

import java.util.ResourceBundle;

import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener;
import com.smartmatic.waffle.ecm.client.worker.SearchCandidateWorker;
import com.smartmatic.waffle.ecm.ui.core.i18n.controller.LanguageController;

/**
 * Controller class used to search candidates.
 * 
 */
public class SearchCandidateController implements IAwtOperationListener {

	EligibleOptionEditorPanel eligibleOptionPanel;

	SearchCandidateWorker searchCandidateWorker;

	ResourceBundle bundle = ResourceBundle
			.getBundle("com/smartmatic/waffle/ecm/client/resources/ECMApp");

	/**
	 * Creates a new instance of SearchCandidateController
	 * 
	 * @param eligibleOptionPanel
	 *            the panel which called this controller
	 */
	public SearchCandidateController(
			EligibleOptionEditorPanel eligibleOptionPanel) {
		this.eligibleOptionPanel = eligibleOptionPanel;
	}

	/**
	 * Method that starts the worker that does the real backend functionality
	 * work.
	 */
	public void startWorker() {
		LanguageData language = LanguageController.getInstance()
				.getSelectedLanguage();

		this.searchCandidateWorker = new SearchCandidateWorker(
				this.eligibleOptionPanel.getSearchText(),
				this.eligibleOptionPanel.getCurrentSearchRegions(),
				this.eligibleOptionPanel.getCurrentSearchContests(),
				this.eligibleOptionPanel.getCurrentSearchParties(), language,
				this.eligibleOptionPanel.getCurrentPage());

		this.searchCandidateWorker.setCandidateTypeMain(this.bundle
				.getString("EligibleOptionEditorPanel.candidateType.main"));

		this.searchCandidateWorker
				.setCandidateTypeAlternate(this.bundle
						.getString("EligibleOptionEditorPanel.candidateType.alternate"));

		this.searchCandidateWorker.addListener(this);

		Thread searchCandidateWorkerThread = new Thread(
				this.searchCandidateWorker, "SearchCandidateWorker");

		searchCandidateWorkerThread.start();
	}

	@Override
	public void awtOperation(AwtOperationType awtOperationType) {

		switch (awtOperationType) {

		case ENABLE_COMPONENTS:
			this.eligibleOptionPanel.enableSearchButtons(true);
			break;

		case DISABLE_COMPONENTS:
			this.eligibleOptionPanel.enableSearchButtons(false);
			break;

		case UPDATE_COMPONENTS:
			this.eligibleOptionPanel.clearSearchResults();
			this.eligibleOptionPanel
					.setTotalNumberOfPages(this.searchCandidateWorker
							.getTotalNumberOfPages());
			this.eligibleOptionPanel.setPaginationLabelText();
			break;
		case SHOW_RESULT_MESSAGE:
			this.eligibleOptionPanel
					.updateResultsTableCandidates(this.searchCandidateWorker
							.getCandidatesList());
			break;
		default:
			break;
		}
	}
}
