package com.smartmatic.waffle.ecm.client.ui;

import javax.swing.JPanel;

import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.client.ui.common.IAwtOperationListener;
import com.smartmatic.waffle.ecm.client.worker.UpdateEligibleOptionWorker;

/**
 * Controller class that performs update operations for EligibleOptionData
 * objects.
 * 
 */
public class UpdateEligibleOptionController implements IAwtOperationListener {

	private JPanel panel;
	private UpdateEligibleOptionWorker updateEligibleOptionWorker;
	private boolean isParty;

	/**
	 * Creates a new instance of the UpdateEligibleOptionController
	 * 
	 * @param panel
	 *            The panel reference which this controller is called.
	 */
	public UpdateEligibleOptionController(JPanel panel) {
		this.panel = panel;
	}

	/**
	 * Method that starts the worker that does the real backend functionality
	 * work.
	 */
	public void startWorker() {
		if (this.panel instanceof EligibleOptionPartyEditorDialog) {
			this.updateEligibleOptionWorker = new UpdateEligibleOptionWorker(
					((EligibleOptionPartyEditorDialog) this.panel)
							.getEligibleOption(),
					true);
			this.isParty = true;
		} else {
			this.updateEligibleOptionWorker = new UpdateEligibleOptionWorker(
					((EligibleOptionCandidateEditorDialog) this.panel)
							.getEligibleOption());
		}

		this.updateEligibleOptionWorker.addListener(this);

		Thread updateEligibleOptionWorkerThread = new Thread(
				this.updateEligibleOptionWorker, "UpdateEligibleOptionWorker");

		updateEligibleOptionWorkerThread.start();
	}

	@Override
	public void awtOperation(AwtOperationType awtOperationType) {
		switch (awtOperationType) {
		case SHOW_ERROR_MESSAGE:
			if (this.isParty) {
				((EligibleOptionPartyEditorDialog) this.panel)
						.showErrorMessage();
			} else {
				((EligibleOptionCandidateEditorDialog) this.panel)
						.showErrorMessage();
			}
			break;
		default:
			break;
		}
	}

}
