package com.smartmatic.waffle.ecm.client.ui.controller;

import java.util.List;

import com.smartmatic.waffle.domain.general.ParameterData;
import com.smartmatic.waffle.ecm.client.ECMServiceProvider;
import com.smartmatic.waffle.ecm.client.exception.ConnectionException;
import com.smartmatic.waffle.ecm.service.lang.XmlGenerationException;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Controller class for the Parameter Configuration Panel
 */
public class ParameterConfigurationPanelController {

	private static SMTTLogger logger = SMTTLogger
			.getLogger(ParameterConfigurationPanelController.class);

	/**
	 * Gets the list of configurable parameters stored in the database
	 * 
	 * @return List of parameters
	 * @throws XmlGenerationException
	 */
	public static List<ParameterData> getParameters()
			throws XmlGenerationException {
		try {
			logger.info("Getting parameters from the server");
			return ECMServiceProvider.getParameters();
		} catch (ConnectionException e) {
			logger.error(e, e.getMessage());
		}
		return null;
	}

	/**
	 * Updates the value of a parameter stored in the database
	 * 
	 * @param parameter
	 *            Parameter which value is going to be updated
	 * @throws XmlGenerationException
	 */
	public static void updateParameter(ParameterData parameter)
			throws XmlGenerationException {
		try {
			logger.info("Updating parameter configuration in the server");
			ECMServiceProvider.updateParameter(parameter);
		} catch (ConnectionException e) {
			logger.error(e, e.getMessage());
		}
	}

}
