/**
 * PassphraseUserUpdateDialog.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2018 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.ui.login;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;

import javax.swing.GroupLayout;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPasswordField;
import javax.swing.JTextField;
import javax.swing.SwingConstants;

import org.jdesktop.application.Action;
import org.jdesktop.application.Application;
import org.jdesktop.application.Task;

import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.ecm.ui.core.TextFieldLimit;
import com.smartmatic.waffle.ecm.ui.util.DotDashBorder;
import com.smartmatic.waffle.ecm.ui.util.ECMOptionPane;

public class PassphraseUserUpdateDialog extends PassphraseInputDialog {

	private static final long serialVersionUID = -9093453331567828278L;

	/** The user label. */
	private JLabel userLabel;

	/** The password label. */
	private JLabel passwordLabel;

	/** The password label. */
	private JLabel confimPasswordLabel;

	/** The password label. */
	public JPasswordField confirmPasswordTextField;

	/** Language code that identifies this application language. */
	private LanguageData languageData;

	/** The adapter. */
	private KeyAdapter adapter = new java.awt.event.KeyAdapter() {

		@Override
		public void keyReleased(KeyEvent e) {
			PassphraseUserUpdateDialog.this.passphraseTextFieldKeyReleased(e);
		}
	};

	/**
	 * Constructor of PassphraseUserUpdateDialog
	 * 
	 * @param languageData
	 */
	public PassphraseUserUpdateDialog(LanguageData languageData) {
		super(new JFrame());
		this.languageData = languageData;
		this.rebuildPanel();
	}

	/**
	 * Executes action for okButton.
	 */
	@SuppressWarnings("rawtypes")
	@Override
	public Task checkPassphrase() {
		return validateConfirmPassword();
	}

	/**
	 * Is password updated, false if experience was canceled.
	 * 
	 * @return
	 */
	public boolean isPasswordUpdated() {
		return !this.canceled;
	}

	/**
	 * Rebuilds the current panel.
	 */
	private void rebuildPanel() {
		Dimension languageLabelSize, languageButtonSize = null;
		Color lblColor = null;

		this.mainFrame.setBorder(null);

		languageLabelSize = new Dimension(650, 90);
		languageButtonSize = new Dimension(200, 75);

		if (this.languageData != null) {
			lblColor = this.getResourceMap().getColor(
					this.languageData.getCustomCode()
							+ ".selection.label.background.color");
		}
		if (lblColor == null) {
			lblColor = Color.WHITE;
		}

		Font tknFont = null;
		if (this.languageData != null) {
			tknFont = this.getResourceMap()
					.getFont(
							this.languageData.getCustomCode()
									+ ".selection.label.font");
		}
		if (tknFont == null) {
			tknFont = this.passphraseLabel.getFont().deriveFont(
					this.passphraseLabel.getFont().getStyle()
							| java.awt.Font.BOLD,
					this.passphraseLabel.getFont().getSize() + 4);
		}

		this.passphraseLabel.setOpaque(true);
		this.passphraseLabel.setBackground(lblColor);
		this.passphraseLabel
				.setBorder(new DotDashBorder(
						DotDashBorder.PatternType.DASH_LONG.getPattern(), 1,
						Color.GRAY));
		this.passphraseLabel.setFont(tknFont);
		this.passphraseLabel.setPreferredSize(languageLabelSize);
		this.passphraseLabel.setMaximumSize(languageLabelSize);
		this.passphraseLabel.setMinimumSize(languageLabelSize);

		if (this.languageData != null) {
			tknFont = this.getResourceMap().getFont(
					this.languageData.getCustomCode()
							+ ".selection.button.font");
		}

		if (tknFont == null) {
			tknFont = this.okButton.getFont().deriveFont(
					this.okButton.getFont().getStyle() | java.awt.Font.BOLD,
					this.okButton.getFont().getSize() + 4);
		}

		this.okButton.setFont(tknFont);
		this.okButton.setPreferredSize(languageButtonSize);
		this.okButton.setMaximumSize(languageButtonSize);
		this.okButton.setMinimumSize(languageButtonSize);

		this.resetButton.setFont(tknFont);
		this.resetButton.setPreferredSize(languageButtonSize);
		this.resetButton.setMaximumSize(languageButtonSize);
		this.resetButton.setMinimumSize(languageButtonSize);

		this.passphraseTextField.setDocument(new TextFieldLimit(50));
		this.confirmPasswordTextField.setDocument(new TextFieldLimit(50));

		this.userField.setDocument(new TextFieldLimit(50));
		this.userField.setText("admin");
		this.userField.setEnabled(false);

		this.passphraseTextField.setAction(this.actionMap
				.get("validatePassword"));
		this.confirmPasswordTextField.setAction(this.actionMap
				.get("validateConfirmPassword"));

		this.errorLabel.setForeground(Color.RED);
		this.errorLabel.setText(" ");

		this.passphraseTextField.addKeyListener(this.adapter);
		this.confirmPasswordTextField.addKeyListener(this.adapter);
		this.pack();

	}

	/**
	 * Validates first field password.
	 * 
	 * @return
	 */
	@SuppressWarnings("rawtypes")
	@Action
	public Task validatePassword() {

		String password = getEnteredPassword();
		if (password.isEmpty()) {
			setErrorMessage("PassphraseUserUpdateDialog.help.empty.password");
		} else if (password.length() < 7) {
			setErrorMessage("PassphraseUserUpdateDialog.help.short.password");
		} else if (!validatePasswordRegex(password)) {
			setErrorMessage("PassphraseUserUpdateDialog.help.invalid.password");
		} else {
			this.errorLabel.setText(" ");
			this.confirmPasswordTextField.requestFocusInWindow();
		}

		return null;
	}

	/**
	 * Validates regex.
	 * 
	 * @param password
	 * @return
	 */
	private boolean validatePasswordRegex(String password) {
		boolean atLeastADigit = password.matches("^(.*(\\d).*)+$");
		boolean atLeastALetter = password.matches("^(.*([a-zA-Z]).*)+$");

		return atLeastADigit && atLeastALetter;
	}

	/**
	 * Validates second field password.
	 * 
	 * @return
	 */
	@SuppressWarnings("rawtypes")
	@Action
	public Task validateConfirmPassword() {

		String passwordretyped = String.valueOf(this.confirmPasswordTextField
				.getPassword());
		String password = String
				.valueOf(this.passphraseTextField.getPassword());

		if (password.isEmpty()) {
			setErrorMessage("PassphraseUserUpdateDialog.help.empty.password");
		} else if (password.length() < 7) {
			setErrorMessage("PassphraseUserUpdateDialog.help.short.password");
		} else if (!validatePasswordRegex(password)) {
			setErrorMessage("PassphraseUserUpdateDialog.help.invalid.password");
		} else {
			if (passwordretyped.length() == 0) {
				setErrorMessage("PassphraseUserUpdateDialog.help.retype.password");
				this.confirmPasswordTextField.requestFocusInWindow();
			} else {
				if (password.equals(passwordretyped)) {

					disableUI();
					PassphraseUserUpdateTask task = new PassphraseUserUpdateTask(
							Application.getInstance(), this);
					return task;
				} else {
					setErrorMessage("PassphraseUserUpdateDialog.help.not.match.password");
				}
			}
		}

		return null;
	}

	/**
	 * Shows Dialog after user update
	 */
	public void showDialogUserUpdated() {
		ECMOptionPane.showMessageDialog(
				this,
				this.getResourceMap().getString(
						"PassphraseUserUpdateDialog.dialog.user.updated.ok"),
				this.getResourceMap().getString("NormalMessage.title"),
				ECMOptionPane.INFORMATION_MESSAGE,
				ECMOptionPane.INFORMATION_DIALOG);
	}

	/**
	 * Shows Dialog after user update
	 */
	public void showDialogUserUpdateError() {
		ECMOptionPane.showMessageDialog(
				this,
				this.getResourceMap().getString(
						"PassphraseUserUpdateDialog.dialog.user.updated.fail"),
				this.getResourceMap().getString("ErrorMessage.title"),
				ECMOptionPane.ERROR_MESSAGE, ECMOptionPane.ERROR_DIALOG);
	}

	/**
	 * Disables UI.
	 */
	public void disableUI() {
		this.okButton.setEnabled(false);
		this.resetButton.setEnabled(false);
		this.confirmPasswordTextField.setEnabled(false);
		this.passphraseTextField.setEnabled(false);
	}

	/**
	 * Resets dialog fields
	 */
	public void resetUI() {

		this.confirmPasswordTextField.setText("");
		this.confirmPasswordTextField.setEnabled(true);

		this.passphraseTextField.setText("");
		this.passphraseTextField.setEnabled(true);
		this.passphraseTextField.requestFocusInWindow();

		this.okButton.setEnabled(false);
		this.resetButton.setEnabled(true);
	}

	@Override
	protected void initComponents() {
		super.initComponents();
		this.passphraseLabel.setText(this.getResourceMap().getString(
				"PassphraseUserUpdateDialog.title"));

		this.userLabel = new JLabel(this.getResourceMap().getString(
				"PassphraseUserUpdateDialog.username.label"));
		this.userLabel.setName("labelUser");
		this.userLabel.setFont(this.getResourceMap().getFont(
				"passphraseTextField.font")); // NOI18N

		this.userField = new JTextField();
		this.userField.setFont(this.getResourceMap().getFont(
				"passphraseTextField.font")); // NOI18N
		this.userField.setHorizontalAlignment(SwingConstants.CENTER);
		this.userField.setName("textFieldUser"); // NOI18N

		this.passwordLabel = new JLabel(this.getResourceMap().getString(
				"PassphraseUserUpdateDialog.password.label"));
		this.passwordLabel.setName("labelPassword");
		this.passwordLabel.setFont(this.getResourceMap().getFont(
				"passphraseTextField.font")); // NOI18N

		this.confimPasswordLabel = new JLabel(this.getResourceMap().getString(
				"PassphraseUserUpdateDialog.confirm.password.label"));
		this.confimPasswordLabel.setName("labelPassword");
		this.confimPasswordLabel.setFont(this.getResourceMap().getFont(
				"passphraseTextField.font")); // NOI18N

		this.confirmPasswordTextField = new javax.swing.JPasswordField();
		this.confirmPasswordTextField.setFont(this.getResourceMap().getFont(
				"passphraseTextField.font")); // NOI18N
		this.confirmPasswordTextField
				.setHorizontalAlignment(SwingConstants.CENTER);
		this.confirmPasswordTextField.setName("textFieldPassphrase"); // NOI18N

		GroupLayout jPanel1Layout = new GroupLayout(this.jPanel1);
		this.jPanel1.setLayout(jPanel1Layout);

		jPanel1Layout
				.setHorizontalGroup(jPanel1Layout
						.createParallelGroup(
								javax.swing.GroupLayout.Alignment.LEADING)
						.addGroup(
								javax.swing.GroupLayout.Alignment.TRAILING,
								jPanel1Layout
										.createSequentialGroup()
										.addContainerGap(34, Short.MAX_VALUE)
										.addGroup(
												jPanel1Layout
														.createParallelGroup(
																javax.swing.GroupLayout.Alignment.CENTER)

														.addComponent(
																this.userLabel,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																540,
																javax.swing.GroupLayout.PREFERRED_SIZE)
														.addComponent(
																this.userField,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																200,
																javax.swing.GroupLayout.PREFERRED_SIZE)
														.addComponent(
																this.passwordLabel,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																540,
																javax.swing.GroupLayout.PREFERRED_SIZE)
														.addComponent(
																this.passphraseTextField,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																200,
																javax.swing.GroupLayout.PREFERRED_SIZE)
														.addComponent(
																this.confimPasswordLabel,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																540,
																javax.swing.GroupLayout.PREFERRED_SIZE)
														.addComponent(
																this.confirmPasswordTextField,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																200,
																javax.swing.GroupLayout.PREFERRED_SIZE)
														.addComponent(
																this.errorLabel,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																javax.swing.GroupLayout.DEFAULT_SIZE,
																javax.swing.GroupLayout.PREFERRED_SIZE))
										.addContainerGap(34, Short.MAX_VALUE)));
		jPanel1Layout
				.setVerticalGroup(jPanel1Layout
						.createParallelGroup(
								javax.swing.GroupLayout.Alignment.LEADING)
						.addGroup(
								jPanel1Layout
										.createSequentialGroup()
										.addGap(12, 12, 12)
										.addComponent(
												this.errorLabel,
												javax.swing.GroupLayout.PREFERRED_SIZE,
												javax.swing.GroupLayout.DEFAULT_SIZE,
												javax.swing.GroupLayout.PREFERRED_SIZE)
										.addPreferredGap(
												javax.swing.LayoutStyle.ComponentPlacement.RELATED,
												34, Short.MAX_VALUE)
										.addGroup(
												jPanel1Layout
														.createParallelGroup(
																javax.swing.GroupLayout.Alignment.CENTER)
														.addComponent(
																this.userLabel,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																10,
																javax.swing.GroupLayout.PREFERRED_SIZE)
														.addComponent(
																this.userField,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																javax.swing.GroupLayout.DEFAULT_SIZE,
																javax.swing.GroupLayout.PREFERRED_SIZE))
										.addGroup(
												jPanel1Layout
														.createParallelGroup(
																javax.swing.GroupLayout.Alignment.CENTER)
														.addComponent(
																this.passwordLabel,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																20,
																javax.swing.GroupLayout.PREFERRED_SIZE)
														.addComponent(
																this.passphraseTextField,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																javax.swing.GroupLayout.DEFAULT_SIZE,
																javax.swing.GroupLayout.PREFERRED_SIZE))
										.addGroup(
												jPanel1Layout
														.createParallelGroup(
																javax.swing.GroupLayout.Alignment.CENTER)
														.addComponent(
																this.confimPasswordLabel,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																20,
																javax.swing.GroupLayout.PREFERRED_SIZE)
														.addComponent(
																this.confirmPasswordTextField,
																javax.swing.GroupLayout.PREFERRED_SIZE,
																javax.swing.GroupLayout.DEFAULT_SIZE,
																javax.swing.GroupLayout.PREFERRED_SIZE))
										.addContainerGap()));
	}

	/**
	 * sets error message
	 * 
	 * @param messageKey
	 */
	public void setErrorMessage(String messageKey) {
		this.errorLabel.setText(this.getString(messageKey));
	}

	/**
	 * Passphrase text field key released.
	 * 
	 * @param evt
	 */
	private void passphraseTextFieldKeyReleased(KeyEvent evt) {
		if (evt.getKeyChar() != '\n') {
			if (this.passphraseTextField.getPassword().length > 0
					|| this.confirmPasswordTextField.getPassword().length > 0) {
				this.okButton.setEnabled(true);
				this.resetButton.setEnabled(true);
				this.errorLabel.setText(" ");
			} else {
				this.okButton.setEnabled(false);
			}
		}
	}
}
