/**
 * BulkUploadDownloadTranslationsTemplateWorker.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.worker;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.ecm.client.ECMServiceProvider;
import com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation;
import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.core.pendrive.util.PendriveUtil;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * The Class BulkUploadDownloadTranslationsTemplateWorker.
 */
public class BulkUploadDownloadTranslationsTemplateWorker extends
		AsynchronousOperation {

	/**
	 * Static reference to log any info or error which occurred executing
	 * methods from this class.
	 */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(BulkUploadDownloadTranslationsTemplateWorker.class);

	/**
	 * Instantiates a new BulkUploadDownloadTranslationsTemplateWorker
	 * 
	 * @param fileToExport
	 *            the file to export
	 */
	public BulkUploadDownloadTranslationsTemplateWorker(File fileToExport) {
		this.fileToExport = fileToExport;
	}

	/**
	 * Gets the multilingual keys pages amount.
	 * 
	 * @return the multilingual keys pages amount
	 */
	public int getMultilingualKeysPagesAmount() {
		return this.multilingualKeysPagesAmount;
	}

	/**
	 * Gets the processed elements.
	 * 
	 * @return the processed elements
	 */
	public int getProcessedElements() {
		return this.processedPages;
	}

	/**
	 * Main method that generate the lines that compose the template to be saved
	 * in the file
	 */
	public void generateFileLines() {
		try {
			int pageSize = 300;

			List<String> linesToFileList = new ArrayList<String>();

			linesToFileList.add("TRANSLATION_KEY");

			int multilingualKeysAmount = ECMServiceProvider
					.retrieveMultilingualKeysAmount();

			this.multilingualKeysPagesAmount = (int) Math
					.ceil((double) multilingualKeysAmount / pageSize);

			fireAwtEvent(AwtOperationType.UPDATE_COMPONENTS);

			for (int i = 0; i < this.multilingualKeysPagesAmount; i++) {

				linesToFileList.addAll(ECMServiceProvider
						.getTranslationkeysToDownload(i, pageSize));

				this.processedPages = i + 1;

				fireAwtEvent(AwtOperationType.UPDATE_PROGRESS_BAR);
			}

			generateFile(linesToFileList);
			PendriveUtil.sync();
			fireAwtEvent(AwtOperationType.SHOW_RESULT_MESSAGE);

		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			fireAwtEvent(AwtOperationType.SHOW_ERROR_MESSAGE);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation#
	 * performOperation()
	 */
	@Override
	protected void performOperation() {
		generateFileLines();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation#onCompleted
	 * ()
	 */
	@Override
	protected void onCompleted() {
	}

	/**
	 * Generates the file with the data processed
	 * 
	 * @param linesToFileList
	 *            list of lines to be saved in the file
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	private void generateFile(List<String> linesToFileList) throws IOException {
		FileUtils.writeLines(this.fileToExport, linesToFileList);
	}

	/** The file to export file. */
	private File fileToExport;

	/** The multilingual keys pages amount. */
	private int multilingualKeysPagesAmount;

	/** The processed pages. */
	private int processedPages;
}
