/**
 * BulkUploadUpdateLoadedNumberOfEachEntityWorker.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.worker;

import java.util.EnumSet;
import java.util.List;
import java.util.Set;

import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.ecm.client.ECMServiceProvider;
import com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation;
import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.ecm.data.transfer.objects.EntityRecordsQuantitiesDTO;
import com.smartmatic.waffle.ecm.data.transfer.type.SmttFileType;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Class that executes the main process to update the loaded amount of each
 * entities
 */
public class BulkUploadUpdateLoadedNumberOfEachEntityWorker extends
		AsynchronousOperation {

	/**
	 * Static reference to log any info or error which occurred executing
	 * methods from this class.
	 */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(BulkUploadUpdateLoadedNumberOfEachEntityWorker.class);

	/**
	 * Gets the entity records quantities list.
	 * 
	 * @return the entity records quantities list
	 */
	public List<EntityRecordsQuantitiesDTO> getEntityRecordsQuantitiesList() {
		return this.entityRecordsQuantitiesList;
	}

	/**
	 * Checks if is smtt data is loaded.
	 * 
	 * @return true, if is smtt data is loaded
	 */
	public boolean isSmttDataIsLoaded() {
		return this.isSmttDataIsLoaded;
	}

	/**
	 * Checks if is some entity loaded.
	 * 
	 * @return true, if is some entity loaded
	 */
	public boolean isSomeEntityLoaded() {
		return this.isSomeEntityLoaded;
	}

	/**
	 * Sets the some entity loaded.
	 * 
	 * @param isSomeEntityLoaded
	 *            the new some entity loaded
	 */
	public void setSomeEntityLoaded(boolean isSomeEntityLoaded) {
		this.isSomeEntityLoaded = isSomeEntityLoaded;
	}


    /**
     * Method that performs updating loaded number of each entity.
     */
    public void startUpdatingLoadedNumberOfEachEntity() {
        final Set<SmttFileType> optionals;      // Files to be excluded from BR
        List<EntityRecordsQuantitiesDTO> erql;  // erqs: EntityRecordsQuantities
        SmttFileType smttFile;                  // Smartmatic File Type

        optionals = EnumSet.of(
            SmttFileType.PROFILE,
            SmttFileType.USER
        );
        try {
            erql = ECMServiceProvider.getEntityRecordsQuantities();
            this.entityRecordsQuantitiesList = erql;
            this.isSmttDataIsLoaded          = true;

            for (EntityRecordsQuantitiesDTO countDTO : erql) {
                smttFile = countDTO.getSmttFileType();

                if ( optionals.contains(smttFile) ) {  // skip ...
                    continue;
                }
                // else ...
                if (countDTO.getRecordsQuantities() > 0) {
                    this.isSomeEntityLoaded = true;

                } else {
                    this.isSmttDataIsLoaded = false;
                }
            }
            fireAndForgetAwtEvent(AwtOperationType.UPDATE_COMPONENTS);

        } catch (Exception e) {
            logger.error(e, StringUtils.defaultString(e.getMessage()));
            fireAwtEvent(AwtOperationType.SHOW_ERROR_MESSAGE);
        }
    }


	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation#
	 * performOperation()
	 */
	@Override
	protected void performOperation() {
		startUpdatingLoadedNumberOfEachEntity();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation#onCompleted
	 * ()
	 */
	@Override
	protected void onCompleted() {
	}

	/** The entity records quantities list. */
	private List<EntityRecordsQuantitiesDTO> entityRecordsQuantitiesList;

	/** The is smtt data is loaded. */
	private boolean isSmttDataIsLoaded;

	/** The is some entity loaded. */
	private boolean isSomeEntityLoaded;
}
