package com.smartmatic.waffle.ecm.client.worker;

import java.io.File;

import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.ecm.client.ui.common.AsynchronousOperation;
import com.smartmatic.waffle.ecm.client.ui.common.AwtOperationType;
import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Worker class used to detect if the mounted device was remove during the
 * generation process.
 *
 */
public class DriveRemovedDetectorWorker extends AsynchronousOperation {

	/** Logger. */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(DriveRemovedDetectorWorker.class);

	private String mountedPath;
	private boolean disableWorker;
	private File mountedPathFile;

	public DriveRemovedDetectorWorker(String mountedPath) {
		this.mountedPath = mountedPath;
		this.disableWorker = false;
		this.mountedPathFile = new File(this.mountedPath);
	}

	/**
	 * Method used to disable the current worker execution
	 */
	public void disableWorker() {
		this.disableWorker = true;
	}

	/**
	 * Method that run the drive removed detection while checking the path is
	 * still present in the system.
	 */
	private void runDetector() {

		while (!this.disableWorker) {
			if (!isDrivePresent()) {
				this.disableWorker = true;
				logger.error("Removed drive mounted at path: "
						+ this.mountedPath);
				fireAwtEvent(AwtOperationType.SHOW_ERROR_MESSAGE);
				return;
			}

			try {
				Thread.sleep(2000);
			} catch (InterruptedException e) {
				logger.error(e, StringUtils.defaultString(e.getMessage()));
			}
		}
	}

	/**
	 * Checks if the mounted path is present
	 * 
	 * @return True is the file exists
	 */
	public boolean isDrivePresent() {
		return this.mountedPathFile.exists();
	}

	@Override
	protected void performOperation() {
		logger.info("Drive removed detection started");
		runDetector();
	}

	@Override
	protected void onCompleted() {
		logger.info("Drive removed detection stopped");
	}

}
