#!/bin/bash -e

# File: smtt-create-disk.sh
# Synopsis: Script to create the necessary partitions for the
#           USB to install the PM-VM Election Application.
# Author: Gustavo Garcia <gustavo.garcia@smartmatic.com>
# Version: 0.0.2
# Last Edited: Fri 18 Aug 2017

###############
#  VARIABLES  #
###############

HELP="Wrong usage\n
Usage: $0 USB_DEVICE\n
where:\n
- USB_DEVICE: Device to be partitioned. i.e. /dev/sdb\n"

###############
#  FUNCTIONS  #
###############

daemon_manager()
{
    if [ "${1}" == "start" ]; then
        nohup devmon > ~/logs/devmon.log 2>&1 &
    else
        killall devmon
    fi
}

trap 'su saes -c "daemon_manager start"' EXIT

# Function: die
# @param1: Message: Message to display
# @param2: Exitcode: Exit code to exit the script

die()
{
    echo -e ${1}
    exit ${2}
}

export -f daemon_manager

##########################
#  VALIDATING ARGUMENTS  #
##########################

if [ ${#} -lt 1 ]
then
    die "${HELP}" 1
fi

if [ "${1}" = "/dev/sda" ]
then
    die "E: Cannot operate over hard drive" 1
fi

#######################
#  DYNAMIC VARIABLES  #
#######################

DEVICE=${1}

###########
#  BEGIN  #
###########

echo "I: Unmounting all partitions in ${DEVICE}"

# Finding all paths mounted for $DEVICE
MOUNT_POINTS=$(cat /proc/mounts | grep ${DEVICE} | awk '{print $2}')
for mounted_path in ${MOUNT_POINTS}
do
    umount ${mounted_path} || die "E: Unable to unmount ${mounted_path}" 1
    rm -rf ${mounted_path}
done

daemon_manager stop

echo "I: Done unmounting all partitions in ${DEVICE}"

################
#  FORMATTING  #
################

echo "I: Starting formatting with fdisk..."
fdisk ${DEVICE} <<EOF
o
n
p
1
2048
+2048000
n
p
2

+204800
n
p
3

+8192000
a
3
t
1
b
t
2
ef
w
EOF

mkfs.vfat -c ${DEVICE}1 || die "Could not create FAT32 partition on ${DEVICE}1" 2
mkfs.vfat -c ${DEVICE}2 || die "Could not create EFI partition on ${DEVICE}2" 2
mkfs.ext3 -Fc ${DEVICE}3 || die "Could not create EXT3 partition on ${DEVICE}3" 2

echo "I: Removing dirty bit from FAT partition... "
fsck.fat ${DEVICE}1 -a
sync

echo "I: Done formatting"

#########
#  END  #
#########
