/**
 * BulkUploadClearDatabaseWorkerTest.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004, 2014 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.worker;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.core.classloader.annotations.PrepareForTest;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.ecm.client.ECMServiceProvider;

/**
 * Class to test BulkUploadClearDatabaseWorker.
 */
@RunWith(PowerMockRunner.class)
@PrepareForTest({ ECMServiceProvider.class, BulkUploadClearDatabaseWorker.class })
public class BulkUploadClearDatabaseWorkerTest {

	/**
	 * Prepares the test
	 * 
	 * @throws Exception
	 *             signals that an exception has occurred preparing the test.
	 *             This test should not throws any exception.
	 */
	@Before
	public void setUp() throws Exception {
		mockStaticMethods();
	}

	/**
	 * Test clearDataBase method.
	 * 
	 * @throws Exception
	 *             signals that an exception has occurred testing the method.
	 *             This test should not throws any exception.
	 */
	@Test
	public final void testClearDataBaseCaseEMLData() throws Exception {
		// arrange
		BulkUploadClearDatabaseWorker bulkUploadEMLFilesWorker = new BulkUploadClearDatabaseWorker(
				true);

		// act
		bulkUploadEMLFilesWorker.clearDataBase();

		// assert
		PowerMockito.verifyStatic();
		ECMServiceProvider.truncateLogicalVotingGroup();
		PowerMockito.verifyStatic();
		ECMServiceProvider.truncateEligibleOption();
		PowerMockito.verifyStatic();
		ECMServiceProvider.truncateCodiNominationTables();
		PowerMockito.verifyStatic();
		ECMServiceProvider.truncatePhysicalLocationsTables();
		PowerMockito.verifyStatic();
		ECMServiceProvider.deleteEMLFiles();
	}

	/**
	 * Test clearDataBase method.
	 * 
	 * @throws Exception
	 *             signals that an exception has occurred testing the method.
	 *             This test should not throws any exception.
	 */
	@Test
	public final void testClearDataBaseCaseSmttData() throws Exception {

		// arrange
		BulkUploadClearDatabaseWorker bulkUploadEMLFilesWorker = new BulkUploadClearDatabaseWorker(
				false);

		// act
		bulkUploadEMLFilesWorker.clearDataBase();

		// assert
		PowerMockito.verifyStatic();
		ECMServiceProvider.truncateLanguageTables();
		PowerMockito.verifyStatic();
		ECMServiceProvider.truncateNominationTables();
		PowerMockito.verifyStatic();
		ECMServiceProvider.truncateUserTables();
		PowerMockito.verifyStatic();
		ECMServiceProvider.truncatePhysicalLocationsTables();
		PowerMockito.verifyStatic();
		ECMServiceProvider.truncateDemographyTables();
		PowerMockito.verifyStatic();
		ECMServiceProvider.truncateReportTemplatesTables();
		PowerMockito.verifyStatic();
		ECMServiceProvider.deleteEMLFiles();
	}

	/**
	 * Prepares mock for ECMServiceProvider class
	 * 
	 * @throws Exception
	 *             signals that an exception has occurred preparing mock. This
	 *             test should not throws any exception.
	 */
	private void mockStaticMethods() throws Exception {
		PowerMockito.mockStatic(ECMServiceProvider.class);

		PowerMockito.doNothing().when(ECMServiceProvider.class,
				"truncateLogicalVotingGroup");

		PowerMockito.doNothing().when(ECMServiceProvider.class,
				"truncateEligibleOption");

		PowerMockito.doNothing().when(ECMServiceProvider.class,
				"truncateCodiNominationTables");

		PowerMockito.doNothing().when(ECMServiceProvider.class,
				"truncatePhysicalLocationsTables");

		PowerMockito.doNothing().when(ECMServiceProvider.class,
				"truncateLanguageTables");

		PowerMockito.doNothing().when(ECMServiceProvider.class,
				"truncateNominationTables");

		PowerMockito.doNothing().when(ECMServiceProvider.class,
				"truncateUserTables");

		PowerMockito.doNothing().when(ECMServiceProvider.class,
				"truncatePhysicalLocationsTables");

		PowerMockito.doNothing().when(ECMServiceProvider.class,
				"truncateDemographyTables");

		PowerMockito.doNothing().when(ECMServiceProvider.class,
				"truncateReportTemplatesTables");

		PowerMockito.doNothing().when(ECMServiceProvider.class,
				"deleteEMLFiles");
	}
}