package com.smartmatic.waffle.ecm.client.worker;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.io.FileUtils;
import org.junit.After;
import org.junit.Before;
import org.junit.Ignore;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mockito;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.core.classloader.annotations.PrepareForTest;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.ecm.client.ECMClientSideConstants;
import com.smartmatic.waffle.ecm.client.ECMServiceProvider;
import com.smartmatic.waffle.ecm.client.util.FileVerificationUtils;
import com.smartmatic.waffle.ecm.client.worker.data.FileBackup;
import com.smartmatic.waffle.ecm.data.transfer.type.USBGenerationType;

@RunWith(PowerMockRunner.class)
@PrepareForTest({ ECMServiceProvider.class, ECMClientSideConstants.class })
public class FileIntegrityVerificationWorkerTest {

	FileIntegrityVerificationWorker fileVerificationWorker;

	private static final String relativePath = "master_folder/test.xml";
	private static final String mounthedPath = "test/resources/";
	private static final String data = "StringTest";

	@Before
	public void setUp() throws IOException {

		Map<String, FileBackup> writtenFiles = new HashMap<String, FileBackup>();

		File dir = new File(mounthedPath, "master_folder");
		dir.mkdirs();

		File fileTest = new File(mounthedPath, relativePath);

		FileUtils.write(fileTest, data);

		FileBackup fileBackup = new FileBackup();
		fileBackup.setFile(fileTest);
		fileBackup.setHash(FileVerificationUtils.getDiskFileHash(fileTest));

		writtenFiles.put(relativePath, fileBackup);

		this.fileVerificationWorker = PowerMockito
				.spy(new FileIntegrityVerificationWorker(mounthedPath,
						writtenFiles, USBGenerationType.MASTER_USB));

	}

	@Test
	public void testGetRelativePath() {

		File file = new File(mounthedPath, relativePath);

		String relativePathResult = this.fileVerificationWorker
				.getRelativePath(file, mounthedPath);

		assertEquals(relativePath, relativePathResult);
	}

	@Test
	public void testGetFileData() throws Exception {

		File fileTest = new File(mounthedPath, relativePath);

		byte[] fileData = this.fileVerificationWorker.getFileData(fileTest);

		assertNotNull(fileData);

	}

	@Test
	@Ignore
	public void testVerifyDirectory() throws Exception {

		List<String> filesVerified = this.fileVerificationWorker
				.verifyDirectory("master_folder");

		String firstLineReturn = String
				.format("./%-120s | %-64s", "master_folder/test.xml",
						"791e8a4ee4dfd4ca604d579d66c880a93f4f8ff5bfff313ebf840d6e4ba84e9c");

		assertEquals(firstLineReturn, filesVerified.get(0));
	}

	@Test
	public void testRecoverFiles() throws Exception {

		PowerMockito.mockStatic(ECMServiceProvider.class);

		PowerMockito.when(
				ECMServiceProvider.getServerPropertyAsString(Mockito
						.anyString())).thenReturn("1");

		PowerMockito.mockStatic(ECMClientSideConstants.class);

		PowerMockito.doReturn(2).when(this.fileVerificationWorker,
				"getAttemptsToFileRecover");

		byte[] fileData = "File Data".getBytes();

		PowerMockito.doReturn(fileData).when(this.fileVerificationWorker,
				"getFileData", Mockito.any(byte[].class));

		List<String> nonConsistent = new ArrayList<String>();
		nonConsistent.add(relativePath);

		File saesFileTest = new File(mounthedPath, relativePath);

		FileUtils.writeByteArrayToFile(saesFileTest, fileData);

		boolean filesRecover = this.fileVerificationWorker
				.recoverFiles(nonConsistent);

		assertTrue(filesRecover);
	}

	@After
	public void clean() {
		File fileTest = new File(mounthedPath, "master_folder");
		FileUtils.deleteQuietly(fileTest);
	}
}
