/**
 * ImagesUploadWorkerTest.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.worker;

import static org.junit.Assert.assertTrue;

import java.io.File;
import java.io.IOException;

import org.apache.commons.io.FileUtils;
import org.junit.Before;
import org.junit.Test;

/**
 * Class used to test ImagesUploadVotingDeviceWorker.
 */
public class ImagesUploadWorkerTest {

	/** The images upload worker. */
	private ImagesUploadWorker imagesUploadWorker;

	/** The image test. */
	private File imageTest;

	/** The dest image test. */
	private File destImageTest;

	/**
	 * Setup.
	 */
	@Before
	public void setup() {
		this.imageTest = new File("test/resources/ImageTest.tar.gz");
		this.destImageTest = new File("test/ImageTestDest.tar.gz");
		this.imagesUploadWorker = new ImagesUploadWorker(this.imageTest,
				this.destImageTest);
	}

	/**
	 * Deletes temporary destination image.
	 * 
	 * @throws IOException
	 *             Signals that an I/O exception has occurred
	 */
	private void deleteDestImage() throws IOException {
		FileUtils.forceDelete(this.destImageTest);
	}

	/**
	 * Validate copied image.
	 * 
	 * @param image
	 *            the image
	 * @param srcImageHash
	 *            the source image hash
	 * @return true, if successful
	 */
	private boolean validateCopiedImage(File image, String srcImageHash) {

		if (image.exists()) {
			HashGetterWorker hashGetterWorker = new HashGetterWorker(image);

			String result = hashGetterWorker.getSHA256Hash();

			if (result.equals(srcImageHash)) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Test copy image.
	 * 
	 * @throws IOException
	 *             Signals that an I/O exception has occurred
	 */
	@Test
	public void testCopyImage() throws IOException {
		File srcFile = this.imageTest;
		File destFile = this.destImageTest;

		this.imagesUploadWorker.copyImage(srcFile, destFile);

		HashGetterWorker hashGetterWorker = new HashGetterWorker(srcFile);

		String srcHash = hashGetterWorker.getSHA256Hash();

		boolean result = validateCopiedImage(destFile, srcHash);

		assertTrue(result);

		deleteDestImage();
	}

}
