/**
 * SecurityComponentsExportWorkerTest.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.client.worker;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.security.PublicKey;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.apache.commons.codec.binary.Base64;
import org.apache.commons.io.FileUtils;
import org.junit.Before;
import org.junit.Ignore;
import org.junit.Test;

import com.smartmatic.waffle.domain.eligibleoption.ImageWrapper;
import com.smartmatic.waffle.ecm.core.util.SAESZipUtil;
import com.smartmatic.waffle.ecm.data.transfer.objects.VotingDeviceSecurityComponentsDTO;
import com.smartmatic.waffle.security.asymmetric.AsymmetricKeyManager;

/**
 * Class used to test <code>SecurityComponentsExportWorker</code>.
 */
public class SecurityComponentsExportWorkerTest {

	/** SecurityComponentsExportWorker instance. */
	SecurityComponentsExportWorker securityComponentsExportWorker;

	/**
	 * Setup method to instantiate needed classes to test.
	 */
	@Before
	public void setUp() throws Exception {
		this.securityComponentsExportWorker = new SecurityComponentsExportWorker();
	}

	/**
	 * Method to test <code>securityComponentsExport</code>.
	 * 
	 * @throws Exception
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception
	 */
	@Test
	@Ignore
	public void testSecurityComponentsExport() throws Exception {

		File exportTemporaryFolder = new File(
				"test/resources/ExportTemporaryFolder");

		File exportTemporaryFolderP12 = new File(
				"test/resources/ExportTemporaryFolder/ExportTemporaryFolderP12");

		File exportTemporaryFolderPublicKey = new File(
				"test/resources/ExportTemporaryFolder/ExportTemporaryFolderPem");

		File exportTemporaryFile = new File(exportTemporaryFolder,
				"VotingDeviceSecurityComponents.txt");

		List<VotingDeviceSecurityComponentsDTO> votingDeviceSecurityComponentsList = generateVotingDeviceSecurityComponentsFiles(
				exportTemporaryFolder, exportTemporaryFolderP12,
				exportTemporaryFolderPublicKey, exportTemporaryFile);

		assertTrue(exportTemporaryFile.exists());

		for (VotingDeviceSecurityComponentsDTO votingDeviceSecurityComponentsDTO : votingDeviceSecurityComponentsList) {
			assertTrue(new File(exportTemporaryFolder,
					"votingDeviceCertificate_"
							+ votingDeviceSecurityComponentsDTO.getCustomCode()
							+ ".p12").exists());
		}

		FileUtils.forceDeleteOnExit(exportTemporaryFolder);
	}

	/**
	 * Method to test compress security components files.
	 * 
	 * @throws Exception
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception
	 */
	@Test
	@Ignore
	public void testCompressSecurityComponents() throws Exception {

		File exportTemporaryFolder = new File(
				"test/resources/ExportTemporaryFolder");

		File exportTemporaryFolderP12 = new File(
				"test/resources/ExportTemporaryFolder/ExportTemporaryFolderP12");

		File exportTemporaryFile = new File(exportTemporaryFolder,
				"VotingDeviceSecurityComponents.txt");

		File exportTemporaryFolderPublicKey = new File(
				"test/resources/ExportTemporaryFolder/ExportTemporaryFolderPem");

		File zipFileP12 = new File(exportTemporaryFolder.getParent(),
				"VotingDeviceSecurityComponentsP12.zip");

		File zipFilePub = new File(exportTemporaryFolder.getParent(),
				"VotingDeviceSecurityComponentsPem.zip");

		File zipFile = new File(exportTemporaryFolder.getParent(),
				"VotingDeviceSecurityComponents.zip");

		generateAndCompressVotingDeviceSecurityComponentsFiles(
				exportTemporaryFolder, exportTemporaryFolderP12,
				exportTemporaryFolderPublicKey, exportTemporaryFile, zipFile,
				zipFileP12, zipFilePub);

		assertTrue(zipFile.exists());

		File outputFolder = new File("test/resources/OutputFolderToUnzip");

		SAESZipUtil.unZipFile(zipFile, outputFolder, null);

		assertTrue(new File(outputFolder,
				"votingDeviceCertificate_ANTWERPEN_001.p12").exists());
		assertTrue(new File(outputFolder,
				"votingDeviceCertificate_ANTWERPEN_002.p12").exists());
		assertTrue(new File(outputFolder,
				"votingDeviceCertificate_ANTWERPEN_003.p12").exists());
		assertTrue(new File(outputFolder, "VotingDeviceSecurityComponents.txt")
				.exists());

		FileUtils.forceDeleteOnExit(exportTemporaryFolder);
		FileUtils.forceDeleteOnExit(zipFile);
		FileUtils.forceDeleteOnExit(outputFolder);
	}

	/**
	 * Method to test copying zip file to final destination.
	 * 
	 * @throws Exception
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception
	 */
	@Test
	@Ignore
	public void testCopyZipFileToFinalDestination() throws Exception {

		File exportTemporaryFolder = new File(
				"test/resources/ExportTemporaryFolder");

		File exportTemporaryFolderP12 = new File(
				"test/resources/ExportTemporaryFolder/ExportTemporaryFolderP12");

		File exportTemporaryFolderPublicKey = new File(
				"test/resources/ExportTemporaryFolder/ExportTemporaryFolderPem");

		File exportTemporaryFile = new File(exportTemporaryFolder,
				"VotingDeviceSecurityComponents.txt");

		File zipFile = new File(exportTemporaryFolder.getParent(),
				"VotingDeviceSecurityComponents.zip");

		File zipFileP12 = new File(exportTemporaryFolder.getParent(),
				"VotingDeviceSecurityComponentsP12.zip");

		File zipFilePub = new File(exportTemporaryFolder.getParent(),
				"VotingDeviceSecurityComponentsPem.zip");

		File destFile = new File(exportTemporaryFolder,
				"VotingDeviceSecurityComponents.zip");

		generateAndCompressVotingDeviceSecurityComponentsFiles(
				exportTemporaryFolder, exportTemporaryFolderP12,
				exportTemporaryFolderPublicKey, exportTemporaryFile, zipFile,
				zipFileP12, zipFilePub);

		assertFalse(destFile.exists());

		this.securityComponentsExportWorker.copyZipFileToFinalDestination(
				zipFile, destFile);

		assertTrue(destFile.exists());

		FileUtils.forceDeleteOnExit(exportTemporaryFolder);
		FileUtils.forceDeleteOnExit(zipFile);
		FileUtils.forceDeleteOnExit(destFile);
	}

	/**
	 * Generates and compress voting device security components files.
	 * 
	 * @param exportTemporaryFolder
	 *            export temporary folder
	 * @param exportTemporaryFile
	 *            export temporary file
	 * @param zipFile
	 *            zip file reference to generate it
	 * @throws Exception
	 *             signal that some problem occurs testing the method
	 */
	public void generateAndCompressVotingDeviceSecurityComponentsFiles(
			File exportTemporaryFolder, File exportTemporaryFolderP12,
			File exportPublicKeyTemporaryFolder, File exportTemporaryFile,
			File zipFile, File zipFilep12, File zipFilePub) throws Exception {
		generateVotingDeviceSecurityComponentsFiles(exportTemporaryFolder,
				exportTemporaryFolderP12, exportPublicKeyTemporaryFolder,
				exportTemporaryFile);

		this.securityComponentsExportWorker.zipSecurityComponents(
				exportTemporaryFolder, zipFile, 0);
	}

	/**
	 * Generate voting device security components files.
	 * 
	 * @param exportTemporaryFolder
	 *            export temporary folder
	 * 
	 * @param exportTemporaryFile
	 *            export temporary file
	 * 
	 * @return voting device security components DTO list
	 * 
	 * @throws Exception
	 *             signal that some problem occurs running the method
	 */
	public List<VotingDeviceSecurityComponentsDTO> generateVotingDeviceSecurityComponentsFiles(
			File exportTemporaryFolder, File exportTemporaryFolderP12,
			File exportPublicKeyTemporaryFolder, File exportTemporaryFile)
			throws Exception {

		List<VotingDeviceSecurityComponentsDTO> votingDeviceSecurityComponentsList = retrieveVotingDeviceSecurityComponentsTestList();

		List<String> votingDevicesSecurityComponentsLinesList = new ArrayList<String>();

		votingDevicesSecurityComponentsLinesList.add(String.format(
				"%-30s | %-30s | %-16s | %-16s | %-13s | %-44s", "Name",
				"Custom Code", "President Key", "Recounter Key",
				"Numeric Key 1", "Protection Key"));

		this.securityComponentsExportWorker.exportSecurityComponents(
				votingDeviceSecurityComponentsList, exportTemporaryFolder,
				exportTemporaryFolderP12, exportPublicKeyTemporaryFolder,
				exportTemporaryFile, votingDevicesSecurityComponentsLinesList);

		return votingDeviceSecurityComponentsList;
	}

	/**
	 * Retrieve voting device security components test list.
	 * 
	 * @return voting device security components list
	 * 
	 * @throws Exception
	 *             signal that some problem occurs running the method
	 */
	private List<VotingDeviceSecurityComponentsDTO> retrieveVotingDeviceSecurityComponentsTestList()
			throws Exception {

		Collection<Object[]> votingDeviceObjects = retrieveVotingDeviceObjectCollection();

		List<VotingDeviceSecurityComponentsDTO> votingDeviceSecurityComponentsList = new ArrayList<VotingDeviceSecurityComponentsDTO>();

		for (Object[] votingDeviceObject : votingDeviceObjects) {
			String votingDeviceCustomCode = (String) votingDeviceObject[1];
			String votingDeviceName = (String) votingDeviceObject[2];
			String votingDeviceProtectionKey = (String) votingDeviceObject[3];
			String votingDeviceTransmissionKey = (String) votingDeviceObject[4];
			String votingDevicePresidentKey = (String) votingDeviceObject[5];
			String votingDeviceNumericKey1 = (String) votingDeviceObject[6];
			String votingDeviceNumericKey2 = (String) votingDeviceObject[7];
			ImageWrapper votingDeviceAsymmetricKey = (ImageWrapper) votingDeviceObject[8];
			String votingDeviceRecounterKey = (String) votingDeviceObject[9];

			ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(
					votingDeviceAsymmetricKey.getBinaryData());

			PublicKey publicKey = AsymmetricKeyManager.getPublicKey(
					byteArrayInputStream, votingDeviceProtectionKey,
					"anyAlias", votingDeviceProtectionKey,
					AsymmetricKeyManager.KEYSTORE_PKCS12);

			String encodePrivateKey = Base64.encodeBase64String(publicKey
					.getEncoded());

			VotingDeviceSecurityComponentsDTO votingDeviceSecurityComponents = new VotingDeviceSecurityComponentsDTO(
					votingDeviceName, encodePrivateKey,
					votingDeviceProtectionKey, votingDeviceCustomCode,
					votingDeviceTransmissionKey, votingDevicePresidentKey,
					votingDeviceNumericKey1, votingDeviceNumericKey2,
					votingDeviceAsymmetricKey.getBinaryData(),
					votingDeviceRecounterKey);

			votingDeviceSecurityComponentsList
					.add(votingDeviceSecurityComponents);
		}

		return votingDeviceSecurityComponentsList;
	}

	private Collection<Object[]> retrieveVotingDeviceObjectCollection()
			throws Exception {
		Collection<Object[]> votingDeviceDataCollection = new ArrayList<Object[]>();

		Object[] votingDeviceObject1 = { 1, "ANTWERPEN_001", "ANTWERPEN001",
				"TMxlye0+OooDceeQwbCI02Y0q4JrOs+pyrLzJrZu3X0=",
				"fGvfw6xGy2c1S9h7kTj9e63W4yaPOzXSoWagkB+buQc=",
				"cbrtshfgaquvynco", "124385", "335369", null,
				"fbycbfooqqubccps" };

		votingDeviceDataCollection.add(votingDeviceObject1);

		Object[] votingDeviceObject2 = { 2, "ANTWERPEN_002", "ANTWERPEN002",
				"TMxlye0+OooDceeQwbCI02Y0q4JrOs+pyrLzJrZu3X0=",
				"fGvfw6xGy2c1S9h7kTj9e63W4yaPOzXSoWagkB+buQc=",
				"cbrtshfgaquvynco", "124385", "335369", null,
				"fbycbfooqqubccps" };

		votingDeviceDataCollection.add(votingDeviceObject2);

		Object[] votingDeviceObject3 = { 3, "ANTWERPEN_003", "ANTWERPEN003",
				"TMxlye0+OooDceeQwbCI02Y0q4JrOs+pyrLzJrZu3X0=",
				"fGvfw6xGy2c1S9h7kTj9e63W4yaPOzXSoWagkB+buQc=",
				"cbrtshfgaquvynco", "124385", "335369", null,
				"fbycbfooqqubccps" };

		votingDeviceDataCollection.add(votingDeviceObject3);
		return votingDeviceDataCollection;
	}
}
