/**
 * SAESTARGZUtil.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.core.tar.gz;

import java.io.BufferedOutputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.zip.GZIPInputStream;
import java.util.zip.GZIPOutputStream;

import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
import org.apache.commons.compress.archivers.tar.TarArchiveOutputStream;
import org.apache.commons.io.FileUtils;
import org.apache.tools.tar.TarEntry;
import org.apache.tools.tar.TarInputStream;

/**
 * Utility class used to compress files
 * 
 * @version 1.0 (05/05/2011)
 * @author Hector Rodri­guez (hector.rodriguez@smartmatic.com)
 */
public class SAESTARGZUtil {

	/**
	 * Tar file.
	 * 
	 * @param files
	 *            the files
	 * @return the byte[]
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	public static byte[] tarFile(File... files) throws IOException {

		ByteArrayOutputStream out = new ByteArrayOutputStream();
		BufferedOutputStream bout = new BufferedOutputStream(out);
		GZIPOutputStream zip = new GZIPOutputStream(bout);
		TarArchiveOutputStream tar = new TarArchiveOutputStream(zip);
		try {
			for (File file : files) {
				File localFile = new File(file.getName());
				TarArchiveEntry archiveEntry = new TarArchiveEntry(localFile);
				archiveEntry.setSize(file.length());
				tar.putArchiveEntry(archiveEntry);
				tar.write(FileUtils.readFileToByteArray(file));
				tar.closeArchiveEntry();
			}
			tar.finish();
		} finally {

			if (tar != null) {
				tar.flush();
				tar.close();
			}
			if (zip != null) {
				zip.flush();
				zip.close();
			}
		}
		return out.toByteArray();
	}

	public static void untar(String tarFileName, File dest) throws IOException {

		// assuming the file you pass in is not a dir

		dest.mkdir();

		// create tar input stream from a .tar.gz file

		TarInputStream tin = new TarInputStream(new GZIPInputStream(
				new FileInputStream(new File(tarFileName))));

		// get the first entry in the archive

		TarEntry tarEntry = tin.getNextEntry();

		while (tarEntry != null) {// create a file with the same name as the
								  // tarEntry

			File destPath = new File(dest.toString() + File.separatorChar
					+ tarEntry.getName());

			if (tarEntry.isDirectory()) {

				destPath.mkdir();

			} else {

				FileOutputStream fout = new FileOutputStream(destPath);

				tin.copyEntryContents(fout);

				fout.close();
			}
			tarEntry = tin.getNextEntry();
		}
		tin.close();
	}

}
