/**
 * SAESCommandUtil.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.core.util;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;

import com.smartmatic.waffle.log.SMTTLogger;

/**
 * Class used to perform a common command.
 */
public class SAESCommandUtil {

	/** The logger. */
	private static SMTTLogger logger = SMTTLogger
			.getLogger(SAESCommandUtil.class);

	private static ProcessBuilder prepareProcess(String command,
			boolean executeAsSudo, String... params) {
		ProcessBuilder processBuilder = new ProcessBuilder();
		List<String> full = new ArrayList<String>();
		StringBuilder parameters = new StringBuilder();

		if (executeAsSudo) {
			parameters.append("sudo ");
		}

		parameters.append("%s");
		full.add(command);
		for (String param : params) {
			parameters.append(" %s");
			full.add(param);
		}

		Object[] parameter = full.toArray(new String[0]);

		String formatted = String.format(parameters.toString(), parameter);

		processBuilder.command("sh", "-c", formatted);

		return processBuilder;
	}

	/**
	 * Command executor method.
	 * 
	 * @param command
	 *            the command to execute
	 * @param executeAsSudo
	 *            defines id execute the command as sudo
	 * @param params
	 *            the command params
	 * 
	 * @return the process object which can be used to get information about how
	 *         the (completed) process ran
	 */
	public static Process execute(String command, boolean executeAsSudo,
			String... params) {
		try {
			ProcessBuilder processBuilder = prepareProcess(command,
					executeAsSudo, params);

			logger.info("Excecuting command: " + processBuilder.command());

			Process process = processBuilder.start();

			process.waitFor();

			return process;

		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new RuntimeException(
					StringUtils.defaultString(e.getMessage()), e);
		}
	}

	/**
	 * Command executor method.
	 * 
	 * @param command
	 *            the command to execute
	 * @param params
	 *            the command params
	 * 
	 * @return the process object which can be used to get information about how
	 *         the (completed) process ran
	 */
	public static Process execute(String command, String... params) {
		return execute(command, false, params);
	}

	public static Process executeAsync(String command, boolean executeAsSudo,
			String... params) {

		try {
			ProcessBuilder processBuilder = prepareProcess(command,
					executeAsSudo, params);

			logger.info("Excecuting command: " + processBuilder.command());

			Process process = processBuilder.start();

			return process;

		} catch (Exception e) {
			logger.error(e, StringUtils.defaultString(e.getMessage()));
			throw new RuntimeException(
					StringUtils.defaultString(e.getMessage()), e);
		}
	}
}
