/**
 * ColumnOfQueryDTO.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.data.transfer.objects;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Class used to group relevant information about the result of execute data
 * integrity queries.
 */
public class ColumnOfQueryDTO implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = -902207527867363945L;

    /***
     * Title to show in result table.
     */
    private String columnName;

    /** The values by rows. */
    private final Map<Integer, List<String>> valuesByRows;

    /** The maximum number elemens. */
    private int maxNumberElemens;

    /**
     * Returns the maximum number of elements.
     * 
     * @return maximum value
     */
    public int getMaxnumberElemens() {
        return this.maxNumberElemens;
    }

    /**
     * * Creates a new DtoColumnOfQuery.
     * 
     * @param columnName
     *            the column name
     */
    public ColumnOfQueryDTO(String columnName) {
        this.columnName = columnName;
        this.valuesByRows = new HashMap<Integer, List<String>>();
        this.maxNumberElemens = 0;
    }

    /**
     * Creates a new DtoColumnOfQuery.
     */
    public ColumnOfQueryDTO() {
        this.valuesByRows = new HashMap<Integer, List<String>>();
        this.maxNumberElemens = 0;
    }

    /**
     * * Getter of {@link #columnName} property.
     * 
     * @return property value
     */
    public String getColumnName() {
        return this.columnName;
    }

    /**
     * * Setter of {@link #columnName} property.
     * 
     * @param columnName
     *            property value
     */
    public void setColumnName(String columnName) {
        this.columnName = columnName;
    }

    /**
     * * Adds or updates values to specific row.
     * 
     * @param row
     *            the row
     * @param value
     *            the value
     */
    public void addValuesByRows(Integer row, String value) {
        int currentSize;
        List<String> valuesList;
        if (this.valuesByRows.containsKey(row)) {
            valuesList = this.valuesByRows.get(row);
            valuesList.add(value);
            currentSize = valuesList.size();
        } else {
            valuesList = new ArrayList<String>();
            valuesList.add(value);
            currentSize = valuesList.size();
            this.valuesByRows.put(row, valuesList);
        }
        if (currentSize > this.maxNumberElemens) {
            this.maxNumberElemens = currentSize;
        }

    }

    /**
     * * Adds or updates values to specific row.
     * 
     * @param row
     *            the row
     * @param values
     *            the values
     */
    public void addValuesByRows(Integer row, List<String> values) {
        for (String current : values) {
            addValuesByRows(row, current);
        }
    }

    /**
     * * Returns a list of row values.
     * 
     * @param row
     *            the row
     * @return the values
     */
    public List<String> getValues(Integer row) {
        List<String> valuesToRetun = this.valuesByRows.get(row);
        if (valuesToRetun == null) {
            valuesToRetun = new ArrayList<String>();
        }
        while (this.maxNumberElemens > valuesToRetun.size()) {
            valuesToRetun.add("-");
        }
        return valuesToRetun;
    }

}
