/**
 * ElectionObjectDTO.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.data.transfer.objects;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.smartmatic.waffle.domain.contest.ContestGroupData;
import com.smartmatic.waffle.domain.demographics.RegionData;
import com.smartmatic.waffle.domain.device.DeviceParameterData;
import com.smartmatic.waffle.domain.i18n.LanguageData;

/**
 * Class that hold relevant information for test data generation.
 */
public class ElectionObjectDTO {

    /**
     * Device {@link DeviceParameterData parameters} associated to
     * the election contained by {@link #electionDto}.
     */
    private List<DeviceParameterData> devParams;

    /** The region language map. */
    private Map<Long, Set<LanguageData>> regionLanguageMap;

    /** The electionDto. */
    private ElectionXmlComponentsDTO electionDto;

    /** The last level region to process. */
    private List<RegionData> lastLevelRegionToProcess;

    /** The region contest group. */
    private Map<Long, List<ContestGroupData>> regionContestGroup;

    /** The resources languages. */
    private Map<String, Map<String, String>> resourcesLanguages;


    /**
     * No Arguments Class Constructor.
     */
    public ElectionObjectDTO() {
        super();
        this.devParams = new ArrayList<DeviceParameterData>();
    }


    /**
     * Returns those device {@link DeviceParameterData parameters} associated
     * to the election contained by {@link #getElectionDto()}.
     *
     * @return
     *      {@code List<DeviceParameterData>} (never {@code null})
     */
    public List<DeviceParameterData> getDeviceParameters() {
        return this.devParams;
    }


    /**
     * Configures the device {@link DeviceParameterData parameters}
     * associated to the election contained by {@link #getElectionDto()}.
     *
     * @param params
     *      a collection of {@code DeviceParameterData}
     */
    public void setDeviceParameters(Collection<DeviceParameterData> params) {
        this.devParams.clear();

        if (params != null) {
            for (DeviceParameterData p : params) {
                this.devParams.add(p);
            }
        }
    }


    /**
     * Getter of <code>resourcesLanguages</code> property.
     * 
     * @return <code>resourcesLanguages</code> property value.
     * @see #resourcesLanguages
     */
    public Map<String, Map<String, String>> getResourcesLanguages() {
        return this.resourcesLanguages;
    }

    /**
     * Setter of <code>resourcesLanguages</code> property.
     * 
     * @param resourcesLanguages
     *            The <code>resourcesLanguages</code> to set.
     * @see #resourcesLanguages
     */
    public void setResourcesLanguages(
            Map<String, Map<String, String>> resourcesLanguages) {
        this.resourcesLanguages = resourcesLanguages;
    }

    /**
     * Getter of <code>regionContestGroup</code> property.
     * 
     * @return <code>regionContestGroup</code> property value.
     * @see #regionContestGroup
     */

    public Map<Long, List<ContestGroupData>> getRegionContestGroup() {
        return this.regionContestGroup;
    }

    /**
     * Setter of <code>regionContestGroup</code> property.
     * 
     * @param regionContestGroup
     *            The <code>regionContestGroup</code> to set.
     * @see #regionContestGroup
     */
    public void setRegionContestGroup(
            Map<Long, List<ContestGroupData>> regionContestGroup) {
        this.regionContestGroup = regionContestGroup;
    }

    /**
     * Getter of <code>electionDto</code> property.
     * 
     * @return <code>electionDto</code> property value.
     * @see #electionDto
     */

    public ElectionXmlComponentsDTO getElectionDto() {
        return this.electionDto;
    }

    /**
     * Setter of <code>electionDto</code> property.
     * 
     * @param electionDto
     *            The <code>electionDto</code> to set.
     * @see #electionDto
     */
    public void setElectionDto(ElectionXmlComponentsDTO electionDto) {
        this.electionDto = electionDto;
    }

    /**
     * Getter of <code>regionLanguageMap</code> property.
     * 
     * @return <code>regionLanguageMap</code> property value.
     * @see #regionLanguageMap
     */

    public Map<Long, Set<LanguageData>> getRegionLanguageMap() {
        return this.regionLanguageMap;
    }

    /**
     * Setter of <code>regionLanguageMap</code> property.
     * 
     * @param regionLanguageMap
     *            The <code>regionLanguageMap</code> to set.
     * @see #regionLanguageMap
     */
    public void setRegionLanguageMap(
            Map<Long, Set<LanguageData>> regionLanguageMap) {
        this.regionLanguageMap = regionLanguageMap;
    }

    /**
     * Getter of <code>lastLevelRegionToProcess</code> property.
     * 
     * @return <code>lastLevelRegionToProcess</code> property value.
     * @see #lastLevelRegionToProcess
     */

    public List<RegionData> getLastLevelRegionToProcess() {
        return this.lastLevelRegionToProcess;
    }

    /**
     * Setter of <code>lastLevelRegionToProcess</code> property.
     * 
     * @param lastLevelRegionToProcess
     *            The <code>lastLevelRegionToProcess</code> to set.
     * @see #lastLevelRegionToProcess
     */
    public void setLastLevelRegionToProcess(
            List<RegionData> lastLevelRegionToProcess) {
        this.lastLevelRegionToProcess = lastLevelRegionToProcess;
    }
}
