/**
 * VotingDeviceKeysDTO.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.data.transfer.objects;

import java.io.Serializable;

/**
 * Class that holds voting device security information from server to be send to
 * client.
 */
public class VotingDeviceSecurityComponentsDTO implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 8867571407251327395L;

    /** The name. */
    String name;

    /** The asymmetric key. */
    String asymmetricKey;

    /** The protection key. */
    String protectionKey;

    /** The custom code. */
    String customCode;

    /** The transmission key. */
    String transmissionKey;

    /** The president key. */
    String presidentKey;

    /** The numeric key1. */
    String numericKey1;

    /** The numeric key2. */
    String numericKey2;

    /** The recounter key. */
    String recounterKey;

    /** The binary certificate. */
    byte[] binaryCertificate;

    /**
     * Instantiates a new voting device keys dto.
     * 
     * @param name
     *            the name
     * @param asymmetricKey
     *            the asymmetric key
     * @param protectionKey
     *            the protection key
     * @param customCode
     *            the custom code
     * @param transmissionKey
     *            the transmission key
     * @param presidentKey
     *            the president key
     * @param numericKey1
     *            the numeric key1
     * @param numericKey2
     *            the numeric key2
     * @param binaryCertificate
     *            the binary certificate
     */
    public VotingDeviceSecurityComponentsDTO(String name, String asymmetricKey,
            String protectionKey, String customCode, String transmissionKey,
            String presidentKey, String numericKey1, String numericKey2,
            byte[] binaryCertificate, String recounterKey) {
        super();
        this.name = name;
        this.asymmetricKey = asymmetricKey;
        this.protectionKey = protectionKey;
        this.customCode = customCode;
        this.transmissionKey = transmissionKey;
        this.presidentKey = presidentKey;
        this.numericKey1 = numericKey1;
        this.numericKey2 = numericKey2;
        if (binaryCertificate != null) {
            this.binaryCertificate = binaryCertificate.clone();
        }
        this.recounterKey = recounterKey;
    }

    /**
     * Instantiates a new voting device keys dto.
     */
    public VotingDeviceSecurityComponentsDTO() {
        super();
    }

    /**
     * Getter of name property.
     * 
     * @return the name property value
     */
    public String getName() {
        return this.name;
    }

    /**
     * Setter of name property.
     * 
     * @param name
     *            property value
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Getter of asymmetricKey property.
     * 
     * @return the asymmetricKey value
     */
    public String getAsymmetricKey() {
        return this.asymmetricKey;
    }

    /**
     * Setter of asymmetricKey property.
     * 
     * @param asymmetricKey
     *            property value
     */
    public void setAsymmetricKey(String asymmetricKey) {
        this.asymmetricKey = asymmetricKey;
    }

    /**
     * Getter of protectionKey property.
     * 
     * @return protectionKey property value
     */
    public String getProtectionKey() {
        return this.protectionKey;
    }

    /**
     * Setter of protectionKey property.
     * 
     * @param protectionKey
     *            property value
     */
    public void setProtectionKey(String protectionKey) {
        this.protectionKey = protectionKey;
    }

    /**
     * Getter of customCode property.
     * 
     * @return customCode property value
     */
    public String getCustomCode() {
        return this.customCode;
    }

    /**
     * Setter of customCode property.
     * 
     * @param customCode
     *            property value
     */
    public void setCustomCode(String customCode) {
        this.customCode = customCode;
    }

    /**
     * Getter of transmissionKey property.
     * 
     * @return transmissionKey property value
     */
    public String getTransmissionKey() {
        return this.transmissionKey;
    }

    /**
     * Setter of transmissionKey property.
     * 
     * @param transmissionKey
     *            property value
     */
    public void setTransmissionKey(String transmissionKey) {
        this.transmissionKey = transmissionKey;
    }

    /**
     * Getter of presidentKey property.
     * 
     * @return property value
     */
    public String getPresidentKey() {
        return this.presidentKey;
    }

    /**
     * Setter of presidentKey property.
     * 
     * @param presidentKey
     *            property value
     */
    public void setPresidentKey(String presidentKey) {
        this.presidentKey = presidentKey;
    }

    /**
     * Getter of numeric key 1 property.
     * 
     * @return numeric key 1 property value
     */
    public String getNumericKey1() {
        return this.numericKey1;
    }

    /**
     * Setter of numericKey1 property.
     * 
     * @param numericKey1
     *            property value
     */
    public void setNumericKey1(String numericKey1) {
        this.numericKey1 = numericKey1;
    }

    /**
     * Getter of numericKey2 property.
     * 
     * @return numericKey2 property value
     */
    public String getNumericKey2() {
        return this.numericKey2;
    }

    /**
     * Setter of numericKey2 property.
     * 
     * @param numericKey2
     *            property value
     */
    public void setNumericKey2(String numericKey2) {
        this.numericKey2 = numericKey2;
    }

    /**
     * Getter of binaryCertificate property.
     * 
     * @return binaryCertificate property value
     */
    public byte[] getBinaryCertificate() {
        return this.binaryCertificate;
    }

    /**
     * Setter of binaryCertificate property.
     * 
     * @param binaryCertificate
     *            property value
     */
    public void setBinaryCertificate(byte[] binaryCertificate) {
        if (binaryCertificate != null) {
            this.binaryCertificate = binaryCertificate.clone();
        }
    }

    /**
     * Gets the recounter key.
     * 
     * @return the recounter key
     */
    public String getRecounterKey() {
        return recounterKey;
    }

    /**
     * Sets the recounter key.
     * 
     * @param recounterKey
     *            the new recounter key
     */
    public void setRecounterKey(String recounterKey) {
        this.recounterKey = recounterKey;
    }
}
