/*
 * SmttFileType.java
 * 
 * Copyright (c) 2022 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.data.transfer.type;

/**
 * Enum to define each Smartmatic file admitted by ECM to perform bulk upload.
 *
 * @author Frederick Faria (frederick.faria@smartmatic.com)
 * @version 1.1.0 (2022/05/30)
 */
public enum SmttFileType {

    /**
     * Ballot Layout.
     */
    BALLOT_LAYOUT,

    /**
     * Ballot Option.
     */
    BALLOT_OPTION,

    /**
     * Candidate.
     */
    CANDIDATE,

    /**
     * Category.
     */
    CATEGORY,

    /**
     * Contest.
     */
    CONTEST,

    /**
     * Contest Class.
     */
    CONTEST_CLASS,

    /**
     * Contest Group.
     */
    CONTEST_GROUP,

    /**
     * Device Parameter.
     */
    DEVICE_PARAMETER,

    /**
     * District.
     */
    DISTRICT,

    /**
     * Election.
     */
    ELECTION,

    /**
     * Electoral Authority.
     */
    ELECTORAL_AUTHORITY,

    /**
     * Eligible Option.
     */
    ELIGIBLE_OPTION,

    /**
     * Eligible Option Role.
     */
    ELIGIBLE_OPTION_ROL,

    /**
     * Keystore.
     */
    KEYSTORE,

    /**
     * Language.
     */
    LANGUAGE,

    /**
     * Multilingual Key.
     */
    MULTILINGUAL_KEY,

    /**
     * Party.
     */
    PARTY,

    /**
     * Path.
     */
    PATH,

    /**
     * Polling Place.
     */
    POLLING_PLACE,

    /**
     * Polling Station.
     */
    POLLING_STATION,

    /**
     * Profile.
     */
    PROFILE,

    /**
     * Programming Unit.
     */
    PROGRAMMING_UNIT,

    /**
     * Region.
     */
    REGION,

    /**
     * Report Template.
     */
    REPORT_TEMPLATE,

    /**
     * Resource.
     */
    RESOURCE,

    /**
     * Sites.
     */
    SITES,

    /**
     * Translation Key.
     */
    TRANSLATION_KEY,

    /**
     * User.
     */
    USER,

    /**
     * Voting Booth.
     */
    VOTING_BOOTH,

    /**
     * Voting Device.
     */
    VOTING_DEVICE;

    /**
     * Hold the translation of each type.
     */
    private String translatedName;

    /**
     * Returns an array that defines how the <i>Smartmatic</i> files should be
     * uploaded and processed by the ECM backend.
     */
    public static SmttFileType[] bulkloadOrder() {
        return new SmttFileType[] { DEVICE_PARAMETER, KEYSTORE, ELECTION,
                CATEGORY, REGION, PROGRAMMING_UNIT, PATH, DISTRICT,
                BALLOT_LAYOUT, CONTEST_CLASS, CONTEST, CONTEST_GROUP, PARTY,
                CANDIDATE, ELIGIBLE_OPTION, ELIGIBLE_OPTION_ROL, BALLOT_OPTION,
                LANGUAGE, ELECTORAL_AUTHORITY, PROFILE, USER, POLLING_PLACE,
                POLLING_STATION, VOTING_DEVICE, VOTING_BOOTH, SITES,
                REPORT_TEMPLATE, MULTILINGUAL_KEY, TRANSLATION_KEY, RESOURCE };
    }

    /**
     * Gets the type for key.
     * 
     * @param key
     *            the key
     * @return the type for key
     */
    public static SmttFileType stringToSmttFileType(String smttFileType) {
        return SmttFileType.valueOf(smttFileType);
    }

    /**
     * Gets the translation of each type.
     * 
     * @return the translation of each type
     */
    public String getTranslatedName() {
        return (this.translatedName == null || this.translatedName.isEmpty())
                ? this.toString()
                : this.translatedName;
    }

    /**
     * Sets the translation of each type.
     * 
     * @param translatedName
     *            the translation of each type
     */
    public void setTranslatedName(String translatedName) {
        this.translatedName = translatedName;
    }
}
