/**
 * DemographyException.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.lang;

import com.smartmatic.waffle.ecm.core.lang.ECMBaseException;
import com.smartmatic.waffle.ecm.core.lang.IECMExceptionInfo;

/**
 * Class to handle any exception that may occur executing a demography
 * operation.
 */
public class DemographyException extends ECMBaseException {

	/**
	 * Holds the version of the class. It is used by the serialization engine to
	 * determine when a class its equivalent to another
	 */
	private static final long serialVersionUID = 1042224267124632834L;

	/**
	 * Enum that contains all the possible reasons because the
	 * DemographyException can be thrown.
	 */
	public enum DemographyExceptionInfo implements IECMExceptionInfo {

		RETRIEVING_PROGRAMMING_UNIT_AMOUNT_FAILURE(
				"retrieving.programming.units.amount.failure"), SETTING_PROTECTION_KEY_TO_PROGRAMMING_UNIT_FAILURE(
				"setting.protection.key.to.programming.unit.failure"), DELETING_PROGRAMMING_UNIT_SECURITY_COMPONENTS_FAILURE(
				"deleting.programming.unit.security.components.failure"), PROBLEM_RETRIEVING_LAST_LEVEL_REGION_BY_REGION_CODES(
				"problem.retrieving.last.level.region.by.region.codes"), PROBLEM_RETRIEVING_LAST_LEVEL_REGION_PARENTS_LANGUAGES(
				"problem.retrieving.last.level.region.parents.languages"), NO_REGIONS_WERE_FOUND_FAILURE(
				"no.regions.were.found.failure"), PROBLEM_GETTING_PROGRAMMING_UNITS_BY_REGIONS(
				"problem.getting.programming.units.by.regions"), PROBLEM_GETTING_ALL_PARENTS_REGIONS(
				"problem.getting.all.parents.regions"), PROBLEM_CHECKING_REGION_PARENT_PATH(
				"problem.checking.region.parent.path"), PROBLEM_GETTING_AVAILABLE_REGIONS_FOR_WIDGET(
				"problem.getting.available.regions.for.widget");

		/**
		 * Variable to hold the exception message.
		 */
		private String exceptionMessage;

		/**
		 * Variable to hold the bundle key to show a user understandable
		 * message.
		 */
		private String bundleKey;

		/**
		 * Gets the variable to hold the exception message.
		 * 
		 * @return the variable to hold the exception message
		 * @inheritDoc
		 */
		@Override
		public String getExceptionMessage() {
			return this.exceptionMessage;
		}

		/**
		 * Gets the variable to hold the bundle key to show a user
		 * understandable message.
		 * 
		 * @return the variable to hold the bundle key to show a user
		 *         understandable message
		 * @inheritDoc
		 */
		@Override
		public String getBundleKey() {
			return this.bundleKey;
		}

		/**
		 * Constructor.
		 * 
		 * @param bundleKey
		 *            Resource bundle's key message
		 */
		private DemographyExceptionInfo(String bundleKey) {
			this.bundleKey = bundleKey;
		}

		/**
		 * Constructor.
		 * 
		 * @param bundleKey
		 *            Resource bundle's key message
		 * @param exceptionMessage
		 *            Exception message
		 */
		private DemographyExceptionInfo(String bundleKey,
				String exceptionMessage) {
			this.bundleKey = bundleKey;
			this.exceptionMessage = exceptionMessage;
		}

	}

	/**
	 * Instantiates an DemographyException.
	 * 
	 * @param throwable
	 *            a nested exception
	 * 
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 */
	public DemographyException(Throwable throwable,
			DemographyExceptionInfo exceptionInfo) {
		super(throwable, exceptionInfo);
	}

	/**
	 * Instantiates an DemographyException.
	 * 
	 * @param throwable
	 *            a nested exception
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 * @param exceptionMessage
	 *            Exception message of nested exception
	 */
	public DemographyException(Throwable throwable,
			DemographyExceptionInfo exceptionInfo, String exceptionMessage) {
		super(throwable, exceptionInfo, exceptionMessage);
	}

	/**
	 * Instantiates an DemographyException.
	 * 
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 */
	public DemographyException(DemographyExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/*
	 * @inheritDoc
	 */
	@Override
	public String getBundleKey() {
		return this.getClass().getSimpleName() + "."
				+ this.exceptionInfo.getBundleKey();
	}
}
