/**
 * ElectoralDemographyException.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.lang;

import com.smartmatic.waffle.ecm.core.lang.ECMBaseException;
import com.smartmatic.waffle.ecm.core.lang.IECMExceptionInfo;

/**
 * Class to handle any exception that may occur executing a electoral demography
 * operation.
 */
public class ElectoralDemographyException extends ECMBaseException {

	/**
	 * Holds the version of the class. It is used by the serialization engine to
	 * determine when a class its equivalent to another
	 */
	private static final long serialVersionUID = 1042224267124632834L;

	/**
	 * Enum that contains all the possible reasons because the
	 * ElectoralDemographyException can be thrown.
	 */
	public enum ElectoralDemographyExceptionInfo implements IECMExceptionInfo {

		PROBLEM_RETRIEVING_CONTEST_LIST_BY_LAST_LEVEL_REGION(
				"problem.retrieving.contest.list.by.last.level.region"), PROBLEM_RETRIEVING_CONTEST_BY_DISTRICT(
				"problem.retrieving.contest.by.district"), PROBLEM_RETRIEVING_CONTEST_GROUP_LIST_BY_LAST_LEVEL_REGION(
				"problem.retrieving.contest.group.list.by.last.level.region"), PROBLEM_RETRIEVING_CONTEST_GROUP_LOADED_IN_DATABASE(
				"problem.retrieving.contest.group.loaded.in.data.base"), PROBLEM_RETRIEVING_CONTEST_LIST_BY_CONTESTS_PERMUTATION(
				"problem.retrieving.contest.list.by.contests.permutation"), PROBLEM_GETTING_CONTEST_BY_CODE(
				"problem.getting.contest.by.code"), PROBLEM_GETTING_LOGICAL_VOTING_GROUP(
				"problem.getting.logical.voting.group"), PROBLEM_GETTING_CONTEST_GROUP_BY_CUSTOM_CODE(
				"problem.getting.contest.group.by.custom.code"), PROBLEM_GETTING_LOGICAL_VOTING_GROUP_BY_CONTEST_GROUP(
				"problem.getting.logical.voting.group.by.contest.group"), PROBLEM_GETTING_MAX_CONTEST_GROUP_CODE(
				"problem.getting.max.contest.group.code"), PROBLEM_GETTING_DISTRICT_LANGUAGES(
				"problem.getting.district.languages"), PROBLEM_EXECUTING_PERSIST_PROCEDURE(
				"problem.executing.persist.procedure");

		/**
		 * Variable to hold the exception message.
		 */
		private String exceptionMessage;

		/**
		 * Variable to hold the bundle key to show a user understandable
		 * message.
		 */
		private String bundleKey;

		/**
		 * Gets the variable to hold the exception message.
		 * 
		 * @return the variable to hold the exception message
		 * @inheritDoc
		 */
		@Override
		public String getExceptionMessage() {
			return this.exceptionMessage;
		}

		/**
		 * Gets the variable to hold the bundle key to show a user
		 * understandable message.
		 * 
		 * @return the variable to hold the bundle key to show a user
		 *         understandable message
		 * @inheritDoc
		 */
		@Override
		public String getBundleKey() {
			return this.bundleKey;
		}

		/**
		 * Constructor.
		 * 
		 * @param bundleKey
		 *            Resource bundle's key message
		 */
		private ElectoralDemographyExceptionInfo(String bundleKey) {
			this.bundleKey = bundleKey;
		}

		/**
		 * Constructor.
		 * 
		 * @param bundleKey
		 *            Resource bundle's key message
		 * @param exceptionMessage
		 *            Exception message
		 */
		private ElectoralDemographyExceptionInfo(String bundleKey,
				String exceptionMessage) {
			this.bundleKey = bundleKey;
			this.exceptionMessage = exceptionMessage;
		}

	}

	/**
	 * Instantiates an ElectoralDemographyException.
	 * 
	 * @param throwable
	 *            a nested exception
	 * 
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 */
	public ElectoralDemographyException(Throwable throwable,
			ElectoralDemographyExceptionInfo exceptionInfo) {
		super(throwable, exceptionInfo);
	}

	/**
	 * Instantiates an ElectoralDemographyException.
	 * 
	 * @param throwable
	 *            a nested exception
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 * @param exceptionMessage
	 *            Exception message of nested exception
	 */
	public ElectoralDemographyException(Throwable throwable,
			ElectoralDemographyExceptionInfo exceptionInfo,
			String exceptionMessage) {
		super(throwable, exceptionInfo, exceptionMessage);
	}

	/**
	 * Instantiates an ElectoralDemographyException.
	 * 
	 * @param exceptionInfo
	 *            an enumeration value regarding the cause of the exception
	 */
	public ElectoralDemographyException(
			ElectoralDemographyExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/*
	 * @inheritDoc
	 */
	@Override
	public String getBundleKey() {
		return this.getClass().getSimpleName() + "."
				+ this.exceptionInfo.getBundleKey();
	}
}
