/**
 * XmlGenerationException.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.ecm.service.lang;

import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.lang.IExceptionInfo;

/**
 * Class that manage any error that can occurs in all process with xml file
 * generation.
 */
public class XmlGenerationException extends BaseException {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -603412327580713716L;

	/** The Constant ERROR_RESOURCE_NAME. */
	private static final String ERROR_RESOURCE_NAME = "properties.exception_messages";

	/**
	 * Enum that contains all the possible reasons because the
	 * XmlGenerationException can be thrown.
	 */
	public enum ExceptionInfo implements IExceptionInfo {

		PROBLEM_PROCESSING_MULTILINGUAL_OBJECT(
				"PROBLEM_PROCESSING_MULTILINGUAL_OBJECT"), PROBLEM_GETTING_TRASTATION_KEY_PER_LANGUAGE(
				"PROBLEM_GETTING_TRASTATION_KEY_PER_LANGUAGE"), ANY_LANGUAGE_DETECTED(
				"ANY_LANGUAGE_DETECTED"), PROBLEM_GETTING_REGION_HIERARCHIES(
				"PROBLEM_GETTING_REGION_HIERARCHIES"), PROBLEM_GETTING_VOTING_DEVICE_PER_REGION(
				"PROBLEM_GETTING_VOTING_DEVICE_PER_REGION"), REGION_ALL_PARENT_NOT_FOUND(
				"REGION_ALL_PARENT_NOT_FOUND"), PROBLEM_GETTING_REGION_ALL_PARENT(
				"PROBLEM_GETTING_REGION_ALL_PARENT"), PROBLEM_CHECKING_REGION_PARENT_PATH(
				"PROBLEM_CHECKING_REGION_PARENT_PATH"), NO_CONTEST_ASSOCIATED_WITH_DISCTRICT(
				"NO_CONTEST_ASSOCIATED_WITH_DISCTRICT"), NO_ELECTORAL_AUTHORITIES_LOADED(
				"NO_ELECTORAL_AUTHORITIES_LOADED"), NO_LOGICAL_VOTING_GROUPS_LOADED(
				"NO_LOGICAL_VOTING_GROUPS_LOADED"), PROBLEM_GETTING_CONTEST_BY_DISCTRICT(
				"PROBLEM_GETTING_CONTEST_BY_DISCTRICT"), PROBLEM_GETTING_ELECTION_DATA(
				"PROBLEM_GETTING_ELECTION_DATA"), NOT_ACTIVE_ELECTION_FOUND(
				"NOT_ACTIVE_ELECTION_FOUND"), PROBLEM_GETTING_CONTEST_GROUP_VALUES(
				"PROBLEM_GETTING_CONTEST_GROUP_VALUES"), PROBLEM_GETTING_CONTEST_VALUES(
				"PROBLEM_GETTING_CONTEST_VALUES"), PROBLEM_GETTING_VOTING_DEVICE_WITH_OUT_CERTIFIED(
				"PROBLEM_GETTING_VOTING_DEVICE_WITH_OUT_CERTIFIED"), PROBLEM_CREATING_KEYSTORE_PKCS12_FILE(
				"PROBLEM_CREATING_KEYSTORE_PKCS12_FILE"), PROBLEM_ENCRYPTING_XML_FILE(
				"PROBLEM_ENCRYPTING_XML_FILE"), PROBLEM_CREATING_XML_FILE(
				"PROBLEM_CREATING_XML_FILE"), PROBLEM_CREATING_VOTING_CENTER_XML(
				"PROBLEM_CREATING_VOTING_CENTER_XML"), PROBLEM_CREATING_DEFAULT_LANGUAGE_XML(
				"PROBLEM_CREATING_DEFAULT_LANGUAGE_XML"), PROBLEM_GETTING_PARAMETERS(
				"PROBLEM_GETTING_PARAMETERS"), PROBLEM_UPDATING_PARAMETERS(
				"PROBLEM_UPDATING_PARAMETERS"), PROBLEM_GETTING_LANGUAGES(
				"PROBLEM_GETTING_LANGUAGES"), PROBLEM_PERSISTING_LOGICAL_VOTING_GROUP(
				"PROBLEM_PERSISTING_LOGICAL_VOTING_GROUP"), PROBLEM_GETTING_LOGICAL_VOTING_GROUP(
				"PROBLEM_GETTING_LOGICAL_VOTING_GROUP"), PROBLEM_GETTING_LOGICAL_VOTING_GROUP_PER_REGION(
				"PROBLEM_GETTING_LOGICAL_VOTING_GROUP_PER_REGION"), PROBLEM_GETTING_BALLOT_OPTION_BY_ELIGIBLE_OPTION(
				"PROBLEM_GETTING_BALLOT_OPTION_BY_ELIGIBLE_OPTION"), PROBLEM_GETTING_INTERCEPTION_CONTEST(
				"PROBLEM_GETTING_INTERCEPTION_CONTEST"), PROBLEM_GETTING_ALL_CONTEST_GROUP(
				"PROBLEM_GETTING_ALL_CONTEST_GROUP"), PROBLEM_GETTING_CONTEST_LIST_FULL(
				"PROBLEM_GETTING_CONTEST_LIST_FULL"), PROBLEM_GETTING_CONTEST_BY_CODE(
				"PROBLEM_GETTING_CONTEST_BY_CODE"), PROBLEM_GETTING_CONTEST_GROUP_REGION_RELATED(
				"PROBLEM_GETTING_CONTEST_GROUP_REGION_RELATED"), PROBLEM_GENERATING_ELECTION_FOR_REGION(
				"PROBLEM_GENERATING_ELECTION_FOR_REGION"), PROBLEM_GETTING_LAST_LEVEL_REGION(
				"PROBLEM_GETTING_LAST_LEVEL_REGION"), PROBLEM_GENERATING_VOTING_DEVICE_FOR_REGION(
				"PROBLEM_GENERATING_VOTING_DEVICE_FOR_REGION"), PROBLEM_GETTING_PROGRAMMING_UNIT_PER_REGION(
				"PROBLEM_GETTING_PROGRAMMING_UNIT_PER_REGION"), PROBLEM_GETTING_TRASLATED_DISCTRICT(
				"PROBLEM_GETTING_TRASLATED_DISCTRICT"), PROBLEM_GETTING_TRASLATED_CONTEST(
				"PROBLEM_GETTING_TRASLATED_CONTEST"), PROBLEM_GETTING_CONTEST_FOR_ELECTION(
				"PROBLEM_GETTING_CONTEST_FOR_ELECTION"), PROBLEM_GETTING_CONTEST_FULL(
				"PROBLEM_GETTING_CONTEST_FULL"), PROBLEM_GETTING_ELIGIBLE_OPTION_ROL_BY_ELIGIBLE_OPTION(
				"PROBLEM_GETTING_ELIGIBLE_OPTION_ROL_BY_ELIGIBLE_OPTION"), PROBLEM_GETTING_ELIGIBLE_OPTION_BY_CONTEST(
				"PROBLEM_GETTING_ELIGIBLE_OPTION_BY_CONTEST"), PROBLEM_GENERATING_ELECTION_FOR_CONTEST(
				"PROBLEM_GENERATING_ELECTION_FOR_CONTEST"), PROBLEM_GETTING_AVAILABLE_REGION_FOR_WIDGET(
				"PROBLEM_GETTING_AVAILABLE_REGION_FOR_WIDGET"), PROBLEM_GETTING_REPORTS_TEMPLATE_BY_REGION(
				"PROBLEM_GETTING_REPORTS_TEMPLATE_BY_REGION"), UNEXPECTED_ERROR(
				"UNEXPECTED_ERROR");
		/**
		 * <p>
		 * Each enumerator's resource bundle's key message.
		 * </p>
		 */

		private String message;

		/**
		 * Getter of <code>message</code> property.
		 * 
		 * @return <code>message</code> property value.
		 * @see #message
		 * 
		 * @author Hector Rodri­guez (hector.rodriguez@smartmatic.com)
		 */

		@Override
		public String getMessage() {
			return this.message;
		}

		/**
		 * Instantiates a new exception info.
		 * 
		 * @param msg
		 *            the msg
		 */
		private ExceptionInfo(String msg) {
			this.message = this.getClass().getName() + "." + msg;
		}
	}

	/**
	 * Instantiates a new xml generation exception.
	 * 
	 * @param exceptionInfo
	 *            the exception info
	 */
	public XmlGenerationException(IExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/**
	 * Instantiates a new xml generation exception.
	 * 
	 * @param exceptionInfo
	 *            the exception info
	 * @param e
	 *            the e
	 */
	public XmlGenerationException(IExceptionInfo exceptionInfo, Throwable e) {
		super(exceptionInfo, e);
	}

}
