/**
 * IECMWorkflowService.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.spec;

import com.smartmatic.waffle.domain.user.UserData;
import com.smartmatic.waffle.ecm.service.workflow.ECMWorkflowStatus;
import com.smartmatic.waffle.lang.BaseException;

/**
 * Interface which establishes methods contract that must be implemented by
 * <code>ECMWorkflowServiceImpl</code> class.
 */
public interface IECMWorkflowService {

	/**
	 * Holds the name of the bean that implements this interface.
	 * 
	 */
	final String SERVICE_NAME = "com.smartmatic.waffle.ecm.service.spec.IECMWorkflowService";

	/***
	 * Method to get the current user logged into app.
	 * 
	 * @return the current user logged into app
	 */
	UserData getActualUser();

	/***
	 * Method to get the user info.
	 * 
	 * @param user
	 *            - login of the user.
	 * @return if the login is valid, returns the user info otherwise returns
	 *         null.
	 * @throws BaseException
	 *             -If there is an error
	 */
	UserData getUserById(String user) throws BaseException;

	/**
	 * Advance to the next node in the workflow. returns the current status of
	 * the node.
	 * 
	 * @return the current status of the node.
	 */
	ECMWorkflowStatus gotoNext();

	/**
	 * Rewinds to the last node executed.
	 */
	void goBack();

	/**
	 * Returns the name of the node that the workflow is.
	 * 
	 * @return Node name
	 */
	String getActualNodeName();

	/**
	 * Returns the value of the specific process instance's variable.
	 * 
	 * @param name
	 *            the name
	 * @return the variable value
	 */
	Object getVariable(String name);

	/**
	 * Increments one step the workflow and updates the database.
	 */
	void moveForward();

	/**
	 * Decrements one step the workflow and updates the database.
	 */
	void moveBackward();

	/***
	 * checks if admin user is already configured.
	 * 
	 * @return true if admin user is already configured otherwise returns false.
	 * @throws BaseException
	 *             -If there is an error
	 */
	boolean isAdminUserConfigured() throws BaseException;

	/**
	 * Updates user password.
	 * 
	 * @param user
	 * @param password
	 * @return User updated.
	 * @throws BaseException
	 */
	UserData updateUser(String user, String password) throws BaseException;

}
