/**
 * ECMDemographyServiceImplTest.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.impl;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mockito;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.domain.demographics.PathData;
import com.smartmatic.waffle.domain.demographics.ProgrammingUnitData;
import com.smartmatic.waffle.domain.demographics.RegionData;
import com.smartmatic.waffle.domain.demographics.RegionViewData;
import com.smartmatic.waffle.domain.user.IUser;
import com.smartmatic.waffle.ecm.data.transfer.objects.ProgrammingUnitLastLevelRegionDTO;
import com.smartmatic.waffle.ecm.service.lang.DemographyException;
import com.smartmatic.waffle.ecm.service.stub.ECMDemographyServiceImplMockClasses;
import com.smartmatic.waffle.ecm.service.stub.ECMDemographyServiceImplMockClasses.RetrieveProgrammingUnitAmount;
import com.smartmatic.waffle.ecm.service.stub.ECMDemographyServiceImplMockClasses.SetProtectionKeyToProgrammingUnit;
import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.persistence.search.SearchExpression;
import com.smartmatic.waffle.persistence.service.spec.IPersistenceServiceLocal;

/**
 * Class used to write unit tests for ECMDemographyServiceImplTest.
 */
@RunWith(PowerMockRunner.class)
public class ECMDemographyServiceImplTest {

	/** Instance of ECMDemographyServiceImpl. */
	ECMDemographyServiceImpl ecmDemographyServiceImpl;

	/**
	 * SetUp method to instantiate ECMDemographyServiceImpl.
	 * 
	 * @throws Exception
	 *             signal that an exception occurs setting up the test
	 */
	@Before
	public void setUp() throws Exception {
		this.ecmDemographyServiceImpl = new ECMDemographyServiceImpl();
	}

	/**
	 * Test that retrieves programming unit amount.
	 * 
	 * @throws DemographyException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testProgrammingUnitsAmount() throws DemographyException {

		// arrange
		RetrieveProgrammingUnitAmount retrieveVotingDevicesAmount = new ECMDemographyServiceImplMockClasses().new RetrieveProgrammingUnitAmount();

		this.ecmDemographyServiceImpl
				.setPersistenceService(retrieveVotingDevicesAmount);

		// act
		int programmingUnitsAmount = this.ecmDemographyServiceImpl
				.retrieveProgrammingUnitsAmount();

		// assert
		assertEquals(programmingUnitsAmount, 1);
	}

	/**
	 * Tests <code>setProtectionKeyToProgrammingUnit</code> method.
	 * 
	 * @throws DemographyException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testSetProtectionKeyToProgrammingUnit()
			throws DemographyException {

		// arrange
		SetProtectionKeyToProgrammingUnit setProtectionKeyToProgrammingUnit = new ECMDemographyServiceImplMockClasses().new SetProtectionKeyToProgrammingUnit();

		this.ecmDemographyServiceImpl
				.setPersistenceService(setProtectionKeyToProgrammingUnit);

		// act
		this.ecmDemographyServiceImpl.setProtectionKeyToProgrammingUnit(1, 100);

		// assert
		assertFalse(setProtectionKeyToProgrammingUnit
				.isProgrammingUnitProtectionKeyNull());
	}

	/**
	 * Tests <code>setProtectionKeyToProgrammingUnit</code> method.
	 * 
	 * @throws DemographyException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testDeleteProgrammingUnitSecurityComponents()
			throws DemographyException {

		// arrange
		SetProtectionKeyToProgrammingUnit setProtectionKeyToProgrammingUnit = new ECMDemographyServiceImplMockClasses().new SetProtectionKeyToProgrammingUnit();

		this.ecmDemographyServiceImpl
				.setPersistenceService(setProtectionKeyToProgrammingUnit);

		// act
		int result = this.ecmDemographyServiceImpl
				.deleteProgrammingUnitSecurityComponents();

		// assert
		assertEquals(result, 10);
	}

	/**
	 * Tests <code>getRegionsWithParentsByRegionCode</code> method.
	 * 
	 * @throws Exception
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testGetRegionsWithParentsByRegionCode() throws Exception {

		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		List<RegionData> lastLevelRegions = new ArrayList<RegionData>();

		PowerMockito.doReturn(lastLevelRegions).when(persistenceServiceLocal,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(String[].class), Mockito.any(IUser.class));

		List<Long> lastLevelRegionsCodes = new ArrayList<Long>();

		this.ecmDemographyServiceImpl
				.setPersistenceService(persistenceServiceLocal);

		// act
		List<RegionData> lastLevelRegionsOut = this.ecmDemographyServiceImpl
				.getRegionsWithParentsByRegionCodes(lastLevelRegionsCodes);

		// assert
		assertTrue(lastLevelRegionsOut.equals(lastLevelRegions));
		PowerMockito.verifyPrivate(persistenceServiceLocal).invoke(
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(String[].class), Mockito.any(IUser.class));
	}

	@Test
	public void testGetLastLevelRegionsNullFilter() throws Exception {

		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		List<RegionData> lastLevelRegions = new ArrayList<RegionData>();
		RegionData region1 = new RegionData();
		region1.setCode(1);
		region1.setName("Region 1");

		lastLevelRegions.add(region1);

		PowerMockito.doReturn(lastLevelRegions).when(persistenceServiceLocal,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

		this.ecmDemographyServiceImpl
				.setPersistenceService(persistenceServiceLocal);

		// act
		List<RegionData> lastLevelRegionsResult = this.ecmDemographyServiceImpl
				.getLastLevelRegions(null);

		// assert
		assertEquals(lastLevelRegions.size(), lastLevelRegionsResult.size());

		assertEquals(region1.getCode(), lastLevelRegionsResult.get(0).getCode());
		assertEquals(region1.getName(), lastLevelRegionsResult.get(0).getName());
	}

	@Test
	public void testGetLastLevelRegions() throws Exception {

		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		List<RegionData> lastLevelRegions = new ArrayList<RegionData>();
		RegionData region1 = new RegionData();
		region1.setCode(1);
		region1.setName("Region 1");

		lastLevelRegions.add(region1);

		PowerMockito.doReturn(lastLevelRegions).when(persistenceServiceLocal,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

		this.ecmDemographyServiceImpl
				.setPersistenceService(persistenceServiceLocal);

		// act
		List<RegionData> lastLevelRegionsResult = this.ecmDemographyServiceImpl
				.getLastLevelRegions(lastLevelRegions);

		// assert
		assertEquals(lastLevelRegions.size(), lastLevelRegionsResult.size());

		assertEquals(region1.getCode(), lastLevelRegionsResult.get(0).getCode());
		assertEquals(region1.getName(), lastLevelRegionsResult.get(0).getName());
	}

	@Test
	public void testGetLastLevelRegionsLight() throws Exception {

		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		ECMDemographyServiceImpl ecmDemographyServiceMock = PowerMockito
				.spy(this.ecmDemographyServiceImpl);

		List<RegionData> lastLevelRegions = new ArrayList<RegionData>();
		RegionData region1 = new RegionData();
		region1.setCode(1);
		region1.setName("Region 1");

		lastLevelRegions.add(region1);

		List<Object[]> regionObjects = new ArrayList<Object[]>();
		Object[] regionObject = new Object[2];
		regionObject[0] = 1L;
		regionObject[1] = "Region 1";
		regionObjects.add(regionObject);

		PowerMockito.doReturn(lastLevelRegions).when(ecmDemographyServiceMock)
				.getLastLevelRegions(lastLevelRegions);

		PowerMockito.doCallRealMethod().when(ecmDemographyServiceMock)
				.getLastLevelRegionsLight(Mockito.anyListOf(RegionData.class));

		PowerMockito.doReturn(regionObjects).when(persistenceServiceLocal,
				"searchObjects", Mockito.any(SearchExpression.class),
				Mockito.any(IUser.class));

		ecmDemographyServiceMock.setPersistenceService(persistenceServiceLocal);

		// act
		List<RegionData> lastLevelRegionsResult = ecmDemographyServiceMock
				.getLastLevelRegionsLight(lastLevelRegions);

		// assert
		assertEquals(1, lastLevelRegionsResult.size());

		assertEquals(regionObject[0], lastLevelRegionsResult.get(0).getCode());
		assertEquals(regionObject[1], lastLevelRegionsResult.get(0)
				.getRegionName());

	}

	@Test
	public void testGetProgrammingUnitsByRegions() throws Exception {
		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		ECMDemographyServiceImpl ecmDemographyServiceMock = PowerMockito
				.spy(this.ecmDemographyServiceImpl);

		List<RegionData> lastLevelRegions = new ArrayList<RegionData>();
		RegionData region1 = new RegionData();
		region1.setCode(1);
		region1.setName("Region 1");

		lastLevelRegions.add(region1);

		List<ProgrammingUnitData> programmingUnitList = new ArrayList<ProgrammingUnitData>();
		ProgrammingUnitData programmingUnit = new ProgrammingUnitData();
		programmingUnit.setCode(1);

		programmingUnitList.add(programmingUnit);

		PowerMockito.doReturn(lastLevelRegions).when(ecmDemographyServiceMock)
				.getLastLevelRegionsLight(lastLevelRegions);

		PowerMockito.doReturn(programmingUnitList).when(
				persistenceServiceLocal, "searchObjects",
				Mockito.any(SearchExpression.class), Mockito.any(IUser.class));

		ecmDemographyServiceMock.setPersistenceService(persistenceServiceLocal);

		// act
		Set<ProgrammingUnitLastLevelRegionDTO> programmingUnitsSet = ecmDemographyServiceMock
				.getProgrammingUnitsByRegions(lastLevelRegions);

		// assert
		assertEquals(1, programmingUnitsSet.size());

		Iterator<ProgrammingUnitLastLevelRegionDTO> iterator = programmingUnitsSet
				.iterator();

		ProgrammingUnitLastLevelRegionDTO programmingUnitDto = iterator.next();

		assertEquals(lastLevelRegions,
				programmingUnitDto.getLastLevelRegionForProgrammingUnit());

		assertEquals(programmingUnit, programmingUnitDto.getProgrammingUnit());

	}

	@Test
	public void testGetAllParentsRegions() throws Exception {

		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		ECMDemographyServiceImpl ecmDemographyServiceMock = PowerMockito
				.spy(this.ecmDemographyServiceImpl);

		RegionData allParentsRegions = new RegionData();
		RegionData region = new RegionData();

		PowerMockito.doReturn(allParentsRegions).when(persistenceServiceLocal,
				"searchObject", Mockito.any(SearchExpression.class),
				Mockito.any(String[].class), Mockito.any(IUser.class));

		ecmDemographyServiceMock.setPersistenceService(persistenceServiceLocal);

		// act
		RegionData allParentsRegionsResult = ecmDemographyServiceMock
				.getAllParentsRegions(region);

		// assert
		assertEquals(allParentsRegionsResult, allParentsRegions);
	}

	@Test
	public void testCheckRegionParentPath() throws Exception {

		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		ECMDemographyServiceImpl ecmDemographyServiceMock = PowerMockito
				.spy(this.ecmDemographyServiceImpl);

		RegionData region = new RegionData();
		PathData path = new PathData();

		PowerMockito.doReturn(region).when(persistenceServiceLocal,
				"searchObject", Mockito.any(SearchExpression.class),
				Mockito.any(String[].class), Mockito.any(IUser.class));

		ecmDemographyServiceMock.setPersistenceService(persistenceServiceLocal);

		// act
		RegionData regionResult = ecmDemographyServiceMock
				.checkRegionParentPath(region, path);

		// assert
		assertEquals(regionResult, region);
	}

	@Test
	public void testGetAvailableRegionsForWidget() throws BaseException,
			DemographyException {
		// arrange
		IPersistenceServiceLocal persistenceServiceLocal = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		List<RegionViewData> regionsFromView = new ArrayList<RegionViewData>();

		RegionViewData region1 = new RegionViewData();
		region1.setCode(1);

		RegionViewData region2 = new RegionViewData();
		region2.setCode(2);

		regionsFromView.add(region1);
		regionsFromView.add(region2);

		PowerMockito
				.doReturn(regionsFromView)
				.when(persistenceServiceLocal)
				.searchObjects(Mockito.any(SearchExpression.class),
						Mockito.any(IUser.class));

		this.ecmDemographyServiceImpl
				.setPersistenceService(persistenceServiceLocal);
		// act
		List<RegionData> regionsResult = this.ecmDemographyServiceImpl
				.getAvailableRegionsForWidget();

		// assert
		assertEquals(2, regionsResult.size());

		assertEquals(region1.getCode(), regionsResult.get(0).getCode());
		assertEquals(region2.getCode(), regionsResult.get(1).getCode());

	}

}
