/**
 * ECMElectoralPhysicalLocationsRegistryServiceImplTest.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.impl;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.io.File;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.apache.commons.io.FileUtils;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mockito;
import org.powermock.api.mockito.PowerMockito;
import org.powermock.core.classloader.annotations.PrepareForTest;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.domain.demographics.RegionData;
import com.smartmatic.waffle.domain.device.VotingDeviceData;
import com.smartmatic.waffle.domain.eligibleoption.ImageWrapper;
import com.smartmatic.waffle.domain.user.IUser;
import com.smartmatic.waffle.ecm.data.transfer.objects.VotingDeviceSecurityComponentsDTO;
import com.smartmatic.waffle.ecm.service.lang.ElectoralOrganizationOperationException;
import com.smartmatic.waffle.ecm.service.lang.ElectoralPhysicalLocationsRegistryException;
import com.smartmatic.waffle.ecm.service.stub.ECMElectoralOrganizationServiceImplMockClasses;
import com.smartmatic.waffle.ecm.service.stub.ECMElectoralPhysicalLocationsRegistryServiceImplMockClasses;
import com.smartmatic.waffle.ecm.service.stub.ECMElectoralPhysicalLocationsRegistryServiceImplMockClasses.SetSecurityComponentsToVotingDevices;
import com.smartmatic.waffle.persistence.search.SearchExpression;
import com.smartmatic.waffle.persistence.service.spec.IPersistenceServiceLocal;
import com.smartmatic.waffle.properties.ApplicationProperties;
import com.smartmatic.waffle.security.lang.CryptographicStaticException;

/**
 * Class used to write unit tests for
 * ECMElectoralPhysicalLocationsRegistryServiceImplTest.
 */
@RunWith(PowerMockRunner.class)
@PrepareForTest({ ApplicationProperties.class, ECMServerCommonImpl.class,
		IPersistenceServiceLocal.class })
public class ECMElectoralPhysicalLocationsRegistryServiceImplTest {

	/** Instance of ECMElectoralPhysicalLocationsRegistryServiceImpl. */
	ECMElectoralPhysicalLocationsRegistryServiceImpl ecmElectoralPhysicalLocationsRegistryServiceImpl;

	/**
	 * SetUp method to instantiate ECMElectoralPhysicalLocations
	 * RegistryServiceImpl.
	 * 
	 * @throws Exception
	 *             signal that an exception occurs setting up the test
	 */
	@Before
	public void setUp() throws Exception {
		this.ecmElectoralPhysicalLocationsRegistryServiceImpl = new ECMElectoralPhysicalLocationsRegistryServiceImpl();
	}

	/**
	 * Test retrieve voting devices amount.
	 * 
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 */
	@Test
	public void testRetrieveVotingDevicesAmount()
			throws ElectoralPhysicalLocationsRegistryException {

		// arrange
		IPersistenceServiceLocal retrieveVotingDevicesAmount = new ECMElectoralPhysicalLocationsRegistryServiceImplMockClasses().new RetrieveVotingDevicesAmount();

		this.ecmElectoralPhysicalLocationsRegistryServiceImpl
				.setPersistenceService(retrieveVotingDevicesAmount);

		// act
		int votingDevicesAmount = this.ecmElectoralPhysicalLocationsRegistryServiceImpl
				.retrieveVotingDevicesAmount();

		// assert
		assertEquals(votingDevicesAmount, 369587);
	}

	/**
	 * Tests <code>setSecurityComponentsToVotingDevices</code> method.
	 * 
	 * @throws ElectoralPhysicalLocationsRegistryException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 * 
	 * @throws ElectoralOrganizationOperationException
	 *             signal that some problem occurs testing the method. This test
	 *             should not throws any exception.
	 * @throws CryptographicStaticException
	 */
	@Test
	public void testSetSecurityComponentsToVotingDevices()
			throws ElectoralPhysicalLocationsRegistryException,
			ElectoralOrganizationOperationException,
			CryptographicStaticException {

		// arrange
		PowerMockito.mockStatic(ApplicationProperties.class,
				ECMServerCommonImpl.class);

		SetSecurityComponentsToVotingDevices setSecurityComponentsToVotingDevices = new ECMElectoralPhysicalLocationsRegistryServiceImplMockClasses().new SetSecurityComponentsToVotingDevices();

		IPersistenceServiceLocal mockedPersistenceServiceLocal = new ECMElectoralOrganizationServiceImplMockClasses().new GetElectionKeyStoreComponents();

		ECMElectoralOrganizationServiceImpl ecmElectoralOrganizationServiceImpl = new ECMElectoralOrganizationServiceImpl();

		PowerMockito.when(ApplicationProperties.getValue(Mockito.anyString()))
				.thenReturn("a,b,c,d");

		PowerMockito.when(ECMServerCommonImpl.generateSymmetricKey())
				.thenReturn("fGvfw6xGy2c1S9h7kTj9e63W4yaPOzXSoWagkB+buQc=");

		PowerMockito.when(
				ECMServerCommonImpl.generateRandomString(Mockito.anyInt(),
						Mockito.any(char[].class))).thenReturn(
				"cbrtshfgaquvynco");

		PowerMockito.when(
				ECMServerCommonImpl.generateRandomString(Mockito.anyInt()))
				.thenReturn("cbrtshfgaquvynco");

		PowerMockito.when(
				ECMServerCommonImpl.generateRandomNumericString(Mockito
						.anyInt())).thenReturn("335369");

		ecmElectoralOrganizationServiceImpl
				.setPersistenceService(mockedPersistenceServiceLocal);

		this.ecmElectoralPhysicalLocationsRegistryServiceImpl
				.setPersistenceService(setSecurityComponentsToVotingDevices);

		this.ecmElectoralPhysicalLocationsRegistryServiceImpl
				.setElectoralOrganizationService(ecmElectoralOrganizationServiceImpl);

		// act
		this.ecmElectoralPhysicalLocationsRegistryServiceImpl
				.setSecurityComponentsToVotingDevices(1, 3);

		List<VotingDeviceData> votingDeviceDataList = setSecurityComponentsToVotingDevices
				.getVotingDeviceDataList();

		// assert
		assertEquals(votingDeviceDataList.size(), 3);

		for (VotingDeviceData votingDeviceData : votingDeviceDataList) {
			assertNotNull(votingDeviceData.getTransmissionKey());
			assertNotNull(votingDeviceData.getProtectionKey());
			assertNotNull(votingDeviceData.getPresidentKey());
			assertNotNull(votingDeviceData.getRecounterKey());
			assertNotNull(votingDeviceData.getNumericKey1());
			assertNotNull(votingDeviceData.getNumericKey2());
		}
	}

	/**
	 * Tests <code>retrieveVotingDeviceSecurityComponents</code> method.
	 */
	@Test
	public void testRetrieveVotingDeviceSecurityComponents() throws Exception {
		// arrange
		IPersistenceServiceLocal retrieveVotingDevicesAmount = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		PowerMockito.when(
				retrieveVotingDevicesAmount.searchPagedObjects(
						Mockito.any(SearchExpression.class),
						Mockito.any(IUser.class), Mockito.anyInt(),
						Mockito.anyInt())).thenReturn(
				retrieveVotingDeviceObjectCollection());

		this.ecmElectoralPhysicalLocationsRegistryServiceImpl
				.setPersistenceService(retrieveVotingDevicesAmount);

		// act
		List<VotingDeviceSecurityComponentsDTO> votingDeviceSecurityComponents = this.ecmElectoralPhysicalLocationsRegistryServiceImpl
				.retrieveVotingDeviceSecurityComponents(1, 3);

		// assert
		assertEquals(votingDeviceSecurityComponents.size(), 3);

		for (VotingDeviceSecurityComponentsDTO votingDeviceSecurityComponentsDTO : votingDeviceSecurityComponents) {
			assertNotNull(votingDeviceSecurityComponentsDTO.getName());
			assertNotNull(votingDeviceSecurityComponentsDTO.getProtectionKey());
			assertNotNull(votingDeviceSecurityComponentsDTO.getCustomCode());
			assertNotNull(votingDeviceSecurityComponentsDTO
					.getTransmissionKey());
			assertNotNull(votingDeviceSecurityComponentsDTO.getPresidentKey());
			assertNotNull(votingDeviceSecurityComponentsDTO.getNumericKey1());
			assertNotNull(votingDeviceSecurityComponentsDTO.getNumericKey2());
			assertNotNull(votingDeviceSecurityComponentsDTO.getRecounterKey());
		}
	}

	@Test
	public void testGetVotingDevicesByRegion() throws Exception {

		// arrange
		IPersistenceServiceLocal persistenceService = PowerMockito
				.mock(IPersistenceServiceLocal.class);

		List<VotingDeviceData> votingDevicesList = new ArrayList<VotingDeviceData>();
		VotingDeviceData votingDevice = new VotingDeviceData();
		votingDevice.setCode(1);
		votingDevice.setName("voting device");

		votingDevicesList.add(votingDevice);

		RegionData region = new RegionData();

		PowerMockito.doReturn(votingDevicesList).when(persistenceService,
				"searchObjects", Mockito.any(String[].class),
				Mockito.any(SearchExpression.class), Mockito.any(IUser.class));

		this.ecmElectoralPhysicalLocationsRegistryServiceImpl
				.setPersistenceService(persistenceService);

		// act
		List<VotingDeviceData> votingDevicesListResult = this.ecmElectoralPhysicalLocationsRegistryServiceImpl
				.getVotingDevicesByRegion(region);

		// assert
		assertEquals(1, votingDevicesListResult.size());

		assertEquals(votingDevice.getCode(), votingDevicesListResult.get(0)
				.getCode());
		assertEquals(votingDevice.getName(), votingDevicesListResult.get(0)
				.getName());
	}

	private Collection<Object[]> retrieveVotingDeviceObjectCollection()
			throws Exception {
		Collection<Object[]> votingDeviceDataCollection = new ArrayList<Object[]>();

		ImageWrapper imageWrapper = new ImageWrapper();

		imageWrapper.setBinaryData(FileUtils.readFileToByteArray(new File(
				"test/resources/votingDeviceCertificate.p12")));

		Object[] votingDeviceObject1 = { 1, "ANTWERPEN_001", "ANTWERPEN001",
				"Iimsdu/k7KRmGo+BlA1SFHEGRO+0yIcjvZInxymVDr8=",
				"fGvfw6xGy2c1S9h7kTj9e63W4yaPOzXSoWagkB+buQc=",
				"cbrtshfgaquvynco", "124385", "335369", imageWrapper,
				"fbycbfooqqubccps" };

		votingDeviceDataCollection.add(votingDeviceObject1);

		Object[] votingDeviceObject2 = { 2, "ANTWERPEN_002", "ANTWERPEN002",
				"Iimsdu/k7KRmGo+BlA1SFHEGRO+0yIcjvZInxymVDr8=",
				"fGvfw6xGy2c1S9h7kTj9e63W4yaPOzXSoWagkB+buQc=",
				"cbrtshfgaquvynco", "124385", "335369", imageWrapper,
				"fbycbfooqqubccps" };

		votingDeviceDataCollection.add(votingDeviceObject2);

		Object[] votingDeviceObject3 = { 3, "ANTWERPEN_003", "ANTWERPEN003",
				"Iimsdu/k7KRmGo+BlA1SFHEGRO+0yIcjvZInxymVDr8=",
				"fGvfw6xGy2c1S9h7kTj9e63W4yaPOzXSoWagkB+buQc=",
				"cbrtshfgaquvynco", "124385", "335369", imageWrapper,
				"fbycbfooqqubccps" };

		votingDeviceDataCollection.add(votingDeviceObject3);
		return votingDeviceDataCollection;
	}
}
