package com.smartmatic.waffle.ecm.service.stub;

import java.util.ArrayList;
import java.util.Collection;

import com.smartmatic.waffle.domain.contest.ContestData;
import com.smartmatic.waffle.domain.eligibleoption.EligibleOptionData;
import com.smartmatic.waffle.domain.user.IUser;
import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.persistence.search.SearchExpression;

/**
 * Class used to override persistence methods used in unit testing.
 * 
 */
public class ECMNominationServiceMockClasses {

	/**
	 * Inner class to override the countObjects method and return the number of
	 * candidates.
	 */
	public class RetrieveNumberOfCandidates extends PersistenceServiceLocalStub {

		@Override
		public int countObjects(SearchExpression searchExpression, IUser user)
				throws BaseException {
			return 20;
		}

	}

	/**
	 * Inner class to override the countObjects method and return the number of
	 * parties.
	 * 
	 */
	public class RetrieveNumberOfParties extends PersistenceServiceLocalStub {

		@Override
		public int countObjects(SearchExpression searchExpression, IUser user)
				throws BaseException {
			return 20;
		}
	}

	/**
	 * Inner class to override the searchPagedObjects method and return a list
	 * of candidates.
	 */
	public class GetCandidates extends PersistenceServiceLocalStub {

		@Override
		public Collection searchPagedObjects(SearchExpression searchExpression,
				String[] path, IUser user, int pageNumber, int pageSize)
				throws BaseException {

			Collection<EligibleOptionData> candidatesList = new ArrayList<EligibleOptionData>();

			EligibleOptionData eoData1 = new EligibleOptionData();
			eoData1.setCode(1);
			eoData1.setBallotName("EO Data1");
			eoData1.setContest(new ContestData());

			EligibleOptionData eoData2 = new EligibleOptionData();
			eoData2.setCode(2);
			eoData2.setBallotName("EO Data2");
			eoData2.setContest(new ContestData());

			EligibleOptionData eoData3 = new EligibleOptionData();
			eoData3.setCode(3);
			eoData3.setBallotName("EO Data3");
			eoData3.setContest(new ContestData());

			candidatesList.add(eoData1);
			candidatesList.add(eoData2);
			candidatesList.add(eoData3);

			return candidatesList;

		}

	}

	/**
	 * Inner class to override the searchPagedObjects method and return a list
	 * of parties.
	 * 
	 */
	public class GetParties extends PersistenceServiceLocalStub {

		@Override
		public Collection searchPagedObjects(SearchExpression searchExpression,
				String[] path, IUser user, int pageNumber, int pageSize)
				throws BaseException {

			Collection<EligibleOptionData> partiesList = new ArrayList<EligibleOptionData>();

			EligibleOptionData eoData1 = new EligibleOptionData();
			eoData1.setCode(1);
			eoData1.setBallotName("EO Party Data1");
			eoData1.setContest(new ContestData());

			EligibleOptionData eoData2 = new EligibleOptionData();
			eoData2.setCode(2);
			eoData2.setBallotName("EO Party Data2");
			eoData2.setContest(new ContestData());

			EligibleOptionData eoData3 = new EligibleOptionData();
			eoData3.setCode(3);
			eoData3.setBallotName("EO Party Data3");
			eoData3.setContest(new ContestData());

			partiesList.add(eoData1);
			partiesList.add(eoData2);
			partiesList.add(eoData3);

			return partiesList;
		}
	}
}
