/**
 * DataTransformationTest.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.service.transformData;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.io.File;
import java.io.IOException;
import java.util.List;

import org.apache.commons.io.FileUtils;
import org.junit.Test;

import com.smartmatic.waffle.ecm.data.transfer.objects.EMLTransformationResultDTO;
import com.smartmatic.waffle.ecm.service.lang.TransformationException;

/**
 * Class used to test DataTransformation class.
 */
public class DataTransformationTest {

	/**
	 * Tests executeSmttFilesTransformation.
	 * 
	 * @throws TransformationException
	 *             signal that an exception has occurred executing the file
	 *             transformation. This test should not throws any exception.
	 */
	@Test
	public void testExecuteSmttFilesTransformation() throws IOException,
			TransformationException {

		DataTransformation data = new DataTransformation("test/resources");

		File inputFile = new File("test/resources/BallotLayout.txt");

		byte[] inputFileByte = FileUtils.readFileToByteArray(inputFile);

		String kettleTransformationFileName = "TemplateXML_ballotLayout.ktr";

		byte[] resultFileContent = data.executeSmttFilesTransformation(
				kettleTransformationFileName, inputFileByte);

		assertNotNull(resultFileContent);
	}

	/**
	 * Tests executeSmttFilesTransformation.
	 * 
	 * @throws TransformationException
	 *             signal that an exception has occurred executing the file
	 *             transformation. This test should not throws any exception.
	 */
	// @Test
	public void testExecuteCodiFilesTransformation() throws IOException,
			TransformationException {

		DataTransformation data = new DataTransformation("test/resources");

		File inputFile = new File("test/resources/DC11002.CK");

		byte[] inputFileByte = FileUtils.readFileToByteArray(inputFile);

		String kettleTransformationFileName = "TemplateXML_codiNominations_windows1252.ktr";

		EMLTransformationResultDTO resultFileContent = data
				.executeEMLFilesTransformation(kettleTransformationFileName,
						inputFileByte);

		assertEquals(resultFileContent.getContestCustomCode(), "CK11002NN");

		assertNotNull(resultFileContent.getResultFilesContent());
	}

	/**
	 * Tests executeSitesFilesTransformation. Case: smartmatic files.
	 * 
	 * @throws TransformationException
	 *             signal that an exception has occurred executing the file
	 *             transformation. This test should not throws any exception.
	 */
	@Test
	public void testExecuteSitesFilesTransformationSmttSites()
			throws IOException, TransformationException {

		DataTransformation data = new DataTransformation("test/resources");

		File inputFile = new File("test/resources/Sites.txt");

		byte[] inputFileByte = FileUtils.readFileToByteArray(inputFile);

		String kettleTransformationFileName = "TemplateXML_smartmaticSites.ktr";

		List<byte[]> resultFilesContent = data.executeSitesFilesTransformation(
				kettleTransformationFileName, inputFileByte, false);

		assertNotNull(resultFilesContent);

		assertEquals(resultFilesContent.size(), 4);
	}

	/**
	 * Tests executeSitesFilesTransformation. Case: codi files.
	 * 
	 * @throws TransformationException
	 *             signal that an exception has occurred executing the file
	 *             transformation. This test should not throws any exception.
	 */
	@Test
	public void testExecuteSitesFilesTransformationCodiSites()
			throws IOException, TransformationException {

		DataTransformation data = new DataTransformation("test/resources");

		File inputFile = new File("test/resources/K11002.csv");

		byte[] inputFileByte = FileUtils.readFileToByteArray(inputFile);

		String kettleTransformationFileName = "TemplateXML_codiSites.ktr";

		List<byte[]> resultFilesContent = data.executeSitesFilesTransformation(
				kettleTransformationFileName, inputFileByte, false);

		assertNotNull(resultFilesContent);

		assertEquals(resultFilesContent.size(), 4);
	}
}