/**
 * BlockingMessageDialog.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

/*
 * BlockingMessageDialog
 *
 * Created on 09/03/2009, 09:02:30 PM
 */

package com.smartmatic.waffle.ecm.ui;

import java.awt.Dimension;
import java.awt.GridBagLayout;

import javax.swing.BoxLayout;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SpringLayout;
import javax.swing.SwingConstants;

import com.smartmatic.waffle.ecm.ui.layout.SpringLayoutUtil;
import com.smartmatic.waffle.ecm.ui.util.DotDashBorder;
import com.smartmatic.waffle.ecm.ui.util.GUIComponentUtil;

/**
 * Class used to show a message at the top of the application.
 */
public class BlockingMessageDialog extends BaseMessageDialog {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -3884890063356116897L;

	/** The use grid bag. */
	private boolean useGridBag = true;

	/**
	 * Creates new form BlockingMessageDialog.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 */
	public BlockingMessageDialog(java.awt.Frame parent, boolean modal) {
		super(parent, modal);
		this.initComponents();
		this.messagesPanel.setLayout(new BoxLayout(this.messagesPanel,
				BoxLayout.PAGE_AXIS));
	}

	/**
	 * Creates new form BlockingMessageDialog.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 */
	public BlockingMessageDialog(JDialog parent, boolean modal) {
		super(parent, modal);
		this.initComponents();
		this.messagesPanel.setLayout(new BoxLayout(this.messagesPanel,
				BoxLayout.PAGE_AXIS));
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	private void initComponents() {

		this.jScrollPane1 = new javax.swing.JScrollPane();
		this.messagesPanel = new javax.swing.JPanel();

		this.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
		this.setName("Form"); // NOI18N

		this.jScrollPane1.setName("jScrollPane1"); // NOI18N

		this.messagesPanel.setName("messagesPanel"); // NOI18N
		this.messagesPanel.setLayout(new javax.swing.BoxLayout(
				this.messagesPanel, javax.swing.BoxLayout.Y_AXIS));
		this.jScrollPane1.setViewportView(this.messagesPanel);

		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(
				this.getContentPane());
		this.getContentPane().setLayout(layout);
		layout.setHorizontalGroup(layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGroup(
				layout.createSequentialGroup()
						.addGap(0, 0, 0)
						.addComponent(this.jScrollPane1,
								javax.swing.GroupLayout.DEFAULT_SIZE, 400,
								Short.MAX_VALUE).addGap(0, 0, 0)));
		layout.setVerticalGroup(layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGroup(
				layout.createSequentialGroup()
						.addGap(0, 0, 0)
						.addComponent(this.jScrollPane1,
								javax.swing.GroupLayout.DEFAULT_SIZE, 300,
								Short.MAX_VALUE).addGap(0, 0, 0)));

		this.pack();
	}

	/**
	 * Sets the messages to display in the dialog window.
	 * 
	 * @param messages
	 *            the messages to set
	 */
	public void setMessages(String... messages) {

		final JPanel theMessagesPanel = this.getMessagesPanel();
		if (this.useGridBag) {
			theMessagesPanel.setLayout(new GridBagLayout());
		}

		JPanel mainFrame = new JPanel(new SpringLayout());
		theMessagesPanel.removeAll();
		theMessagesPanel.add(mainFrame);

		mainFrame
				.setBorder(new DotDashBorder(
						DotDashBorder.PatternType.DASH_SHORT.getPattern(), 2,
						this.resourceMap
								.getColor("information.dot.dash.border.color")));
		mainFrame
				.setBackground(this.resourceMap
						.getColor("voting.experience.general.message.background.color"));

		Dimension d = new Dimension(500, 500);

		mainFrame.setSize(d);
		mainFrame.setPreferredSize(d);
		mainFrame.setMinimumSize(d);
		mainFrame.setMaximumSize(d);

		int height = d.height / messages.length, row = 0;

		for (String message : messages) {

			JLabel langLabel = new JLabel(this.getString(message));
			langLabel.setFont(langLabel.getFont().deriveFont(
					langLabel.getFont().getStyle() | java.awt.Font.BOLD,
					langLabel.getFont().getSize() + 8));
			langLabel.setHorizontalAlignment(SwingConstants.CENTER);
			langLabel.setVerticalAlignment(SwingConstants.CENTER);
			langLabel.setHorizontalTextPosition(SwingConstants.CENTER);
			langLabel.setSize(d.width, height);

			JPanel horizontalPanel = new JPanel();
			horizontalPanel.setLayout(new GridBagLayout());

			horizontalPanel.add(langLabel,
					GUIComponentUtil.buildConstraints(0, row++, true, false));
			mainFrame.add(horizontalPanel);
			horizontalPanel.setOpaque(false);
			horizontalPanel.setSize(d.width, height);

			GUIComponentUtil.wrapLabelText(langLabel, langLabel.getText());
		}
		SpringLayoutUtil.makeCompactGrid(mainFrame, messages.length, 1, 30, 30,
				20, 75);
		this.repaint();
	}

	/** The j scroll pane1. */
	private javax.swing.JScrollPane jScrollPane1;

	/** The messages panel. */
	private javax.swing.JPanel messagesPanel;

	/**
	 * Gets the messages panel.
	 * 
	 * @return the messages panel
	 */
	public javax.swing.JPanel getMessagesPanel() {
		return this.messagesPanel;
	}

	/**
	 * Sets the key listener.
	 * 
	 * @param l
	 *            the new key listener
	 */
	public void setKeyListener(BaseKeyListener l) {
		l.addKeyAndContainerListenerRecursively(this);
	}

	/**
	 * Method used to set the main panel of this dialog.
	 * 
	 * @param panel
	 *            the new messages panel
	 */
	public void setMessagesPanel(JPanel panel) {
		this.messagesPanel = panel;
		this.jScrollPane1.setViewportView(this.messagesPanel);
		this.jScrollPane1.updateUI();
	}
}