/**
 * CellCheckEditor.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.controls.commons;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.List;

import javax.swing.DefaultCellEditor;
import javax.swing.JCheckBox;
import javax.swing.JTable;
import javax.swing.SwingUtilities;

/**
 * Controller class for the region's checkbox in the
 * <code>RegionLevelNavigationWidget</code>'s table.
 * 
 * @author mbislick
 */
public class CellCheckEditor extends DefaultCellEditor {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 8424569961175584144L;

	/** The button. */
	protected JCheckBox button;

	/** The is pushed. */
	private boolean isPushed;

	/** The listeners. */
	private List<ICellCheckEventListener> listeners;

	/** The object selected. */
	private Object objectSelected;

	/**
	 * Inti values.
	 */
	private void intiValues() {
		this.listeners = new ArrayList<ICellCheckEventListener>();
		this.button = new JCheckBox();
		this.button.setOpaque(true);
		this.button.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				fireEditingStopped();
			}
		});
	}

	/**
	 * Class constructor.
	 * 
	 * @param checkBox
	 *            the check box
	 */
	public CellCheckEditor(JCheckBox checkBox) {
		super(checkBox);
		this.intiValues();
	}

	/**
	 * Class constructor.
	 * 
	 * @param checkBox
	 *            the check box
	 * @param listener
	 *            the listener
	 */
	public CellCheckEditor(JCheckBox checkBox, ICellCheckEventListener listener) {
		super(checkBox);
		this.intiValues();
		this.listeners.add(listener);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * javax.swing.DefaultCellEditor#getTableCellEditorComponent(javax.swing
	 * .JTable, java.lang.Object, boolean, int, int)
	 */
	@Override
	public Component getTableCellEditorComponent(JTable table, Object value,
			boolean isSelected, int row, int column) {
		if (isSelected) {
			this.button.setForeground(table.getSelectionForeground());
			this.button.setBackground(table.getSelectionBackground());
		} else {
			this.button.setForeground(table.getForeground());
			this.button.setBackground(table.getBackground());
		}
		this.objectSelected = value;
		this.isPushed = true;
		return this.button;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.DefaultCellEditor#getCellEditorValue()
	 */
	@Override
	public Object getCellEditorValue() {
		if (this.isPushed) {
			SwingUtilities.invokeLater(new Runnable() {

				@Override
				public void run() {
					for (ICellCheckEventListener current : CellCheckEditor.this.listeners) {
						current.onPush(CellCheckEditor.this.objectSelected);
					}
				}
			});
		}
		this.isPushed = false;
		return this.objectSelected;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.DefaultCellEditor#stopCellEditing()
	 */
	@Override
	public boolean stopCellEditing() {
		this.isPushed = false;
		return super.stopCellEditing();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.AbstractCellEditor#fireEditingStopped()
	 */
	@Override
	protected void fireEditingStopped() {
		super.fireEditingStopped();
	}
}