/**
 * LanguageSelectionDialog.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.core.i18n;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Collection;

import javax.swing.AbstractButton;
import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingConstants;

import org.jdesktop.application.ResourceMap;

import com.smartmatic.waffle.domain.i18n.LanguageData;
import com.smartmatic.waffle.ecm.ui.DialogListener;
import com.smartmatic.waffle.ecm.ui.LanguageConfirmationDialog;
import com.smartmatic.waffle.ecm.ui.core.ShutDownMachineActionListener;
import com.smartmatic.waffle.ecm.ui.core.i18n.controller.LanguageController;
import com.smartmatic.waffle.ecm.ui.util.DotDashBorder;
import com.smartmatic.waffle.ecm.ui.util.GUIComponentUtil;
import com.smartmatic.waffle.ecm.ui.votingexperience.VotingExperienceDialog;

/**
 * Dialog used to choose the language used in the application.
 * 
 * @author Ithamar Torres
 */
public class LanguageSelectionDialog extends JPanel implements ActionListener,
		DialogListener {

	/** The resource map. */
	protected ResourceMap resourceMap = LanguageController.getInstance()
			.getResourceMap();

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 6542217864567405898L;

	/**
	 * Creates new form LanguageSelectionDialog.
	 */
	public LanguageSelectionDialog() {
		this.initComponents();
		this.setBorder(null);
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// desc="Generated Code">//GEN-BEGIN:initComponents
	private void initComponents() {
		Dimension panelSize;
		Dimension shutDownPanelSize;

		this.isLandscape = GUIComponentUtil.isLandscape(this);

		if (this.isLandscape) {
			panelSize = new java.awt.Dimension(900, 250);
			shutDownPanelSize = new Dimension(900, 60);
		} else {
			panelSize = new Dimension(700, 400);
			shutDownPanelSize = new Dimension(700, 60);
		}

		this.languagesLabelsPanel = new javax.swing.JPanel();
		this.languagesButtonsPanel = new javax.swing.JPanel();
		this.shutdownButtonPanel = new javax.swing.JPanel();

		this.setBackground(this.resourceMap.getColor("mainPane.background")); // NOI18N

		this.languagesLabelsPanel.setMaximumSize(panelSize);
		this.languagesLabelsPanel.setMinimumSize(panelSize);
		this.languagesLabelsPanel.setName("panelLanguagesLabels"); // NOI18N
		this.languagesLabelsPanel.setOpaque(false);
		this.languagesLabelsPanel.setPreferredSize(panelSize);

		this.languagesButtonsPanel.setMaximumSize(panelSize);
		this.languagesButtonsPanel.setMinimumSize(panelSize);
		this.languagesButtonsPanel.setName("panelLanguagesButtons"); // NOI18N
		this.languagesButtonsPanel.setOpaque(false);
		this.languagesButtonsPanel.setPreferredSize(panelSize);

		this.shutdownButtonPanel.setMaximumSize(shutDownPanelSize);
		this.shutdownButtonPanel.setMinimumSize(shutDownPanelSize);
		this.shutdownButtonPanel.setName("panelShutdownButton"); // NOI18N
		this.shutdownButtonPanel.setOpaque(false);
		this.shutdownButtonPanel.setPreferredSize(shutDownPanelSize);

		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
		this.setLayout(layout);
		layout.setHorizontalGroup(layout
				.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addComponent(this.languagesLabelsPanel,
						javax.swing.GroupLayout.PREFERRED_SIZE,
						javax.swing.GroupLayout.PREFERRED_SIZE, Short.MAX_VALUE)
				.addComponent(this.languagesButtonsPanel,
						javax.swing.GroupLayout.PREFERRED_SIZE,
						javax.swing.GroupLayout.PREFERRED_SIZE, Short.MAX_VALUE)
				.addComponent(this.shutdownButtonPanel,
						javax.swing.GroupLayout.PREFERRED_SIZE,
						javax.swing.GroupLayout.PREFERRED_SIZE, Short.MAX_VALUE));
		layout.setVerticalGroup(layout.createParallelGroup(
				javax.swing.GroupLayout.Alignment.LEADING).addGroup(
				layout.createSequentialGroup()
						.addComponent(this.languagesLabelsPanel,
								javax.swing.GroupLayout.PREFERRED_SIZE,
								javax.swing.GroupLayout.PREFERRED_SIZE,
								javax.swing.GroupLayout.PREFERRED_SIZE)
						.addComponent(this.languagesButtonsPanel,
								javax.swing.GroupLayout.PREFERRED_SIZE,
								javax.swing.GroupLayout.PREFERRED_SIZE,
								Short.MAX_VALUE)
						.addComponent(this.shutdownButtonPanel,
								javax.swing.GroupLayout.PREFERRED_SIZE,
								javax.swing.GroupLayout.PREFERRED_SIZE,
								Short.MAX_VALUE)));

	}// </editor-fold>//GEN-END:initComponents

	/**
	 * Cancel button action performed.
	 * 
	 * @param evt
	 *            the evt
	 */
	@SuppressWarnings("unused")
	private void cancelButtonActionPerformed(java.awt.event.ActionEvent evt) {// GEN
		// -
		// FIRST
		// :
		// event_cancelButtonActionPerformed
		// Iterates over all the radio buttons to obtain the selected one.
		for (AbstractButton actualButton : this.languageButtons) {
			if (actualButton.isSelected()) {
				actualButton.setSelected(false);
			}
		}
	}// GEN-LAST:event_cancelButtonActionPerformed

	// Variables declaration - do not modify//GEN-BEGIN:variables
	/** The languages buttons panel. */
	private javax.swing.JPanel languagesButtonsPanel;

	/** The languages labels panel. */
	private javax.swing.JPanel languagesLabelsPanel;

	/** The shutdown button panel. */
	private javax.swing.JPanel shutdownButtonPanel;
	// End of variables declaration//GEN-END:variables

	/**
	 * Radio buttons displayed in this form to select the language desired.
	 */
	private AbstractButton[] languageButtons;

	/**
	 * Complete list of supported languages.
	 */
	private Collection<LanguageData> supportedLanguages;

	/**
	 * The selected language. This field is set when the user press the button
	 * accept.
	 * 
	 * @see LanguageSelectionDialog#okButtonActionPerformed(ActionEvent)
	 */
	private LanguageData selectedLanguage;

	/** The listener. */
	private DialogListener listener;

	/** The language. */
	private String language;

	/** The is landscape. */
	private boolean isLandscape;

	/**
	 * Adds the supported languages in this dialog. This method displays in the
	 * dialog a set of radio buttons to obtain the desired language from the
	 * user.
	 * 
	 * @param languages
	 *            Collection of languages supported by the application.
	 * @author Ithamar Torres
	 */
	public void setSupportedLanguages(Collection<LanguageData> languages) {

		// Creates the radio buttons used to select the desired language
		AbstractButton[] languageButtons = new AbstractButton[languages.size()];
		ButtonGroup group = new ButtonGroup();

		Dimension languageLabelSize, languageButtonSize;
		Insets insets;

		int sizeDefault;

		if (this.isLandscape) {
			sizeDefault = 100;
			int Aditionallanguages = languages.size() - 2;
			sizeDefault -= (25 * Aditionallanguages);
			languageLabelSize = new Dimension(550, sizeDefault);
			languageButtonSize = new Dimension(200, sizeDefault);
			insets = new Insets(0, 0, 15, 0);
		} else {
			languageLabelSize = new Dimension(700, 75);
			languageButtonSize = new Dimension(250, 75);
			insets = new Insets(0, 0, 15, 0);
		}

		this.languagesLabelsPanel.removeAll();
		this.languagesLabelsPanel.setLayout(new GridBagLayout());

		this.languagesButtonsPanel.removeAll();
		this.languagesButtonsPanel.setLayout(new GridBagLayout());

		java.awt.GridBagConstraints gridBagConstraints = new GridBagConstraints();
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.gridx = 0;
		gridBagConstraints.insets = new Insets(0, 0, 15, 0);

		int idx = 0;

		for (LanguageData languageData : languages) {
			String btnText;
			Font tknFont = null;
			Color lblColor = null;

			String keyName = languageData.getCustomCode() + ".langSelect";

			// Creates the labels
			JLabel langLabel = new JLabel(this.getString(keyName));
			langLabel.setName(keyName);

			tknFont = this.resourceMap.getFont(languageData.getCustomCode()
					+ ".selection.label.font");
			if (tknFont == null) {
				tknFont = langLabel.getFont().deriveFont(
						langLabel.getFont().getStyle() | java.awt.Font.BOLD,
						langLabel.getFont().getSize() + 4);
			}
			langLabel.setFont(tknFont);
			langLabel.setHorizontalAlignment(SwingConstants.CENTER);
			langLabel.setVerticalAlignment(SwingConstants.CENTER);
			langLabel.setHorizontalTextPosition(SwingConstants.CENTER);
			langLabel.setBorder(new DotDashBorder(
					DotDashBorder.PatternType.DASH_LONG.getPattern(), 1,
					Color.GRAY));
			langLabel.setOpaque(true);
			lblColor = this.resourceMap.getColor(languageData.getCustomCode()
					+ ".selection.label.background.color");
			if (lblColor == null) {
				lblColor = Color.WHITE;
			}

			langLabel.setBackground(lblColor);

			langLabel.setPreferredSize(languageLabelSize);
			langLabel.setMaximumSize(languageLabelSize);
			langLabel.setMinimumSize(languageLabelSize);

			gridBagConstraints.gridy = idx;

			this.languagesLabelsPanel.add(langLabel, gridBagConstraints);

			String btnKeyText = languageData.getCustomCode() + ".button.text";
			btnText = this.getString(btnKeyText);

			JButton button = new JButton();
			button.setName(btnKeyText);

			button.setText(btnText);
			button.setFocusable(false);

			tknFont = this.resourceMap.getFont(languageData.getCustomCode()
					+ ".selection.button.font");

			if (tknFont == null) {
				tknFont = button.getFont().deriveFont(
						button.getFont().getStyle() | java.awt.Font.BOLD,
						button.getFont().getSize() + 4);
			}
			// button.setLabelFont(tknFont);
			button.setFont(tknFont);
			// estimated size
			button.setPreferredSize(languageButtonSize);
			button.setMaximumSize(languageButtonSize);
			button.setMinimumSize(languageButtonSize);

			group.add(button);
			button.addActionListener(this);

			button.setAlignmentY(CENTER_ALIGNMENT);
			button.setAlignmentX(CENTER_ALIGNMENT);

			gridBagConstraints.insets = insets;

			this.languagesButtonsPanel.add(button, gridBagConstraints);

			languageButtons[idx++] = button;
		}
		this.shutdownButtonPanel.removeAll();
		JButton shutDown = new JButton();
		shutDown.setName("buttonShutdown");

		shutDown.addActionListener(new ShutDownMachineActionListener(this));

		Dimension shutDownDimension = new Dimension(60, 60);
		shutDown.setPreferredSize(shutDownDimension);
		shutDown.setMaximumSize(shutDownDimension);
		shutDown.setMinimumSize(shutDownDimension);
		shutDown.setAlignmentY(CENTER_ALIGNMENT);
		shutDown.setAlignmentX(CENTER_ALIGNMENT);
		shutDown.setIcon(this.resourceMap.getIcon("Application.shutdown.ico"));
		shutDown.setFocusable(false);

		this.shutdownButtonPanel.add(shutDown);
		// Sets the radio buttons and the supported languages
		this.languageButtons = languageButtons;
		this.supportedLanguages = languages;
	}

	/**
	 * Returns the selected language.
	 * 
	 * @return The selected language
	 * @author Ithamar Torres
	 */
	public LanguageData getSelectedLanguage() {
		return this.selectedLanguage;
	}

	/**
	 * Method that checks every time a language radio button is pressed and
	 * enables/disables the ok button accordingly.
	 * 
	 * The user can continue from this form only after selecting a language. The
	 * accept button is disabled when the user hasn't selected a language.
	 * 
	 * @param e
	 *            The event triggered by the user when he selects/deselects a
	 *            language
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		if (e.getSource() instanceof JButton) {
			JButton selectedButton = (JButton) e.getSource();
			String[] splitted = selectedButton.getName().split("\\.");
			this.confirmLangSelection(splitted[0]);
		}
	}

	/**
	 * Confirm lang selection.
	 * 
	 * @param language
	 *            the language
	 */
	private void confirmLangSelection(String language) {
		this.language = language;
		LanguageConfirmationDialog languageConfirmationDialog = new LanguageConfirmationDialog();
		languageConfirmationDialog.setLanguage(language,
				this.supportedLanguages);
		languageConfirmationDialog.setListener(this);

		VotingExperienceDialog.instance
				.setFullPanel(languageConfirmationDialog);

	}

	/**
	 * Sets the listener.
	 * 
	 * @param theListener
	 *            the new listener
	 */
	public void setListener(DialogListener theListener) {
		this.listener = theListener;

		return;

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.ui.DialogListener#ok()
	 */
	@Override
	public void ok() {
		for (LanguageData actualLanguage : this.supportedLanguages) {
			if (actualLanguage.getCustomCode().compareTo(this.language) == 0) {
				this.selectedLanguage = actualLanguage;
				break;
			}
		}

		if (this.listener != null) {
			this.listener.ok();
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.ui.DialogListener#cancel()
	 */
	@Override
	public void cancel() {
		VotingExperienceDialog.instance.setFullPanel(this);
	}

	/**
	 * Gets the string.
	 * 
	 * @param key
	 *            the key
	 * @param arg
	 *            the arg
	 * @return the string
	 */
	public String getString(String key, Object... arg) {
		String result = this.resourceMap.getString(key, arg);
		if (result == null || result.length() == 0) {
			result = key;
		}
		return result;
	}
}
