/**
 * AbstractMenuDispatch.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.menu;

import java.util.List;

import javax.swing.JPanel;

import com.smartmatic.waffle.domain.security.IActionData;
import com.smartmatic.waffle.ecm.core.IFunctDispatcher;
import com.smartmatic.waffle.ecm.ui.DialogState;

/**
 * Abstract class to define a menu dispatcher that should be used by all
 * functionalities.
 */
public abstract class AbstractMenuDispatch implements IFunctDispatcher {

	/** The critical process running. */
	boolean criticalProcessRunning;

	/** The state. */
	protected DialogState state = DialogState.INIT;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.core.IFunctDispatcher#dispatch(java.util.
	 * List, boolean)
	 */
	@Override
	public abstract JPanel dispatch(List<IActionData> actions,
			boolean allowDisplay);

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.core.IFunctDispatcher#isEnabled(java.util
	 * .List)
	 */
	@Override
	public abstract boolean isEnabled(List<IActionData> actions);

	/**
	 * Builds the ui panel.
	 * 
	 * @param actions
	 *            the actions
	 * @return the j panel
	 */
	public abstract JPanel buildUIPanel(List<IActionData> actions);

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.core.IFunctDispatcher#refresh()
	 */
	@Override
	public abstract void refresh();

	/**
	 * Getter for the <code>state</code> property.
	 * 
	 * @return the <code>state</code> property
	 * @author Yenny Villalba <yenny.villalba@smartmatic.com>
	 * @version (1.0)
	 */
	public DialogState getState() {
		return this.state;
	}

	/**
	 * Setter for the <code>state</code> property.
	 * 
	 * @param state
	 *            the state value to set
	 * @author Yenny Villalba <yenny.villalba@smartmatic.com>
	 * @version (1.0)
	 */
	public void setState(DialogState state) {
		this.state = state;
	}

	/**
	 * Checks if is critical process running.
	 * 
	 * @return true, if is critical process running
	 * @inheritDoc
	 */
	@Override
	public boolean isCriticalProcessRunning() {
		return this.criticalProcessRunning;
	}

	/**
	 * Sets the running critical process.
	 * 
	 * @param run
	 *            the new running critical process
	 * @inheritDoc
	 */
	@Override
	public void setRunningCriticalProcess(boolean run) {
		this.criticalProcessRunning = run;
	}

}
