/**
 * FunctionalityShortcutMenuItem.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.menu;

import java.util.List;
import java.util.Map;

import com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum;
import com.smartmatic.waffle.domain.security.IActionData;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamConverter;
import com.thoughtworks.xstream.converters.enums.EnumConverter;

/**
 * Class used to create a shortcut item for application functionalities.
 */
public class FunctionalityShortcutMenuItem extends BasicMenuItem {

	/**
	 * Instantiates a new functionality shortcut menu item.
	 */
	public FunctionalityShortcutMenuItem() {
		super();
	}

	/** The functionality. */
	@XStreamAlias("func-shortcut-name")
	@XStreamConverter(EnumConverter.class)
	@XStreamAsAttribute
	private FunctionalityDefinitionEnum functionality;

	/**
	 * Getter for the <code>functionality</code> attribute.
	 * 
	 * @return <code>functionality</code> attribute value.
	 * @see FunctionalityShortcutMenuItem#functionality
	 */
	public FunctionalityDefinitionEnum getFunctionality() {
		return this.functionality;
	}

	/**
	 * Setter for the <code>functionality</code> attribute.
	 * 
	 * @param functionality
	 *            the functionality to set
	 * @see FunctionalityShortcutMenuItem#functionality
	 */
	public void setFunctionality(FunctionalityDefinitionEnum functionality) {
		this.functionality = functionality;
	}

	/*
	 * @see
	 * com.smartmatic.waffle.ui.menu.BasicMenuItem#createAndCloneCustomInformation
	 * (java.util.Set)
	 */
	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.ui.menu.BasicMenuItem#
	 * createAndCloneCustomInformation(java.util.Map)
	 */
	@Override
	protected BasicMenuItem createAndCloneCustomInformation(
			Map<FunctionalityDefinitionEnum, List<IActionData>> availableFunctionalities) {
		FunctionalityShortcutMenuItem menuItem = new FunctionalityShortcutMenuItem();
		if (availableFunctionalities.keySet().contains(this.functionality)) {
			menuItem.setFunctionality(this.functionality);
		}
		return menuItem;
	}

	/*
	 * @see com.smartmatic.waffle.ui.menu.BasicMenuItem#functionalityCount()
	 */
	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ecm.ui.menu.BasicMenuItem#functionalityCount()
	 */
	@Override
	public int functionalityCount() {
		if (this.functionality == null) {
			return 0;
		} else {
			return 1;
		}
	}

}
