/**
 * MenuCategoryItem.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.ecm.ui.menu;

import java.util.EnumSet;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.smartmatic.waffle.domain.security.FunctionalityDefinitionEnum;
import com.smartmatic.waffle.domain.security.IActionData;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamConverter;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import com.thoughtworks.xstream.converters.enums.EnumSetConverter;

/**
 * Class used to generate a menu category item.
 */
@XStreamAlias("menu-category")
public class MenuCategoryItem extends BasicMenuItem {

	/**
	 * Instantiates a new menu category item.
	 */
	public MenuCategoryItem() {
		super();
	}

	/** The functionality definitions. */
	@XStreamOmitField
	private Map<FunctionalityDefinitionEnum, List<IActionData>> functionalityDefinitions;

	/** The functionalities. */
	@XStreamAlias("functionalities")
	@XStreamConverter(EnumSetConverter.class)
	public EnumSet<FunctionalityDefinitionEnum> functionalities;

	/**
	 * Getter of <code>functionalities</code> property.
	 * 
	 * @return <code>functionalities</code> property value.
	 * @see #functionalities
	 */
	public EnumSet<FunctionalityDefinitionEnum> getFunctionalities() {
		return this.functionalities;
	}

	/**
	 * Setter of <code>functionalities</code> property.
	 * 
	 * @param functionalities
	 *            The <code>functionalities</code> to set.
	 * @see #functionalities
	 */
	public void setFunctionalities(
			EnumSet<FunctionalityDefinitionEnum> functionalities) {
		this.functionalities = functionalities;
	}

	/**
	 * Getter for the <code>functionalityDefinitions</code> attribute.
	 * 
	 * @return <code>functionalityDefinitions</code> attribute value.
	 * @see MenuCategoryItem#functionalityDefinitions
	 */
	public Map<FunctionalityDefinitionEnum, List<IActionData>> getFunctionalityDefinitions() {
		return this.functionalityDefinitions;
	}

	/**
	 * Setter for the <code>functionalityDefinitions</code> attribute.
	 * 
	 * @param functionalityDefinitions
	 *            the functionalityDefinitions to set
	 * @see MenuCategoryItem#functionalityDefinitions
	 */
	public void setFunctionalityDefinitions(
			Map<FunctionalityDefinitionEnum, List<IActionData>> functionalityDefinitions) {
		this.functionalityDefinitions = functionalityDefinitions;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.waffle.ui.menu.BasicMenuItem#createAndCloneCustomInformation
	 * (java.util.Set)
	 */
	@Override
	protected BasicMenuItem createAndCloneCustomInformation(
			Map<FunctionalityDefinitionEnum, List<IActionData>> availableFunctionalities) {
		MenuCategoryItem item = new MenuCategoryItem();

		Map<FunctionalityDefinitionEnum, List<IActionData>> funcDefinitions = new HashMap<FunctionalityDefinitionEnum, List<IActionData>>();
		item.setFunctionalityDefinitions(funcDefinitions);
		item.setFunctionalities(this.getFunctionalities());
		// Iterates over the functionalities to create a restricted version of a
		// MenuCategory item
		Set<FunctionalityDefinitionEnum> funcEnum = this
				.getFunctionalityDefinitions().keySet();
		for (FunctionalityDefinitionEnum funcDefinition : funcEnum) {

			if (availableFunctionalities.keySet().contains(funcDefinition)) {
				List<IActionData> supportedActions = availableFunctionalities
						.get(funcDefinition);
				funcDefinitions.put(funcDefinition, supportedActions);
			}
		}

		return item;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.smartmatic.waffle.ui.menu.BasicMenuItem#functionalityCount()
	 */
	@Override
	public int functionalityCount() {
		if (this.functionalityDefinitions == null) {
			return 0;
		} else {
			return this.functionalityDefinitions.size();
		}
	}
}
