/**
 * ApplianceCommonDestinations.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.localpersistence;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * Class used to reference and handle files and folders used by the appliance.
 */
@XStreamAlias(value = "appliance-common-destinations")
public class ApplianceCommonDestinations extends CommonDestinations {

	/** The diagnostics script. */
	@XStreamAlias(value = "device-util-script")
	@CommonDestinationInfo(existence = Existence.MANDATORY, existenceLevel = 0, type = DestinationType.FILE_PLAIN)
	public final File deviceUtilScript;

	/**
	 * Returns the current instance of the class.
	 * 
	 * @return the current instance
	 */
	public static CommonDestinations getInstance() {
		if (CommonDestinations.instance == null) {
			CommonDestinations.setInstance(SAESLocalPersistenceManager
					.getInstance().getDefaultDestinations());
		}
		return CommonDestinations.getInstance();
	}

	/**
	 * Creates a new ApplianceCommonDestinations instance.
	 * 
	 * @param theBaseDir
	 *            the the base dir
	 * @param dynamicDirName
	 *            the dynamic dir name
	 * @throws IllegalArgumentException
	 *             the illegal argument exception
	 * @throws IllegalAccessException
	 *             the illegal access exception
	 */
	public ApplianceCommonDestinations(File theBaseDir, String dynamicDirName)
			throws IllegalArgumentException, IllegalAccessException {
		super(theBaseDir);

		this.deviceUtilScript = new File(this.scriptsDir, "deviceUtil.sh");

		this.processAnnotations();

		return;
	}

	/**
	 * Creates a new ApplianceCommonDestinations instance.
	 * 
	 * @param theBaseDir
	 *            the the base dir
	 * @param dynamicDirName
	 *            the dynamic dir name
	 * @param confFile
	 *            the conf file
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 * @throws IllegalArgumentException
	 *             the illegal argument exception
	 * @throws IllegalAccessException
	 *             the illegal access exception
	 */
	public ApplianceCommonDestinations(File theBaseDir, String dynamicDirName,
			InputStream confFile) throws IOException, IllegalArgumentException,
			IllegalAccessException {
		super(theBaseDir, confFile);

		confFile.reset();

		ApplianceCommonDestinations instance = (ApplianceCommonDestinations) LocalPersistenceManager
				.getInstance().loadFromXML(confFile);

		ApplianceCommonDestinations defaultInstance = new ApplianceCommonDestinations(
				theBaseDir, dynamicDirName);

		this.deviceUtilScript = this.composePath(this.scriptsDir,
				instance.deviceUtilScript, defaultInstance.scriptsDir);

		this.processAnnotations();

		return;
	}
}
