/**
 * SAESLocalPersistenceListener.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.localpersistence;

import java.io.IOException;
import java.io.InputStream;

import com.smartmatic.waffle.localpersistence.SAESLocalPersistenceManager.MountedDrive;

/**
 * The listener interface for receiving SAESLocalPersistence events. The class
 * that is interested in processing a SAESLocalPersistence event implements this
 * interface, and the object created with that class is registered with a
 * component using the component's
 * <code>addSAESLocalPersistenceListener<code> method. When
 * the SAESLocalPersistence event occurs, that object's appropriate
 * method is invoked.
 * 
 * @see SAESLocalPersistenceEvent
 */
public interface SAESLocalPersistenceListener {

	/**
	 * Creates the common destinations.
	 * 
	 * @param theNewDrive
	 *            the the new drive
	 * @param dynamicDirName
	 *            the dynamic dir name
	 * @param confFile
	 *            the conf file
	 * @return the sAES common destinations
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 * @throws IllegalArgumentException
	 *             the illegal argument exception
	 * @throws IllegalAccessException
	 *             the illegal access exception
	 */
	public SAESCommonDestinations createCommonDestinations(
			MountedDrive theNewDrive, String dynamicDirName,
			InputStream confFile) throws IOException, IllegalArgumentException,
			IllegalAccessException;

}
