/**
 * SAESLocalPersistenceException.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.localpersistence.exception;

import java.io.File;

import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.lang.IExceptionInfo;
import com.smartmatic.waffle.localpersistence.SAESCommonDestinations;

/**
 * Class used to be thrown if an error occurred during persistence operations on
 * local system files.
 * 
 * 
 * @version 1.0 (Jun 10, 2011)
 * @author Carlos Ramirez (cramirez@smartmatic.com)
 */
public class SAESLocalPersistenceException extends BaseException {

	/** The media where the error occurred. */
	public final SAESCommonDestinations relatedMedia;

	/** The file involved in exception. */
	public final File fileInvolved;
	/**
	 * Since this class is serializable it needs a version number that
	 * increments every time the internal data structure is changed (a.k.a.
	 * field addition)
	 */
	private static final long serialVersionUID = 2L;

	/**
	 * Class used for specifying cause of exceptions.
	 * 
	 * @version 1.0 (Jun 10, 2011)
	 * @author Carlos Ramirez (cramirez@smartmatic.com)
	 */
	public enum ExceptionInfo implements IExceptionInfo {

		/** The more than one ocurrence found. */
		MORE_THAN_ONE_OCURRENCE_FOUND,
		/** The error writting in media. */
		ERROR_WRITTING_IN_MEDIA,
		/** The error cleanning folder in media. */
		ERROR_CLEANNING_FOLDER_IN_MEDIA,
		/** The inconsistence status. */
		INCONSISTENCE_STATUS;

		/** The message. */
		private String message;

		/**
		 * Gets the message.
		 * 
		 * @return the message
		 * @inheritDoc
		 */
		@Override
		public String getMessage() {
			return this.message;
		}

		/**
		 * Default constructor.
		 */
		private ExceptionInfo() {
			this.message = this.getClass().getName() + "." + this.name();
		}

	}

	/**
	 * Default constructor.
	 * 
	 * @param theExceptionInfo
	 *            indicate the cause of the exception
	 * @param theRelatedMedia
	 *            the related media
	 * @param theFileInvolved
	 *            the file
	 * @see com.smartmatic.waffle.localpersistence.SAESCommonDestinations
	 */
	public SAESLocalPersistenceException(IExceptionInfo theExceptionInfo,
			SAESCommonDestinations theRelatedMedia, File theFileInvolved) {
		super(theExceptionInfo);
		this.relatedMedia = theRelatedMedia;
		this.fileInvolved = theFileInvolved;

		return;

	}

	/**
	 * Default constructor.
	 * 
	 * @param theExceptionInfo
	 *            indicate the cause of the exception
	 * @param theRelatedMedia
	 *            the related media
	 * @param theFileInvolved
	 *            the file
	 * @param theThrowable
	 *            the error
	 * @see com.smartmatic.waffle.localpersistence.SAESCommonDestinations
	 */
	public SAESLocalPersistenceException(IExceptionInfo theExceptionInfo,
			SAESCommonDestinations theRelatedMedia, File theFileInvolved,
			Throwable theThrowable) {
		super(theExceptionInfo, theThrowable);
		this.relatedMedia = theRelatedMedia;
		this.fileInvolved = theFileInvolved;

		return;

	}

	/**
	 * Default constructor.
	 * 
	 * @param theExceptionInfo
	 *            indicate the cause of the exception
	 * @param theRelatedMedia
	 *            the related media
	 * @param theFileInvolved
	 *            the file
	 * @param theThrowable
	 *            the error
	 * @param theParameters
	 *            the parameters
	 * @see com.smartmatic.waffle.localpersistence.SAESCommonDestinations
	 */
	public SAESLocalPersistenceException(IExceptionInfo theExceptionInfo,
			SAESCommonDestinations theRelatedMedia, File theFileInvolved,
			Throwable theThrowable, Object... theParameters) {
		super(theExceptionInfo, theThrowable, theParameters);
		this.relatedMedia = theRelatedMedia;
		this.fileInvolved = theFileInvolved;

		return;

	}

	/**
	 * Default constructor.
	 * 
	 * @param theExceptionInfo
	 *            indicate the cause of the exception
	 * @param theRelatedMedia
	 *            the related media
	 * @param theFileInvolved
	 *            the file
	 * @param theParameters
	 *            the parameters
	 * @see com.smartmatic.waffle.localpersistence.SAESCommonDestinations
	 */
	public SAESLocalPersistenceException(IExceptionInfo theExceptionInfo,
			SAESCommonDestinations theRelatedMedia, File theFileInvolved,
			Object... theParameters) {
		super(theExceptionInfo, theParameters);
		this.relatedMedia = theRelatedMedia;
		this.fileInvolved = theFileInvolved;

		return;

	}
}
