/**
 * NoticeLevel.java
 *
 * $Revision: 1.3 $ ($Date: 2009-11-12 21:15:10 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.log;

import org.apache.log4j.Level;

/**
 * New custom level for the log4j logging framework. This level is intended to
 * have a relevance between Level.INFO and Level.WARN To be used as the level of
 * <code> audit </code> logging calls.
 * 
 * @see org.apache.log4j.Level
 * 
 * @author Ricardo Monascal
 */
public class NoticeLevel extends Level {

	/**
	 * Class serialization id.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Integer representing the flag
	 */
	public static final int NOTICE_INT = (WARN_INT + INFO_INT) >> 1;

	/**
	 * Static class variable
	 */
	public static final Level NOTICE = new NoticeLevel();

	/**
	 * Constructor of NoticeLevel Class
	 * 
	 * @param level
	 *            The level integer
	 * @param name
	 *            The level name
	 * @param sysLogEquivalent
	 *            The syslog equivalent of this priority
	 */
	public NoticeLevel(int level, String name, int sysLogEquivalent) {
		super(level, name, sysLogEquivalent);
	}

	/**
	 * Default constructor of NoticeLevel Class
	 */
	public NoticeLevel() {
		this(NOTICE_INT, "NOTICE", 5);
	}
}
