/**
 * ConfigurationAttributeType.java
 *
 * $Revision: 1.5 $ ($Date: 2011-04-06 04:43:04 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.log.configuration;

/**
 * The configuration attribute type representation enum
 * 
 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
 * @version 1.0 (Nov 11, 2009)
 */
public enum ConfigurationAttributeType {
	/**
	 * Attribute name type
	 */
	Name(0x001),
	/**
	 * Attribute value type
	 */
	Value(0x002),
	/**
	 * Attribute type type
	 */
	Type(0x004),
	/**
	 * Attribute reference type
	 */
	Ref(0x008),
	/**
	 * Attribute type
	 */
	Additivity(0x010),
	/**
	 * Logger Element fields
	 */
	LoggerElement(Name.getBitMask() | Additivity.getBitMask()),
	/**
	 * Appender Element fields
	 */
	AppenderElement(Name.getBitMask() | Type.getBitMask()),
	/**
	 * Level Element fields
	 */
	LevelElement(Value.getBitMask()),
	/**
	 * Appender Reference Element fields
	 */
	AppenderReferenceElement(Ref.getBitMask()),
	/**
	 * Appender Reference Element fields
	 */
	All(Name.getBitMask() | Value.getBitMask() | Type.getBitMask()
			| Ref.getBitMask() | Additivity.getBitMask());

	/**
	 * Bit mask configuration, containing the fields
	 */
	public int bitMask;

	/**
	 * Getter of <code>bitMask</code> property.
	 * 
	 * @return <code>bitMask</code> property value.
	 * @see #bitMask
	 */
	public int getBitMask() {
		return this.bitMask;
	}

	/**
	 * Default constructor
	 * 
	 * @param bitMask
	 *            Attribute's bit mask
	 */
	private ConfigurationAttributeType(int bitMask) {
		this.bitMask = bitMask;
	}

}
