/**
 * BetweenCriteria.java
 *
 * $Revision: 1.3 $ ($Date: 2011-04-06 04:44:55 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.criteria;

/**
 * Constrains a property to between two values
 * 
 * @author Ithamar Torres
 */

public class BetweenCriteria implements ISearchCriteria {

	/**
	 * Holds the serialization id of the class
	 */
	private static final long serialVersionUID = -1639118978347732628L;

	/**
	 * Property that will be filtered using a between expression.
	 */

	private final String propertyName;

	/**
	 * Lower value of the filter that will be used using a between expression
	 */

	private final Object lo;

	/**
	 * Upper value of the filter that will be used using a between expression
	 */

	private final Object hi;

	/**
	 * Constructor of a Between Expression
	 * 
	 * @param propertyName
	 *            Property that will be filtered using a between expression.
	 * @param lo
	 *            Lower value of the filter that will be used using a between
	 *            expression
	 * @param hi
	 *            Upper value of the filter that will be used using a between
	 *            expression
	 */

	BetweenCriteria(String propertyName, Object lo, Object hi) {
		this.propertyName = propertyName;
		this.lo = lo;
		this.hi = hi;
	}

	/**
	 * Returns a string representation of the object.
	 * 
	 * @return The string representation of the criteria
	 */
	@Override
	public String toString() {
		return this.propertyName + " between " + this.lo + " and " + this.hi;
	}

	/**
	 * Getter of <code>hi</code> property.
	 * 
	 * @return <code>hi</code> property value.
	 * @see #hi
	 */

	public Object getHi() {
		return this.hi;
	}

	/**
	 * Getter of <code>lo</code> property.
	 * 
	 * @return <code>lo</code> property value.
	 * @see #lo
	 */

	public Object getLo() {
		return this.lo;
	}

	/**
	 * Getter of <code>propertyName</code> property.
	 * 
	 * @return <code>propertyName</code> property value.
	 * @see #propertyName
	 */

	public String getPropertyName() {
		return this.propertyName;
	}
}
