/**
 * EqPropertyCriteria.java
 *
 * $Revision: 1.3 $ ($Date: 2011-04-06 04:45:08 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.persistence.search.criteria;

/**
 * Class that implements a Equal Expression when the value to be compared is two
 * properties of the same object.
 * 
 * @author Ithamar Torres
 */

public class EqPropertyCriteria extends PropertyCriteria {

	/**
	 * Holds the serialization id of the class
	 */

	private static final long serialVersionUID = -268534631264385099L;

	/**
	 * Constructor of a Equal Expression.
	 * 
	 * @param propertyName
	 *            property that will be used in the equal comparison
	 * @param otherPropertyName
	 *            other property that will be used in the equal comparison
	 */

	public EqPropertyCriteria(String propertyName, String otherPropertyName) {
		super(propertyName, otherPropertyName);
	}

	/**
	 * Operator applied to the logical expression
	 * 
	 * @return The operator used in the logical operation
	 */
	@Override
	String getOp() {
		return "=";
	}

}
