/**
 * FullTextSearchCriteriaFactory.java
 * 
 * $Revision: 1.4 $ ($Date: 2011-04-06 04:45:07 $)
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 * 
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.criteria;

/**
 * Equal comparison (with SQL binary operators)
 * 
 * @author luis.cisneros
 */
public class FullTextSearchEqCriteria extends FullTextSearchSimpleCriteria {

	/**
	 * Holds the serialization id of the class
	 */

	private static final long serialVersionUID = 2749581568972796446L;

	/**
	 * Gives the option to automatically add wildcards
	 */
	private boolean addWildcards;

	/**
	 * Constructor of a Equal Expression.
	 * 
	 * @param propertyName
	 *            property that will be used in the equal comparison
	 * @param value
	 *            Value that will be used in the comparison process
	 * @param ignoreCase
	 *            parameter that indicate if the comparison is case sensitive or
	 *            not
	 * @param addWildcards
	 *            gives the option to automatically add wildcards
	 */

	public FullTextSearchEqCriteria(String propertyName, String value,
			boolean ignoreCase, boolean addWildcards) {
		super(propertyName, value, ignoreCase);

		this.addWildcards = addWildcards;
	}

	/**
	 * Constructor of a Equal Expression.
	 * 
	 * @param propertyName
	 *            property that will be used in the equal comparison
	 * @param value
	 *            Value that will be used in the comparison process
	 */

	public FullTextSearchEqCriteria(String propertyName, String value) {
		super(propertyName, value);
	}

	/**
	 * Operator applied to the logical expression
	 * 
	 * @return The operator used in the logical operation
	 */
	@Override
	public String getOp() {
		return ":";
	}

	/**
	 * @return the addWildcards
	 */
	public boolean isAddWildcards() {
		return this.addWildcards;
	}

	/**
	 * @param addWildcards
	 *            the addWildcards to set
	 */
	public void setAddWildcards(boolean addWildcards) {
		this.addWildcards = addWildcards;
	}

}
