/**
 * SimpleCriteria.java
 *
 * $Revision: 1.3 $ ($Date: 2011-04-06 04:44:55 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.criteria;

/**
 * Superclass for "simple" comparisons (with SQL binary operators)
 * 
 * @author Ithamar Torres
 */

public abstract class SimpleCriteria implements ISearchCriteria {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Getter of <code>ignoreCase</code> property.
	 * 
	 * @return <code>ignoreCase</code> property value.
	 * @see #ignoreCase
	 */

	public boolean isIgnoreCase() {
		return this.ignoreCase;
	}

	/**
	 * Getter of <code>propertyName</code> property.
	 * 
	 * @return <code>propertyName</code> property value.
	 * @see #propertyName
	 */

	public String getPropertyName() {
		return this.propertyName;
	}

	/**
	 * Getter of <code>value</code> property.
	 * 
	 * @return <code>value</code> property value.
	 * @see #value
	 */

	public Object getValue() {
		return this.value;
	}

	/**
	 * Property that will be used in the expression
	 */

	private final String propertyName;

	/**
	 * Value used with the property defined as the parameter to the operation
	 * that will be performed
	 */

	private final Object value;

	/**
	 * Flag that indicates if the operation is case sensitive.
	 */

	private boolean ignoreCase;

	/**
	 * Constructor of a SimpleExpression.
	 * 
	 * @param propertyName
	 *            Property that will be used in the expression
	 * @param value
	 *            Value used with the property defined as the parameter to the
	 *            operation that will be performed
	 */

	SimpleCriteria(String propertyName, Object value) {
		this.propertyName = propertyName;
		this.value = value;
	}

	/**
	 * Constructor of a SimpleExpression.
	 * 
	 * @param propertyName
	 *            Property that will be used in the expression
	 * @param value
	 *            Value used with the property defined as the parameter to the
	 *            operation that will be performed
	 * @param ignoreCase
	 *            Flag that indicates if the operation is case sensitive
	 */

	SimpleCriteria(String propertyName, Object value, boolean ignoreCase) {
		this.propertyName = propertyName;
		this.value = value;
		this.ignoreCase = ignoreCase;
	}

	/**
	 * Method that sets this expression as case insensitive
	 * 
	 * @return The SimpleExpresion
	 */

	public SimpleCriteria ignoreCase() {
		this.ignoreCase = true;
		return this;
	}

	/**
	 * Returns a string representation of the object.
	 * 
	 * @return The string representation of the criteria
	 */
	@Override
	public String toString() {
		return this.propertyName + this.getOp() + this.value;
	}

	/**
	 * Method used to obtain the operation that is used in the expression
	 * 
	 * @return The String representation of the operation
	 */
	abstract String getOp();

}
