/**
 * SizeEqCriteria.java
 *
 * $Revision: 1.2 $ ($Date: 2011-04-06 04:45:08 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.criteria;

/**
 * Constrain a collection valued property by size.
 * 
 * @author Carlos Ramirez
 */
public class SizeEqCriteria implements ISearchCriteria {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Property that will be used in the expression
	 */
	private final String propertyName;

	/**
	 * Constraint the collection to this value
	 */
	private final int size;

	/**
	 * Constructor of a SizeEqCriteria.
	 * 
	 * @param propertyName
	 *            Property that will be used in the expression it must represent
	 *            a collection
	 * @param size
	 *            Constraint the collection to this value
	 */
	SizeEqCriteria(String propertyName, int size) {
		this.propertyName = propertyName;
		this.size = size;
	}

	/**
	 * Getter of <code>propertyName</code> property.
	 * 
	 * @return <code>propertyName</code> property value.
	 * @see #propertyName
	 */
	public String getPropertyName() {
		return this.propertyName;
	}

	/**
	 * Getter of <code>value</code> property.
	 * 
	 * @return <code>value</code> property value.
	 * @see #size
	 */
	public int getSize() {
		return this.size;
	}

	/**
	 * Returns a string representation of the object.
	 * 
	 * @return The string representation of the criteria
	 */
	@Override
	public String toString() {
		return this.propertyName + ".size = " + this.size;
	}

}
