/**
 * CountTransformation.java
 *
 * $Revision: 1.3 $ ($Date: 2011-04-06 04:45:09 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.transformation;

/**
 * Transformation used to count the numbers of rows or distinct rows for a
 * property that a query returns
 * 
 * @author Carlos Rafael Ramirez
 */

public class CountTransformation implements ITransformation {

	/**
	 * Holds the serialization id of the class
	 */

	private static final long serialVersionUID = 2718553799828134229L;

	/**
	 * Name of the property to count
	 */

	private String propertyName;

	/**
	 * Indicates if the transformation is distinct or not
	 */

	private boolean distinct;

	/**
	 * Constructor used to create a CountTransformation with the property used
	 * already set.
	 * 
	 * @param property
	 *            Property to group the entities
	 * @param property
	 *            Property to set distinct property
	 */

	protected CountTransformation(String prop, boolean distinct) {
		this.propertyName = prop;
		this.distinct = distinct;
	}

	/**
	 * Constructor used to create a CountTransformation with the property used
	 * already set.
	 * 
	 * @param property
	 *            Property to group the entities
	 */
	protected CountTransformation(String prop) {
		this(prop, false);
	}

	/**
	 * Getter of <code>propertyName</code> property.
	 * 
	 * @return <code>propertyName</code> property value.
	 * @see #propertyName
	 */

	public String getPropertyName() {
		return this.propertyName;
	}

	/**
	 * Getter of <code>distinct</code> property.
	 * 
	 * @return <code>distinct</code> property value.
	 * @see #distinct
	 */

	public boolean getDistinct() {
		return this.distinct;
	}

}
