/**
 * RegExprSearchExpressionBuilder.java
 *
 * $Revision: 1.6 $ ($Date: 2011-04-06 04:45:13 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.search.util;

import java.util.HashMap;
import java.util.Map;

import com.smartmatic.waffle.persistence.search.SearchExpression;

/**
 * Generates a SearchExpression for the given class and data provided in an only
 * string parameter. We will call it the <b>search data</b>.
 * 
 * It must be configured using two parameters:
 * <ol>
 * <li>A list of regular expressions that uniquely will match against the search
 * data and will identify the fields contained in</li>
 * <li>A field - regex map that allows identify the data that corresponds to
 * each field</li>
 * </ol>
 * 
 * After be configured a SearchExpression for looking the class can be generated
 * providing the search data.
 * 
 * @version 1.0 (15/10/2008)
 * @author Carlos Ramirez (cramirez@smartmatic.com)
 */
public class RegExprSearchExpressionBuilder {

	/**
	 * Actually the class that make the work to accept templates and extract the
	 * field values and put them in a field-value map
	 */
	private RegExprFieldMatcher matcher;

	/**
	 * Constructs a RegExprSearchExpressionBuilder with the supplied field-regex
	 * and templates
	 * 
	 * @param theFieldsRegExpr
	 *            A field - regex map that allows identify the data that
	 *            corresponds to each field
	 * @param theTemplates
	 *            A list of regular expressions that uniquely will match against
	 *            the search data and will identify the fields contained in.
	 */
	public RegExprSearchExpressionBuilder(Map<String, String> theFieldsRegExpr,
			String... theTemplates) {
		this.matcher = new RegExprFieldMatcher(theFieldsRegExpr, theTemplates);

	}

	/**
	 * Creates a SearchExpression with the values obtained by matching
	 * <code>textToMatch</code> against the templates
	 * 
	 * @param entity
	 *            Entity Class that its has to be searched
	 * @param textToMatch
	 *            the text that contains the data and will be matched against
	 *            templates.
	 * @return the new created SearchExpression with the populated values
	 */
	public SearchExpression createSearchExpression(Class entity,
			String textToMatch) {

		Map<String, Object> values = new HashMap<String, Object>();

		int templateMatched = this.matcher.matchTemplate(textToMatch, values);

		if (templateMatched != -1) {
			return new SearchExpression(entity, values);

		} else {
			return null;
		}
	}
}
