/**
 * HBCriteriaTransformer.java
 * 
 * $Revision: 1.6 $ ($Date: 2011-04-06 04:45:10 $)
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 * 
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.service.impl;

import java.util.List;

import org.hibernate.criterion.Conjunction;
import org.hibernate.criterion.Criterion;
import org.hibernate.criterion.DetachedCriteria;
import org.hibernate.criterion.Disjunction;
import org.hibernate.criterion.Restrictions;
import org.hibernate.criterion.Subqueries;

import com.smartmatic.waffle.persistence.search.criteria.AndCriteria;
import com.smartmatic.waffle.persistence.search.criteria.BetweenCriteria;
import com.smartmatic.waffle.persistence.search.criteria.ConjunctionCriteria;
import com.smartmatic.waffle.persistence.search.criteria.DisjunctionCriteria;
import com.smartmatic.waffle.persistence.search.criteria.EqCriteria;
import com.smartmatic.waffle.persistence.search.criteria.EqPropertyCriteria;
import com.smartmatic.waffle.persistence.search.criteria.GeCriteria;
import com.smartmatic.waffle.persistence.search.criteria.GtCriteria;
import com.smartmatic.waffle.persistence.search.criteria.ISearchCriteria;
import com.smartmatic.waffle.persistence.search.criteria.IdentifierEqCriteria;
import com.smartmatic.waffle.persistence.search.criteria.IlikeCriteria;
import com.smartmatic.waffle.persistence.search.criteria.InCriteria;
import com.smartmatic.waffle.persistence.search.criteria.InSubqueryPropertyCriteria;
import com.smartmatic.waffle.persistence.search.criteria.LeCriteria;
import com.smartmatic.waffle.persistence.search.criteria.LePropertyCriteria;
import com.smartmatic.waffle.persistence.search.criteria.LikeCriteria;
import com.smartmatic.waffle.persistence.search.criteria.LtCriteria;
import com.smartmatic.waffle.persistence.search.criteria.LtPropertyCriteria;
import com.smartmatic.waffle.persistence.search.criteria.NotCriteria;
import com.smartmatic.waffle.persistence.search.criteria.NotNullCriteria;
import com.smartmatic.waffle.persistence.search.criteria.NullCriteria;
import com.smartmatic.waffle.persistence.search.criteria.OrCriteria;
import com.smartmatic.waffle.persistence.search.criteria.SizeCollectionCriteria;
import com.smartmatic.waffle.persistence.search.criteria.SqlCriteria;
import com.smartmatic.waffle.persistence.search.criteria.SizeCollectionCriteria.RestrictMode;

/**
 * Class used to transform a criteria into a expression in the hibernate
 * language.
 * 
 * @version 1.0 (Aug 18, 2006)
 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
 */
public class HBCriteriaTransformer {

	/**
	 * Method used to transform a SizeCollectionCriteria into a expression in
	 * the hibernate language.
	 * 
	 * @param sizeCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */

	public static Criterion transformCriteria(
			SizeCollectionCriteria sizeCriteria) {
		RestrictMode mode = sizeCriteria.getMode();
		if (mode == RestrictMode.EQUAL) {
			return Restrictions.sizeEq(sizeCriteria.getPropertyName(),
					sizeCriteria.getSize());
		} else if (mode == RestrictMode.NOTEQUAL) {
			return Restrictions.sizeNe(sizeCriteria.getPropertyName(),
					sizeCriteria.getSize());

		} else {
			return null;
		}
	}

	/**
	 * Method used to transform a IdentifierEqCriteria into a expression in the
	 * hibernate language.
	 * 
	 * @param idEqCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */

	public static Criterion transformCriteria(IdentifierEqCriteria idEqCriteria) {
		return Restrictions.idEq(idEqCriteria.getValue());
	}

	/**
	 * Method used to transform a ConjunctionCriteria into a expression in the
	 * hibernate language.
	 * 
	 * @param conjunctionCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(
			ConjunctionCriteria conjunctionCriteria) {
		List<ISearchCriteria> criteriaList = conjunctionCriteria.getCriteria();
		Conjunction conj = Restrictions.conjunction();
		for (ISearchCriteria actualCriteria : criteriaList) {
			conj.add(HBPersistenceServiceImpl
					.transformExpression(actualCriteria));
		}
		return conj;
	}

	/**
	 * Method used to transform a EqCriteria into a expression in the Hibernate
	 * language.
	 * 
	 * @param eqCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(EqCriteria eqCriteria) {
		return Restrictions.eq(eqCriteria.getPropertyName(),
				eqCriteria.getValue());
	}

	/**
	 * Method used to transform a InCriteria into a expression in the Hibernate
	 * language.
	 * 
	 * @param inCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(InCriteria inCriteria) {
		return Restrictions.in(inCriteria.getPropertyName(),
				inCriteria.getValues());
	}

	/**
	 * Method used to transform a AndCriteria into a expression in the Hibernate
	 * language.
	 * 
	 * @param andCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(AndCriteria andCriteria) {
		return Restrictions.and(HBPersistenceServiceImpl
				.transformExpression(andCriteria.getLhs()),
				HBPersistenceServiceImpl.transformExpression(andCriteria
						.getRhs()));
	}

	/**
	 * Method used to transform a BetweenCriteria into a expression in the
	 * hibernate language.
	 * 
	 * @param betweenCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(BetweenCriteria betweenCriteria) {
		return Restrictions.between(betweenCriteria.getPropertyName(),
				betweenCriteria.getLo(), betweenCriteria.getHi());
	}

	/**
	 * Method used to transform a DisjunctionCriteria into a expression in the
	 * hibernate language.
	 * 
	 * @param disjunctionCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(
			DisjunctionCriteria disjunctionCriteria) {
		List<ISearchCriteria> criteriaList = disjunctionCriteria.getCriteria();
		Disjunction disj = Restrictions.disjunction();
		for (ISearchCriteria actualCriteria : criteriaList) {
			disj.add(HBPersistenceServiceImpl
					.transformExpression(actualCriteria));
		}
		return disj;
	}

	/**
	 * Method used to transform a EqPropertyCriteria into a expression in the
	 * hibernate language.
	 * 
	 * @param eqPropertyCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(
			EqPropertyCriteria eqPropertyCriteria) {
		return Restrictions.eqProperty(eqPropertyCriteria.getPropertyName(),
				eqPropertyCriteria.getOtherPropertyName());
	}

	/**
	 * Method used to transform a GeCriteria into a expression in the hibernate
	 * language.
	 * 
	 * @param geCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(GeCriteria geCriteria) {
		return Restrictions.ge(geCriteria.getPropertyName(),
				geCriteria.getValue());
	}

	/**
	 * Method used to transform a GtCriteria into a expression in the hibernate
	 * language.
	 * 
	 * @param gtCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 */
	public static Criterion transformCriteria(GtCriteria gtCriteria) {
		return Restrictions.gt(gtCriteria.getPropertyName(),
				gtCriteria.getValue());
	}

	/**
	 * Method used to transform a IlikeCriteria into a expression in the
	 * hibernate language.
	 * 
	 * @param ilikeCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(IlikeCriteria ilikeCriteria) {
		return Restrictions.ilike(ilikeCriteria.getPropertyName(),
				ilikeCriteria.getValue());
	}

	/**
	 * Method used to transform a LeCriteria into a expression in the hibernate
	 * language.
	 * 
	 * @param leCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(LeCriteria leCriteria) {
		return Restrictions.le(leCriteria.getPropertyName(),
				leCriteria.getValue());
	}

	/**
	 * Method used to transform a LePropertyCriteria into a expression in the
	 * hibernate language.
	 * 
	 * @param lePropertyCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(
			LePropertyCriteria lePropertyCriteria) {
		return Restrictions.leProperty(lePropertyCriteria.getPropertyName(),
				lePropertyCriteria.getOtherPropertyName());
	}

	/**
	 * Method used to transform a LikeCriteria into a expression in the
	 * hibernate language.
	 * 
	 * @param likeCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(LikeCriteria likeCriteria) {
		return Restrictions.like(likeCriteria.getPropertyName(),
				likeCriteria.getValue());
	}

	/**
	 * Method used to transform a LtCriteria into a expression in the hibernate
	 * language.
	 * 
	 * @param ltCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(LtCriteria ltCriteria) {
		return Restrictions.lt(ltCriteria.getPropertyName(),
				ltCriteria.getValue());
	}

	/**
	 * Method used to transform a LtPropertyCriteria into a expression in the
	 * hibernate language.
	 * 
	 * @param ltPropertyCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(
			LtPropertyCriteria ltPropertyCriteria) {
		return Restrictions.ltProperty(ltPropertyCriteria.getPropertyName(),
				ltPropertyCriteria.getOtherPropertyName());
	}

	/**
	 * Method used to transform a NotCriteria into a expression in the hibernate
	 * language.
	 * 
	 * @param notCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(NotCriteria notCriteria) {
		return Restrictions.not(HBPersistenceServiceImpl
				.transformExpression(notCriteria.getCriteria()));
	}

	/**
	 * Method used to transform a NotNullCriteria into a expression in the
	 * hibernate language.
	 * 
	 * @param notNullCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(NotNullCriteria notNullCriteria) {
		return Restrictions.isNotNull(notNullCriteria.getPropertyName());
	}

	/**
	 * Method used to transform a NullCriteria into a expression in the
	 * hibernate language.
	 * 
	 * @param nullCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(NullCriteria nullCriteria) {
		return Restrictions.isNull(nullCriteria.getPropertyName());
	}

	/**
	 * Method used to transform a OrCriteria into a expression in the hibernate
	 * language.
	 * 
	 * @param orCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(OrCriteria orCriteria) {
		return Restrictions.or(HBPersistenceServiceImpl
				.transformExpression(orCriteria.getLhs()),
				HBPersistenceServiceImpl.transformExpression(orCriteria
						.getRhs()));
	}

	/**
	 * Method used to transform a SqlCriteria into a expression in the hibernate
	 * language.
	 * 
	 * @param sqlCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Maria Franco (maria.franco@smartmatic.com)
	 */
	public static Criterion transformCriteria(SqlCriteria sqlCriteria) {
		return Restrictions.sqlRestriction(sqlCriteria.getSql());
	}

	/**
	 * Method used to transform a InCriteria into a expression in the hibernate
	 * language.
	 * 
	 * @param inCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformCriteria(
			InSubqueryPropertyCriteria inCriteria) {

		DetachedCriteria crit = HBPersistenceServiceImpl
				.transformSearchExpression(inCriteria.getSubquery());

		return Subqueries.propertyIn(inCriteria.getPropertyName(), crit);
	}
}
