/**
 * HBPersistenceServiceImpl.java
 * 
 * $Revision: 1.20 $ ($Date: 2011-06-11 00:16:54 $)
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 * 
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.persistence.service.impl;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.StringTokenizer;

import javax.persistence.EntityManager;

import org.apache.commons.beanutils.PropertyUtils;
import org.hibernate.Criteria;
import org.hibernate.FetchMode;
import org.hibernate.Hibernate;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.criterion.CriteriaSpecification;
import org.hibernate.criterion.Criterion;
import org.hibernate.criterion.DetachedCriteria;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Projection;
import org.hibernate.criterion.Projections;
import org.hibernate.ejb.HibernateEntityManager;
import org.hibernate.transform.AliasToBeanResultTransformer;

import com.smartmatic.waffle.persistence.search.JoinType;
import com.smartmatic.waffle.persistence.search.SearchExpression;
import com.smartmatic.waffle.persistence.search.SearchExpression.SubSearchExpression;
import com.smartmatic.waffle.persistence.search.criteria.AndCriteria;
import com.smartmatic.waffle.persistence.search.criteria.BetweenCriteria;
import com.smartmatic.waffle.persistence.search.criteria.ConjunctionCriteria;
import com.smartmatic.waffle.persistence.search.criteria.DisjunctionCriteria;
import com.smartmatic.waffle.persistence.search.criteria.EqCriteria;
import com.smartmatic.waffle.persistence.search.criteria.EqPropertyCriteria;
import com.smartmatic.waffle.persistence.search.criteria.GeCriteria;
import com.smartmatic.waffle.persistence.search.criteria.GtCriteria;
import com.smartmatic.waffle.persistence.search.criteria.ISearchCriteria;
import com.smartmatic.waffle.persistence.search.criteria.IdentifierEqCriteria;
import com.smartmatic.waffle.persistence.search.criteria.IlikeCriteria;
import com.smartmatic.waffle.persistence.search.criteria.InCriteria;
import com.smartmatic.waffle.persistence.search.criteria.InSubqueryPropertyCriteria;
import com.smartmatic.waffle.persistence.search.criteria.LeCriteria;
import com.smartmatic.waffle.persistence.search.criteria.LePropertyCriteria;
import com.smartmatic.waffle.persistence.search.criteria.LikeCriteria;
import com.smartmatic.waffle.persistence.search.criteria.LtCriteria;
import com.smartmatic.waffle.persistence.search.criteria.LtPropertyCriteria;
import com.smartmatic.waffle.persistence.search.criteria.NotCriteria;
import com.smartmatic.waffle.persistence.search.criteria.NotNullCriteria;
import com.smartmatic.waffle.persistence.search.criteria.NullCriteria;
import com.smartmatic.waffle.persistence.search.criteria.OrCriteria;
import com.smartmatic.waffle.persistence.search.criteria.OrderCriteria;
import com.smartmatic.waffle.persistence.search.criteria.SizeCollectionCriteria;
import com.smartmatic.waffle.persistence.search.criteria.SqlCriteria;
import com.smartmatic.waffle.persistence.search.transformation.AliasTransformationsMap;
import com.smartmatic.waffle.persistence.search.transformation.CountTransformation;
import com.smartmatic.waffle.persistence.search.transformation.DistinctTransformation;
import com.smartmatic.waffle.persistence.search.transformation.GroupTransformation;
import com.smartmatic.waffle.persistence.search.transformation.ITransformation;
import com.smartmatic.waffle.persistence.search.transformation.IdentifierTransformation;
import com.smartmatic.waffle.persistence.search.transformation.MaxTransformation;
import com.smartmatic.waffle.persistence.search.transformation.MinTransformation;
import com.smartmatic.waffle.persistence.search.transformation.PropertyTransformation;
import com.smartmatic.waffle.persistence.search.transformation.RowCountTransformation;
import com.smartmatic.waffle.persistence.search.transformation.SumTransformation;
import com.smartmatic.waffle.persistence.search.transformation.TransformationsList;

/**
 * Class that acts as a bridge between the objects used by the application and
 * the relational database where all the information is stored. This class uses
 * Hibernate as a object relational mapping library.
 * 
 * @version 1.0 (Aug 22, 2006)
 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
 */
public class HBPersistenceServiceImpl {
	/**
	 * Method that executes a defined query, returning a collection of objects
	 * 
	 * @param searchExpression
	 *            The predefined query
	 * @param entityManager
	 *            The system entity manager
	 * @return a collection of objects that match the search criteria.
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Collection searchObjects(SearchExpression searchExpression,
			EntityManager entityManager) {
		return HBPersistenceServiceImpl.searchObjects(searchExpression,
				entityManager, null);
	}

	/**
	 * Method that executes a defined query, returning a collection of objects
	 * 
	 * @param searchExpression
	 *            The predefined query
	 * @param entityManager
	 *            The system entity manager
	 * @param path
	 *            variable path to initialize
	 * @return a collection of objects that match the search criteria.
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Collection searchObjects(SearchExpression searchExpression,
			EntityManager entityManager, String[] path) {
		return HBPersistenceServiceImpl.searchObjects(searchExpression,
				entityManager, path, false);
	}

	/**
	 * Method that executes a defined query, returning a collection of objects
	 * 
	 * @param searchExpression
	 *            The predefined query
	 * @param entityManager
	 *            The system entity manager
	 * @param path
	 *            variable path to initialize
	 * @param recursive
	 *            if recursively process the entity fields
	 * @return a collection of objects that match the search criteria.
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */

	public static Collection searchObjects(SearchExpression searchExpression,
			EntityManager entityManager, String[] path, boolean recursive) {

		// Check for different hibernate versions.
		Session hbSession = HBPersistenceServiceImpl
				.obtainHbSession(entityManager);

		Criteria actualCriteria = HBPersistenceServiceImpl
				.transformSearchExpression(searchExpression, hbSession);

		Collection objectsCollection = actualCriteria.list();
		Iterator objectsIterator = objectsCollection.iterator();

		if (path != null) {
			while (objectsIterator.hasNext()) {
				Object object = objectsIterator.next();
				try {
					HBPersistenceServiceImpl.invokePathOfGetters(object, path,
							recursive);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		}
		return objectsCollection;
	}

	/**
	 * Method that executes a defined query, returning a collection of objects
	 * 
	 * @param searchExpression
	 *            The predefined query
	 * @param entityManager
	 *            The system entity manager
	 * @param path
	 *            variable path to initialize
	 * @param recursive
	 *            if recursively process the entity fields
	 * @param pageNumber
	 *            the requested page number
	 * @param pageSize
	 *            number of elements per page
	 * @return the requested objects
	 */
	public static Collection searchObjects(SearchExpression searchExpression,
			EntityManager entityManager, String[] path, boolean recursive,
			int pageNumber, int pageSize) {

		Session hbSession = HBPersistenceServiceImpl
				.obtainHbSession(entityManager);

		Criteria actualCriteria = HBPersistenceServiceImpl
				.transformSearchExpression(searchExpression, hbSession);
		actualCriteria.setMaxResults(pageSize);
		actualCriteria.setFirstResult(pageNumber * pageSize);

		Collection objectsCollection = actualCriteria.list();
		Iterator objectsIterator = objectsCollection.iterator();

		if (path != null) {
			while (objectsIterator.hasNext()) {
				Object object = objectsIterator.next();
				try {
					HBPersistenceServiceImpl.invokePathOfGetters(object, path,
							recursive);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		}
		return objectsCollection;
	}

	/**
	 * Method that executes a defined query, returning a unique object
	 * 
	 * @param searchExpression
	 *            The predefined query
	 * @param entityManager
	 *            The system entity manager
	 * @return a unique object that match the search criteria. If more than an
	 *         object match the criteria returns any of them
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Object searchObject(SearchExpression searchExpression,
			EntityManager entityManager) {
		return HBPersistenceServiceImpl.searchObject(searchExpression,
				entityManager, null);
	}

	/**
	 * Method that executes a defined query, returning a unique object
	 * 
	 * @param searchExpression
	 *            The predefined query
	 * @param entityManager
	 *            The system entity manager
	 * @param path
	 *            variable path to initialize
	 * @return a unique object that match the search criteria. If more than an
	 *         object match the criteria returns any of them
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Object searchObject(SearchExpression searchExpression,
			EntityManager entityManager, String[] path) {
		return HBPersistenceServiceImpl.searchObject(searchExpression,
				entityManager, path, false);
	}

	/**
	 * Method that obtains the session object from the entity manager. It
	 * depends on hibernate.
	 * 
	 * @param entityManager
	 *            The system entity manager
	 * @return The hibernate session
	 */

	public static Session obtainHbSession(EntityManager entityManager) {
		Session hbSession = null;
		if (entityManager.getDelegate() instanceof HibernateEntityManager) {
			hbSession = ((HibernateEntityManager) entityManager.getDelegate())
					.getSession();
		} else {
			hbSession = ((Session) entityManager.getDelegate());
		}

		return hbSession;
	}

	/**
	 * Method that executes a defined query, returning a unique object
	 * 
	 * @param searchExpression
	 *            The predefined query
	 * @param entityManager
	 *            The system entity manager
	 * @param path
	 *            variable path to initialize
	 * @param recursive
	 *            if recursively process the entity fields
	 * @return a unique object that match the search criteria. If more than an
	 *         object match the criteria returns any of them
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Object searchObject(SearchExpression searchExpression,
			EntityManager entityManager, String[] path, boolean recursive) {
		// Check for different hibernate versions.
		Session hbSession = HBPersistenceServiceImpl
				.obtainHbSession(entityManager);

		Criteria actualCriteria = HBPersistenceServiceImpl
				.transformSearchExpression(searchExpression, hbSession);

		Object object = actualCriteria.uniqueResult();

		if (path != null) {
			try {
				HBPersistenceServiceImpl.invokePathOfGetters(object, path,
						recursive);
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
		return object;
	}

	/**
	 * Method that allows to count the objects that match a specified criteria.
	 * 
	 * @param searchExpression
	 *            The predefined query
	 * @param entityManager
	 *            The system entity manager
	 * 
	 * @return The number of objects that match the required criteria
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	@SuppressWarnings("unchecked")
	public static int countObjects(SearchExpression searchExpression,
			EntityManager entityManager) {
		Session hbSession = HBPersistenceServiceImpl
				.obtainHbSession(entityManager);
		Criteria actualCriteria = HBPersistenceServiceImpl
				.transformSearchExpression(searchExpression, hbSession);
		actualCriteria.setProjection(Projections.countDistinct("id"));

		List<Integer> collection = actualCriteria.list();

		if (collection.size() > 0) {
			Integer value = collection.iterator().next();

			if (value != null) {
				return value;
			} else {
				return 0;
			}
		} else {
			return 0;
		}

	}

	/**
	 * Method that transform a SearchExpression into a Criteria.
	 * 
	 * @param theSearchExpression
	 *            SearchExpression that has to be transformed into a criteria
	 * @param theSession
	 *            The session used by hibernate
	 * 
	 * @return the criteria transformed
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	private static Criteria transformSearchExpression(
			SearchExpression theSearchExpression, Session theSession) {

		DetachedCriteria detachedCrit = HBPersistenceServiceImpl
				.transformSearchExpression(theSearchExpression);

		Criteria crit = detachedCrit.getExecutableCriteria(theSession);

		if (theSearchExpression.getMaxResults() > 0) {
			crit.setMaxResults(theSearchExpression.getMaxResults());
		}

		crit.setCacheable(theSearchExpression.isCacheable());

		if (theSearchExpression.getCacheRegion() != null) {
			crit.setCacheRegion(theSearchExpression.getCacheRegion());
		}

		return crit;

	}

	/**
	 * Method that transform a SearchExpression into a DetachedCriteria.
	 * 
	 * @param theSearchExpression
	 *            SearchExpression that has to be transformed into a criteria
	 * 
	 * @return the criteria transformed
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	static DetachedCriteria transformSearchExpression(
			SearchExpression theSearchExpression) {
		DetachedCriteria crit;

		if (theSearchExpression.getAlias() != null) {

			crit = DetachedCriteria.forClass(
					theSearchExpression.getEntityClass(),
					theSearchExpression.getAlias());

		} else {
			crit = DetachedCriteria.forClass(theSearchExpression
					.getEntityClass());
		}

		// Transformes criterias into the respective hibernate classes
		Criterion theTransformedExpression = HBPersistenceServiceImpl
				.transformExpression(theSearchExpression.getSearchCriteria());

		if (theTransformedExpression != null) {
			crit.add(theTransformedExpression);
		}

		ITransformation theTransformation = theSearchExpression
				.getTransformation();
		if (theTransformation != null) {
			crit.setProjection(HBPersistenceServiceImpl
					.transformProjection(theTransformation));
		}

		// Transforms each sub searc expressions helper
		HBPersistenceServiceImpl.transformSearchSubexpressionsHelper(
				theSearchExpression, crit);

		// Adds order into Criteria
		crit = HBPersistenceServiceImpl.addSearchExpressionsOrderCriteria(
				theSearchExpression, crit);

		// If the transformation is distinct, looks for the real transformation
		theTransformation = HBPersistenceServiceImpl
				.distinctRealTransformation(theTransformation);

		// Setting Criteria result transformer
		crit = HBPersistenceServiceImpl.setCriteriaResultTransformer(
				theTransformation, crit);

		return crit;

	}

	/**
	 * Sets Criteria result transformer
	 * 
	 * @param theTransformation
	 *            The transformation to set
	 * @param crit
	 *            The detached criteria
	 * @return The requested criteria
	 */
	public static DetachedCriteria setCriteriaResultTransformer(
			ITransformation theTransformation, DetachedCriteria crit) {
		if (theTransformation != null) {
			if (theTransformation instanceof AliasTransformationsMap) {
				Class beanClass = ((AliasTransformationsMap) theTransformation)
						.getBeanClass();

				if (beanClass == null) {
					crit.setResultTransformer(CriteriaSpecification.ALIAS_TO_ENTITY_MAP);
				} else {
					crit.setResultTransformer(new AliasToBeanResultTransformer(
							beanClass));
				}
			} else {
				crit.setResultTransformer(CriteriaSpecification.PROJECTION);
			}
		} else {
			crit.setResultTransformer(CriteriaSpecification.DISTINCT_ROOT_ENTITY);
		}
		return crit;
	}

	/**
	 * The transformation is distinct, looks for the real transformation
	 * 
	 * @param theTransformation
	 *            The transformation to set
	 * @return The distinct transformation
	 */
	public static ITransformation distinctRealTransformation(
			ITransformation theTransformation) {
		while ((theTransformation != null)
				&& (theTransformation instanceof DistinctTransformation)) {
			theTransformation = ((DistinctTransformation) theTransformation)
					.getTargetTransformation();
		}
		return theTransformation;
	}

	/**
	 * Adds order into Criteria
	 * 
	 * @param theSearchExpression
	 *            The search expressions to process
	 * @param crit
	 *            The base detached criteria to add the order
	 * @return criteria with order expressions
	 */
	public static DetachedCriteria addSearchExpressionsOrderCriteria(
			SearchExpression theSearchExpression, DetachedCriteria crit) {
		Iterator<OrderCriteria> orderIterator = theSearchExpression.getOrders()
				.iterator();
		while (orderIterator.hasNext()) {
			OrderCriteria order = orderIterator.next();
			crit.addOrder(order.isAscending() ? Order.asc(order
					.getPropertyName()) : Order.desc(order.getPropertyName()));
		}
		return crit;
	}

	/**
	 * Transforms each sub search expressions helper
	 * 
	 * @param theSearchExpression
	 *            The search expressions to process
	 * @param crit
	 *            The base detached criteria to add the order
	 */
	public static void transformSearchSubexpressionsHelper(
			SearchExpression theSearchExpression, DetachedCriteria crit) {

		Iterator<SubSearchExpression> iterator = theSearchExpression
				.getSubExpressions();
		while (iterator.hasNext()) {
			SubSearchExpression subExpression = iterator.next();
			HBPersistenceServiceImpl.transformSearchExpressionHelper(
					subExpression, crit);
		}
	}

	/**
	 * Method used to transform a query expression into a expression in the
	 * hibernate language.
	 * 
	 * @param theCriteria
	 *            The criteria that needs to be transformed
	 * @return The criteria transformed in Hibernate.
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Criterion transformExpression(ISearchCriteria theCriteria) {
		// transform to the correct criteria
		Criterion resultCriterion = null;
		if (theCriteria instanceof IdentifierEqCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((IdentifierEqCriteria) theCriteria);
		} else if (theCriteria instanceof ConjunctionCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((ConjunctionCriteria) theCriteria);
		} else if (theCriteria instanceof DisjunctionCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((DisjunctionCriteria) theCriteria);
		} else if (theCriteria instanceof EqCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((EqCriteria) theCriteria);
		} else if (theCriteria instanceof InCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((InCriteria) theCriteria);
		} else if (theCriteria instanceof AndCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((AndCriteria) theCriteria);
		} else if (theCriteria instanceof BetweenCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((BetweenCriteria) theCriteria);
		} else if (theCriteria instanceof EqPropertyCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((EqPropertyCriteria) theCriteria);
		} else if (theCriteria instanceof GeCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((GeCriteria) theCriteria);
		} else if (theCriteria instanceof GtCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((GtCriteria) theCriteria);
		} else if (theCriteria instanceof IlikeCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((IlikeCriteria) theCriteria);
		} else if (theCriteria instanceof LeCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((LeCriteria) theCriteria);
		} else if (theCriteria instanceof LePropertyCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((LePropertyCriteria) theCriteria);
		} else if (theCriteria instanceof LikeCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((LikeCriteria) theCriteria);
		} else if (theCriteria instanceof LtCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((LtCriteria) theCriteria);
		} else if (theCriteria instanceof LtPropertyCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((LtPropertyCriteria) theCriteria);
		} else if (theCriteria instanceof NotCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((NotCriteria) theCriteria);
		} else if (theCriteria instanceof NotNullCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((NotNullCriteria) theCriteria);
		} else if (theCriteria instanceof NullCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((NullCriteria) theCriteria);
		} else if (theCriteria instanceof OrCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((OrCriteria) theCriteria);
		} else if (theCriteria instanceof SizeCollectionCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((SizeCollectionCriteria) theCriteria);
		} else if (theCriteria instanceof SqlCriteria) {
			resultCriterion = HBCriteriaTransformer
					.transformCriteria((SqlCriteria) theCriteria);

		} else if (theCriteria instanceof InSubqueryPropertyCriteria) {

			resultCriterion = HBCriteriaTransformer
					.transformCriteria((InSubqueryPropertyCriteria) theCriteria);
		}

		return resultCriterion;
	}

	/**
	 * Method that allows to translates a transformation into the proper
	 * projection
	 * 
	 * @param transformation
	 *            The transformation
	 * @return The projection
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	public static Projection transformProjection(ITransformation transformation) {
		Projection projection = null;

		if (transformation instanceof PropertyTransformation) {
			projection = HBProjectionTransformer
					.transformProjection((PropertyTransformation) transformation);
		} else if (transformation instanceof MinTransformation) {
			projection = HBProjectionTransformer
					.transformProjection((MinTransformation) transformation);
		} else if (transformation instanceof MaxTransformation) {
			projection = HBProjectionTransformer
					.transformProjection((MaxTransformation) transformation);
		} else if (transformation instanceof SumTransformation) {
			projection = HBProjectionTransformer
					.transformProjection((SumTransformation) transformation);
		} else if (transformation instanceof GroupTransformation) {
			projection = HBProjectionTransformer
					.transformProjection((GroupTransformation) transformation);
		} else if (transformation instanceof TransformationsList) {
			projection = HBProjectionTransformer
					.transformProjection((TransformationsList) transformation);
		} else if (transformation instanceof AliasTransformationsMap) {
			projection = HBProjectionTransformer
					.transformProjection((AliasTransformationsMap) transformation);
		} else if (transformation instanceof RowCountTransformation) {
			projection = HBProjectionTransformer
					.transformProjection((RowCountTransformation) transformation);
		} else if (transformation instanceof DistinctTransformation) {
			projection = HBProjectionTransformer
					.transformProjection(HBPersistenceServiceImpl
							.transformProjection(((DistinctTransformation) transformation)
									.getTargetTransformation()));
		} else if (transformation instanceof IdentifierTransformation) {
			projection = HBProjectionTransformer
					.transformProjection((IdentifierTransformation) transformation);
		} else if (transformation instanceof CountTransformation) {
			projection = HBProjectionTransformer
					.transformProjection((CountTransformation) transformation);
		}
		return projection;
	}

	/**
	 * Method that creates the hierarchy of criteria from the SearchExpression
	 * defined by the developer
	 * 
	 * @param expression
	 *            SearchExpression that has to be transformed into a criteria
	 * @param parentCriteria
	 *            The criteria parent that should be used as the parent of the
	 *            criteria that must be created
	 * @return the criteria created
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	private static DetachedCriteria transformSearchExpressionHelper(
			SubSearchExpression expression, DetachedCriteria parentCriteria) {
		DetachedCriteria criteria;

		if (expression.getAlias() != null) {
			criteria = parentCriteria.createCriteria(expression.getPath(),
					expression.getAlias(), HBPersistenceServiceImpl
							.transformJoinType(expression.getJoinType()));

		} else {
			criteria = parentCriteria.createCriteria(expression.getPath(),
					HBPersistenceServiceImpl.transformJoinType(expression
							.getJoinType()));

		}
		parentCriteria.setFetchMode(expression.getPath(), FetchMode.SELECT);

		Criterion theTransformExpression = HBPersistenceServiceImpl
				.transformExpression(expression.getSearchCriteria());
		if (theTransformExpression != null) {
			criteria.add(theTransformExpression);
		}

		Iterator<SubSearchExpression> iterator = expression.getSubExpressions();
		while (iterator.hasNext()) {
			SubSearchExpression subExpression = iterator.next();
			HBPersistenceServiceImpl.transformSearchExpressionHelper(
					subExpression, criteria);
		}

		return criteria;
	}

	/**
	 * Method that convert an enumerated value into a hibernate criteria join
	 * type.
	 * 
	 * @param theJoinType
	 *            The type of join to use when the method createAlias from
	 *            SearchExpression is used.
	 * @return the converted join type value
	 * 
	 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
	 */
	private static int transformJoinType(JoinType theJoinType) {
		if (theJoinType != null) {
			switch (theJoinType) {
			case FULL_JOIN:
				return CriteriaSpecification.FULL_JOIN;
			case INNER_JOIN:
				return CriteriaSpecification.INNER_JOIN;
			default: // case LEFT_JOIN:
				return CriteriaSpecification.LEFT_JOIN;
			}
		}
		return CriteriaSpecification.LEFT_JOIN;
	}

	/**
	 * <p>
	 * Initializes all attributes specified in the path starting from the
	 * BComponentEntity passed as parameter.
	 * </p>
	 * <p>
	 * The path must separates the attributes with a '.'.
	 * </p>
	 * 
	 * @param result
	 *            The result object
	 * @param path
	 *            The path variable to initialize
	 * @param recursive
	 *            if recursively process the entity fields
	 * @throws Exception
	 *             If any error occurs during the processing
	 */
	private static void invokePathOfGetters(Object result, String path,
			boolean recursive) throws Exception {
		try {
			if (result == null) {
				return;
			}
			StringTokenizer pathTokenized = new StringTokenizer(path, ".");
			List<Object> objectsInit = new ArrayList<Object>(
					pathTokenized.countTokens());
			objectsInit.add(result);
			while (pathTokenized.hasMoreTokens()) {
				String attribute = pathTokenized.nextToken();
				Object objInPath = objectsInit.get(objectsInit.size() - 1);

				if (objInPath == null) {
					break;
				}

				Object nextObjInPath = PropertyUtils.getProperty(objInPath,
						attribute);

				Hibernate.initialize(nextObjInPath);
				if (nextObjInPath instanceof Collection) {
					Iterator nextObjIter = ((Collection) nextObjInPath)
							.iterator();
					while (nextObjIter.hasNext()) {
						HBPersistenceServiceImpl.processObjectInPath(result,
								path, recursive, attribute, nextObjIter);
					}
					break;
				} else {
					objectsInit.add(nextObjInPath);
				}
			}
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

	/**
	 * Initializes Objects In Path of BComponentEntity passed as parameter.
	 * 
	 * @param result
	 *            The object to process
	 * @param path
	 *            The object path
	 * @param recursive
	 *            if recursively process the entity fields
	 * @param attribute
	 *            attribute string
	 * @param nextObjIter
	 *            Object iterator
	 * @throws Exception
	 *             Thrown if any error eccur
	 */
	private static void processObjectInPath(Object result, String path,
			boolean recursive, String attribute, Iterator nextObjIter)
			throws Exception {
		Object nextResult = nextObjIter.next();
		if ((nextResult.getClass().equals(result.getClass())) && recursive) {
			HBPersistenceServiceImpl.invokePathOfGetters(nextResult, path,
					recursive);
		}
		if (path.indexOf(attribute) + attribute.length() < path.length()) {
			try {
				String nextPath = path.substring(path.indexOf(attribute)
						+ attribute.length() + 1);
				HBPersistenceServiceImpl.invokePathOfGetters(nextResult,
						nextPath, recursive);
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
	}

	/**
	 * <p>
	 * Initializes all attributes specified in the path starting from the
	 * BComponentEntity passed as parameter.
	 * </p>
	 * <p>
	 * The path must separates the attributes with a '.'.
	 * </p>
	 * 
	 * @param result
	 *            The result object
	 * @param path
	 *            The path variables to initialize
	 * @param recursive
	 *            if recursively process the entity fields
	 * @throws Exception
	 *             If any error occurs during the processing
	 */
	private static void invokePathOfGetters(Object result, String[] path,
			boolean recursive) throws Exception {
		for (String element : path) {
			HBPersistenceServiceImpl.invokePathOfGetters(result, element,
					recursive);
		}
	}

	/**
	 * Retreives an object by its primary key. Also initializes the properties
	 * specified in path parameter
	 * 
	 * @param entityClass
	 *            The class of the object to search for
	 * @param pk
	 *            The primary key to search for
	 * @param entityManager
	 *            The system entity manager
	 * @param path
	 *            The path variables to initialize
	 * @param recursive
	 *            if recursively process the entity fields
	 * @return the found object
	 */
	public static Object find(Class entityClass, Object pk,
			EntityManager entityManager, String[] path, boolean recursive) {

		Session hbSession = HBPersistenceServiceImpl
				.obtainHbSession(entityManager);

		Object object = hbSession.get(entityClass.getName(), (Serializable) pk);

		if (path != null) {
			try {
				HBPersistenceServiceImpl.invokePathOfGetters(object, path,
						recursive);
			} catch (Exception e) {
				e.printStackTrace();
			}
		}

		return object;
	}

	/**
	 * Method used to clean all the second level cache of Hibernate. This method
	 * occurs outside of any transaction; it performs an immediate "hard" remove
	 * in all the entities of the second-level cache, so does not respect any
	 * transaction isolation semantics of the usage strategy. Use with care.
	 * 
	 * @param entityManager
	 *            The system entity manager
	 * @throws Exception
	 *             If any error occurs during the processing
	 */
	public static void cleanSecondLevelCache(EntityManager entityManager)
			throws Exception {
		Session session = HBPersistenceServiceImpl
				.obtainHbSession(entityManager);
		SessionFactory sessionFactory = session.getSessionFactory();
		Map mapClass = sessionFactory.getAllClassMetadata();
		Set<String> keys = mapClass.keySet();
		Iterator ite = keys.iterator();
		while (ite.hasNext()) {
			String className = (String) ite.next();
			sessionFactory.evictEntity(className);
		}

	}

	/**
	 * Method used to clean all collections contained in the second level cache
	 * of Hibernate. This method occurs outside of any transaction; it performs
	 * an immediate "hard" remove in all the collections of the second-level
	 * cache, so does not respect any transaction isolation semantics of the
	 * usage strategy. Use with care.
	 * 
	 * @param entityManager
	 *            The system entity manager
	 * @throws Exception
	 *             If any error occurs during the processing
	 */
	public static void cleanCollectionSecondLevelCache(
			EntityManager entityManager) throws Exception {
		Session session = HBPersistenceServiceImpl
				.obtainHbSession(entityManager);
		SessionFactory sessionFactory = session.getSessionFactory();
		Map mapClass = sessionFactory.getAllCollectionMetadata();
		Set<String> keys = mapClass.keySet();
		Iterator ite = keys.iterator();
		while (ite.hasNext()) {
			String className = (String) ite.next();
			sessionFactory.evictCollection(className);
		}

	}

	/**
	 * Remove the given entity from the persistence context, causing a managed
	 * entity to become detached. Unflushed changes made to the entity if any
	 * (including removal of the entity), will not be synchronized to the
	 * database. Entities which previously referenced the detached entity will
	 * continue to reference it.
	 * 
	 * @param entity
	 *            entity instance
	 * @param entityManager
	 *            The system entity manager
	 * 
	 */
	public static void detach(Object entity, EntityManager entityManager) {
		Session session = HBPersistenceServiceImpl
				.obtainHbSession(entityManager);

		session.evict(entity);
	}

}
