package com.smartmatic.waffle.properties;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

/**
 * Base class used to obtain a property from a .properties file in the
 * application.
 * 
 * @version 1.0 (Aug, 2017)
 */
public class ECMApplicationProperties {
	/** Singleton application properties instance. */
	private static ECMApplicationProperties singletonInstance = null;

	/**
	 * Property used to indicate the path to load the config properties file
	 * plain.
	 */
	private static final String PLAIN_PROPERTIES_FILEPATH = System
			.getProperty("jboss.server.home.dir")
			+ "/conf/props/os-regex.properties";

	/**
	 * Property object instance.
	 */
	private Properties prop = new Properties();

	/**
	 * InputStream object to read the property file.
	 */
	private InputStream input = null;

	/**
	 * Instantiates a new application properties.
	 */
	private ECMApplicationProperties() {

		try {
			this.input = new FileInputStream(PLAIN_PROPERTIES_FILEPATH);
			this.prop.load(this.input);
		} catch (Exception e) {
			throw new ApplicationPropertiesException(
					ApplicationPropertiesException.ExceptionInfo.INITIALIZATION_EXCEPTION);
		} finally {
			if (this.input != null) {
				try {
					this.input.close();
				} catch (IOException e) {
					throw new ApplicationPropertiesException(
							ApplicationPropertiesException.ExceptionInfo.INITIALIZATION_EXCEPTION);
				}
			}
		}
	}

	/**
	 * Returns the singleton instance.
	 * 
	 * @return the singleton instance
	 */
	public static ECMApplicationProperties getInstance() {
		if (singletonInstance == null) {
			singletonInstance = new ECMApplicationProperties();
		}
		return singletonInstance;
	}

	/**
	 * Gets the value.
	 * 
	 * @param propertyName
	 *            the property name.
	 * @return the value
	 */
	@SuppressWarnings("unchecked")
	public static String getValue(String propertyName) {
		String result = ECMApplicationProperties.getInstance().prop
				.getProperty(propertyName);

		if (result == null) {
			throw new ApplicationPropertiesException(
					ApplicationPropertiesException.ExceptionInfo.PROPERTY_NOT_FOUND,
					propertyName);
		}

		return result;
	}
}
