/**
 * SmartPropertiesLocator.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.properties;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;

import org.igfay.jfig.JFigConstants;
import org.igfay.jfig.JFigException;

/**
 * The Class SmartPropertiesLocator.
 * 
 * @version 1.0 (Nov 30, 2010)
 * @author Hector Rodriguez (hector.rodriguez@smartmatic.com)
 */

public class SmartPropertiesLocator implements SmartJFigLocatorIF {

	/** The config file. */
	private String configFile;

	/** The config location. */
	private String configLocation = JFigConstants.LOCATION_PROPERTY;

	/** The input stream. */
	private InputStream inputStream;

	/** The xsd path. */
	private String xsdPath;

	/**
	 * Instantiates a new smart properties locator.
	 * 
	 * @param filePath
	 *            the file path
	 * @param xsdPathFile
	 *            the xsd path file
	 */
	public SmartPropertiesLocator(String filePath, String xsdPathFile) {
		this.configFile = filePath;
		this.xsdPath = xsdPathFile;
	}

	/**
	 * Instantiates a new smart properties locator.
	 * 
	 * @param stream
	 *            the stream
	 * @param xsdPathFile
	 *            the xsd path file
	 */
	public SmartPropertiesLocator(InputStream stream, String xsdPathFile) {
		this.inputStream = stream;
		this.configLocation = JFigConstants.CLASSPATH;
		this.xsdPath = xsdPathFile;
	}

	/**
	 * Gets the config file name.
	 * 
	 * @return the config file name
	 * @inheritDoc
	 */
	@Override
	public String getConfigFileName() {
		return this.configFile;
	}

	/**
	 * Sets the config file name.
	 * 
	 * @param value
	 *            the new config file name
	 * @inheritDoc
	 */
	@Override
	public void setConfigFileName(String value) {
	}

	/**
	 * Gets the config location.
	 * 
	 * @return the config location
	 * @throws JFigException
	 *             the j fig exception
	 * @inheritDoc
	 */
	@Override
	public String getConfigLocation() throws JFigException {
		return this.configLocation;
	}

	/**
	 * Sets the config location.
	 * 
	 * @param value
	 *            the new config location
	 * @throws JFigException
	 *             the j fig exception
	 * @inheritDoc
	 */
	@Override
	public void setConfigLocation(String value) throws JFigException {
		this.configLocation = value;
	}

	/**
	 * Gets the default config file name.
	 * 
	 * @return the default config file name
	 * @inheritDoc
	 */
	@Override
	public String getDefaultConfigFileName() {
		return this.configFile;
	}

	/**
	 * Sets the default config file name.
	 * 
	 * @param value
	 *            the new default config file name
	 * @inheritDoc
	 */
	@Override
	public void setDefaultConfigFileName(String value) {
		this.configFile = value;
	}

	/**
	 * Gets the input stream.
	 * 
	 * @return the input stream
	 * @throws JFigException
	 *             the j fig exception
	 * @inheritDoc
	 */
	@Override
	public InputStream getInputStream() throws JFigException {
		try {
			if (this.configFile != null) {
				this.inputStream = new FileInputStream(this.configFile);
			}
		} catch (FileNotFoundException e) {
			String msg = "FileNotFoundException for " + getConfigFileName();
			throw new JFigException(msg);
		}
		return this.inputStream;
	}

	@Override
	public String getXSDConfigFileName() {
		return this.xsdPath;
	}
}
