/**
 * DetachedSignatureCreator.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2018 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */

package com.smartmatic.waffle.signingtool;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.io.FileUtils;
import org.apache.xml.security.signature.XMLSignature;

import com.smartmatic.waffle.security.sign.SignXMLUtil;

/**
 * Generates detached signature.
 */
public class DetachedSignatureCreator {

	
	private static final String ALGORITHM = XMLSignature.ALGO_ID_SIGNATURE_ECDSA_SHA256;
	private static final String SIGN_FILE_NAME = "SignatureFile.xml";
	private byte[] pkcs12;
	private String alias;
	private String password;
	
	
	/**
	 * Class constructor.
	 * @param pkcs12
	 * 		pkcs12 that will be used to sign. ECDSA_SHA256
	 * @param alias
	 * 		key alias 
	 * @param password
	 * 		key password
	 */
	public DetachedSignatureCreator(byte[] pkcs12, String alias, String password){
		
		this.pkcs12 = pkcs12;
		this.alias = alias;
		this.password = password;
	}
	

	/**
	 * Signs specific directory no including internal directories. 
	 * @param directory
	 * 		Directory to sign.
	 * @throws SignDirException
	 */
	private void signDir(File directory) throws SignDirException {

		List<File> fileListToSign = new ArrayList<File>();
		for(File file : directory.listFiles()){
			if(file.isFile() && !file.getName().equals(SIGN_FILE_NAME)){
				fileListToSign.add(file);
			}
		}
		
		Map<String, List<File>> filesByUriBase = new HashMap<String, List<File>>();

		filesByUriBase.put(directory.getAbsolutePath(), fileListToSign);
		String xml;
		try {
			xml = SignXMLUtil.signDetachedXML(pkcs12, alias, password, filesByUriBase, ALGORITHM);
		} catch (Exception e) {
			throw new SignDirException("Error creating xml signature for directory", e);
		}
		
		try {
			FileUtils.write(new File(directory, SIGN_FILE_NAME), xml);
		} catch (IOException e) {
			throw new SignDirException("Error writing signature file on disk", e);
		}
	}

	/**
	 * Signs directory including internal directories.
	 * @param directory
	 * @throws SignDirException
	 */
	public void sign(File directory) throws SignDirException {
		
		if(!directory.exists() || !directory.isDirectory()){
			throw new SignDirException("Invalid path to sign " + directory.toString());
		}
		
		signDir(directory);
		
		for(File file : directory.listFiles()){
			if(file.isDirectory()){
				signDir(file);
			}
		}
	}
}
