/*
 * SingCreator.java
 */

package com.smartmatic.waffle.signingtool.ui;

import java.awt.Dimension;
import java.awt.Toolkit;
import java.io.File;

import org.apache.commons.io.FileUtils;
import org.jdesktop.application.Application;
import org.jdesktop.application.SingleFrameApplication;

import com.smartmatic.waffle.signingtool.SignDirUtil;

/**
 * The main class of the application.
 */
public class SignCreator extends SingleFrameApplication {

    /**
     * At startup create and show the main frame of the application.
     */
    @Override protected void startup() {
        show(new SignCreatorView(this));
    }

    /**
     * This method is to initialize the specified window by injecting resources.
     * Windows shown in our application come fully initialized from the GUI
     * builder, so this additional configuration is not needed.
     */
    @Override protected void configureWindow(java.awt.Window root) {
    	Dimension screen = Toolkit.getDefaultToolkit().getScreenSize(); 
    	root.setLocation((screen.width - 910)/2, (screen.height - 768)/2);
    }

    /**
     * A convenient static getter for the application instance.
     * @return the instance of SingCreator
     */
    public static SignCreator getApplication() {
        return Application.getInstance(SignCreator.class);
    }

    /**
     * Main method launching the application.
     */
    public static void main(String[] args) {
    	
    	SignDirUtil.checkDependencies();
    	
    	if(args.length == 0){
    		launch(SignCreator.class, args);
   		}
    	else if(args.length != 4)
    	{
    		System.out.println("CLI arguments: "
    				+ "directoryToSign certificateFile "
    				+ "certificateAlias certificatePassword");
    	}
    	else{
    		mainCli(args);
    	}
    }
    
	/**
	 * Calls CLI application.
	 * 
	 * @param args needs four arguments -[0]folderPathToSign,
	 * -[1]certificatePath, -[2]aliasCert, -[3]passwordCert
	 */
	public static void mainCli(String[] args) {
		String folderPathToSign = args[0];
		String certificatePath = args[1];
		String aliasCert = args[2];
		String passwordCert = args[3];

		try {
			
			File folderTosign = new File(folderPathToSign);
			
			System.out.println("Signing directory: "+  folderTosign.getPath());
			
			SignDirUtil.validateCertificate(certificatePath, aliasCert, passwordCert);
			
			File caFile = new File(folderPathToSign, "dataProvider.crt");
			
			if(caFile.exists())
				caFile.delete();
			
			SignDirUtil.signDir(folderTosign, certificatePath, aliasCert, passwordCert);
			
			
			SignDirUtil.writeCertificateFile(caFile, certificatePath, aliasCert, passwordCert);

			System.out.println(folderPathToSign	+ " was successfully signed");
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}
    
}
