/**
 * PollingPlaceDataValidator.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.validator.demographics;

import com.smartmatic.waffle.client.ClientJNDIWrapper;
import com.smartmatic.waffle.domain.demographics.PollingPlaceData;
import com.smartmatic.waffle.domain.demographics.RegionData;
import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.persistence.search.SearchExpression;
import com.smartmatic.waffle.persistence.search.criteria.CriteriaFactory;
import com.smartmatic.waffle.persistence.service.spec.IPersistenceService;
import com.smartmatic.waffle.validator.ObjectDataValidator;
import com.smartmatic.waffle.validator.ObjectDataValidatorException;
import com.smartmatic.waffle.validator.Validator;

/**
 * Class used to validate Polling Place Data.
 */
public class PollingPlaceDataValidator extends
		ObjectDataValidator<PollingPlaceData> {

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.validator.ObjectDataValidator#postPersist(java.lang.Object
	 * )
	 */
	@Override
	public void postPersist(PollingPlaceData component)
			throws ObjectDataValidatorException {
		Validator v = new Validator();
		v.prePersist(component);
	}

	/**
	 * *.
	 * 
	 * @param component
	 *            the component
	 * @throws ObjectDataValidatorException
	 *             the object data validator exception
	 */
	@Override
	public void prePersist(PollingPlaceData component)
			throws ObjectDataValidatorException {
		try {
			if (component.getRegion() == null
					&& component.getRegionNisCode() != null) {
				getRegionByNisCode(component);
			}
		} catch (BaseException e) {
			throw new ObjectDataValidatorException(
					ObjectDataValidatorException.ExceptionInfo.LISTENER_INNER_PROBLEM,
					e);
		}
	}

	/**
	 * *.
	 * 
	 * @param pollingPlace
	 *            the polling place
	 * @return the region by nis code
	 * @throws BaseException
	 *             the base exception
	 */
	public void getRegionByNisCode(PollingPlaceData pollingPlace)
			throws BaseException {
		IPersistenceService iPersistenceService = ClientJNDIWrapper
				.getInstance().getReference(IPersistenceService.class);

		SearchExpression search = new SearchExpression(RegionData.class);
		search.createAlias("category", "category");
		search.addSearchCriteria(CriteriaFactory.eq("nisCode",
				pollingPlace.getRegionNisCode()));
		search.addSearchCriteria(CriteriaFactory.eq(
				"category.lastLevelCategory", true));

		RegionData region = (RegionData) iPersistenceService.searchObject(
				search, null);
		pollingPlace.setRegion(region);
	}
}
