/**
 * RegionDataValidator.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.validator.demographics;

import java.util.Collection;
import java.util.HashSet;

import com.smartmatic.waffle.client.ClientJNDIWrapper;
import com.smartmatic.waffle.client.JNDICommunicationException;
import com.smartmatic.waffle.domain.demographics.RegionData;
import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.persistence.search.SearchExpression;
import com.smartmatic.waffle.persistence.search.criteria.CriteriaFactory;
import com.smartmatic.waffle.persistence.service.spec.IPersistenceService;
import com.smartmatic.waffle.validator.ObjectDataValidator;
import com.smartmatic.waffle.validator.ObjectDataValidatorException;
import com.smartmatic.waffle.validator.Validator;

/**
 * Class used to validate Region Data.
 */
public class RegionDataValidator extends ObjectDataValidator<RegionData> {

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.validator.ObjectDataValidator#postPersist(java.lang.Object
	 * )
	 */
	@Override
	public void postPersist(RegionData component)
			throws ObjectDataValidatorException {
		try {
			this.generateAllParentInfo(component);
			Validator v = new Validator();
			v.prePersist(component);
		} catch (JNDICommunicationException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.smartmatic.validator.ObjectDataValidator#postUpdate(java.lang.Object)
	 */
	@Override
	public void postUpdate(RegionData component)
			throws ObjectDataValidatorException {
		// try {
		// this.generateAllParentInfo(component);
		// } catch (JNDICommunicationException e) {
		// TODO Auto-generated catch block
		// e.printStackTrace();
		// }
	}

	/**
	 * Generate all parent info.
	 * 
	 * @param region
	 *            the region
	 * @throws RegionDataValidatorException
	 *             the region data validator exception
	 * @throws JNDICommunicationException
	 *             the jNDI communication exception
	 */
	private void generateAllParentInfo(RegionData region)
			throws RegionDataValidatorException, JNDICommunicationException {

		try {
			IPersistenceService iPersistenceService = ClientJNDIWrapper
					.getInstance().getReference(IPersistenceService.class);
			// PersistenceServiceBean.setLocalCreationMode();
			// PersistenceServiceBean ps = new PersistenceServiceBean();
			HashSet<RegionData> parents = new HashSet<RegionData>();
			if (region.getParent() == null) {
				parents.add(region);
				region.setAllParents(parents);
				iPersistenceService.update(region, null);
				// ps.getEntityManager().merge(region);
			} else {
				SearchExpression search = new SearchExpression(RegionData.class);
				Long[] object = new Long[region.getParent().size()];
				int i = 0;
				for (RegionData regionIndex : region.getParent()) {
					object[i++] = regionIndex.getCode();
				}

				search.addSearchCriteria(CriteriaFactory.in("code", object));

				String[] initPath = new String[] { "allParents" };
				Collection<RegionData> parentsRegion = iPersistenceService
						.searchObjects(search, initPath, null);
				for (RegionData currentRegion : parentsRegion) {
					parents.addAll(currentRegion.getAllParents());
				}
				parents.add(region);
				region.setAllParents(parents);
				iPersistenceService.update(region, null);
				// ps.getEntityManager().merge(region);
			}
		} catch (BaseException e) {
			throw new RegionDataValidatorException(
					RegionDataValidatorException.ExceptionInfo.ALL_PARENT_CONSTRUCTION_PROBLEM,
					e);
		}
	}

}
