package com.smartmatic.waffle.validator.demographics;

import java.io.File;

import org.apache.commons.io.FileUtils;
import org.junit.Before;
import org.junit.Test;

import com.smartmatic.waffle.domain.eligibleoption.ImageWrapper;
import com.smartmatic.waffle.domain.general.KeystoreData;
import com.smartmatic.waffle.validator.ObjectDataValidatorException;
import com.smartmatic.waffle.validator.ObjectDataValidatorException.ExceptionInfo;

/**
 * Keystore data validation test class.
 * 
 */
public class KeystoreDataValidationTest {

	KeystoreDataValidation keystoreDataValidation;

	KeystoreData validKeyStore;

	KeystoreData notValidKeyStore;

	@Before
	public void setUp() throws Exception {

		File validPkcs12File = new File(
				"test/resources/ecm_trust_chain_valid.p12");

		ImageWrapper validKeyStore = new ImageWrapper();

		validKeyStore.setBinaryData(FileUtils
				.readFileToByteArray(validPkcs12File));

		File notValidPkcs12File = new File(
				"test/resources/ecm_trust_chain_not_valid.p12");

		ImageWrapper notValidKeyStore = new ImageWrapper();

		notValidKeyStore.setBinaryData(FileUtils
				.readFileToByteArray(notValidPkcs12File));

		this.keystoreDataValidation = new KeystoreDataValidation();

		this.validKeyStore = new KeystoreData();

		this.validKeyStore.setAlias("ecm");

		this.validKeyStore.setPassword("5737b3f");

		this.validKeyStore.setPkcs12(validKeyStore);

		this.notValidKeyStore = new KeystoreData();

		this.notValidKeyStore.setAlias("ecm");

		this.notValidKeyStore.setPassword("bel2013");

		this.notValidKeyStore.setPkcs12(notValidKeyStore);
	}

	@Test
	public void testPrePersistTrustChainValid()
			throws ObjectDataValidatorException {
		try {
			this.keystoreDataValidation.prePersist(this.validKeyStore);
		} catch (ObjectDataValidatorException e) {
			throw e;
		}
		assert true;
	}

	@Test
	public void testPrePersistTrustChainNotValid()
			throws ObjectDataValidatorException {
		try {
			this.keystoreDataValidation.prePersist(this.notValidKeyStore);
		} catch (ObjectDataValidatorException e) {
			if (e.getInfo().equals(ExceptionInfo.INVALID_KEYSTORE)) {
				assert true;
			} else {
				throw e;
			}
		}
	}
}
