/**
 * GeneratorException.java
 *
 * $Revision: 1.6 $ ($Date: 2011-04-06 05:08:28 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.generator.spec;

import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.lang.IExceptionInfo;

/**
 * Exceptions occurred during the object attributes auto-generation
 * 
 * @author Carlos Lameda (carlos.lameda@smartmatic.com)
 * @version 1.0 (Nov 5, 2009)
 */
public class GeneratorException extends BaseException {
	/**
	 * Holds the version of the class. It is used by the serialization engine to
	 * determine when a class its equivalent to another
	 * 
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */
	private static final long serialVersionUID = 1768997305484418752L;

	/**
	 * Enum that contains all the possible reasons because the
	 * GeneratorException can be thrown
	 * 
	 * @version 1.0 (23/10/2006)
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */

	public enum ExceptionInfo implements IExceptionInfo {

		/**
		 * Thrown when a problem occurred while the value generation is taking
		 * place
		 */
		VALUE_GENERATION;
		private String message;

		/**
		 * Getter of <code>message</code> property.
		 * 
		 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
		 * @return <code>message</code> property value.
		 * @see #message
		 */
		@Override
		public String getMessage() {
			return this.message;
		}

		/**
		 * Constructor
		 * 
		 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
		 * @param msg
		 *            the resource bundle's key message
		 */
		private ExceptionInfo() {
			this.message = this.getClass().getName() + "." + this.name();
		}
	}

	/**
	 * Creates a instance of a GeneratorException
	 * 
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * @param theParameters
	 *            The array of placeholder values used as parameters for this
	 *            exception's enumerated cause's related message
	 */
	public GeneratorException(IExceptionInfo theExceptionInfo,
			Object... theParameters) {

		super(theExceptionInfo, theParameters);

		return;
	}

	/**
	 * Creates a instance of a GeneratorException
	 * 
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * @param theThrowable
	 *            params used to give information about the exception
	 * @param theParameters
	 *            the array of placeholder values used as parameters for this
	 *            exception's enumerated cause's related message
	 */
	public GeneratorException(IExceptionInfo theExceptionInfo,
			Throwable theThrowable, Object... theParameters) {
		super(theExceptionInfo, theThrowable, theParameters);
		return;
	}

	/**
	 * Creates a instance of a GeneratorException
	 * 
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * @param theThrowable
	 *            params used to give information about the exception
	 * 
	 */
	public GeneratorException(IExceptionInfo theExceptionInfo,
			Throwable theThrowable) {
		super(theExceptionInfo, theThrowable);

		return;
	}

	/**
	 * Creates a instance of a GeneratorException
	 * 
	 * @param exceptionInfo
	 *            The reason because the exception is being thrown
	 * 
	 */
	public GeneratorException(IExceptionInfo theExceptionInfo) {
		super(theExceptionInfo);

		return;
	}

}
