/*
 * GZipWrongMessageFormatException.java
 *
 * Revision: $Revision$  (Last Modified: $Date$)
 * Last Modified by: [$Author$]
 * 
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.lang;

/**
 * The Class GZipWrongMessageFormatException.
 * 
 * @author Hector Rodriguez (hector.rodriguez@smartmatic.com)
 * @version 1.0 (Dec 1, 2009)
 */
public class GZipWrongMessageFormatException extends BaseException {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 2738560626232033365L;

	/**
	 * Enum that contains all the possible reasons because the
	 * GZipWrongMessageFormatException can be thrown.
	 * 
	 * @version 1.0 (06/02/2009)
	 * @author Hector Rodri­guez (hector.rodriguez@smartmatic.com)
	 */
	public enum ExceptionInfo implements IExceptionInfo {

		/** The unable decompress message. */
		UNABLE_DECOMPRESS_MESSAGE("UNABLE_DECOMPRESS_MESSAGE"), //

		/** The unable compress message. */
		UNABLE_COMPRESS_MESSAGE("UNABLE_COMPRESS_MESSAGE"); //
		/**
		 * <p>
		 * Each enumerator's resource bundle's key message.
		 * </p>
		 */

		private String message;

		/**
		 * Getter of <code>message</code> property.
		 * 
		 * @return <code>message</code> property value.
		 * @author Hector Rodri­guez (hector.rodriguez@smartmatic.com)
		 * @see #message
		 */
		@Override
		public String getMessage() {
			return this.message;
		}

		/**
		 * Constructor.
		 * 
		 * @param msg
		 *            the resource bundle's key message
		 * @author Hector Rodri­guez (hector.rodriguez@smartmatic.com)
		 */
		private ExceptionInfo(String msg) {
			this.message = this.getClass().getName() + "." + msg;
		}
	}

	/**
	 * Instantiates a new g zip wrong message format exception.
	 * 
	 * @param exceptionInfo
	 *            the exception info
	 */
	public GZipWrongMessageFormatException(IExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/**
	 * Instantiates a new g zip wrong message format exception.
	 * 
	 * @param exceptionInfo
	 *            the exception info
	 * @param throwable
	 *            the throwable
	 */
	public GZipWrongMessageFormatException(IExceptionInfo exceptionInfo,
			Throwable throwable) {
		super(exceptionInfo, throwable);
	}

	/**
	 * Instantiates a new g zip wrong message format exception.
	 * 
	 * @param exceptionInfo
	 *            the exception info
	 * @param throwable
	 *            the throwable
	 * @param parameters
	 *            the parameters
	 */
	public GZipWrongMessageFormatException(IExceptionInfo exceptionInfo,
			Throwable throwable, Object... parameters) {
		super(exceptionInfo, throwable, parameters);
	}

	/**
	 * Instantiates a new g zip wrong message format exception.
	 * 
	 * @param exceptionInfo
	 *            the exception info
	 * @param parameters
	 *            the parameters
	 */
	public GZipWrongMessageFormatException(IExceptionInfo exceptionInfo,
			Object... parameters) {
		super(exceptionInfo, parameters);
	}

}
