/**
 * IExceptionInfo.java
 *
 * $Revision: 1.3 $ ($Date: 2011-04-06 05:08:29 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.lang;

/**
 * <p>
 * This <code>class</code> provides an interface for enumerations used for
 * specifying cause of exceptions.
 * </p>
 * 
 * <p>
 * Whenever an application's exception is created it is mandatory:
 * <ul>
 * <li>To specify the cause of the error to its constructor.</li>
 * <li>To specify the cause of the error through an enumeration compliant with
 * this interface.</li>
 * <li>To have a message bundle key related to each enumerated value and have a
 * key for it in the application's resource bundle.</li>
 * </p>
 * 
 * @author Ithamar Torres (itorres@smartmatic.com)
 * @version 1.0 (03/05/2006)
 */
public interface IExceptionInfo {

	/**
	 * <p>
	 * Enumerators implementing this interface will be required to implement
	 * this method to provide a resource bundle's key that should resolve to an
	 * event message containing information regarding the cause of the
	 * <code>Exception</code> to which the <code>IExceptionInfo</code> is
	 * related.
	 * </p>
	 * 
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 * @return the resource bundle's key.
	 */
	public String getMessage();

}
