/**
 * ApplicationMessages.java
 *
 * $Revision: 1.6 $ ($Date: 2011-04-06 05:08:31 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.messages;

import com.smartmatic.waffle.text.impl.BundleKeyFormatter;
import com.smartmatic.waffle.text.spec.ITextFormatter;

/**
 * Class responsible to obtain and display the messages required in the
 * application.
 * 
 * @author Ithamar Torres (itorres@smartmatic.com)
 * @version 1.0 (Aug 17, 2007)
 */
public class ApplicationMessages {
	/**
	 * The single instance used to format the messages
	 */
	private static ITextFormatter singletonInstance = null;

	/**
	 * Getter of <code>singletonInstance</code> property.
	 * 
	 * @return <code>singletonInstance</code> property value.
	 * @see #singletonInstance
	 */
	public static ITextFormatter getSingletonInstance() {
		return singletonInstance;
	}

	/**
	 * Method that Initializes the application message service
	 * 
	 * @param filePath
	 *            The bundle key formatter path
	 * @throws ApplicationMessagesException
	 *             If an error occur initializing the service
	 */
	public synchronized static void init(String filePath)
			throws ApplicationMessagesException {
		if (ApplicationMessages.singletonInstance != null) {
			throw new ApplicationMessagesException(
					ApplicationMessagesException.ExceptionInfo.SERVICE_ALREADY_INITIALIZED);
		}
		ApplicationMessages.singletonInstance = new BundleKeyFormatter(filePath);
	}

	/**
	 * Getter of <code>singletonInstance</code> property.
	 * 
	 * @return <code>singletonInstance</code> property value.
	 * @see #singletonInstance
	 */
	public static ITextFormatter getTextFormatter() {
		return singletonInstance;
	}
}
