/**
 * ObjectDataValidatorException.java
 *
 * $Revision: 1.5 $ ($Date: 2011-04-06 05:08:28 $)
 *
 * Copyright (c) 2004 Smartmatic Corp.
 * 1001 Broken Sound Parkway NW, Suite D
 * Boca Raton FL 33487, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Smartmatic Corp. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered
 * into with Smartmatic Corp.
 */
package com.smartmatic.waffle.validator;

import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.lang.IExceptionInfo;

/**
 * Base class that represents any exception during a validation process.
 * 
 * @author Ithamar Torres (itorres@smartmatic.com)
 * @version 1.0 (Aug 30, 2007)
 */
public class ObjectDataValidatorException extends BaseException {
	/**
	 * Holds the version of the class. It is used by the serialization engine to
	 * determine when a class its equivalent to another
	 */
	private static final long serialVersionUID = -6639235325582302516L;

	/**
	 * Enum that contains all the possible reasons because the
	 * ObjectDataValidatorException can be thrown
	 * 
	 * 
	 * @version 1.0 (30/08/2007)
	 * @author Ithamar Torres (itorres@smartmatic.com)
	 */

	public enum ExceptionInfo implements IExceptionInfo {

		INVALID_LISTENER("INVALID_LISTENER"), LISTENER_INNER_PROBLEM(
				"LISTENER_INNER_PROBLEM"), INVALID_KEYSTORE("INVALID_KEYSTORE"), INVALID_KEYSTORE_ALIAS(
				"INVALID_KEYSTORE_ALIAS"), INVALID_KEYSTORE_PASSWORD(
				"INVALID_KEYSTORE_PASSWORD"), KEYSTORE_UNKNOWN_ERROR(
				"KEYSTORE_UNKNOWN_ERROR"), KEYSTORE_EXPIRED("KEYSTORE_EXPIRED"), KEYSTORE_VALIDATION_BEFORE(
				"KEYSTORE_VALIDATION_BEFORE"), CERTIFICATE_FAIL_VERIFIED(
				"CERTIFICATE_FAIL_VERIFIED"), KEYSTORE_NOT_FOUND(
				"KEYSTORE_NOT_FOUND");
		/**
		 * <p>
		 * Each enumerator's resource bundle's key message.
		 * </p>
		 */

		private String message;

		/**
		 * Getter of <code>message</code> property.
		 * 
		 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
		 * @return <code>message</code> property value.
		 * @see #message
		 */
		@Override
		public String getMessage() {
			return this.message;
		}

		/**
		 * Constructor
		 * 
		 * @author Edgar Trejo (edgar.trejo@smartmatic.com)
		 * @param msg
		 *            the resource bundle's key message
		 */
		private ExceptionInfo(String msg) {
			this.message = this.getClass().getName() + "." + msg;
		}
	}

	/**
	 * Creates a ObjectDataValidatorException instance
	 * 
	 * @param exceptionInfo
	 *            The cause of the exception
	 */

	public ObjectDataValidatorException(IExceptionInfo exceptionInfo) {
		super(exceptionInfo);
	}

	/**
	 * Creates a ObjectDataValidatorException instance
	 * 
	 * @param exceptionInfo
	 *            The cause of the exception
	 * @param inner
	 *            Inner exception cause of the error condition
	 */

	public ObjectDataValidatorException(IExceptionInfo exceptionInfo,

	Exception inner) {
		super(exceptionInfo, inner);
	}

}
