package com.smartmatic.waffle.lang.util;

import static org.junit.Assert.assertTrue;

import java.lang.reflect.InvocationTargetException;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.powermock.modules.junit4.PowerMockRunner;

import com.smartmatic.waffle.lang.BaseException;
import com.smartmatic.waffle.lang.InvalidConversionDataTypeException.ExceptionInfo;

/**
 * Class used to write unit tests for ExceptionHandler.
 */
@RunWith(PowerMockRunner.class)
public class ExceptionHandlerTest {

	@Test
	public void wrapExceptionTest() {
		Exception invocationTargetException = new InvocationTargetException(
				new BaseException(ExceptionInfo.INVALID_CHARACTER_HEXADECIMAL),
				"Unit test");
		BaseException baseException = ExceptionHandler
				.wrapException(new Exception(invocationTargetException));

		assertTrue(baseException.getInfo().equals(
				ExceptionInfo.INVALID_CHARACTER_HEXADECIMAL));
	}

	@Test
	public void isWrapOfBaseExceptionNoRuntimeTest() {
		Exception invocationTargetException = new InvocationTargetException(
				new BaseException(ExceptionInfo.INVALID_CHARACTER_HEXADECIMAL),
				"Unit test");
		BaseException baseException = ExceptionHandler
				.wrapException(new Exception(invocationTargetException));

		boolean result = ExceptionHandler.isWrapOfBaseException(baseException);

		assertTrue(result);
	}

	@Test
	public void isWrapOfBaseExceptionFalseTest() {
		Exception invocationTargetException = new InvocationTargetException(
				new BaseException(ExceptionInfo.INVALID_CHARACTER_HEXADECIMAL),
				"Unit test");

		boolean result = ExceptionHandler
				.isWrapOfBaseException(invocationTargetException);

		assertTrue(!result);
	}

	@Test
	public void isWrapOfBaseExceptionNoCauseTest() {
		Exception runtimeException = new RuntimeException("Unit test",
				new Throwable());

		boolean result = ExceptionHandler
				.isWrapOfBaseException(runtimeException);

		assertTrue(!result);
	}

}
