/**
 * @file BarcodeConfigPrinting.cxx
 * @brief Body class barcode config printing
 * @date 07/03/2012
 * @author Yadickson Soto
 */

#include "BarcodeConfigPrinting.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Environment/Configurations/resource-path-provider.h>
#include <Configuration/s-a-e-s-conf-manager.h>
#include <System/IO/File.h>
#include <Printing/LPSpooler.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Printing;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::System::IO;

ISMTTLog * BarcodeConfigPrinting::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Printing.BarcodeConfigPrinting", GETTEXT_PACKAGE );

BarcodeConfigPrinting::BarcodeConfigPrinting()
{
    client = NULL;
}

BarcodeConfigPrinting::~BarcodeConfigPrinting()
{
}

void BarcodeConfigPrinting::Print()
{
    std::string pdf;
    PrintDocumentResult res;

    switch ( getBackendType() )
    {
        case PrinterBackendType::CONFIGURATION_GTKPRINTING:
            pdf = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/barcode-reader-configuration-gtk.pdf" );
            break;

        default:
        case PrinterBackendType::CONFIGURATION_DIRECTPRINTING:
            pdf = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/barcode-reader-configuration-direct.pdf" );
            break;
    }

    LPSpooler barcodeSpooler ( pdf );
    LPSpooler::JobStateEnumType printjob_status = barcodeSpooler.Print();
    std::string msg = barcodeSpooler.getLastMessage();

    if ( printjob_status != LPSpooler::LPSPOOLER_JOB_COMPLETED )
    {
        res.setResult ( false, msg, PrintDocumentResult::PRINTING_UNEXPECTED_ERROR );
        logger->Debug ( "Error detected " + msg );
    }
    else
    {
        res.setResult ( true, msg, PrintDocumentResult::PRINTING_COMPLETED );
        logger->Debug ( "Print finish " + msg );
    }

    sleep ( 5 );

    if ( client )
    {
        client->onDocumentPrinted ( res );
    }
}

void BarcodeConfigPrinting::setClient ( PrintDocumentClient * client )
{
    this->client = client;
}
