/**
 * @file	BarcodePrinting.hxx
 * @brief	barcode printing class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */

#ifndef BARCODEPRINTING_HXX_
#define BARCODEPRINTING_HXX_

#include <gtkmm.h>
#include <Printing/BasePrintDocument.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Printing
        {
            /**
             * @class	BarcodePrinting
             * @brief	Barcode printing.
             * @author	Youssef.tourkmani
             * @date	31/10/2012
             */
            class BarcodePrinting : public Smartmatic::SAES::Printing::BasePrintDocument
            {
                public:
                    /**
                     * @fn	BarcodePrinting::BarcodePrinting(std::string data);
                     * @brief	Constructor.
                     * @author	Youssef.tourkmani
                     * @date	31/10/2012
                     * @param	data	The data.
                     */
                    explicit BarcodePrinting ( const std::string& data );
                    /**
                     * @fn	virtual BarcodePrinting::~BarcodePrinting();
                     * @brief	Destructor.
                     * @author	Youssef.tourkmani
                     * @date	31/10/2012
                     */
                    virtual ~BarcodePrinting();

                protected:
                    /**
                     * @fn	void BarcodePrinting::PrintDoc();
                     * @brief	Print document.
                     * @author	Youssef.tourkmani
                     * @date	31/10/2012
                     */
                    void PrintDoc();
                    /**
                     * @fn	void BarcodePrinting::BeginPrint();
                     * @brief	Begins a print.
                     * @author	Youssef.tourkmani
                     * @date	31/10/2012
                     */
                    void BeginPrint();
                    /**
                     * @fn	void BarcodePrinting::EndPrint();
                     * @brief	Ends a print.
                     * @author	Youssef.tourkmani
                     * @date	31/10/2012
                     */
                    void EndPrint();
                    /**
                     * @fn	void BarcodePrinting::setQRCode();
                     * @brief	Method getter set qr code.
                     * @author	Yadickson Soto
                     * @date	24/10/2011
                     */
                    void setQRCode();
                    /**
                     * @fn	void BarcodePrinting::setQRCodeImage();
                     * @brief	Method getter set qr code image.
                     * @author	Yadickson Soto
                     * @date	24/10/2011
                     */
                    void setQRCodeImage();

                private:

                    std::string data; ///< data qr code
                    Glib::RefPtr<Gdk::Pixbuf> pixBuff;	///< Buffer for pix data
            };
        }
    }
}

#endif /* BARCODEPRINTING_HXX_ */
