/**
 * @file CalibrationPrinting.hxx
 * @brief Header class calibration test report printing
 * @date 10/09/2013
 * @author Yadickson Soto
 */

#ifndef CalibrationPrinting_HXX_
#define CalibrationPrinting_HXX_

#include <gtkmm.h>
#include <Printing/BasePrintDocument.h>
#include <Configuration/s-a-e-s-conf-manager.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            class OperationStatus;
        }
        namespace Printing
        {
            /**
             * @class	CalibrationPrinting
             * @brief	Class calibration test report printing.
             * @author	Yadickson Soto
             * @see BasePrintDocument
             * @date	10/09/2013
             */
            class CalibrationPrinting : public Smartmatic::SAES::Printing::BasePrintDocument
            {
                public:
                    /**
                     * @fn	CalibrationPrinting::CalibrationPrinting( Smartmatic::SAES::Voting::OperationStatus * operationStatus );
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	10/09/2013
                     * @param operationStatus The operation status
                     */
                    explicit CalibrationPrinting ( Smartmatic::SAES::Voting::OperationStatus * operationStatus );
                    /**
                     * @fn	virtual CalibrationPrinting::~CalibrationPrinting();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	10/09/2013
                     */
                    virtual ~CalibrationPrinting();

                protected:
                    /**
                     * @fn	void CalibrationPrinting::PrintDoc();
                     * @brief	Method print doc.
                     * @author	Yadickson Soto
                     * @date	10/09/2013
                     */
                    void PrintDoc();
                    /**
                     * @fn	void CalibrationPrinting::PrintQR();
                     * @brief	Method print QR Code.
                     * @author	Yadickson Soto
                     * @date	02/10/2013
                     */
                    void PrintQR();
                    /**
                     * @fn	void CalibrationPrinting::BeginPrint();
                     * @brief	Method begin print.
                     * @author	Yadickson Soto
                     * @date	10/09/2013
                     */
                    void BeginPrint();
                    /**
                     * @fn	void CalibrationPrinting::EndPrint();
                     * @brief	Method end print.
                     * @author	Yadickson Soto
                     * @date	10/09/2013
                     */
                    void EndPrint();

                private:

                    Smartmatic::SAES::Configuration::ConfigurationCalibrationPrinting configuration; ///< The configuration
                    Smartmatic::SAES::Voting::OperationStatus * operationStatus; ///< The operation status
            };
        }
    }
}

#endif /* CalibrationPrinting_HXX_ */
