/**
 * @file HelpPrinting.cxx
 * @brief Body class help printing
 * @date 29/03/2012
 * @author Yadickson Soto
 */

#include "HelpPrinting.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Environment/Configurations/resource-path-provider.h>
#include <System/IO/File.h>
#include <Printing/LPSpooler.h>
#include <Printing/PrinterStatusNotifier.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Printing;
using namespace Smartmatic::Log;
using namespace Smartmatic::Environment;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::SAES::Common::Configuration;

ISMTTLog * HelpPrinting::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Printing.HelpPrinting", GETTEXT_PACKAGE );

HelpPrinting::HelpPrinting ( const std::string& file )
    : file(file)
    , client(NULL)
{
}

HelpPrinting::~HelpPrinting()
{

}

void HelpPrinting::Print()
{
    LPSpooler * spooler = new LPSpooler();

    spooler->SetFileName ( file );

    if ( getBackendType() == PrinterBackendType::CONFIGURATION_DIRECTPRINTING )
    {
        spooler->CancelJobs();
        spooler->ClearOptions();
    }

    LPSpooler::JobStateEnumType printjob_status = spooler->Print();
    std::string msg = spooler->getLastMessage();
    PrintDocumentResult res;

    if ( printjob_status != LPSpooler::LPSPOOLER_JOB_COMPLETED )
    {
        res.setResult ( false, msg, PrintDocumentResult::PRINTING_UNEXPECTED_ERROR );
        logger->Debug ( "Error detected " + msg );
    }
    else
    {
        res.setResult ( true, msg, PrintDocumentResult::PRINTING_COMPLETED );
        logger->Debug ( "Print finish " + msg );
    }

    sleep ( 5 );

    if ( client )
    {
        client->onDocumentPrinted ( res );
    }

    delete ( spooler );
    spooler = NULL;
}

void HelpPrinting::setClient ( PrintDocumentClient * client )
{
    this->client = client;
}
