/**
 * @file	SmartcardRemovedPrintDocument.cc
 * @brief	Implementation of entity that prints the report smartcard removal.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */

#include "SmartcardRemovedPrintDocument.h"
#include "Printing/TranslatorTextConfiguration.h"
#include "Resources/election-string-resources-manager.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Printing;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Voting::VotingDevice;
using namespace Smartmatic::SAES::Resources;

SmartcardRemovedPrintDocument::SmartcardRemovedPrintDocument ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration,
        Glib::ustring voteCode, int timesRemoved )
{
    this->electoralConfiguration =  electoralConfiguration;
    this->voteCode = voteCode;
    this->timesRemoved = timesRemoved;
    configurationSmartcardRemovedPrinting = SAESConfigurationManager::getInstance()->getConfiguration()->getConfigurationPrinter().getConfigurationSmartcardRemoved();
}

void SmartcardRemovedPrintDocument::PrintDoc()
{
    this->AddBreak();

    // Title
    if ( configurationSmartcardRemovedPrinting.getTextTitle().getVisible() )
    {
        DocumentTextOptions textOptionTextTitle = TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( configurationSmartcardRemovedPrinting.getTextTitle() );
        this->AddBreak();
        this->NewTextBlock ( textOptionTextTitle );
        Glib::ustring toCompose = _ ( "Smartmatic.SAES.Printing.SmartcardRemovedPrintDocument.PrintDoc_Title" );
        std::stringstream ss;
        ss << this->timesRemoved;
        Glib::ustring composed = Glib::ustring::compose ( toCompose, ss.str() );
        this->DrawString ( " ", true );
        this->DrawString ( " ", true );
        this->DrawString ( composed, true );
    }

    this->DrawString ( "", true );

    // ELECTION NAME
    if ( configurationSmartcardRemovedPrinting.getTextElectionName().getVisible() )
    {
        Smartmatic::SAES::Voting::Election::Election election = electoralConfiguration->getElection()->getElection();
        Glib::ustring strElectionName = ElectionStringResourcesManager::getInstance()->getResource ( election.getName_key() );
        DocumentTextOptions textOptionElectionName = TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( configurationSmartcardRemovedPrinting.getTextElectionName() );
        this->AddBreak();
        this->NewTextBlock ( textOptionElectionName );
        this->DrawString ( " ", true );
        this->DrawString ( strElectionName, true );
        this->DrawString ( " ", true );
    }

    this->DrawString ( " ", true );
    this->DrawString ( _ ( "Smartmatic.SAES.Printing.VotePrintDocument.HorizontalLineSeparator" ), true );
    this->DrawString ( " ", true );
    this->DrawString ( " ", true );
    this->DrawString ( " ", true );

    // Voting booths
    if ( configurationSmartcardRemovedPrinting.getTextVotingBooth().getVisible() )
    {
        Voting_device device = electoralConfiguration->getVotingDevice()->getFirstVotingDevice();
        Voting_booths votingBooths =  electoralConfiguration->getVotingDevice()->getVotingBooths ( device );
        Voting_booths::Voting_boothIterator iteratorVotingBooths ( votingBooths.getVoting_booth ().begin() );
        const Voting_booth & votingBooth ( *iteratorVotingBooths );
        Glib::ustring strVotingBooth = votingBooth.getCustom_code ();
        DocumentTextOptions textOptionVotingBooths = TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( configurationSmartcardRemovedPrinting.getTextVotingBooth() );
        this->AddBreak();
        this->NewTextBlock ( textOptionVotingBooths );
        this->DrawString ( strVotingBooth, true );
        this->DrawString ( " ", true );
    }

    this->DrawString ( "", true );

    // Vote Code
    if ( configurationSmartcardRemovedPrinting.getTextVoteID().getVisible() )
    {
        DocumentTextOptions textOptionVoteId = TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( configurationSmartcardRemovedPrinting.getTextVoteID() );
        this->AddBreak();
        this->NewTextBlock ( textOptionVoteId );
        this->DrawString ( voteCode, true );
    }

    this->DrawString ( _ ( "Smartmatic.SAES.Printing.VotePrintDocument.HorizontalLineSeparator" ), true );
    this->DrawString ( "", true );
    this->DrawString ( " ", true );

    // Description
    if ( configurationSmartcardRemovedPrinting.getTextDescription().getVisible() )
    {
        DocumentTextOptions textOptionTextDescription = TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( configurationSmartcardRemovedPrinting.getTextDescription() );
        this->AddBreak();
        this->NewTextBlock ( textOptionTextDescription );
        Glib::ustring toCompose = _ ( "Smartmatic.SAES.Printing.SmartcardRemovedPrintDocument.PrintDoc_Description" );
        std::stringstream ss;
        ss << this->timesRemoved;
        Glib::ustring composed = Glib::ustring::compose ( toCompose, ss.str() );
        this->DrawString ( " ", true );
        this->DrawString ( composed, true );
        this->DrawString ( " ", true );
    }

    this->DrawString ( " ", true );
    this->DrawString ( " ", true );
    this->DrawString ( " ", true );
    this->DrawString ( " ", true );
    this->DrawString ( " ", true );
    this->DrawString ( " ", true );

    this->AddBreak();
}

void SmartcardRemovedPrintDocument::BeginPrint()
{
}

void SmartcardRemovedPrintDocument::EndPrint()
{
}
