/**
 * @file	SmartcardRemovedPrintDocument.h
 * @brief	Declaration of entity that prints the report smartcard removal.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */


#ifndef _SMARTCARDREMOVEDPRINTDOCUMENT_H_
#define _SMARTCARDREMOVEDPRINTDOCUMENT_H_

#include "Printing/BasePrintDocument.h"
#include <Voting/ElectoralConfiguration.hxx>
#include "Configuration/s-a-e-s-conf-manager.h"


namespace Smartmatic
{
    namespace SAES
    {
        namespace Printing
        {
            /**
             * @class	SmartcardRemovedPrintDocument
             * @brief	Mediator which contains the printing operation for the report smartcard removal.
             * @author	Eduardo.campione
             * @date	28/04/2011
             */

            class SmartcardRemovedPrintDocument : public BasePrintDocument
            {
                public:

                    /**
                     * @fn	SmartcardRemovedPrintDocument::SmartcardRemovedPrintDocument(Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration,
                     * 			Glib::ustring voteCode, int timesRemoved);
                     * @brief	Constructor initializes an instance of the SmartcardRemovedPrintDocument class.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     * @param	electoralConfiguration	The pointer reference to electoral configuration.
                     * @param	voteCode								The vote code.
                     * @param	timesRemoved The timestamp with information identifies when a certain event occurred.
                     */

                    SmartcardRemovedPrintDocument ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration, Glib::ustring voteCode, int timesRemoved );
                protected:

                    /**
                     * @fn	void SmartcardRemovedPrintDocument::PrintDoc();
                     * @brief	Composes the report with the information of the event.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     */

                    void PrintDoc();

                    /**
                     * @fn	void SmartcardRemovedPrintDocument::BeginPrint();
                     * @brief	Begins a print.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     */

                    void BeginPrint();

                    /**
                     * @fn	void SmartcardRemovedPrintDocument::EndPrint();
                     * @brief	Ends a print.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     */

                    void EndPrint();
                private:
                    Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration; ///< The pointer reference to electoral configuration.
                    Glib::ustring voteCode; ///< The vote code
                    int timesRemoved;   ///< The timestamp with information identifies when a certain event occurred.
                    Smartmatic::SAES::Configuration::ConfigurationSmartcardRemoved configurationSmartcardRemovedPrinting; ///< The configuration smartcard removed printing

            };
        }
    }
}

#endif // _SMARTCARDREMOVEDPRINTDOCUMENT_H_
