/**
 * @file TestPrinting.cxx
 * @brief Body class test printing
 * @date 24/10/2011
 * @author Yadickson Soto
 */

#include "TestPrinting.hxx"
#include <Environment/Configurations/resource-path-provider.h>
#include <Graphics/Encoding2D/QREncoding.h>
#include "Printing/TranslatorTextConfiguration.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Printing;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::Graphics::Encoding2D;
using namespace Smartmatic::System;
using namespace Smartmatic::SAES::Configuration;

TestPrinting::TestPrinting ( const std::string& data )
    : BasePrintDocument ( false )
    , data(data)
{
    configuration = SAESConfigurationManager::getInstance()->getConfiguration()->getConfigurationPrinter().getConfigurationTestPrinting();
}

TestPrinting::~TestPrinting()
{
}

void TestPrinting::PrintDoc()
{
    Glib::RefPtr<Gdk::Pixbuf> logo;
    DocumentTextOptions titleOption = TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( configuration.getTextInstallationTitle() );

    switch ( getBackendType() )
    {
        case PrinterBackendType::CONFIGURATION_GTKPRINTING:
            logo = Gdk::Pixbuf::create_from_file ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/printer-test-logo-gtk.bmp" ) );
            break;

        default:
        case PrinterBackendType::CONFIGURATION_DIRECTPRINTING:
            logo = Gdk::Pixbuf::create_from_file ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/printer-test-logo-direct.bmp" ) );
            break;
    }

    this->AddBreak();
    this->NewTextBlock ( titleOption );
    this->DrawString ( " ", true );
    this->DrawString ( _ ( "Smartmatic.SAES.Printing.TestPrinting.Title" ), true );
    this->DrawString ( " ", true );
    this->AddBreak();
    this->DrawImage ( logo, Center );
    this->AddBreak();
    this->NewTextBlock ( titleOption );
    this->DrawString ( " ", true );
    this->AddBreak();

    if ( configuration.getShowBarCode() )
    {
        switch ( getBackendType() )
        {
            case PrinterBackendType::CONFIGURATION_GTKPRINTING:
                setQRCodeImage();
                break;

            case PrinterBackendType::CONFIGURATION_DIRECTPRINTING:
                setQRCode();
                break;

            default:
                break;
        }

        this->AddBreak();
    }

    this->NewTextBlock ( titleOption );
    this->DrawString ( " ", true );
    this->DrawString ( " ", true );
    this->AddBreak();
}

void TestPrinting::BeginPrint()
{
}

void TestPrinting::EndPrint()
{
}

void TestPrinting::setQRCode()
{
    SafeBuffer toEncode ( data );
    Glib::RefPtr<Gdk::Pixbuf> backgroundImage;
    QRCodeConfig config = SAESConfigurationManager::getInstance()->getQRCodeBarcodeConfig();
    int pixel_size = config.getSizeQRCode();
    int margin = config.getMarginQRCode();
    int version = config.getVersionQRCode();
    QRecLevel correctionLevel = SAESConfigurationManager::getInstance()->GetCorrectionModeQRCode ( config.getCorrectionModeQRCode() );

    if ( toEncode.GetSize() > 0 )
    {
        this->DrawQRCode (
            toEncode
            , pixel_size
            , margin
            , correctionLevel
            , version
            // Image content
            , backgroundImage
            , Center );
    }
}

void TestPrinting::setQRCodeImage()
{
    SafeBuffer toEncode ( data );
    Glib::RefPtr<Gdk::Pixbuf> backgroundImage;
    QRCodeConfig config = SAESConfigurationManager::getInstance()->getQRCodeBarcodeConfig();
    int pixel_size = config.getSizeQRCode();
    int margin = config.getMarginQRCode();
    int version = config.getVersionQRCode();
    QRecLevel correctionLevel = SAESConfigurationManager::getInstance()->GetCorrectionModeQRCode ( config.getCorrectionModeQRCode() );
    Glib::RefPtr<Gdk::Bitmap> bitmap ( QREncoding::GenerateSymbol ( ( guchar * ) toEncode.GetData(),
                                       toEncode.GetSize(),
                                       pixel_size,
                                       margin,
                                       correctionLevel,
                                       version ) );
    Glib::RefPtr<Gdk::Drawable> drwptr = bitmap;
    gint width ( 0 );
    gint height ( 0 );
    bitmap->get_size ( width, height );
    this->pixBuff = Gdk::Pixbuf::create ( drwptr, 0, 0, width, height );
    this->DrawImage ( pixBuff, Center );
}
