/**
 * @file TestPrinting.hxx
 * @brief Header class test printing
 * @date 24/10/2011
 * @author Yadickson Soto
 */

#ifndef TESTPRINTING_HXX_
#define TESTPRINTING_HXX_

#include <gtkmm.h>
#include <Printing/BasePrintDocument.h>
#include <Configuration/s-a-e-s-conf-manager.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Printing
        {
            /**
             * @class	TestPrinting
             * @brief	Class test printing.
             * @author	Yadickson Soto
             * @see BasePrintDocument
             * @date	24/10/2011
             */
            class TestPrinting : public Smartmatic::SAES::Printing::BasePrintDocument
            {
                public:
                    /**
                     * @fn	TestPrinting::TestPrinting(std::string data);
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	24/10/2011
                     * @param	data	string data to print.
                     */
                    explicit TestPrinting ( const std::string& data );
                    /**
                     * @fn	virtual TestPrinting::~TestPrinting();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	24/10/2011
                     */
                    virtual ~TestPrinting();

                protected:
                    /**
                     * @fn	void TestPrinting::PrintDoc();
                     * @brief	Method print doc.
                     * @author	Yadickson Soto
                     * @date	24/10/2011
                     */
                    void PrintDoc();
                    /**
                     * @fn	void TestPrinting::BeginPrint();
                     * @brief	Method begin print.
                     * @author	Yadickson Soto
                     * @date	24/10/2011
                     */
                    void BeginPrint();
                    /**
                     * @fn	void TestPrinting::EndPrint();
                     * @brief	Method end print.
                     * @author	Yadickson Soto
                     * @date	24/10/2011
                     */
                    void EndPrint();
                    /**
                     * @fn	void TestPrinting::setQRCode();
                     * @brief	Method getter set qr code.
                     * @author	Yadickson Soto
                     * @date	24/10/2011
                     */
                    void setQRCode();
                    /**
                     * @fn	void TestPrinting::setQRCodeImage();
                     * @brief	Method getter set qr code image.
                     * @author	Yadickson Soto
                     * @date	24/10/2011
                     */
                    void setQRCodeImage();

                private:

                    std::string data; ///< data qr code
                    Glib::RefPtr<Gdk::Pixbuf> pixBuff; ///< pix buf
                    Smartmatic::SAES::Configuration::ConfigurationTestPrinting configuration; ///< The configuration
            };
        }
    }
}

#endif /* TESTPRINTING_HXX_ */
