/**
 * @file	TimeoutPrintDocument.cc
 * @brief	timeout print document class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */


#include "Printing/TimeoutPrintDocument.h"
#include "Resources/election-string-resources-manager.h"
#include "Printing/TranslatorTextConfiguration.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Printing;
using namespace Smartmatic::SAES::Voting::VotingDevice;
using namespace Smartmatic::SAES::Resources;

TimeoutPrintDocument::TimeoutPrintDocument ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration, Glib::ustring voteCode )
{
    _electoralConfiguration =  electoralConfiguration;
    _voteCode = voteCode;
    _configurationTimeoutPrinting = SAESConfigurationManager::getInstance()->getConfiguration()->getConfigurationPrinter().getConfigurationTimeout();
}

void TimeoutPrintDocument::PrintDoc()
{
    this->AddBreak();

    // Title
    if ( _configurationTimeoutPrinting.getTextTitle().getVisible() )
    {
        DocumentTextOptions textOptionTextTitle = TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( _configurationTimeoutPrinting.getTextTitle() );
        this->AddBreak();
        this->NewTextBlock ( textOptionTextTitle );
        this->DrawString ( _ ( "Smartmatic.SAES.Printing.TimeoutPrintDocument.PrintDoc_Title" ), true );
    }

    this->DrawString ( "", true );

    // ELECTION NAME
    if ( _configurationTimeoutPrinting.getTextElectionName().getVisible() )
    {
        Smartmatic::SAES::Voting::Election::Election election = _electoralConfiguration->getElection()->getElection();
        Glib::ustring strElectionName = ElectionStringResourcesManager::getInstance()->getResource ( election.getName_key() );
        DocumentTextOptions textOptionElectionName = TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( _configurationTimeoutPrinting.getTextElectionName() );
        this->AddBreak();
        this->NewTextBlock ( textOptionElectionName );
        this->DrawString ( strElectionName, true );
    }

    this->DrawString ( _ ( "Smartmatic.SAES.Printing.VotePrintDocument.HorizontalLineSeparator" ), true );

    // Voting booths
    if ( _configurationTimeoutPrinting.getTextVotingBooth().getVisible() )
    {
        Voting_device device = _electoralConfiguration->getVotingDevice()->getFirstVotingDevice();
        Voting_booths votingBooths =  _electoralConfiguration->getVotingDevice()->getVotingBooths ( device );
        Voting_booths::Voting_boothIterator iteratorVotingBooths ( votingBooths.getVoting_booth ().begin() );
        const Voting_booth & votingBooth ( *iteratorVotingBooths );
        Glib::ustring strVotingBooth = votingBooth.getCustom_code ();
        DocumentTextOptions textOptionVotingBooths = TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( _configurationTimeoutPrinting.getTextVotingBooth() );
        this->AddBreak();
        this->NewTextBlock ( textOptionVotingBooths );
        this->DrawString ( strVotingBooth, true );
    }

    this->DrawString ( "", true );

    // Vote Code
    if ( _configurationTimeoutPrinting.getTextVoteID().getVisible() )
    {
        DocumentTextOptions textOptionVoteId = TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( _configurationTimeoutPrinting.getTextVoteID() );
        this->AddBreak();
        this->NewTextBlock ( textOptionVoteId );
        this->DrawString ( _voteCode, true );
    }

    this->DrawString ( _ ( "Smartmatic.SAES.Printing.VotePrintDocument.HorizontalLineSeparator" ), true );
    this->DrawString ( "", true );

    // Description
    if ( _configurationTimeoutPrinting.getTextDescription().getVisible() )
    {
        DocumentTextOptions textOptionTextDescription = TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( _configurationTimeoutPrinting.getTextDescription() );
        this->AddBreak();
        this->NewTextBlock ( textOptionTextDescription );
        this->DrawString ( _ ( "Smartmatic.SAES.Printing.TimeoutPrintDocument.PrintDoc_Description" ), true );
    }

    this->AddBreak();
}


void TimeoutPrintDocument::BeginPrint()
{
}

void TimeoutPrintDocument::EndPrint()
{
}
