/**
 * @file	TranslatorTextConfiguration.cc
 * @brief	translator text configuration class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */


#include "TranslatorTextConfiguration.h"

using namespace Smartmatic::SAES::Printing;
using namespace Smartmatic::SAES::Configuration;

DocumentTextOptions TranslatorTextConfiguration::TextConfigurationToDocumentTextOptions ( TextConfiguration textConfiguration )
{
    //TextConfiguration
    int size = textConfiguration.getSize ();
    AlignType alignType = textConfiguration.getAlign();
    bool bold = textConfiguration.getBold();
    bool italic = textConfiguration.getItalic();
    // TODO pasar a configuracion
    bool underline = false;
    int vPandding = textConfiguration.getVPandding();
    //int hPandding = textConfiguration.getHPandding();
    int levelPaddin = textConfiguration.getLevelPaddingSpaceChar();
    DocumentFontSize documentFontSize = TinyFont;
    DocumentJustifitacion documentJustifitacion = LeftJustified;
    DocumentFontStyle documentFontStyle = Normal;
    int lineSpacingVal = vPandding;
    int indentationLevelVal = levelPaddin;
    int boldWeightVal = 700;

    // FONT SIZE
    switch ( size )
    {
        case 5:
        case 6:
            documentFontSize = TinyFont;
            break;

        case 7:
        case 8:
            documentFontSize = SmallFont;
            break;

        case 9:
        case 10:
            documentFontSize = MediumFont;
            break;

        case 11:
        case 12:
            documentFontSize = LargeFont;
            break;

        default:

            if ( size < 5 )
            {
                documentFontSize = TinyFont;
            }

            if ( size > 12 )
            {
                documentFontSize = Biggest;
            }

            break;
    }

    // ALIGN
    switch ( alignType )
    {
        default:
        case AlignType::CONFIGURATION_CENTER:
            documentJustifitacion = Centered;
            break;

        case AlignType::CONFIGURATION_LEFT:
            documentJustifitacion = LeftJustified;
            break;

        case AlignType::CONFIGURATION_RIGHT:
            documentJustifitacion = RightJustified;
            break;
    }

    //STYLE
    if ( bold )
    {
        documentFontStyle = static_cast<DocumentFontStyle> ( documentFontStyle | Bold );
    }

    if ( italic )
    {
        documentFontStyle = static_cast<DocumentFontStyle> ( documentFontStyle | Italic );
    }

    if ( underline )
    {
        documentFontStyle = static_cast<DocumentFontStyle> ( documentFontStyle | Underlined );
    }

    DocumentTextOptions documentTextOptions ( documentFontSize, documentJustifitacion, documentFontStyle, lineSpacingVal, indentationLevelVal, boldWeightVal );
    return documentTextOptions;
}

