/**
 * @file CardDataFactory.cxx
 * @brief Body Card Data Factory Class
 * @date 29/04/2013
 * @author Yadickson Soto
 */

#include "CardDataFactory.hxx"
#include <Voting/OperationStatus.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::Voting::CardData;

Card_data CardDataFactory::createCardData (
    const Smartmatic::SAES::Voting::VotingDevice::Logical_voter_group & logicalVoterGroup,
    Smartmatic::SAES::Voting::OperationStatus * operationStatus,
    Smartmatic::SAES::Voting::SessionIDManager * sessionIDManager,
    Smartmatic::SAES::Voting::BallotIDManager * ballotIDManager )
{
    Card_data cardData;

    cardData.setCode ( "x" );
    cardData.setActivation_code ( "x" );
    cardData.setCard_status ( Card_status::CARD_DATA_NOT_USED );
    cardData.setCard_type ( Card_type::CARD_DATA_OFFICIAL_VOTE_CARD );
    cardData.setIsAudio ( false );
    cardData.setBallotID ( ballotIDManager != NULL ? ballotIDManager->getID() : "" );
    cardData.setSessionID ( sessionIDManager != NULL ? sessionIDManager->getID ( operationStatus ) : "" );
    cardData.setLogical_voter_group ( logicalVoterGroup );

    return cardData;
}

bool CardDataFactory::bufferToCardData ( const Smartmatic::System::SafeBuffer & bufferIn, Card_data & cardData )
{
    bool validate = false;

    try
    {
        std::string data;
        data.append ( ( const char * ) bufferIn.GetData(), bufferIn.GetSize() );
        std::istringstream istr ( data );

        cardData = ( * ( Smartmatic::SAES::Voting::CardData::parseCard_data ( istr, Smartmatic::SAES::Voting::CardDataTypes::Flags::dont_validate ) ) );

        validate = true;
    }
    catch ( ... )
    {

    }

    return validate;
}

bool CardDataFactory::cardDataToBuffer ( Card_data & cardData, Smartmatic::System::SafeBuffer & bufferOut )
{
    bool validate = false;
    bufferOut.Clear();

    try
    {
        std::ostringstream str;
        CardDataTypes::NamespaceInfomap mapv;
        mapv[""].name = NAMESPACE_VOTING_CARD_DATA;
        mapv[""].schema = "";
        mapv["lvg"].name = NAMESPACE_VOTING_VOTINGDEVICE;
        mapv["lvg"].schema = "";

        serializeCard_data ( str, cardData, mapv, "UTF-8", Smartmatic::SAES::Voting::CardDataTypes::Flags::dont_validate );

        bufferOut.AddData ( str.str() );
        validate = true;
    }
    catch ( ... )
    {

    }

    return validate;
}
