/**
 * @file HashValidator.hxx
 * @brief Header class for election files hashes validation.
 * @author	Eduardo Fernández
 * @date	07/01/2019
 */

#ifndef HASH_VALIDATOR_HXX
#define HASH_VALIDATOR_HXX

#include <string>

#include <Runtime/Environment/saes-directories.h>
#include <Voting/Election/election-schema.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Voting
        {
            namespace Election
            {
                /**
                 * @class	HashValidator
                 * @brief	Class for election files hashes validation.
                 * @author	Eduardo Fernández
                 * @date	07/01/2019
                 */
                class HashValidator
                {
                    public:

                        /**
                         * @brief  Class constructor.
                         * @author Eduardo Fernández
                         * @date   07/01/2019
                         * @param  saesDirectories The SAES directories.
                         * @param  runningOnPM Whether the verification is being run on a PM.
                         */
                        HashValidator(
                            Runtime::Environment::SaesDirectories * const saesDirectories,
                            const bool runningOnPM = true);

                        /**
                         * @brief	Class destructor.
                         * @author	Eduardo Fernández
                         * @date	07/01/2019
                         */
                        ~HashValidator();

                    public:

                        /**
                         * @brief Class constructor.
                         * @author Eduardo Fernández
                         * @date   07/01/2019
                         * @param  checksums Election files checksums.
                         * @param  errorMessage Message displayed in case of error.
                         * @return Whether the validation is successful.
                         */
                        bool validateChecksums(const Election::ChecksumsOptional& checksums, std::string& errorMessage);

                    private:

                        static Smartmatic::Log::ISMTTLog *m_logger;

                        Runtime::Environment::SaesDirectories *m_saesDirectories;
                        bool m_runningOnPM;
                };
            }
        }
    }
}

#endif /* HASH_VALIDATOR_HXX */
