/**
 * @file	ElectoralFactory.hxx
 * @brief	electoral factory class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */

#ifndef __ELECTORAL_FACTORY_WRAPPER_H__
#define __ELECTORAL_FACTORY_WRAPPER_H__

#include <string>
#include <Voting/Election/ElectionWrapper.hxx>
#include <Voting/VotingDevice/VotingDeviceWrapper.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Voting
        {
            /**
             * @class	ElectoralFactory
             * @brief	Electoral factory.
             * @author	Eduardo.campione
             * @date	28/04/2011
             */

            class ElectoralFactory
            {
                public:

                    /**
                     * @fn	static Smartmatic::SAES::Voting::Election::ElectionWrapper * ElectoralFactory::getElection (std::istream & xml) throw (Smartmatic::System::Exception::ElectionException);
                     * @brief	Gets an election.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     * @exception	Smartmatic::System::Exception::ElectionException	Thrown when an election error
                     * 																															condition occurs.
                     * @param	xml	The xml.
                     * @return	null if it fails, else the election.
                     */

                    static Smartmatic::SAES::Voting::Election::ElectionWrapper *
                    /**
                     * @fn	ElectoralFactory::getElection (std::istream & xml) throw (Smartmatic::System::Exception::ElectionException);
                     * @brief	Constructor.
                     * @author	Youssef.tourkmani
                     * @date	31/10/2012
                     * @exception	Smartmatic::System::Exception::ElectionException	Thrown when an election error
                     * 																															condition occurs.
                     * @param [in,out]	xml	The XML.
                     */
                    getElection ( std::istream & xml )
                    throw ( Smartmatic::System::Exception::ElectionException );

                    /**
                     * @fn	static Smartmatic::SAES::Voting::VotingDevice::VotingDeviceWrapper * ElectoralFactory::getVotingDevice (std::istream & xml) throw (Smartmatic::System::Exception::VotingDeviceException);
                     * @brief	Gets a voting device.
                     * @author	Eduardo.campione
                     * @date	28/04/2011
                     * @exception	Smartmatic::System::Exception::VotingDeviceException	Thrown when a voting device
                     * 																																	error condition occurs.
                     * @param	xml	The xml.
                     * @return	null if it fails, else the voting device.
                     */

                    static Smartmatic::SAES::Voting::VotingDevice::VotingDeviceWrapper *
                    /**
                     * @fn	ElectoralFactory::getVotingDevice (std::istream & xml) throw (Smartmatic::System::Exception::VotingDeviceException);
                     * @brief	Constructor.
                     * @author	Youssef.tourkmani
                     * @date	31/10/2012
                     * @exception	Smartmatic::System::Exception::VotingDeviceException	Thrown when a voting device
                     * 																																	error condition occurs.
                     * @param [in,out]	xml	The XML.
                     */
                    getVotingDevice ( std::istream & xml )
                    throw ( Smartmatic::System::Exception::VotingDeviceException );

                private:
                    static Smartmatic::Log::ISMTTLog * logger; ///< The logger
            };
        }
    }
}

#endif /*__ELECTORAL_FACTORY_WRAPPER_H__*/
