/**
 * @file   EmlFileInfo.hxx
 * @brief  Declaration of EmlFileInfo functions.
 * @author manuel.arguelles
 * @date   Jan  5, 2018
 */

#ifndef EML_FILE_INFO_HXX
#define EML_FILE_INFO_HXX

#include <Voting/Eml/510.hxx>
#include <string>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace Eml
            {
                namespace EmlFileInfo
                {
                    /**
                     * @brief  Get input contest file name.
                     * @author manuel.arguelles
                     * @date   Jan  5, 2018
                     * @param  customCode The custom code.
                     * @return The file name of the contest.
                     */
                    std::string getInputContestFileName(const std::string& customCode);

                    /**
                     * @brief  Get the output contest file name.
                     * @author manuel.arguelles
                     * @date   Jan  5, 2018
                     * @param  customCode    The custom code.
                     * @param  machine       The machine.
                     * @param  votingType    The voting type.
                     * @param  customNisCode The custom NIS code.
                     * @return The file name of the contest.
                     */
                    std::string getOutputContestFileName(const std::string& customCode,
                                                         const std::string& machine,
                                                         const std::string& votingType,
                                                         const std::string& customNisCode);

                    /**
                     * @brief  Load EML, deserialize it from file.
                     * @author manuel.arguelles
                     * @date   Jan 11, 2018
                     * @param  filename The file to load.
                     * @return The 510 EML object.
                     * @throws FileSystemException If the parsing fails or the file
                     * is not present.
                     */
                    Eml::EML loadEmlFromFile(const std::string& filename);

                } /* namespace EmlFileInfo */
            } /* namespace Eml */
        } /* namespace Voting */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* EML_FILE_INFO_HXX */

