/**
 * @file   X7SEmlFileWrapper.hxx
 * @brief  Declaration of X7SEmlFileWrapper class.
 * @author manuel.arguelles
 * @date   Feb 14, 2018
 */

#ifndef X7S_EML_FILE_WRAPPER_HXX
#define X7S_EML_FILE_WRAPPER_HXX

#include <Voting/Eml/x7s-eml-file-schema.hxx>
#include <string>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Runtime
        {
            namespace Environment
            {
                class SaesDirectories;
            }
        }

        namespace Voting
        {
            class ElectoralConfiguration;

            namespace EmlX7S
            {
                /**
                 * @class  X7SEmlFileWrapper
                 * @brief  Generation of X7S files.
                 * @author manuel.arguelles
                 * @date   Feb 14, 2018
                 */
                class X7SEmlFileWrapper
                {
                    public:

                        /**
                         * @brief  Create an instance of the class.
                         * @author manuel.arguelles
                         * @date   Feb 14, 2018
                         */
                        X7SEmlFileWrapper(SAES::Voting::ElectoralConfiguration* configuration,
                                          SAES::Runtime::Environment::SaesDirectories* directories);

                        /**
                         * @brief  Destroys an instance of the class.
                         * @author manuel.arguelles
                         * @date   Feb 14, 2018
                         */
                        ~X7SEmlFileWrapper();

                    public:

                        /**
                         * @brief  Persist the given EML file to disk.
                         * @author manuel.arguelles
                         * @date   Mar  2, 2018
                         * @param  emlFile             The plain EML file.
                         * @param  emlX7SFile          The X7S output file.
                         * @param  pvFormFile          The PVForm file.
                         * @throws XmlException        If the serialization operation failed.
                         * @throws FileSystemException If the required files are not found.
                         * @throws CryptoException     If a crypto error condition occurs.
                         * @throws SignedException     If errors while signing occur.
                         */
                        void persistX7SEmlFile(const std::string& emlFile,
                                               const std::string& emlX7SFile,
                                               const std::string& pvFormFile);

                    private:

                        /**
                         * @brief  Serializes the X7S EML file to string.
                         * @author manuel.arguelles
                         * @date   Mar  2, 2018
                         * @param  x7sEml The X7S EML file.
                         * @return The serialized X7S file.
                         * @throws XmlException If the serialization operation failed.
                         */
                        std::string x7sEmlToString(const X7SEmlFile& x7sEml) const;

                    private:

                        SAES::Voting::ElectoralConfiguration*        m_electoralConfiguration;
                        SAES::Runtime::Environment::SaesDirectories* m_directories;
                };

            } /* namespace EmlX7S */
        } /* namespace Voting */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* X7S_EML_FILE_WRAPPER_HXX */

