/**
 * @file X7SSecurity.hxx
 * @brief Header class x7s security
 * @date 19/03/2012
 * @author Yadickson Soto
 */

#ifndef X7SSECURITY_HXX_
#define X7SSECURITY_HXX_

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace System
    {
        class SafeBuffer;
    }

    namespace SAES
    {
        namespace Runtime
        {
            namespace Environment
            {
                class SaesDirectories;
            }
        }

        namespace Voting
        {
            class ElectoralConfiguration;

            namespace EmlX7S
            {
                /**
                 * @class	X7SSecurity
                 * @brief	Class x7s security.
                 * @author	Yadickson Soto
                 * @date	19/03/2012
                 */
                class X7SSecurity
                {
                    public:

                        /**
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	19/03/2012
                         */
                        X7SSecurity();

                        /**
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	19/03/2012
                         */
                        virtual ~X7SSecurity();

                    public:

                        /**
                         * @brief	Method init class.
                         * @author	Yadickson Soto
                         * @date	19/03/2012
                         * @param	electoralConfiguration Electoral configuration.
                         * @param	directories            SAES directories.
                         */
                        void init(Voting::ElectoralConfiguration* electoralConfiguration,
                                  Runtime::Environment::SaesDirectories* directories);
                        /**
                         * @brief	Method signed buffer.
                         * @author	Yadickson Soto
                         * @date	19/03/2012
                         * @param	bufferIn 	buffer in.
                         * @param	bufferOut	buffer out.
                         * @throws	CryptoException	Thrown when a crypto error condition occurs.
                         * @throws	SignedException	Thrown when a signed error condition occurs.
                         */
                        void signBuffer(const System::SafeBuffer& bufferIn,
                                        System::SafeBuffer& bufferOut);

                        /**
                         * @brief	Method crypto buffer.
                         * @author	Yadickson Soto
                         * @date	19/03/2012
                         * @param	bufferIn        buffer in.
                         * @param	bufferOut       buffer out.
                         * @throws	CryptoException Thrown when a crypto error condition occurs.
                         */
                        void encryptBuffer(const System::SafeBuffer& bufferIn,
                                           System::SafeBuffer& bufferOut);

                    private:

                        Voting::ElectoralConfiguration*        m_electoralConfiguration;
                        Runtime::Environment::SaesDirectories* m_directories;
                        static Smartmatic::Log::ISMTTLog*      m_logger;
                };
            }
        }
    }
}

#endif /* X7SSECURITY_HXX_ */
