/**
 * @file SessionIDManager.cxx
 * @brief Body class to generate and verify unique session id
 * @date 08/05/2013
 * @author Yadickson Soto
 */

#include "SessionIDManager.hxx"
#include <Voting/OperationStatus.hxx>
#include <System/guid-class.h>

using namespace Smartmatic::SAES::Voting;

SessionIDManager * SessionIDManager::instance = NULL;

SessionIDManager::SessionIDManager()
{

}

SessionIDManager::~SessionIDManager()
{
    instance = NULL;
}

std::string SessionIDManager::getID ( OperationStatus * operationStatus )
{
    if ( uuid.empty() && operationStatus != NULL )
    {
        uuid = operationStatus->getElectionStatusWrapper()->getOpeningCode();
        uuid = Smartmatic::System::GuidClass::Parse ( uuid ).ToBase64String();
    }
    else if ( uuid.empty() )
    {
        uuid = Smartmatic::System::GuidClass::NewGuid().ToBase64String();
    }

    return uuid;
}

bool SessionIDManager::verifyID ( OperationStatus * operationStatus, const std::string & uuid )
{
    std::string currentID = getID ( operationStatus );
    return !currentID.empty() && currentID.compare ( uuid ) == 0;
}

SessionIDManager * SessionIDManager::getInstance(SessionIDManager * externInstance)
{
    if ( !instance || externInstance != NULL)
    {
        instance = (externInstance == NULL ? new SessionIDManager() : externInstance);
    }

    return instance;
}
