/**
 * @file SessionIDManager.hxx
 * @brief Header class to generate and verify unique session id
 * @date 08/05/2013
 * @author Yadickson Soto
 */

#ifndef SESSIONIDMANAGER_HXX_
#define SESSIONIDMANAGER_HXX_

#include <string>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            class  OperationStatus;

            /**
             * @class SessionIDManager
             * @brief class to generate and verify unique session id
             * @date 08/05/2013
             * @author Yadickson Soto
             */
            class SessionIDManager
            {
                protected:
                    /**
                     * @fn SessionIDManager();
                     * @brief Class constructor
                     * @date 08/05/2013
                     * @author Yadickson Soto
                     */
                    SessionIDManager();

                    static SessionIDManager * instance; ///< instance of the class
                    std::string uuid; ///< unique session uuid

                public:
                    /**
                     * @fn virtual ~SessionIDManager();
                     * @brief Class destructor
                     * @date 08/05/2013
                     * @author Yadickson Soto
                     */
                    virtual ~SessionIDManager();
                    /**
                     * @fn virtual std::string getID( OperationStatus * operationStatus );
                     * @brief Getter unique session id
                     * @date 08/05/2013
                     * @author Yadickson Soto
                     * @param operationStatus The OperationStatus object
                     * @return unique session id
                     * @see IDManager
                     */
                    virtual std::string getID ( OperationStatus * operationStatus );
                    /**
                     * @fn bool verifyID( OperationStatus * operationStatus, const std::string & sessionId );
                     * @brief Verify a session id, if session id is valid, not is removed.
                     * @date 08/05/2013
                     * @author Yadickson Soto
                     * @param sessionId session id to verify
                     * @return	true if session id is valid
                     * @see IDManager
                     */
                    virtual bool verifyID ( OperationStatus * operationStatus, const std::string & sessionId );
                    /**
                     * @fn static SessionIDManager * getInstance(SessionIDManager * externInstance);
                     * @brief Getter instance of class
                     * @date 07/02/2017
                     * @author Juan Valera
                     * @param externInstance The SessionIDManager object
                     * @return instance of class
                     */
                    static SessionIDManager * getInstance(SessionIDManager * externInstance = NULL);
            };
        } /* namespace Voting */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* SESSIONIDMANAGER_HXX_ */
