/**
 * @file   VotecounterByCA.hxx
 * @brief  Declaration of VoteCounterByCA class.
 * @author manuel.arguelles
 * @date   Jun 27, 2017
 */

#ifndef _VOTE_COUNTER_BY_CA_HXX_
#define _VOTE_COUNTER_BY_CA_HXX_

#include <string>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace PBReports
            {

                /**
                 * @class  VoteCounterByCA
                 * @brief  Vote counter by CA.
                 * @author Eduardo.campione
                 * @date   28/04/2011
                 */
                class VoteCounterByCA
                {
                    public:

                        /**
                         * @brief  Constructor.
                         * @author Eduardo.campione
                         * @date   28/04/2011
                         * @param  caCode The ca code.
                         * @param  caValue The ca value.
                         * @param  initialCounter The initial counter.
                         */
                        VoteCounterByCA(const std::string& caCode, const std::string& caValue, unsigned int initialCounter = 0);

                        /**
                         * @brief  Finaliser.
                         * @author Eduardo.campione
                         * @date   28/04/2011
                         */
                        virtual ~VoteCounterByCA();

                        /**
                         * @brief  Increment counter.
                         * @author Eduardo.campione
                         * @date   28/04/2011
                         */
                        void incrementCounter();

                        /**
                         * @brief  Gets the ca code.
                         * @author Eduardo.campione
                         * @date   28/04/2011
                         * @return The ca code.
                         */
                        std::string getCACode();

                        /**
                         * @brief  Gets the ca value.
                         * @author Eduardo.campione
                         * @date   28/04/2011
                         * @return The ca value.
                         */
                        std::string getCAValue();

                        /**
                         * @brief  Gets the counter.
                         * @author Eduardo.campione
                         * @date   28/04/2011
                         * @return The counter.
                         */
                        unsigned int getCounter();

                        /**
                         * @brief  Clears the counter.
                         * @author Youssef.tourkmani
                         * @date   31/10/2012
                         */
                        void clearCounter();

                    private:
                        std::string  m_caCode;
                        std::string  m_caValue;
                        unsigned int m_counter;
                };
            }
        }
    }
}

#endif /* _VOTE_COUNTER_BY_CA_HXX_ */
