/**
 * @file VoteResultsWrapper.hxx
 * @brief Header of the vote results wrapper class, which fills the VoteResults object to insert in the pv-data.xml file.
 * @date 25/03/2014
 * @author Yadickson Soto
 */

#ifndef VOTERESULTSWRAPPER_HXX_
#define VOTERESULTSWRAPPER_HXX_

#include <Voting/ElectoralConfiguration.hxx>
#include <Voting/Vote/StationTallyWrapper.hxx>
#include <Voting/PBReports/vote-results-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace PBReports
            {
                /**
                 * @class VoteResultsWrapper
                 * @brief Vote results wrapper class, which fills the VoteResults object to insert in the pv-data.xml file.
                 * @date 25/03/2014
                 * @author Yadickson Soto
                 */
                class VoteResultsWrapper
                {
                    public:
                        /**
                         * @fn VoteResultsWrapper ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration,
                         * 		Smartmatic::SAES::Voting::Vote::StationTallyWrapper * stationTallyWrapper );
                         * @brief Class constructor
                         * @date 25/03/2014
                         * @author Yadickson Soto
                         * @param electoralConfiguration The electoral configuration instance
                         * @param stationTallyWrapper The station tally instance
                         */
                        VoteResultsWrapper ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration,
                                             Smartmatic::SAES::Voting::Vote::StationTallyWrapper * stationTallyWrapper );

                        /**
                         * @fn virtual ~VoteResultsWrapper();
                         * @brief Class destructor
                         * @date 25/03/2014
                         * @author Yadickson Soto
                         */
                        virtual ~VoteResultsWrapper();

                        /**
                         * @fn virtual Smartmatic::SAES::Voting::PBReports::VoteResults getVoteResults ();
                         * @brief Gets VoteResults information
                         * @date 25/03/2014
                         * @author Yadickson Soto
                         * @return The vote results information
                         */
                        virtual Smartmatic::SAES::Voting::PBReports::VoteResults getVoteResults ();

                    private:

                        Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration; ///< The electoral configuration
                        Smartmatic::SAES::Voting::Vote::StationTallyWrapper * stationTallyWrapper; ///< The station tally wrapper
                };

            } /* namespace PBReports */
        } /* namespace Voting */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* VOTERESULTSWRAPPER_HXX_ */
