/*
 * DiagnoseStepWrapper.hxx
 *
 *  Created on: 16/09/2013
 *      Author: soto
 */

#ifndef DIAGNOSE_STEP_WRAPPER_HXX_
#define DIAGNOSE_STEP_WRAPPER_HXX_

#include <Voting/Status/voting-machine-status-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace Status
            {

                class DiagnoseStepWrapper
                {
                    protected:
                        DiagnoseStepWrapper();

                    public:

                        virtual ~DiagnoseStepWrapper();

                        static Smartmatic::SAES::Voting::Status::DiagnoseStep createDiagnoseStep (
                            Smartmatic::SAES::Common::Configuration::DeviceType type =
                                Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_UNKNOWN );

                        /**
                         * @fn	static std::string getDiagnoseStepString (
                         * 		const Smartmatic::SAES::Voting::Status::DiagnoseStep & step,
                         * 		const std::string & fieldSeparator,
                         * 		const std::string & interSeparator,
                         * 		const std::string & ok = "OK",
                         * 		const std::string & nok = "NOK",
                         * 		const std::string & na = "N/A" );
                         *
                         * @brief	Getter plain result field.
                         * @author	Yadickson Soto
                         * @date	16/09/2013
                         * @param step step diagnose
                         * @param fieldSeparator field separator, used (,) example "field1,field2,..."
                         * @param interSeparator separator inside of field, used (:) example "A:OK,B:OK"
                         * @param ok string diagnose ok, use (OK) example "A:OK"
                         * @param nok string diagnose nok, use (NOK) example "B:NOK"
                         * @param na string diagnose n/a, use (N/A) example "B:N/A"
                         * @return 	plain result
                         */
                        static std::string getDiagnoseStepString (
                            const Smartmatic::SAES::Voting::Status::DiagnoseStep & step,
                            const std::string & fieldSeparator,
                            const std::string & interSeparator,
                            const std::string & ok = "OK",
                            const std::string & nok = "NOK",
                            const std::string & na = "N/A" );

                };

            } /* namespace Status */
        } /* namespace Voting */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* DIAGNOSE_STEP_WRAPPER_HXX_ */
