/**
 * @file	VMProcessStatusWrapper.hxx
 * @brief	Header voting machine process status wrapper class.
 * @author	Yadickson Soto
 * @date	07/11/2012
 */

#ifndef __V_M_PSTATUS_WRAPPER_H__
#define __V_M_PSTATUS_WRAPPER_H__

#include <string>
#include <list>
#include <Voting/Status/voting-machine-process-status-schema.hxx>
#include <System/SafeTime.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Voting
        {
            namespace Status
            {
                /**
                 * @class	VMProcessStatusWrapper
                 * @brief	Voting machine process status wrapper.
                 * @author	Yadickson Soto
                 * @date	07/11/2012
                 */

                class VMProcessStatusWrapper
                {
                    private:

                        /**
                         * @fn	VMProcessStatusWrapper::VMProcessStatusWrapper();
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         */
                        VMProcessStatusWrapper ();

                        static VMProcessStatusWrapper * instance; ///< instance class
                        std::string currentLanguage; ///< current language
                        std::string currentCountry; ///< current country

                        VotingMachineProcessStatus currentObjetc; ///< current object
                        std::list < MachineProcessStatus * > listMachineStatus; ///< list machine status
                        MachineProcessStatus * currentMachine; ///< current machine

                        Smartmatic::System::SafeTime safeTime; ///< safe time
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger

                        int countFail; ///< count fail
                        int countSuccess; ///< count success

                    protected:

                        /**
                         * @fn	void VMProcessStatusWrapper::add( const std::string & domain, const std::string & key, const std::string & resource, bool status);
                         * @brief	Method add new info process
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         * @param domain current domain
                         * @param key any key
                         * @param resource any resource
                         * @param status info status
                         */
                        void add ( const std::string & domain, const std::string & key, const std::string & resource, bool status );
                        /**
                         * @fn	void VMProcessStatusWrapper::getAllByStatus( std::list < MachineProcessStatus * > & list, bool status);
                         * @brief	Method getter all fail process
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         * @param list result
                         * @param status status to find
                         */
                        void getAllByStatus ( std::list < MachineProcessStatus * > & list, bool status );
                        /**
                         * @fn	void VMProcessStatusWrapper::translate ( InfoStatus & info );
                         * @brief	Method translate text
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         * @param info result translate text
                         */
                        void translate ( InfoStatus & info );
                        /**
                         * @fn	void persistencePartial();
                         * @brief	Persistence partial results
                         * @author	Yadickson Soto
                         * @date	12/06/2013
                         */
                        void persistencePartial();

                    public:

                        /**
                         * @fn	virtual VMProcessStatusWrapper::~VMProcessStatusWrapper();
                         * @brief	Default constructor.
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         */
                        virtual ~VMProcessStatusWrapper();

                        /**
                         * @fn	static VMProcessStatusWrapper::VMProcessStatusWrapper * getInstance();
                         * @brief	Method getter instance class
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         * @return instance class
                         */
                        static VMProcessStatusWrapper * getInstance();

                        /**
                         * @fn	void VMProcessStatusWrapper::init( const std::string & currentLanguage, const std::string & currentCountry, const std::string & currentMachine );
                         * @brief	Method init process
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         * @param currentLanguage current language
                         * @param currentCountry current country
                         * @param currentMachine current machine
                         */
                        void init ( const std::string & currentLanguage, const std::string & currentCountry, const std::string & currentMachine );
                        /**
                         * @fn	void VMProcessStatusWrapper::addSuccess( const std::string & domain, const std::string & key, std::string resource = "");
                         * @brief	Method add success result
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         * @param domain current domain
                         * @param key any key
                         * @param resource any resource
                         */
                        void addSuccess ( const std::string & domain, const std::string & key, std::string resource = "" );
                        /**
                         * @fn	void VMProcessStatusWrapper::addFail( const std::string & key );
                         * @brief	Method add fail result
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         * @param key any key
                         */
                        void addFail ( const std::string & key );
                        /**
                         * @fn	void VMProcessStatusWrapper::addFail( const std::string & domain, const std::string & key, std::string resource = "");
                         * @brief	Method add fail result
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         * @param domain current domain
                         * @param key any key
                         * @param resource any resource
                         */
                        void addFail ( const std::string & domain, const std::string & key, std::string resource = "" );
                        /**
                         * @fn	bool VMProcessStatusWrapper::isFail();
                         * @brief	Method getter is fail all process
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         * @return true is fail
                         */
                        bool isFail();
                        /**
                         * @fn	void VMProcessStatusWrapper::getAllSuccess( std::list < MachineProcessStatus * > & list);
                         * @brief	Method getter all success process
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         * @param list result
                         */
                        void getAllSuccess ( std::list < MachineProcessStatus * > & list );
                        /**
                         * @fn	void VMProcessStatusWrapper::getAllFail( std::list < MachineProcessStatus * > & list);
                         * @brief	Method getter all fail process
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         * @param list result
                         */
                        void getAllFail ( std::list < MachineProcessStatus * > & list );
                        /**
                         * @fn	int VMProcessStatusWrapper::getFailCount();
                         * @brief	Method getter fail count process
                         * @author	Yadickson Soto
                         * @date	12/11/2012
                         * @return fail count process
                         */
                        int getFailCount();
                        /**
                         * @fn	int VMProcessStatusWrapper::getSuccessCount();
                         * @brief	Method getter success count process
                         * @author	Yadickson Soto
                         * @date	12/11/2012
                         * @return success count process
                         */
                        int getSuccessCount();
                        /**
                         * @fn	void VMProcessStatusWrapper::dispose();
                         * @brief	Method dispose all list process
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         */
                        void dispose();
                        /**
                         * @fn	void VMProcessStatusWrapper::start();
                         * @brief	Method start time process
                         * @author	Yadickson Soto
                         * @date	27/03/2013
                         */
                        void start();
                        /**
                         * @fn	void VMProcessStatusWrapper::stop();
                         * @brief	Method stop time process
                         * @author	Yadickson Soto
                         * @date	27/03/2013
                         */
                        void stop();
                        /**
                         * @fn	std::string getTime ();
                         * @brief	Method getter time process
                         * @author	Yadickson Soto
                         * @date	27/03/2013
                         * @return time process
                         */
                        std::string getTime ();
                        /**
                         * @fn	void persistence();
                         * @brief	Method persistence results
                         * @author	Yadickson Soto
                         * @date	27/03/2013
                         */
                        void persistence();
                };
            }
        }
    }
}

#endif /*__V_M_PSTATUS_WRAPPER_H__*/
