/**
 * @file	VMStatusWrapper.hxx
 * @brief	voting machine status wrapper class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */

#ifndef __V_M_STATUS_WRAPPER_H__
#define __V_M_STATUS_WRAPPER_H__

#include <string>
#include <list>
#include <Voting/Status/voting-machine-status-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace Status
            {
                /**
                 * @class	VotingMachineStatusWrapper
                 * @brief	Voting machine status wrapper.
                 * @author	Eduardo.campione
                 * @date	28/04/2011
                 */

                class VotingMachineStatusWrapper
                {
                    public:

                        /**
                         * @fn	VotingMachineStatusWrapper::VotingMachineStatusWrapper ();
                         * @brief	Constructor.
                         * @param   runFunctionalityDescriptors run functionality descriptors.
                         * @author	Yadickson Soto
                         * @date	28/04/2011
                         */
                        explicit VotingMachineStatusWrapper ( const std::list<std::string>& runFunctionalityDescriptors );

                        /**
                         * @fn	virtual VotingMachineStatusWrapper::~VotingMachineStatusWrapper();
                         * @brief	Default constructor.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         */
                        virtual ~VotingMachineStatusWrapper();

                        /**
                         * @fn	std::string VotingMachineStatusWrapper::getSerial();
                         * @brief	Method getter serial machine.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	serial machine.
                         */
                        std::string getSerial();

                        /**
                         * @fn	std::string VotingMachineStatusWrapper::getSerialDetected();
                         * @brief	Method getter serial machine detected.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	serial machine detected.
                         */
                        std::string getSerialDetected();

                        /**
                         * @fn  std::string VotingMachineStatusWrapper::getAbled20SerialDetected();
                         * @brief   Method getter abled 2.0 serial detected.
                         * @author  eduardo.fernandez
                         * @date    02/02/2018
                         * @return  Abled 2.0 serial detected.
                         */
                        std::string getAbled20SerialDetected();

                        /**
                         * @fn	std::string VotingMachineStatusWrapper::getDate();
                         * @brief	Method getter date.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	date.
                         */
                        std::string getDate();

                        /**
                         * @fn	std::string VotingMachineStatusWrapper::getZipCode();
                         * @brief	Method getter zip code.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @return	zip code.
                         */
                        std::string getZipCode();

                        /**
                         * @fn	std::string getObservation();
                         * @brief	Getter observation.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @retunr	observation of diagnose.
                         */
                        std::string getObservation();

                        /**
                         * @fn	void VotingMachineStatusWrapper::setSerial(const std::string & serial);
                         * @brief	Method setter serial machine.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @param	serial	serial machine.
                         */
                        void setSerial ( const std::string & serial );

                        /**
                         * @fn	void VotingMachineStatusWrapper::setSerialDetected(const std::string & serial);
                         * @brief	Method setter serial machine detected.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @param	serial	serial machine detected.
                         */
                        void setSerialDetected ( const std::string & serial );

                        /**
                         * @fn  void VotingMachineStatusWrapper::setAbled20SerialDetected(const std::string & serial);
                         * @brief   Method setter abled 2.0 serial detected.
                         * @author  eduardo.fernandez
                         * @date    01/02/2018
                         * @param   serial  Abled 2.0 serial detected.
                         */
                        void setAbled20SerialDetected ( const std::string & serial );

                        /**
                         * @fn	void VotingMachineStatusWrapper::setDate(const std::string & date);
                         * @brief	Method setter date.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @param	date	date.
                         */
                        void setDate ( const std::string & date );

                        /**
                         * @fn	void VotingMachineStatusWrapper::setZipCode(const std::string & zipCode);
                         * @brief	Method setter zip code.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @param	zipCode	zip code.
                         */
                        void setZipCode ( const std::string & zipCode );

                        /**
                         * @fn	void VotingMachineStatusWrapper::setObservation(std::string observation, const unsigned int maxLines );
                         * @brief	Setter observation.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @param	observation	observation of diagnose.
                         * @param 	maxLines maximum number of new lines allowed.
                         */
                        void setObservation ( const std::string & observation, const unsigned int maxLines );

                        /**
                         * @fn	void addCustomCheckList ( const std::string & customCode, bool value );
                         * @brief	Add custom check list information.
                         * @author	Yadickson Soto
                         * @date	16/09/2013
                         * @param	customCode	custom code of information.
                         * @param 	value	value of information
                         */
                        void addCustomCheckList ( const std::string & customCode, bool value );

                        /**
                         * @fn	Smartmatic::SAES::Voting::Status::DeviceStatus & addDevice ( Smartmatic::SAES::Common::Configuration::DeviceType type );
                         * @brief	Add new device to list.
                         * @author	Yadickson Soto
                         * @date	16/09/2013
                         * @param	type device type.
                         * @return 	reference to device
                         */
                        Smartmatic::SAES::Voting::Status::DeviceStatus & addDevice ( Smartmatic::SAES::Common::Configuration::DeviceType type );

                        /**
                         * @fn	void clearDevice ( Smartmatic::SAES::Common::Configuration::DeviceType type );
                         * @brief	Clear device status list.
                         * @author	Yadickson Soto
                         * @date	07/01/2014
                         * @param	type device type.
                         */
                        void clearDevice ( Smartmatic::SAES::Common::Configuration::DeviceType type );

                        /**
                         * @fn	void changeStatus ( Smartmatic::SAES::Common::Configuration::DeviceType type, Smartmatic::SAES::Voting::Status::VMStatus status );
                         * @brief	Add new status to device.
                         * @author	Yadickson Soto
                         * @date	16/09/2013
                         * @param	type device type.
                         * @param	status new status to device
                         */
                        void changeStatus ( Smartmatic::SAES::Common::Configuration::DeviceType type, Smartmatic::SAES::Voting::Status::VMStatus status );

                        /**
                         * @fn	void addDiagnoseStepToDevice ( Smartmatic::SAES::Common::Configuration::DeviceType type, const DiagnoseStep & step );
                         * @brief	Add new diagnose step to device.
                         * @author	Yadickson Soto
                         * @date	16/09/2013
                         * @param	type device type.
                         * @param	step new step to device
                         */
                        void addDiagnoseStepToDevice ( Smartmatic::SAES::Common::Configuration::DeviceType type, const DiagnoseStep & step );

                        /**
                         * @fn	void setAlarmBoxFullStatus ( bool deviceDetected, bool buzzerTest = false, bool redLedTest = false, bool greenLedTest = false, bool buttonTest = false );
                         * @brief	set all alarm box diagnose status
                         * @author	Yadickson Soto
                         * @date	16/09/2013
                         * @param	deviceDetected device detected diagnose, if false the other test haven't efect
                         * @param	buzzerTest buzzer test result diagnose
                         * @param	redLedTest red led test result diagnose
                         * @param	greenLedTest green led test result diagnose
                         * @param	buttonTest button test result diagnose
                         */
                        void setAlarmBoxFullStatus ( bool deviceDetected, bool buzzerTest = false, bool redLedTest = false, bool greenLedTest = false, bool buttonTest = false );

                        /**
                         * @fn	void setBarcodeReaderFullStatus ( bool deviceDetected, bool configurationSuccessful = false, bool scanSuccessful = false, bool QRMatch = false );
                         * @brief	set all barcode reader diagnose status, all diagnoses are mutually exclusive.
                         * @author	Yadickson Soto
                         * @date	31/10/2013
                         * @param	deviceDetected device detected diagnose, if false the other test haven't efect
                         * @param	configurationSuccessful configuration test result diagnose
                         * @param	scanSuccessful scan step not skip by user
                         * @param	QRMatch data scan result diagnose
                         */
                        void setBarcodeReaderFullStatus ( bool deviceDetected, bool configurationSuccessful = false, bool scanSuccessful = false, bool QRMatch = false );

                        /**
                         * @fn	void setEunrFullStatus ( bool deviceDetected, bool configurationSuccessful = false, bool scanSuccessful = false, bool QRMatch = false );
                         * @brief	set all eUrn diagnose status.
                         * @author	Juan Valera
                         * @date	07/11/2017
                         * @param	deviceDetected device detected diagnose, if false the other test haven't efect
                         * @param	door open test result diagnose
                         * @param	door close test result diagnose
                         * @param	green led test result diagnose
                         * @param	red led test result diagnose
                         */
                        void setEurnFullStatus ( bool deviceDetected, bool doorOpenResult = false, bool doorCloseResult = false, bool greenLedResult = false, bool redLedResult = false );

                        /**
                         * @fn	void setStatusSmartcardReaderNotDetected ();
                         * @brief	set smartcard reader diagnose not detected status.
                         * @author	Beatriz Avila
                         * @date	18/11/2013
                         */
                        void setStatusSmartcardReaderNotDetected ();

                        /**
                         * @fn	void setStatusSmartcardReaderWriteError ();
                         * @brief	set smartcard reader diagnose write error status.
                         * @author	Beatriz Avila
                         * @date	18/11/2013
                         */
                        void setStatusSmartcardReaderWriteError ();

                        /**
                         * @fn	void setStatusSmartcardReaderReadError ();
                         * @brief	set smartcard reader diagnose read error status.
                         * @author	Beatriz Avila
                         * @date	18/11/2013
                         */
                        void setStatusSmartcardReaderReadError ();

                        /**
                         * @fn	void setStatusSmartcardReaderInsertionError ();
                         * @brief	set smartcard reader diagnose insertion error status.
                         * @author	Beatriz Avila
                         * @date	18/11/2013
                         */
                        void setStatusSmartcardReaderInsertionError ();

                        /**
                         * @fn	void setStatusSmartcardReaderExtractionError ();
                         * @brief	set smartcard reader diagnose extraction error status.
                         * @author	Beatriz Avila
                         * @date	18/11/2013
                         */
                        void setStatusSmartcardReaderExtractionError ();

                        /**
                         * @fn  void setStatusSmartcardReaderLedStripError ();
                         * @brief   set smartcard reader diagnose led strip status to error status.
                         * @author  Marcel Mancini
                         * @date    18/11/2017
                         */
                        void setStatusSmartcardReaderLedStripError();

                        /**
                         * @fn	void setStatusSmartcardReaderPowerCycleOffError ();
                         * @brief	set smartcard reader diagnose power cycle off error status.
                         * @author	Beatriz Avila
                         * @date	18/11/2013
                         */
                        void setStatusSmartcardReaderPowerCycleOffError ();

                        /**
                         * @fn	void setStatusSmartcardReaderPowerCycleOnError ();
                         * @brief	set smartcard reader diagnose power cycle on error status.
                         * @author	Beatriz Avila
                         * @date	18/11/2013
                         */
                        void setStatusSmartcardReaderPowerCycleOnError ();
                        /**
                         * @fn	void clearPrinterStatus();
                         * @brief	clear printer status.
                         * @author	Yadickson Soto
                         * @date	07/01/2014
                         */
                        void clearPrinterStatus();
                        /**
                         * @fn	void setStatusPrinterNotDetected ();
                         * @brief	set printer not detected (ND) on error status.
                         * @author	Yadickson Soto
                         * @date	07/01/2014
                         */
                        void setStatusPrinterNotDetected();

                        /**
                         * @fn	void addStatusPrinterNoPaper ();
                         * @brief	add printer No Paper (NP) on error status.
                         * @author	Yadickson Soto
                         * @date	06/01/2014
                         */
                        void addStatusPrinterNoPaper();

                        /**
                         * @fn	void addStatusPrinterPaperJam ();
                         * @brief	add printer paper jam (PJ) on error status, only in HP printer.
                         * @author	Yadickson Soto
                         * @date	07/01/2014
                         */
                        void addStatusPrinterPaperJam();

                        /**
                         * @fn	void addStatusPrinterCoverOpen ();
                         * @brief	add printer cover open (CO) on error status, only in HP printer.
                         * @author	Yadickson Soto
                         * @date	07/01/2014
                         */
                        void addStatusPrinterCoverOpen();

                        /**
                         * @fn	void addStatusPrinterFeederOpen ();
                         * @brief	add printer feeder open (FO) on error status, only in APS printer.
                         * @author	Yadickson Soto
                         * @date	06/01/2014
                         */
                        void addStatusPrinterFeederOpen();

                        /**
                         * @fn	void addStatusPrinterNearEndOfPaper ();
                         * @brief	add printer Near End Of Paper (NE) on error status, only in APS printer.
                         * @author	Yadickson Soto
                         * @date	06/01/2014
                         */
                        void addStatusPrinterNearEndOfPaper();

                        /**
                         * @fn	void addStatusPrinterSupplyLowWarn ();
                         * @brief	add printer SupplyLow Warn (SL) on error status, only in HP printer.
                         * @author	Yadickson Soto
                         * @date	07/01/2014
                         */
                        void addStatusPrinterSupplyLowWarn();

                        /**
                         * @fn	void addStatusPrinterNoToner ();
                         * @brief	add printer Out Of Toner(NT) on error status, only in HP printer.
                         * @author	Yadickson Soto
                         * @date	07/01/2014
                         */
                        void addStatusPrinterNoToner();

                        /**
                         * @fn	void addStatusPrinterNoCartridge ();
                         * @brief	add printer Cartridge Not Present (NC) on error status, only in HP printer.
                         * @author	Yadickson Soto
                         * @date	07/01/2014
                         */
                        void addStatusPrinterNoCartridge();

                        /**
                         * @fn	void addStatusPrintingCanceled ();
                         * @brief	add printing canceled error (PC) on error status.
                         * @author	Yadickson Soto
                         * @date	07/01/2014
                         */
                        void addStatusPrintingCanceled();

                        /**
                         * @fn	void addStatusPrintingError ();
                         * @brief	add printing generic error (PE) on error status.
                         * @author	Yadickson Soto
                         * @date	07/01/2014
                         */
                        void addStatusPrintingError();

                        /**
                         * @fn  void addStatusAbled10Ok();
                         * @brief   add abled 1.0 ok status.
                         * @author  eduardo.fernandez
                         * @date    01/02/2018
                         */
                        void addStatusAbled10Ok();

                        /**
                         * @fn  void addStatusAbled10Error();
                         * @brief   add abled 1.0 generic error on error status.
                         * @author  eduardo.fernandez
                         * @date    01/02/2018
                         */
                        void addStatusAbled10Error();

                        /**
                         * @fn  void addStatusAbled10SoundError();
                         * @brief   add abled 1.0 sound error on error status.
                         * @author  eduardo.fernandez
                         * @date    26/02/2018
                         */
                        void addStatusAbled10SoundError();

                        /**
                         * @fn  void addStatusAbled20Ok();
                         * @brief   add abled 2.0 ok status.
                         * @author  eduardo.fernandez
                         * @date    01/02/2018
                         */
                        void addStatusAbled20Ok();

                        /**
                         * @fn  void addStatusAbled20Error();
                         * @brief   add abled 2.0 generic error on error status.
                         * @author  eduardo.fernandez
                         * @date    01/02/2018
                         */
                        void addStatusAbled20Error();

                        /**
                         * @fn  void addStatusAbled20SoundError();
                         * @brief   add abled 2.0 sound error on error status.
                         * @author  eduardo.fernandez
                         * @date    26/02/2018
                         */
                        void addStatusAbled20SoundError();

                        /**
                         * @fn  void setStatusAbledNotDiagnosed();
                         * @brief   set abled not diagnosed status.
                         * @author  eduardo.fernandez
                         * @date    01/02/2018
                         */
                        void setStatusAbledNotDiagnosed();

                        /**
                         * @fn	void setStatusPrinterManualError ();
                         * @brief	set printer generic manual error (ME) on error status.
                         * @author	Yadickson Soto
                         * @date	09/01/2014
                         */
                        void setStatusPrinterManualError();

                        /**
                         * @fn	std::string getVersion (
                         * 		const std::string & fieldSeparator,
                         * 		const std::string & interSeparator );
                         *
                         * @brief	Getter version plain result.
                         * @author	Yadickson Soto
                         * @date	14/01/2014
                         * @param fieldSeparator field separator, used (,) example "field1,field2,..."
                         * @param interSeparator separator inside of field, used (:) example "A:OK,B:OK"
                         * @return 	version plain result
                         */
                        std::string getVersion (
                            const std::string & fieldSeparator,
                            const std::string & interSeparator );

                        /**
                         * @fn	std::string getResult (
                         * 		const std::string & fieldSeparator,
                         * 		const std::string & interSeparator,
                         * 		const std::string & ok = "OK",
                         * 		const std::string & nok = "NOK",
                         * 		const std::string & na = "N/A" );
                         *
                         * @brief	Getter plain result.
                         * @author	Yadickson Soto
                         * @date	16/09/2013
                         * @param fieldSeparator field separator, used (,) example "field1,field2,..."
                         * @param interSeparator separator inside of field, used (:) example "A:OK,B:OK"
                         * @param ok string diagnose ok, use (OK) example "A:OK"
                         * @param nok string diagnose nok, use (NOK) example "B:NOK"
                         * @param na string diagnose n/a, use (N/A) example "B:N/A"
                         * @param able20IsConnected Whether the able 2.0 is connected.
                         * @return 	plain result
                         */
                        std::string getResult (
                            const std::string & fieldSeparator,
                            const std::string & interSeparator,
                            const std::string & ok = "OK",
                            const std::string & nok = "NOK",
                            const std::string & na = "N/A",
                            const bool able20IsConnected = false);

                        /**
                         * @fn	VotingMachineStatus & VotingMachineStatusWrapper::getVotingMachineStatus();
                         * @brief	Gets the voting machine status.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @return	The voting machine status.
                         */
                        VotingMachineStatus & getVotingMachineStatus();

                        /**
                         * @fn	void addErrorStatusCode(Smartmatic::SAES::Common::Configuration::DeviceType deviceType, const std::string & code );
                         * @brief	Add to device error status code.
                         * @author	Yadickson Soto
                         * @date	09/01/2014
                         * @param	type device type.
                         * @param	code error code
                         */
                        void addErrorStatusCode ( Smartmatic::SAES::Common::Configuration::DeviceType deviceType, const std::string & code );

                        /**
                         * @fn	void addStatusCode(Smartmatic::SAES::Common::Configuration::DeviceType deviceType, const std::string & code, VMStatus status = VMStatus::VOTING_MACHINE_STATUS_OK );
                         * @brief	Add to device status code.
                         * @author	Yadickson Soto
                         * @date	14/01/2014
                         * @param	type device type.
                         * @param	code error code
                         * @param	status new status, default OK
                         */
                        void addStatusCode ( Smartmatic::SAES::Common::Configuration::DeviceType deviceType, const std::string & code, VMStatus status = VMStatus::VOTING_MACHINE_STATUS_OK );
                        /**
                         * @fn	std::list <Smartmatic::SAES::Voting::Status::DeviceStatus> getDeviceStatusList();
                         * @brief	Gets all the devices' statuses.
                         * @author	Yadickson Soto
                         * @date	31/10/2012
                         * @return	list of devices' statuses.
                         */
                        std::list <Smartmatic::SAES::Voting::Status::DeviceStatus> getDeviceStatusList();

                        /**
                         * @fn	void OperationStatus::clearDeviceStatusList();
                         * @brief	Clears the device status list.
                         * @author	Youssef.tourkmani
                         * @date	31/10/2012
                         */
                        void clearDeviceStatusList();

                        /**
                         * @fn	Smartmatic::SAES::Voting::Status::DeviceStatus & OperationStatus::getDeviceStatus( Smartmatic::SAES::Common::Configuration::DeviceType type );
                         * @brief	Gets a device status by type.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @param	type	Device type
                         * @return	The device status pointer by type.
                         */

                        Smartmatic::SAES::Voting::Status::DeviceStatus & getDeviceStatus ( Smartmatic::SAES::Common::Configuration::DeviceType type );

                        /**
                         * @fn	void OperationStatus::setDiagnosisStatus(Smartmatic::SAES::Common::Configuration::DeviceType diagnosis,
                         * 			Smartmatic::SAES::Voting::Status::VMStatus status, bool mandatory);
                         * @brief	Change diagnosis status.
                         * @author	Eduardo.campione
                         * @date	28/04/2011
                         * @param	diagnosis		 	The diagnosis.
                         * @param	status		 	The status.
                         * @param	mandatory		True if this device must not fail its diagnosis - failure will lead to a machine shutdown; false if failure / undetected is acceptable.
                         */

                        void setDiagnosisStatus ( Smartmatic::SAES::Common::Configuration::DeviceType diagnosis,
                                                  Smartmatic::SAES::Voting::Status::VMStatus status, bool mandatory );

                    private:

                        VotingMachineStatus status;	///< The status
                        std::list<std::string> m_runFunctionalityDescriptors;
                };
            }
        }
    }
}

#endif /*__V_M_STATUS_WRAPPER_H__*/
