/**
 * @file HashVoteManager.hxx
 * @brief Header Hash vote manager
 * @date 31/05/2013
 * @author Yadickson Soto
 */

#ifndef HASHVOTESTATISTICS_HXX_
#define HASHVOTESTATISTICS_HXX_

#include <string>
#include <map>
#include <list>
#include <Voting/Vote/vote-schema.hxx>
#include <Configuration/SaesCommonConfiguration-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            namespace Vote
            {
                /**
                 * @file HashVoteManager
                 * @brief Class Hash vote manager for all vote in file system, is used for sync and validate all votes
                 * @date 31/05/2013
                 * @author Yadickson Soto
                 */
                class HashVoteManager
                {
                    public:
                        /**
                         * @fn HashVoteManager();
                         * @brief Class constructor
                         * @date 31/05/2013
                         * @author Yadickson Soto
                         */
                        HashVoteManager();
                        /**
                         * @fn virtual ~HashVoteManager();
                         * @brief Class destructor
                         * @date 31/05/2013
                         * @author Yadickson Soto
                         */
                        virtual ~HashVoteManager();
                        /**
                         * @fn void processVote ( const Smartmatic::SAES::Voting::Vote::Vote & vote );
                         * @brief Process vote, get relationship vote code and vote file name, get hash to vote and save in map.
                         * @date 31/05/2013
                         * @author Yadickson Soto
                         * @param vote vote to process
                         */
                        void processVote ( const Smartmatic::SAES::Voting::Vote::Vote & vote );
                        /**
                         * @fn bool validateVote ( const std::string & filename );
                         * @brief Validate file name vote, get hash to vote and compare with hash in map.
                         * @date 31/05/2013
                         * @author Yadickson Soto
                         * @param filename file name to vote
                         * @return true if success
                         */
                        bool validateVote ( const std::string & filename );
                        /**
                         * @fn std::list < std::string > & getFileNameList();
                         * @brief Getter method: list with all file names of votes.
                         * @date 31/05/2013
                         * @author Yadickson Soto
                         * @return file name list.
                         */
                        std::list < std::string > & getFileNameList();
                        /**
                         * @fn void clear();
                         * @brief Clear all list and map.
                         * @date 31/05/2013
                         * @author Yadickson Soto
                         * @return file name list.
                         */
                        void clear();

                    protected:

                        /**
                         * @fn virtual std::string getHash ( const std::string & filename );
                         * @brief getter method: hash file name.
                         * @date 31/05/2013
                         * @author Yadickson Soto
                         * @param filename file name.
                         * @return hash to file name
                         */
                        virtual std::string getHash ( const std::string & filename );

                    private:

                        std::map < std::string, std::string > map; ///< relationship filename - hash
                        std::list < std::string > list; ///< file name list
                };

            } /* namespace Vote */
        } /* namespace Voting */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* HASHVOTESTATISTICS_HXX_ */
