/**
 * @file VoteOptimized.cxx
 * @brief Body class for transformation full vote to size optimized
 * @date21/05/2013
 * @author Yadickson Soto
 */

#include "VoteOptimized.hxx"
#include "VoteFactory.hxx"
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::SAES::Voting::Vote;
using namespace Smartmatic::System::Utils;

VoteOptimized::VoteOptimized()
{

}

VoteOptimized::~VoteOptimized()
{

}

bool VoteOptimized::sizeOptimizedToVote (
    Smartmatic::System::SafeBuffer & bufferIn,
    Vote *& vote,
    VoteOptimizedSelection * selectionManager,
    VoteOptimizedSigned * signedManager )
{
    if ( vote != NULL )
    {
        delete vote;
        vote = NULL;
    }

    if ( bufferIn.GetSize() == 0 || !signedManager->validateBuffer ( bufferIn ) )
    {
        return false;
    }

    std::string input;
    input.assign ( ( const char * ) bufferIn.GetData(), bufferIn.GetSize() );

    std::vector <std::string> result;
    StringUtils::splitToVector ( input, ",", result );

    if ( result.size() < ( unsigned int ) SESSION_ID )
    {
        return false;
    }

    vote = VoteFactory::createVote ();

    for ( unsigned int i = VOTE_CODE; i <= SESSION_ID && result.size() >= ( unsigned int ) SESSION_ID; i++ )
    {
        switch ( i )
        {
            case VOTE_CODE:
                vote->setCode ( result [ i ] );
                break;

            case LOGICAL_VOTER_GROUP_CODE:
                vote->setLogicalVoterGroup ( result [ i ] );
                break;

            case VOTING_DEVICE_CODE:
                vote->setVotingDeviceCode ( result [ i ] );
                break;

            case VOTE_MODE:
                vote->setMode ( VoteMode ( result [ i ] ) );
                break;

            case BALLOT_ID:
                vote->setBallotID ( result [ i ] );
                break;

            case SESSION_ID:
                vote->setSessionID ( result [ i ] );
                break;

            default:
                break;
        }
    }

    std::map <std::string, std::string> maps;

    for ( unsigned int i = SESSION_ID + 1; i < result.size() - 1; i += 2 )
    {
        maps [ result [ i ] ] = result [ i + 1 ];
    }

    selectionManager->getBallots ( maps, vote );

    return true;
}

bool VoteOptimized::voteToSizeOptimized (
    const Vote * vote,
    Smartmatic::System::SafeBuffer & bufferOut,
    VoteOptimizedSelection * selectionManager,
    VoteOptimizedSigned * optimizedSigned )
{
    bufferOut.Clear();

    if ( vote == NULL )
    {
        return false;
    }

    std::string output;

    for ( unsigned int i = VOTE_CODE; i <= SESSION_ID; i++, output.append ( "," ) )
    {
        switch ( i )
        {
            case VOTE_CODE:
                output.append ( vote->getCode () );
                break;

            case LOGICAL_VOTER_GROUP_CODE:
                output.append ( vote->getLogicalVoterGroup () );
                break;

            case VOTING_DEVICE_CODE:
                output.append ( vote->getVotingDeviceCode () );
                break;

            case VOTE_MODE:
                output.append ( vote->getMode () );
                break;

            case BALLOT_ID:
                output.append ( vote->getBallotID () );
                break;

            case SESSION_ID:
                output.append ( vote->getSessionID () );
                break;

            default:
                break;
        }
    }

    std::map < std::string, std::string > maps;
    std::map < std::string, std::string >::iterator it;

    selectionManager->getChecksum ( vote, maps );

    for ( it = maps.begin();
            it != maps.end();
            ++it )
    {
        output.append ( ( *it ).first ); // context code
        output.append ( "," );
        output.append ( ( *it ).second ); // checksum selection ballots
        output.append ( "," );
    }

    bufferOut.AddData ( output );

    return optimizedSigned->signedBuffer ( bufferOut );
}
