#ifndef EML_WRAPPER_TEST_H
#define EML_WRAPPER_TEST_H

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <tests/MockElectoralConfiguration.hxx>
#include <Voting/Eml/EmlWrapper.hxx>
#include <Exceptions/Voting/Eml/EmlElementNotFoundException.hxx>
#include <iostream>
#include <iomanip>
#include <sstream>

typedef Smartmatic::SAES::Voting::Eml::EML EML;
typedef Smartmatic::SAES::Voting::Eml::EmlWrapper EmlWrapper;
typedef Smartmatic::SAES::Exceptions::Voting::Eml::EmlElementNotFoundException EmlElementNotFoundException;

typedef EML::EMLHeaderType                                  EMLHeaderType;
typedef EMLHeaderType::ManagingAuthorityType                ManagingAuthorityType;
typedef EMLHeaderType::OfficialStatusDetailType             OfficialStatusDetailType;
typedef OfficialStatusDetailType::StatusDateType            StatusDateType;
typedef EML::CountType                                      CountType;
typedef CountType::ElectionSequence                         ElectionSequence;
typedef CountType::ElectionType                             ElectionType;
typedef CountType::EventIdentifierType                      EventIdentifierType;
typedef ElectionType::ContestsType                          ContestsType;
typedef ContestsType::ContestSequence                       ContestSequence;
typedef ContestsType::ContestType                           ContestType;
typedef ContestType::ContestIdentifierType                  ContestIdentifierType;
typedef ContestType::TotalVotesType                         TotalVotesType;
typedef TotalVotesType::SelectionSequence                   SelectionSequence;
typedef TotalVotesType::SelectionType                       SelectionType;
typedef ContestType::ReportingUnitVotesSequence             ReportingUnitVotesSequence;
typedef ContestType::ReportingUnitVotesType                 ReportingUnitVotesType;
typedef ReportingUnitVotesType::ReportingUnitIdentifierType ReportingUnitIdentifierType;
typedef SelectionType::CountMetricSequence                  CountMetricSequence;
typedef SelectionType::CountMetricType                      CountMetricType;
typedef SelectionType::AffiliationIdentifierType            AffiliationIdentifierType;
typedef SelectionType::CandidateType                        CandidateType;
typedef CandidateType::CandidateFullNameType                CandidateFullNameType;
typedef CandidateType::CandidateIdentifierType              CandidateIdentifierType;

/**************************** Functions to build an EML object ***************************************/

static void addHeader(EML& eml)
{
    EMLHeaderType            header;
    ManagingAuthorityType    managingAuthority;
    OfficialStatusDetailType officialStatusDetail;
    StatusDateType           statusDate;

    statusDate.day(1);
    statusDate.month(1);
    statusDate.year(1900);

    officialStatusDetail.setStatusDate(statusDate);

    header.setTransactionId("01");
    header.setManagingAuthority(managingAuthority);
    header.setIssueDate("1900-01-01");
    header.setOfficialStatusDetail(officialStatusDetail);

    eml.setEMLHeader(header);
}

static void addContest(EML& eml, const std::string& id)
{
    CountType             count;
    ElectionSequence      elections;
    ElectionType          election;
    EventIdentifierType   identifier;
    ContestsType          contest;
    ContestSequence       contests;
    ContestType           oneContest;
    ContestIdentifierType contestId;

    contestId.setIdNumber(id);
    oneContest.setContestIdentifier(contestId);

    contests.push_back(oneContest);
    contest.setContest(contests);

    election.setContests(contest);
    elections.push_back(election);

    count.setEventIdentifier(identifier);
    count.setElection(elections);
    eml.setCount(count);
}

static void addTotalVotes(EML& eml, const std::string& category)
{
    CountMetricSequence countMetrics;
    CountMetricType     invalidVotesMetric;
    CountMetricType     depositedVotesMetric;
    CountMetricType     levelDepositListMetric;
    SelectionType       selection;

    invalidVotesMetric.setType("BlankAndInvalidVotes");
    depositedVotesMetric.setType("VotesDeposited");
    levelDepositListMetric.setType("LevelDepositList");
    levelDepositListMetric.setId("C");
    levelDepositListMetric += std::atol(category.c_str());

    countMetrics.push_back(invalidVotesMetric);
    countMetrics.push_back(depositedVotesMetric);
    countMetrics.push_back(levelDepositListMetric);

    selection.setCategory(category);
    selection.setCountMetric(countMetrics);

    if (eml.getCount().getElection().front().getContests().getContest().front().getTotalVotes().present())
    {
        TotalVotesType& totalVotes = eml.getCount().getElection().front().getContests().getContest().front().getTotalVotes().get();
        SelectionSequence& selections = totalVotes.getSelection();

        selections.push_back(selection);
    }
    else
    {
        TotalVotesType    totalVotes;
        SelectionSequence selections;

        selections.push_back(selection);
        totalVotes.setSelection(selections);
        eml.getCount().getElection().front().getContests().getContest().front().setTotalVotes(totalVotes);
    }
}

static void addGlobalSituation(EML& eml)
{
    CountMetricSequence countMetrics;
    CountMetricType     checkSum;
    SelectionType       selection;

    checkSum.setType("CheckSum");
    countMetrics.push_back(checkSum);

    selection.setCategory("GlobalSituation");
    selection.setCountMetric(countMetrics);
    selection.setValidVotes(0);

    if (eml.getCount().getElection().front().getContests().getContest().front().getTotalVotes().present())
    {
        TotalVotesType& totalVotes = eml.getCount().getElection().front().getContests().getContest().front().getTotalVotes().get();
        SelectionSequence& selections = totalVotes.getSelection();

        selections.push_back(selection);
    }
    else
    {
        TotalVotesType    totalVotes;
        SelectionSequence selections;

        selections.push_back(selection);
        totalVotes.setSelection(selections);
        eml.getCount().getElection().front().getContests().getContest().front().setTotalVotes(totalVotes);
    }
}

static void addParty(EML& eml, const std::string& partyId)
{
    AffiliationIdentifierType   party;
    CountMetricType             listVotes;
    CountMetricType             principalVotes;
    CountMetricType             substitutesVotes;
    CountMetricType             principalSubstitutesVotes;
    CountMetricType             checkSum;
    CountMetricSequence         countMetrics;
    SelectionType               partySelection;
    SelectionSequence           selections;
    ReportingUnitVotesType      unitVote;
    ReportingUnitIdentifierType reportingUnitIdentifier;

    listVotes.setType("NumberOfHeaderVotes");
    principalVotes.setType("NumberOfBallotsWithOnlyTitularVotes");
    substitutesVotes.setType("NumberOfBallotsWithOnlySubstitutesVotes");
    principalSubstitutesVotes.setType("NumberOfBallotsWithTitularAndSubstitutesVotes");
    checkSum.setType("CheckSum");

    countMetrics.push_back(listVotes);
    countMetrics.push_back(principalVotes);
    countMetrics.push_back(principalSubstitutesVotes);
    countMetrics.push_back(substitutesVotes);
    countMetrics.push_back(checkSum);

    party.setExpectedConfirmationReference(partyId);

    partySelection.setAffiliationIdentifier(party);
    partySelection.setCountMetric(countMetrics);

    selections.push_back(partySelection);
    unitVote.setSelection(selections);
    unitVote.setReportingUnitIdentifier(reportingUnitIdentifier);

    eml.getCount().getElection().front().getContests().getContest().front().getReportingUnitVotes().push_back(unitVote);
}

static void addCandidate(EML& eml, const std::string& id, const std::string& name)
{
    std::string partyId = id.substr(0, 13);

    ReportingUnitVotesSequence& unitVotes = eml.getCount().getElection().front().getContests().getContest().front().getReportingUnitVotes();
    ContestType::ReportingUnitVotesIterator it;

    for (it = unitVotes.begin(); it != unitVotes.end(); ++it)
    {
        SelectionSequence& selections = it->getSelection();
        TotalVotesType::SelectionIterator sIt;

        for (sIt = selections.begin(); sIt != selections.end(); ++sIt)
        {
            if (sIt->getAffiliationIdentifier().present() &&
                sIt->getAffiliationIdentifier().get().getExpectedConfirmationReference().present() &&
                sIt->getAffiliationIdentifier().get().getExpectedConfirmationReference().get() == partyId)
            {
                SelectionType candidateSelection;
                CandidateType candidate;
                CandidateFullNameType candidateName;
                CandidateIdentifierType candidateId;

                candidateName.setPersonFullName(name);
                candidateId.setExpectedConfirmationReference(id);

                candidate.setCandidateFullName(candidateName);
                candidate.setCandidateIdentifier(candidateId);

                candidateSelection.setCandidate(candidate);
                candidateSelection.setValidVotes(0);

                selections.push_back(candidateSelection);

                break;
            }
        }
    }
}

static EML createDefaultEml()
{
    EML eml;

    addHeader(eml);
    addContest(eml, "21004");
    addTotalVotes(eml, "210041");
    addGlobalSituation(eml);
    addParty(eml, "IBZVLC3100501");
    addCandidate(eml, "IBZVLC3100501E01", "John Doe");

    return eml;
}

/************************ Functions to query EML values ********************************/

static long getTotalVotesMetric(const EML& eml, const std::string& metric)
{
    long value = -1;
    TotalVotesType totalVotes = eml.getCount().getElection().front().getContests().getContest().front().getTotalVotes().get();
    TotalVotesType::SelectionIterator it;

    for (it = totalVotes.getSelection().begin(); it != totalVotes.getSelection().end(); ++it)
    {
        TotalVotesType::CountMetricIterator cIt;

        for (cIt = it->getCountMetric().begin(); cIt != it->getCountMetric().end(); ++cIt)
        {
            if (cIt->getType() == metric)
            {
                value = *cIt;
                break;
            }
        }
    }

    return value;
}

static long getGlobalSituationValidVotes(const EML& eml)
{
    long value = -1;
    TotalVotesType totalVotes = eml.getCount().getElection().front().getContests().getContest().front().getTotalVotes().get();
    TotalVotesType::SelectionIterator it;

    for (it = totalVotes.getSelection().begin(); it != totalVotes.getSelection().end(); ++it)
    {
        if (it->getCategory().present() && it->getCategory().get() == "GlobalSituation")
        {
            value = it->getValidVotes();
        }
    }

    return value;
}

static long getPartyMetric(const EML& eml, const std::string& partyId, const std::string& metric)
{
    long value = -1;
    const ReportingUnitVotesSequence& unitVotes = eml.getCount().getElection().front().getContests().getContest().front().getReportingUnitVotes();
    ContestType::ReportingUnitVotesConstIterator it;

    for (it = unitVotes.begin(); it != unitVotes.end(); ++it)
    {
        const SelectionSequence& selections = it->getSelection();
        TotalVotesType::SelectionConstIterator sIt;

        for (sIt = selections.begin(); sIt != selections.end(); ++sIt)
        {
            if (sIt->getAffiliationIdentifier().present() &&
                sIt->getAffiliationIdentifier().get().getExpectedConfirmationReference().present() &&
                sIt->getAffiliationIdentifier().get().getExpectedConfirmationReference().get() == partyId)
            {
                const CountMetricSequence& metrics = sIt->getCountMetric();
                SelectionType::CountMetricConstIterator mIt;

                for (mIt = metrics.begin(); mIt != metrics.end(); ++mIt)
                {
                    if (mIt->getType() == metric)
                    {
                        value = *mIt;
                    }
                }
            }
        }
    }

    return value;
}

static long getCandidateVotes(const EML& eml, const std::string& candidateId)
{
    long value = -1;
    const ReportingUnitVotesSequence& unitVotes = eml.getCount().getElection().front().getContests().getContest().front().getReportingUnitVotes();
    ContestType::ReportingUnitVotesConstIterator it;

    for (it = unitVotes.begin(); it != unitVotes.end(); ++it)
    {
        const SelectionSequence& selections = it->getSelection();
        TotalVotesType::SelectionConstIterator sIt;

        for (sIt = selections.begin(); sIt != selections.end(); ++sIt)
        {
            if (sIt->getCandidate().present() &&
                sIt->getCandidate().get().getCandidateIdentifier().present() &&
                sIt->getCandidate().get().getCandidateIdentifier().get().getExpectedConfirmationReference().present() &&
                sIt->getCandidate().get().getCandidateIdentifier().get().getExpectedConfirmationReference().get() == candidateId)
            {
                value = sIt->getValidVotes();
            }
        }
    }

    return value;
}

static std::string getCandidateName(const EML& eml, const std::string& candidateId)
{
    std::string name;
    const ReportingUnitVotesSequence& unitVotes = eml.getCount().getElection().front().getContests().getContest().front().getReportingUnitVotes();
    ContestType::ReportingUnitVotesConstIterator it;

    for (it = unitVotes.begin(); it != unitVotes.end(); ++it)
    {
        const SelectionSequence& selections = it->getSelection();
        TotalVotesType::SelectionConstIterator sIt;

        for (sIt = selections.begin(); sIt != selections.end(); ++sIt)
        {
            if (sIt->getCandidate().present() &&
                sIt->getCandidate().get().getCandidateIdentifier().present() &&
                sIt->getCandidate().get().getCandidateIdentifier().get().getExpectedConfirmationReference().present() &&
                sIt->getCandidate().get().getCandidateIdentifier().get().getExpectedConfirmationReference().get() == candidateId)
            {
                name = sIt->getCandidate().get().getCandidateFullName().get().getPersonFullName().get();
            }
        }
    }

    return name;
}

static std::string getPartyName(const EML& eml, const std::string& partyId)
{
    std::string name;
    const ReportingUnitVotesSequence& unitVotes = eml.getCount().getElection().front().getContests().getContest().front().getReportingUnitVotes();
    ContestType::ReportingUnitVotesConstIterator it;

    for (it = unitVotes.begin(); it != unitVotes.end(); ++it)
    {
        const SelectionSequence& selections = it->getSelection();
        TotalVotesType::SelectionConstIterator sIt;

        for (sIt = selections.begin(); sIt != selections.end(); ++sIt)
        {
            if (sIt->getAffiliationIdentifier().present() &&
                sIt->getAffiliationIdentifier().get().getExpectedConfirmationReference().present() &&
                sIt->getAffiliationIdentifier().get().getExpectedConfirmationReference().get() == partyId)
            {
                name = sIt->getAffiliationIdentifier().get().getRegisteredName();
            }
        }
    }

    return name;
}

static std::string getTotalVotesSelectionCategory(const EML& eml)
{
    std::string result;
    const TotalVotesType totalVotes = eml.getCount().getElection().front().getContests().getContest().front().getTotalVotes().get();
    TotalVotesType::SelectionConstIterator it;

    for (it = totalVotes.getSelection().begin(); it != totalVotes.getSelection().end(); ++it)
    {
        if (it->getCategory().present() && it->getCategory().get() != "GlobalSituation")
        {
            result = it->getCategory().get();
        }
    }

    return result;
}

static std::string getContestShortCode(const EML& eml)
{
    std::string result = eml.getCount().getElection().front().getContests().getContest().front().getContestIdentifier().getShortCode().get();

    return result;
}

static std::string getContestId(const EML& eml)
{
    std::string id = eml.getCount().getElection().front().getContests().getContest().front().getContestIdentifier().getIdNumber();

    return id;
}

static std::string getIssueDate(const EML& eml)
{
    std::string date = eml.getEMLHeader().getIssueDate().get();

    return date;
}

static std::string getStatusDate(const EML& eml)
{
    StatusDateType statusDate = eml.getEMLHeader().getOfficialStatusDetail().getStatusDate();
    std::stringstream date;

    date << statusDate.year() << "-"
         << std::setfill('0') << std::setw(2) << statusDate.month() << "-"
         << std::setfill('0') << std::setw(2) << statusDate.day();

    return date.str();
}

static std::string getElectronicVotingCountersValue(const EML& eml, const std::string& type)
{
    std::string result;
    CountType::ElectronicVotingCountersConstIterator it;

    for (it = eml.getCount().getElectronicVotingCounters().begin();
         it != eml.getCount().getElectronicVotingCounters().end();
         ++it)
    {
        if (it->getType().get() == type)
        {
            result = *it;
        }
    }

    return result;
}


/***************************************************************************************/

class EmlWrapperTest : public CPPUNIT_NS::TestFixture
{
    public:

        EmlWrapperTest()
        {
            CountType emptyCount;

            m_emptyEml.setCount(emptyCount);
        }

        virtual ~EmlWrapperTest()
        {
        }

        void setUp()
        {
            m_validEml = createDefaultEml();
        }

        void tearDown()
        {
            CountType emptyCount;

            m_validEml.setCount(emptyCount);
        }

    public:

        void testIncreaseBlankInvalidNotFound()
        {
            EmlWrapper eml(m_emptyEml);

            CPPUNIT_ASSERT_THROW(eml.increaseBlankInvalid("BR210041"), EmlElementNotFoundException);
        }

        void testIncreaseBlankInvalidNotFound1()
        {
            EmlWrapper eml(m_validEml);

            CPPUNIT_ASSERT_THROW(eml.increaseBlankInvalid("BR210042"), EmlElementNotFoundException);
            CPPUNIT_ASSERT_THROW(eml.increaseBlankInvalid("BR210043"), EmlElementNotFoundException);
            CPPUNIT_ASSERT_THROW(eml.increaseBlankInvalid("BR210045"), EmlElementNotFoundException);
            CPPUNIT_ASSERT_THROW(eml.increaseBlankInvalid("BR210441"), EmlElementNotFoundException);
        }

        void testIncreaseBlankInvalid()
        {
            EmlWrapper eml(m_validEml);
            int actualBlankVotes;
            int actualDepositedVotes;

            eml.increaseBlankInvalid("BR210041");

            actualBlankVotes     = getTotalVotesMetric(m_validEml, "BlankAndInvalidVotes");
            actualDepositedVotes = getTotalVotesMetric(m_validEml, "VotesDeposited");

            CPPUNIT_ASSERT_EQUAL(1, actualBlankVotes);
            CPPUNIT_ASSERT_EQUAL(1, actualDepositedVotes);
        }

        void testIncreasePartyListBallotCountContestAndPartyNotFound()
        {
            EmlWrapper eml(m_validEml);

            CPPUNIT_ASSERT_THROW(
                eml.increasePartyListBallotCount("BR212042", "IBZVLC3100502"),
                EmlElementNotFoundException);
        }

        void testIncreasePartyListBallotCountPartyNotFound()
        {
            EmlWrapper eml(m_validEml);

            CPPUNIT_ASSERT_THROW(
                eml.increasePartyListBallotCount("BR210041", "IBZVLC3100502"),
                EmlElementNotFoundException);
        }

        void testIncreasePartyListBallotCount()
        {
            EmlWrapper eml(m_validEml);
            long expectedValue = 1;
            long expectedNull = 0;

            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyListBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_EQUAL(expectedValue, getGlobalSituationValidVotes(m_validEml));

            CPPUNIT_ASSERT_EQUAL(
                expectedValue,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfHeaderVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithOnlyTitularVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithTitularAndSubstitutesVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithOnlySubstitutesVotes"));
        }

        void testIncreasePartyPrincipalBallotCountContestAndPartyNotFound()
        {
            EmlWrapper eml(m_validEml);

            CPPUNIT_ASSERT_THROW(
                eml.increasePartyPrincipalBallotCount("BR212042", "IBZVLC3100502"),
                EmlElementNotFoundException);
        }

        void testIncreasePartyPrincipalBallotCountPartyNotFound()
        {
            EmlWrapper eml(m_validEml);

            CPPUNIT_ASSERT_THROW(
                eml.increasePartyPrincipalBallotCount("BR210041", "IBZVLC3100502"),
                EmlElementNotFoundException);
        }

        void testIncreasePartyPrincipalBallotCount()
        {
            EmlWrapper eml(m_validEml);
            long expectedValue = 1;
            long expectedNull = 0;

            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyPrincipalBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_EQUAL(expectedValue, getGlobalSituationValidVotes(m_validEml));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfHeaderVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedValue,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithOnlyTitularVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithTitularAndSubstitutesVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithOnlySubstitutesVotes"));
        }

        void testIncreasePartyStandInBallotCountContestAndPartyNotFound()
        {
            EmlWrapper eml(m_validEml);

            CPPUNIT_ASSERT_THROW(
                eml.increasePartyStandInBallotCount("BR212042", "IBZVLC3100502"),
                EmlElementNotFoundException);
        }

        void testIncreasePartyStandInBallotCountPartyNotFound()
        {
            EmlWrapper eml(m_validEml);

            CPPUNIT_ASSERT_THROW(
                eml.increasePartyStandInBallotCount("BR210041", "IBZVLC3100502"),
                EmlElementNotFoundException);
        }

        void testIncreasePartyStandInBallotCount()
        {
            EmlWrapper eml(m_validEml);
            long expectedValue = 1;
            long expectedNull = 0;

            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyStandInBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_EQUAL(expectedValue, getGlobalSituationValidVotes(m_validEml));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfHeaderVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithOnlyTitularVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithTitularAndSubstitutesVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedValue,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithOnlySubstitutesVotes"));
        }

        void testIncreasePartyPrincipalStandInBallotCountContestAndPartyNotFound()
        {
            EmlWrapper eml(m_validEml);

            CPPUNIT_ASSERT_THROW(
                eml.increasePartyPrincipalStandInBallotCount("BR212042", "IBZVLC3100502"),
                EmlElementNotFoundException);
        }

        void testIncreasePartyPrincipalStandInBallotCountPartyNotFound()
        {
            EmlWrapper eml(m_validEml);

            CPPUNIT_ASSERT_THROW(
                eml.increasePartyPrincipalStandInBallotCount("BR210041", "IBZVLC3100502"),
                EmlElementNotFoundException);
        }

        void testIncreasePartyPrincipalStandInBallotCount()
        {
            EmlWrapper eml(m_validEml);
            long expectedValue = 1;
            long expectedNull = 0;

            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyPrincipalStandInBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_EQUAL(expectedValue, getGlobalSituationValidVotes(m_validEml));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfHeaderVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithOnlyTitularVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedValue,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithTitularAndSubstitutesVotes"));

            CPPUNIT_ASSERT_EQUAL(
                expectedNull,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithOnlySubstitutesVotes"));

        }

        void testIncreasePartyCounters()
        {
            EmlWrapper eml(m_validEml);
            long totalVotes = 11;
            long listVotes = 2;
            long principalOnlyVotes = 3;
            long standinOnlyVotes = 4;
            long principalAndStandinVotes = 2;

            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyListBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyListBallotCount("BR210041", "IBZVLC3100501"));

            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyPrincipalBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyPrincipalBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyPrincipalBallotCount("BR210041", "IBZVLC3100501"));

            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyStandInBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyStandInBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyStandInBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyStandInBallotCount("BR210041", "IBZVLC3100501"));

            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyPrincipalStandInBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyPrincipalStandInBallotCount("BR210041", "IBZVLC3100501"));

            CPPUNIT_ASSERT_EQUAL(totalVotes, getGlobalSituationValidVotes(m_validEml));

            CPPUNIT_ASSERT_EQUAL(
                listVotes,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfHeaderVotes"));

            CPPUNIT_ASSERT_EQUAL(
                principalOnlyVotes,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithOnlyTitularVotes"));

            CPPUNIT_ASSERT_EQUAL(
                principalAndStandinVotes,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithTitularAndSubstitutesVotes"));

            CPPUNIT_ASSERT_EQUAL(
                standinOnlyVotes,
                getPartyMetric(m_validEml, "IBZVLC3100501", "NumberOfBallotsWithOnlySubstitutesVotes"));
        }

        void testIncreaseCandidateVoteContestAndCandidateNotFound()
        {
            EmlWrapper eml(m_validEml);

            CPPUNIT_ASSERT_THROW(
                eml.increaseCandidateVote("BR120001", "IBZVLC3100501E02"),
                EmlElementNotFoundException);
        }

        void testIncreaseCandidateVoteCandidateNotFound()
        {
            EmlWrapper eml(m_validEml);

            CPPUNIT_ASSERT_THROW(
                eml.increaseCandidateVote("BR210041", "IBZVLC3100501E02"),
                EmlElementNotFoundException);
        }

        void testIncreaseCandidateVote()
        {
            EmlWrapper eml(m_validEml);
            long totalVotes = 0;
            long candidateVotes = 1;

            CPPUNIT_ASSERT_NO_THROW(eml.increaseCandidateVote("BR210041", "IBZVLC3100501E01"));
            CPPUNIT_ASSERT_EQUAL(totalVotes, getGlobalSituationValidVotes(m_validEml));
            CPPUNIT_ASSERT_EQUAL(candidateVotes, getCandidateVotes(m_validEml, "IBZVLC3100501E01"));
        }

        void testIncreaseCandidateVoteAndParty()
        {
            EmlWrapper eml(m_validEml);
            long totalVotes = 1;
            long candidateVotes = 1;

            CPPUNIT_ASSERT_NO_THROW(eml.increasePartyPrincipalBallotCount("BR210041", "IBZVLC3100501"));
            CPPUNIT_ASSERT_NO_THROW(eml.increaseCandidateVote("BR210041", "IBZVLC3100501E01"));

            CPPUNIT_ASSERT_EQUAL(totalVotes, getGlobalSituationValidVotes(m_validEml));
            CPPUNIT_ASSERT_EQUAL(candidateVotes, getCandidateVotes(m_validEml, "IBZVLC3100501E01"));
        }

        void testChecksum()
        {
            EmlWrapper eml(m_validEml);
            long checksum = 63;

            CPPUNIT_ASSERT_NO_THROW(eml.sort());
            CPPUNIT_ASSERT_NO_THROW(eml.calculateChecksums());
            CPPUNIT_ASSERT_EQUAL(checksum, getTotalVotesMetric(m_validEml, "CheckSum"));
        }

        void testUpdateTotalVotesSelectionCategory()
        {
            EmlWrapper eml(m_validEml);
            std::string category = "BR210041";
            std::string expected = "210041";

            CPPUNIT_ASSERT_NO_THROW(eml.updateTotalVotesSelectionCategory(category));
            CPPUNIT_ASSERT_EQUAL(expected, getTotalVotesSelectionCategory(m_validEml));
        }

        void testPrepareForOutput()
        {
            EmlWrapper eml(m_validEml);
            std::string expected = "C210041";
            std::string shortCode = "K";
            std::string id = "21004";

            CPPUNIT_ASSERT_NO_THROW(eml.prepareForOutput("V00121004_BR.EML", "K", "001"));
            CPPUNIT_ASSERT_EQUAL(expected, getTotalVotesSelectionCategory(m_validEml));
            CPPUNIT_ASSERT_EQUAL(id, getContestId(m_validEml));
            CPPUNIT_ASSERT_EQUAL(shortCode, getContestShortCode(m_validEml));
        }

        void testElectionDate()
        {
            EmlWrapper eml(m_validEml);
            std::string newDate = "1987-06-28T00:00:00";
            std::string expected = "1987-06-28";

            CPPUNIT_ASSERT_NO_THROW(eml.setElectionDate(newDate));
            CPPUNIT_ASSERT_EQUAL(expected, getIssueDate(m_validEml));
            CPPUNIT_ASSERT_EQUAL(expected, getStatusDate(m_validEml));
        }

        void testPartyAndCandidateNamesCandidate()
        {
            EmlWrapper eml(m_validEml);
            std::string name = "Johnny Doe";
            std::string party = "Party One";
            MockElectoralConfiguration electoralConfiguration;

            electoralConfiguration.customCodeNameMap["IBZVLC3100501"]    = party;
            electoralConfiguration.customCodeNameMap["IBZVLC3100501E01"] = name;

            CPPUNIT_ASSERT_NO_THROW(eml.updatePartyAndCandidateNames("BR210041", electoralConfiguration));
            CPPUNIT_ASSERT_EQUAL(party, getPartyName(m_validEml, "IBZVLC3100501"));
            CPPUNIT_ASSERT_EQUAL(name, getCandidateName(m_validEml, "IBZVLC3100501E01"));
        }

        void testTotalsByType()
        {
            EmlWrapper eml(m_validEml);
            std::map<std::string, long> totalsByType;

            totalsByType["T"] = 1;
            totalsByType["N"] = 2;
            totalsByType["E"] = 3;
            totalsByType["S"] = 4;
            totalsByType["A"] = 5;
            totalsByType["B"] = 6;
            totalsByType["C"] = 7;
            totalsByType["D"] = 8;
            totalsByType["H"] = 9;
            totalsByType["F"] = 10;
            totalsByType["G"] = 11;
            totalsByType["R"] = 12;

            eml.setTotalsByType(totalsByType);

            CPPUNIT_ASSERT_EQUAL(
                std::string("1"),
                getElectronicVotingCountersValue(m_validEml, "T_TotalVoters"));
            CPPUNIT_ASSERT_EQUAL(
                std::string("2"),
                getElectronicVotingCountersValue(m_validEml, "N_NationalVoters"));
            CPPUNIT_ASSERT_EQUAL(
                std::string("3"),
                getElectronicVotingCountersValue(m_validEml, "E_EuropeanVoters"));
            CPPUNIT_ASSERT_EQUAL(
                std::string("4"),
                getElectronicVotingCountersValue(m_validEml, "S_NationalVotersAbroad"));
            CPPUNIT_ASSERT_EQUAL(
                std::string("5"),
                getElectronicVotingCountersValue(m_validEml, "A_FouronRegNationalVoters"));
            CPPUNIT_ASSERT_EQUAL(
                std::string("6"),
                getElectronicVotingCountersValue(m_validEml, "B_FouronRegCkNationalVoters"));
            CPPUNIT_ASSERT_EQUAL(
                std::string("7"),
                getElectronicVotingCountersValue(m_validEml, "C_FouronRegEuNationalVoters"));
            CPPUNIT_ASSERT_EQUAL(
                std::string("8"),
                getElectronicVotingCountersValue(m_validEml, "D_FouronRegEuCkNationalVoters"));
            CPPUNIT_ASSERT_EQUAL(
                std::string("9"),
                getElectronicVotingCountersValue(m_validEml, "H_FouronEuNationalVoters"));
            CPPUNIT_ASSERT_EQUAL(
                std::string("10"),
                getElectronicVotingCountersValue(m_validEml, "F_FouronCkNationalVoters"));
            CPPUNIT_ASSERT_EQUAL(
                std::string("11"),
                getElectronicVotingCountersValue(m_validEml, "G_FouronEuCkNationalVoters"));
            CPPUNIT_ASSERT_EQUAL(
                std::string("12"),
                getElectronicVotingCountersValue(m_validEml, "R_NationalVotersAbroadType4or5"));
        }

        CPPUNIT_TEST_SUITE(EmlWrapperTest);

        CPPUNIT_TEST(testIncreaseBlankInvalidNotFound);
        CPPUNIT_TEST(testIncreaseBlankInvalidNotFound1);
        CPPUNIT_TEST(testIncreaseBlankInvalid);

        CPPUNIT_TEST(testIncreasePartyListBallotCountContestAndPartyNotFound);
        CPPUNIT_TEST(testIncreasePartyListBallotCountPartyNotFound);
        CPPUNIT_TEST(testIncreasePartyListBallotCount);

        CPPUNIT_TEST(testIncreasePartyPrincipalBallotCountContestAndPartyNotFound);
        CPPUNIT_TEST(testIncreasePartyPrincipalBallotCountPartyNotFound);
        CPPUNIT_TEST(testIncreasePartyPrincipalBallotCount);

        CPPUNIT_TEST(testIncreasePartyStandInBallotCountContestAndPartyNotFound);
        CPPUNIT_TEST(testIncreasePartyStandInBallotCountPartyNotFound);
        CPPUNIT_TEST(testIncreasePartyStandInBallotCount);

        CPPUNIT_TEST(testIncreasePartyPrincipalStandInBallotCountContestAndPartyNotFound);
        CPPUNIT_TEST(testIncreasePartyPrincipalStandInBallotCountPartyNotFound);
        CPPUNIT_TEST(testIncreasePartyPrincipalStandInBallotCount);

        CPPUNIT_TEST(testIncreasePartyCounters);

        CPPUNIT_TEST(testIncreaseCandidateVoteContestAndCandidateNotFound);
        CPPUNIT_TEST(testIncreaseCandidateVoteCandidateNotFound);
        CPPUNIT_TEST(testIncreaseCandidateVote);
        CPPUNIT_TEST(testIncreaseCandidateVoteAndParty);

        CPPUNIT_TEST(testUpdateTotalVotesSelectionCategory);

        CPPUNIT_TEST(testChecksum);

        CPPUNIT_TEST(testPrepareForOutput);
        CPPUNIT_TEST(testElectionDate);

        CPPUNIT_TEST(testPartyAndCandidateNamesCandidate);

        CPPUNIT_TEST(testTotalsByType);

        CPPUNIT_TEST_SUITE_END();

    private:

        EML m_emptyEml;
        EML m_validEml;
};

#endif /* ECUT_MAIN */

#endif /* EML_WRAPPER_TEST_H */
