#ifndef TEST_VOTE_RESULTS_WRAPPER_TEST
#define TEST_VOTE_RESULTS_WRAPPER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <tests/MockElectionStringResourcesManager.hxx>
#include <tests/MockElectoralConfiguration.hxx>
#include <tests/MockStationTallyWrapper.hxx>
#include <tests/MockSaesConfigurationManager.hxx>
#include <Voting/PBReports/VoteResultsWrapper.hxx>

class VoteResultsWrapperTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::SAES::Configuration::SAESConfigurationManager SAESConfigurationManager;
        typedef Smartmatic::SAES::Voting::PBReports::VoteResultsWrapper VoteResultsWrapper;
        typedef Smartmatic::SAES::Resources::ElectionStringResourcesManager ElectionStringResourcesManager;
        typedef Smartmatic::SAES::Voting::Vote::StationTally StationTally;
        typedef Smartmatic::SAES::Voting::Vote::Register Register;
        typedef Smartmatic::SAES::Voting::PBReports::VoteResults VoteResults;
        typedef Smartmatic::SAES::Voting::PBReports::ContestResults ContestResults;
        typedef Smartmatic::SAES::Voting::PBReports::ItemsResults ItemsResults;
        typedef Smartmatic::SAES::Voting::PBReports::ItemResult ItemResult;
        typedef Smartmatic::SAES::Voting::Election::Contest Contest;
        typedef Smartmatic::SAES::Voting::Election::Contest_class Contest_class;
        typedef Smartmatic::SAES::Voting::Election::Eligible_option Eligible_option;
        typedef Smartmatic::SAES::Voting::Election::Ballot_option Ballot_option;
        typedef Smartmatic::SAES::Voting::Election::Ballot_options Ballot_options;
        typedef Smartmatic::SAES::Voting::Election::Party Party;
        typedef Smartmatic::SAES::Voting::Election::Category Category;
        typedef MockElectoralConfiguration::ElectoralNames ElectoralNames;

        VoteResultsWrapperTest ()
        {
            m_saesConfigurationManager = new MockSaesConfigurationManager();

            SAESConfigurationManager::getInstance ( m_saesConfigurationManager );
        }

        ~VoteResultsWrapperTest ()
        {
            delete m_saesConfigurationManager;
        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testGetsVoteResultsIfElectoralConfiguration_Is_NULL()
        {
            MockStationTallyWrapper stationTally;
            VoteResultsWrapper voteResultsWrapper ( NULL, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();

            CPPUNIT_ASSERT ( true == voteResults.getContestResults().empty() );
        }

        void testGetsVoteResultsIfStationTally_Is_NULL()
        {
            MockElectoralConfiguration electoralConfiguration;
            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, NULL );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();

            CPPUNIT_ASSERT ( true == voteResults.getContestResults().empty() );
        }

        void testGetsVoteResultsIfStationTallyList_Is_Empty()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::never () );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();

            CPPUNIT_ASSERT ( true == voteResults.getContestResults().empty() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_OneContest()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            StationTally * st = new StationTally ();
            st->setContest ( "1" );

            stationTally.stationTallyList.push_back ( st );

            Contest * contest = new Contest();
            contest->setCode ( "1" );
            contest->setContest_class_code ( "cc1" );

            Contest_class * contestClass = new Contest_class ();
            contestClass->setCode ( "cc1" );

            electoralConfiguration.contestMap [ contest->getCode() ] = contest;
            electoralConfiguration.contestClassMap [ contestClass->getCode() ] = contestClass;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::once () )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "contest name" ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 1 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( true == ( *it ).getPartyResults().empty() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_OneContest_SetVotes()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            StationTally * st = new StationTally ();
            st->setContest ( "1" );
            st->setEmptyVotes ( 10 );
            st->setProcessedVotes ( 45 );

            stationTally.stationTallyList.push_back ( st );

            Contest * contest = new Contest();
            contest->setCode ( "1" );
            contest->setContest_class_code ( "cc1" );

            Contest_class * contestClass = new Contest_class ();
            contestClass->setCode ( "cc1" );

            electoralConfiguration.contestMap [ contest->getCode() ] = contest;
            electoralConfiguration.contestClassMap [ contestClass->getCode() ] = contestClass;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::once () )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "contest name" ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 1 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 10 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 35 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 45 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( true == ( *it ).getPartyResults().empty() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_TwoContest_SetVotes()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            StationTally * st1 = new StationTally ();
            st1->setContest ( "1" );
            st1->setEmptyVotes ( 10 );
            st1->setProcessedVotes ( 11 );

            StationTally * st2 = new StationTally ();
            st2->setContest ( "2" );
            st2->setEmptyVotes ( 20 );
            st2->setProcessedVotes ( 21 );

            stationTally.stationTallyList.push_back ( st1 );
            stationTally.stationTallyList.push_back ( st2 );

            Contest * contest1 = new Contest();
            contest1->setCode ( "1" );
            contest1->setContest_class_code ( "cc1" );

            Contest_class * contestClass1 = new Contest_class ();
            contestClass1->setCode ( "cc1" );

            Contest * contest2 = new Contest();
            contest2->setCode ( "2" );
            contest2->setContest_class_code ( "cc2" );

            Contest_class * contestClass2 = new Contest_class ();
            contestClass2->setCode ( "cc2" );

            electoralConfiguration.contestMap [ contest1->getCode() ] = contest1;
            electoralConfiguration.contestMap [ contest2->getCode() ] = contest2;
            electoralConfiguration.contestClassMap [ contestClass1->getCode() ] = contestClass1;
            electoralConfiguration.contestClassMap [ contestClass2->getCode() ] = contestClass2;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "contest name 1" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "contest name 2" ) ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 2 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name 1" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 10 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 1 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 11 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( true == ( *it ).getPartyResults().empty() );

            ++it;

            CPPUNIT_ASSERT ( "2" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name 2" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 20 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 1 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 21 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( true == ( *it ).getPartyResults().empty() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_OneContest_OneParty()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            StationTally * st = new StationTally ();
            st->setContest ( "1" );

            Register reg;
            reg.setBallotOption ( "bo1" );

            st->getRegisters().push_back ( reg );

            stationTally.stationTallyList.push_back ( st );

            Contest * contest = new Contest();
            contest->setCode ( "1" );
            contest->setContest_class_code ( "cc1" );

            Contest_class * contestClass = new Contest_class ();
            contestClass->setCode ( "cc1" );

            Eligible_option * eligible = new Eligible_option();

            eligible->setCode ( "eo1" );
            eligible->setParent_code ( "" );

            Ballot_option ballot;
            ballot.setCode ( "bo1" );
            ballot.setTally_position ( 1 );
            ballot.setCategory ( Category::ELECTION_LIST );

            Party party;
            party.setName ( "" );

            ballot.setParty ( party );

            Ballot_options ballots;
            ballots.getBallot_option().push_back ( ballot );

            eligible->setBallot_options ( ballots );

            electoralConfiguration.contestMap [ contest->getCode() ] = contest;
            electoralConfiguration.contestClassMap [ contestClass->getCode() ] = contestClass;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballot.getCode() ] = eligible;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "contest name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "party name" ) ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 1 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( 1 == ( *it ).getPartyResults().size() );

            ContestResults::PartyResultsIterator partyit = ( *it ).getPartyResults().begin();

            CPPUNIT_ASSERT ( "eo1" == ( *partyit ).getCode() );
            CPPUNIT_ASSERT ( "party name" == ( *partyit ).getName() );
            CPPUNIT_ASSERT ( 1 == ( *partyit ).getTally_position() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_preference_votes() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_votes() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getList_votes() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getCandidateResults().present() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getSubstituteResults().present() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_OneContest_OneParty_SetValues()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            StationTally * st = new StationTally ();
            st->setContest ( "1" );

            Register reg;
            reg.setBallotOption ( "bo1" );
            reg.setCountList ( 1 );
            reg.setCountListP ( 10 );
            reg.setCountListPS ( 22 );
            reg.setCountListS ( 43 );
            reg.setTotal ( 50 );

            st->getRegisters().push_back ( reg );

            stationTally.stationTallyList.push_back ( st );

            Contest * contest = new Contest();
            contest->setCode ( "1" );
            contest->setContest_class_code ( "cc1" );

            Contest_class * contestClass = new Contest_class ();
            contestClass->setCode ( "cc1" );

            Eligible_option * eligible = new Eligible_option();

            eligible->setCode ( "eo1" );
            eligible->setParent_code ( "" );

            Ballot_option ballot;
            ballot.setCode ( "bo1" );
            ballot.setTally_position ( 1 );
            ballot.setCategory ( Category::ELECTION_LIST );

            Party party;
            party.setName ( "" );

            ballot.setParty ( party );

            Ballot_options ballots;
            ballots.getBallot_option().push_back ( ballot );

            eligible->setBallot_options ( ballots );

            electoralConfiguration.contestMap [ contest->getCode() ] = contest;
            electoralConfiguration.contestClassMap [ contestClass->getCode() ] = contestClass;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballot.getCode() ] = eligible;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "contest name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "party name" ) ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 1 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( 1 == ( *it ).getPartyResults().size() );

            ContestResults::PartyResultsIterator partyit = ( *it ).getPartyResults().begin();

            CPPUNIT_ASSERT ( "eo1" == ( *partyit ).getCode() );
            CPPUNIT_ASSERT ( "party name" == ( *partyit ).getName() );
            CPPUNIT_ASSERT ( 1 == ( *partyit ).getTally_position() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_preference_votes() );
            CPPUNIT_ASSERT ( 76 == ( *partyit ).getTotal_votes() );
            CPPUNIT_ASSERT ( 50 == ( *partyit ).getList_votes() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getCandidateResults().present() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getSubstituteResults().present() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_OneContest_TwoParty()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            StationTally * st = new StationTally ();
            st->setContest ( "1" );

            Register reg1;
            reg1.setBallotOption ( "bo1" );
            reg1.setTotal ( 10 );

            Register reg2;
            reg2.setBallotOption ( "bo2" );
            reg2.setTotal ( 20 );

            st->getRegisters().push_back ( reg1 );
            st->getRegisters().push_back ( reg2 );

            stationTally.stationTallyList.push_back ( st );

            Contest * contest = new Contest();
            contest->setCode ( "1" );
            contest->setContest_class_code ( "cc1" );

            Contest_class * contestClass = new Contest_class ();
            contestClass->setCode ( "cc1" );

            Eligible_option * eligible1 = new Eligible_option();

            eligible1->setCode ( "eo1" );
            eligible1->setParent_code ( "" );

            Ballot_option ballot1;
            ballot1.setCode ( "bo1" );
            ballot1.setTally_position ( 1 );
            ballot1.setCategory ( Category::ELECTION_LIST );

            Party party1;
            party1.setName ( "" );

            ballot1.setParty ( party1 );

            Ballot_options ballots1;
            ballots1.getBallot_option().push_back ( ballot1 );

            eligible1->setBallot_options ( ballots1 );

            Eligible_option * eligible2 = new Eligible_option();

            eligible2->setCode ( "eo2" );
            eligible2->setParent_code ( "" );

            Ballot_option ballot2;
            ballot2.setCode ( "bo2" );
            ballot2.setTally_position ( 2 );
            ballot2.setCategory ( Category::ELECTION_LIST );

            Party party2;
            party2.setName ( "" );

            ballot2.setParty ( party2 );

            Ballot_options ballots2;
            ballots2.getBallot_option().push_back ( ballot2 );

            eligible2->setBallot_options ( ballots2 );

            electoralConfiguration.contestMap [ contest->getCode() ] = contest;
            electoralConfiguration.contestClassMap [ contestClass->getCode() ] = contestClass;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballot1.getCode() ] = eligible1;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballot2.getCode() ] = eligible2;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 3 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "contest name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "party name 1" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "party name 2" ) ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 1 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( 2 == ( *it ).getPartyResults().size() );

            ContestResults::PartyResultsIterator partyit = ( *it ).getPartyResults().begin();

            CPPUNIT_ASSERT ( "eo1" == ( *partyit ).getCode() );
            CPPUNIT_ASSERT ( "party name 1" == ( *partyit ).getName() );
            CPPUNIT_ASSERT ( 1 == ( *partyit ).getTally_position() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_preference_votes() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_votes() );
            CPPUNIT_ASSERT ( 10 == ( *partyit ).getList_votes() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getCandidateResults().present() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getSubstituteResults().present() );

            ++partyit;

            CPPUNIT_ASSERT ( "eo2" == ( *partyit ).getCode() );
            CPPUNIT_ASSERT ( "party name 2" == ( *partyit ).getName() );
            CPPUNIT_ASSERT ( 2 == ( *partyit ).getTally_position() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_preference_votes() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_votes() );
            CPPUNIT_ASSERT ( 20 == ( *partyit ).getList_votes() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getCandidateResults().present() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getSubstituteResults().present() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_OneContest_TwoParty_SortByTally()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            StationTally * st = new StationTally ();
            st->setContest ( "1" );

            Register reg1;
            reg1.setBallotOption ( "bo1" );
            reg1.setTotal ( 10 );

            Register reg2;
            reg2.setBallotOption ( "bo2" );
            reg2.setTotal ( 20 );

            st->getRegisters().push_back ( reg1 );
            st->getRegisters().push_back ( reg2 );

            stationTally.stationTallyList.push_back ( st );

            Contest * contest = new Contest();
            contest->setCode ( "1" );
            contest->setContest_class_code ( "cc1" );

            Contest_class * contestClass = new Contest_class ();
            contestClass->setCode ( "cc1" );

            Eligible_option * eligible1 = new Eligible_option();

            eligible1->setCode ( "eo1" );
            eligible1->setParent_code ( "" );

            Ballot_option ballot1;
            ballot1.setCode ( "bo1" );
            ballot1.setTally_position ( 2 );
            ballot1.setCategory ( Category::ELECTION_LIST );

            Party party1;
            party1.setName ( "" );

            ballot1.setParty ( party1 );

            Ballot_options ballots1;
            ballots1.getBallot_option().push_back ( ballot1 );

            eligible1->setBallot_options ( ballots1 );

            Eligible_option * eligible2 = new Eligible_option();

            eligible2->setCode ( "eo2" );
            eligible2->setParent_code ( "" );

            Ballot_option ballot2;
            ballot2.setCode ( "bo2" );
            ballot2.setTally_position ( 1 );
            ballot2.setCategory ( Category::ELECTION_LIST );

            Party party2;
            party2.setName ( "" );

            ballot2.setParty ( party2 );

            Ballot_options ballots2;
            ballots2.getBallot_option().push_back ( ballot2 );

            eligible2->setBallot_options ( ballots2 );

            electoralConfiguration.contestMap [ contest->getCode() ] = contest;
            electoralConfiguration.contestClassMap [ contestClass->getCode() ] = contestClass;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballot1.getCode() ] = eligible1;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballot2.getCode() ] = eligible2;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 3 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "contest name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "party name 1" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "party name 2" ) ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 1 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( 2 == ( *it ).getPartyResults().size() );

            ContestResults::PartyResultsIterator partyit = ( *it ).getPartyResults().begin();

            CPPUNIT_ASSERT ( "eo2" == ( *partyit ).getCode() );
            CPPUNIT_ASSERT ( "party name 2" == ( *partyit ).getName() );
            CPPUNIT_ASSERT ( 1 == ( *partyit ).getTally_position() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_preference_votes() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_votes() );
            CPPUNIT_ASSERT ( 20 == ( *partyit ).getList_votes() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getCandidateResults().present() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getSubstituteResults().present() );

            ++partyit;

            CPPUNIT_ASSERT ( "eo1" == ( *partyit ).getCode() );
            CPPUNIT_ASSERT ( "party name 1" == ( *partyit ).getName() );
            CPPUNIT_ASSERT ( 2 == ( *partyit ).getTally_position() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_preference_votes() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_votes() );
            CPPUNIT_ASSERT ( 10 == ( *partyit ).getList_votes() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getCandidateResults().present() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getSubstituteResults().present() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_OneContest_OneParty_OneCandidate()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

//            MockSaesConfigurationManager saesConfigurationManager;
//            SAESConfigurationManager::getInstance ( &saesConfigurationManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            electoralConfiguration.nameList.push_back ( ElectoralNames ( "first-name", "last-name", "f" ) );

            StationTally * st = new StationTally ();
            st->setContest ( "1" );

            Register reg;
            reg.setBallotOption ( "bo1" );
            reg.setTotal ( 1 );

            Register regC;
            regC.setBallotOption ( "bo2" );
            regC.setTotal ( 5 );

            st->getRegisters().push_back ( reg );
            st->getRegisters().push_back ( regC );

            stationTally.stationTallyList.push_back ( st );

            Contest * contest = new Contest();
            contest->setCode ( "1" );
            contest->setContest_class_code ( "cc1" );

            Contest_class * contestClass = new Contest_class ();
            contestClass->setCode ( "cc1" );

            Eligible_option * eligible = new Eligible_option();

            eligible->setCode ( "eo1" );
            eligible->setParent_code ( "" );

            Ballot_option ballot;
            ballot.setCode ( "bo1" );
            ballot.setTally_position ( 1 );
            ballot.setCategory ( Category::ELECTION_LIST );

            Party party;
            party.setName ( "" );

            ballot.setParty ( party );

            Ballot_options ballots;
            ballots.getBallot_option().push_back ( ballot );

            eligible->setBallot_options ( ballots );

            Eligible_option * eligibleC = new Eligible_option();

            eligibleC->setCode ( "eo2" );
            eligibleC->setParent_code ( "eo1" );
            eligibleC->setBallot_name_key("");

            Ballot_option ballotC;
            ballotC.setCode ( "bo2" );
            ballotC.setTally_position ( 2 );
            ballotC.setCategory ( Category::ELECTION_PRINCIPAL );

            Party partyC;
            partyC.setName ( "" );

            ballotC.setParty ( party );

            Ballot_options ballotsC;
            ballotsC.getBallot_option().push_back ( ballotC );

            eligibleC->setBallot_options ( ballotsC );

            electoralConfiguration.contestMap [ contest->getCode() ] = contest;
            electoralConfiguration.contestClassMap [ contestClass->getCode() ] = contestClass;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballot.getCode() ] = eligible;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballotC.getCode() ] = eligibleC;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 3 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "contest name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "party name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "last-name#first-name" ) ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 1 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( 1 == ( *it ).getPartyResults().size() );

            ContestResults::PartyResultsIterator partyit = ( *it ).getPartyResults().begin();

            CPPUNIT_ASSERT ( "eo1" == ( *partyit ).getCode() );
            CPPUNIT_ASSERT ( "party name" == ( *partyit ).getName() );
            CPPUNIT_ASSERT ( 1 == ( *partyit ).getTally_position() );
            CPPUNIT_ASSERT ( 5 == ( *partyit ).getTotal_preference_votes() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_votes() );
            CPPUNIT_ASSERT ( 1 == ( *partyit ).getList_votes() );
            CPPUNIT_ASSERT ( true == ( *partyit ).getCandidateResults().present() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getSubstituteResults().present() );

            ItemsResults & candidateResults ( ( *partyit ).getCandidateResults().get() );
            ItemsResults::CandidateSequence & candidates ( candidateResults.getCandidate() );

            CPPUNIT_ASSERT ( 1 == candidates.size() );

            ItemsResults::CandidateIterator candidateit = candidates.begin();

            CPPUNIT_ASSERT ( "bo2" == ( *candidateit ).getCode() );
            CPPUNIT_ASSERT ( "first-name" == ( *candidateit ).getName() );
            CPPUNIT_ASSERT ( "last-name" == ( *candidateit ).getLastname() );
            CPPUNIT_ASSERT ( 2 == ( *candidateit ).getTally_position() );
            CPPUNIT_ASSERT ( 5 == ( *candidateit ).getPreference_votes() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_OneContest_OneParty_OneSubstitute()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            electoralConfiguration.nameList.push_back ( ElectoralNames ( "first-name", "last-name", "f" ) );

            StationTally * st = new StationTally ();
            st->setContest ( "1" );

            Register reg;
            reg.setBallotOption ( "bo1" );
            reg.setTotal ( 1 );

            Register regC;
            regC.setBallotOption ( "bo2" );
            regC.setTotal ( 5 );

            st->getRegisters().push_back ( reg );
            st->getRegisters().push_back ( regC );

            stationTally.stationTallyList.push_back ( st );

            Contest * contest = new Contest();
            contest->setCode ( "1" );
            contest->setContest_class_code ( "cc1" );

            Contest_class * contestClass = new Contest_class ();
            contestClass->setCode ( "cc1" );

            Eligible_option * eligible = new Eligible_option();

            eligible->setCode ( "eo1" );
            eligible->setParent_code ( "" );
            eligible->setBallot_name_key ( "" );

            Ballot_option ballot;
            ballot.setCode ( "bo1" );
            ballot.setTally_position ( 1 );
            ballot.setCategory ( Category::ELECTION_LIST );

            Party party;
            party.setName ( "" );

            ballot.setParty ( party );

            Ballot_options ballots;
            ballots.getBallot_option().push_back ( ballot );

            eligible->setBallot_options ( ballots );

            Eligible_option * eligibleC = new Eligible_option();

            eligibleC->setCode ( "eo2" );
            eligibleC->setParent_code ( "eo1" );
            eligibleC->setBallot_name_key ( "" );

            Ballot_option ballotC;
            ballotC.setCode ( "bo2" );
            ballotC.setTally_position ( 2 );
            ballotC.setCategory ( Category::ELECTION_STAND_IN );

            Party partyC;
            partyC.setName ( "" );

            ballotC.setParty ( party );

            Ballot_options ballotsC;
            ballotsC.getBallot_option().push_back ( ballotC );

            eligibleC->setBallot_options ( ballotsC );

            electoralConfiguration.contestMap [ contest->getCode() ] = contest;
            electoralConfiguration.contestClassMap [ contestClass->getCode() ] = contestClass;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballot.getCode() ] = eligible;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballotC.getCode() ] = eligibleC;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 3 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "contest name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "party name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "last-name#first-name" ) ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 1 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( 1 == ( *it ).getPartyResults().size() );

            ContestResults::PartyResultsIterator partyit = ( *it ).getPartyResults().begin();

            CPPUNIT_ASSERT ( "eo1" == ( *partyit ).getCode() );
            CPPUNIT_ASSERT ( "party name" == ( *partyit ).getName() );
            CPPUNIT_ASSERT ( 1 == ( *partyit ).getTally_position() );
            CPPUNIT_ASSERT ( 5 == ( *partyit ).getTotal_preference_votes() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_votes() );
            CPPUNIT_ASSERT ( 1 == ( *partyit ).getList_votes() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getCandidateResults().present() );
            CPPUNIT_ASSERT ( true == ( *partyit ).getSubstituteResults().present() );

            ItemsResults & substituteResults ( ( *partyit ).getSubstituteResults().get() );
            ItemsResults::CandidateSequence & substitutes ( substituteResults.getCandidate() );

            CPPUNIT_ASSERT ( 1 == substitutes.size() );

            ItemsResults::CandidateIterator substituteit = substitutes.begin();

            CPPUNIT_ASSERT ( "bo2" == ( *substituteit ).getCode() );
            CPPUNIT_ASSERT ( "first-name" == ( *substituteit ).getName() );
            CPPUNIT_ASSERT ( "last-name" == ( *substituteit ).getLastname() );
            CPPUNIT_ASSERT ( 2 == ( *substituteit ).getTally_position() );
            CPPUNIT_ASSERT ( 5 == ( *substituteit ).getPreference_votes() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_OneContest_OneParty_TwoCandidate()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            electoralConfiguration.nameList.push_back ( ElectoralNames ( "first-name1", "last-name1", "f" ) );
            electoralConfiguration.nameList.push_back ( ElectoralNames ( "first-name2", "last-name2", "f" ) );

            StationTally * st = new StationTally ();
            st->setContest ( "1" );

            Register reg;
            reg.setBallotOption ( "bo1" );
            reg.setTotal ( 2 );

            Register regC;
            regC.setBallotOption ( "bo2" );
            regC.setTotal ( 5 );

            Register regC2;
            regC2.setBallotOption ( "bo3" );
            regC2.setTotal ( 4 );

            st->getRegisters().push_back ( reg );
            st->getRegisters().push_back ( regC );
            st->getRegisters().push_back ( regC2 );

            stationTally.stationTallyList.push_back ( st );

            Contest * contest = new Contest();
            contest->setCode ( "1" );
            contest->setContest_class_code ( "cc1" );

            Contest_class * contestClass = new Contest_class ();
            contestClass->setCode ( "cc1" );

            Eligible_option * eligible = new Eligible_option();

            eligible->setCode ( "eo1" );
            eligible->setParent_code ( "" );

            Ballot_option ballot;
            ballot.setCode ( "bo1" );
            ballot.setTally_position ( 1 );
            ballot.setCategory ( Category::ELECTION_LIST );

            Party party;
            party.setName ( "" );

            ballot.setParty ( party );

            Ballot_options ballots;
            ballots.getBallot_option().push_back ( ballot );

            eligible->setBallot_options ( ballots );

            Eligible_option * eligibleC = new Eligible_option();

            eligibleC->setCode ( "eo2" );
            eligibleC->setParent_code ( "eo1" );
            eligibleC->setBallot_name_key( "" );

            Ballot_option ballotC;
            ballotC.setCode ( "bo2" );
            ballotC.setTally_position ( 2 );
            ballotC.setCategory ( Category::ELECTION_PRINCIPAL );

            Party partyC;
            partyC.setName ( "" );

            ballotC.setParty ( partyC );

            Ballot_options ballotsC;
            ballotsC.getBallot_option().push_back ( ballotC );

            eligibleC->setBallot_options ( ballotsC );
            eligibleC->setBallot_name_key ( "" );

            Eligible_option * eligibleC2 = new Eligible_option();

            eligibleC2->setCode ( "eo3" );
            eligibleC2->setParent_code ( "eo1" );
            eligibleC2->setBallot_name_key ( "" );

            Ballot_option ballotC2;
            ballotC2.setCode ( "bo3" );
            ballotC2.setTally_position ( 3 );
            ballotC2.setCategory ( Category::ELECTION_PRINCIPAL );

            Party partyC2;
            partyC2.setName ( "" );

            ballotC2.setParty ( partyC2 );

            Ballot_options ballotsC2;
            ballotsC2.getBallot_option().push_back ( ballotC2 );

            eligibleC2->setBallot_options ( ballotsC2 );

            electoralConfiguration.contestMap [ contest->getCode() ] = contest;
            electoralConfiguration.contestClassMap [ contestClass->getCode() ] = contestClass;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballot.getCode() ] = eligible;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballotC.getCode() ] = eligibleC;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballotC2.getCode() ] = eligibleC2;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 4 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "contest name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "party name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "last-name1#first-name1" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "last-name2#first-name2" ) ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 1 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( 1 == ( *it ).getPartyResults().size() );

            ContestResults::PartyResultsIterator partyit = ( *it ).getPartyResults().begin();

            CPPUNIT_ASSERT ( "eo1" == ( *partyit ).getCode() );
            CPPUNIT_ASSERT ( "party name" == ( *partyit ).getName() );
            CPPUNIT_ASSERT ( 1 == ( *partyit ).getTally_position() );
            CPPUNIT_ASSERT ( 9 == ( *partyit ).getTotal_preference_votes() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_votes() );
            CPPUNIT_ASSERT ( 2 == ( *partyit ).getList_votes() );
            CPPUNIT_ASSERT ( true == ( *partyit ).getCandidateResults().present() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getSubstituteResults().present() );

            ItemsResults & candidateResults ( ( *partyit ).getCandidateResults().get() );
            ItemsResults::CandidateSequence & candidates ( candidateResults.getCandidate() );

            CPPUNIT_ASSERT ( 2 == candidates.size() );

            ItemsResults::CandidateIterator candidateit = candidates.begin();

            CPPUNIT_ASSERT ( "bo2" == ( *candidateit ).getCode() );
            CPPUNIT_ASSERT ( "first-name1" == ( *candidateit ).getName() );
            CPPUNIT_ASSERT ( "last-name1" == ( *candidateit ).getLastname() );
            CPPUNIT_ASSERT ( 2 == ( *candidateit ).getTally_position() );
            CPPUNIT_ASSERT ( 5 == ( *candidateit ).getPreference_votes() );

            ++candidateit;

            CPPUNIT_ASSERT ( "bo3" == ( *candidateit ).getCode() );
            CPPUNIT_ASSERT ( "first-name2" == ( *candidateit ).getName() );
            CPPUNIT_ASSERT ( "last-name2" == ( *candidateit ).getLastname() );
            CPPUNIT_ASSERT ( 3 == ( *candidateit ).getTally_position() );
            CPPUNIT_ASSERT ( 4 == ( *candidateit ).getPreference_votes() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_OneContest_OneParty_TwoSubstitute()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            electoralConfiguration.nameList.push_back ( ElectoralNames ( "first-name1", "last-name1", "f" ) );
            electoralConfiguration.nameList.push_back ( ElectoralNames ( "first-name2", "last-name2", "f" ) );

            StationTally * st = new StationTally ();
            st->setContest ( "1" );

            Register reg;
            reg.setBallotOption ( "bo1" );
            reg.setTotal ( 2 );

            Register regC;
            regC.setBallotOption ( "bo2" );
            regC.setTotal ( 5 );

            Register regC2;
            regC2.setBallotOption ( "bo3" );
            regC2.setTotal ( 4 );

            st->getRegisters().push_back ( reg );
            st->getRegisters().push_back ( regC );
            st->getRegisters().push_back ( regC2 );

            stationTally.stationTallyList.push_back ( st );

            Contest * contest = new Contest();
            contest->setCode ( "1" );
            contest->setContest_class_code ( "cc1" );

            Contest_class * contestClass = new Contest_class ();
            contestClass->setCode ( "cc1" );

            Eligible_option * eligible = new Eligible_option();

            eligible->setCode ( "eo1" );
            eligible->setParent_code ( "" );
            eligible->setBallot_name_key ( "" );

            Ballot_option ballot;
            ballot.setCode ( "bo1" );
            ballot.setTally_position ( 1 );
            ballot.setCategory ( Category::ELECTION_LIST );

            Party party;
            party.setName ( "" );

            ballot.setParty ( party );

            Ballot_options ballots;
            ballots.getBallot_option().push_back ( ballot );

            eligible->setBallot_options ( ballots );

            Eligible_option * eligibleC = new Eligible_option();

            eligibleC->setCode ( "eo2" );
            eligibleC->setParent_code ( "eo1" );
            eligibleC->setBallot_name_key ( "" );

            Ballot_option ballotC;
            ballotC.setCode ( "bo2" );
            ballotC.setTally_position ( 2 );
            ballotC.setCategory ( Category::ELECTION_STAND_IN );

            Party partyC;
            partyC.setName ( "" );

            ballotC.setParty ( partyC );

            Ballot_options ballotsC;
            ballotsC.getBallot_option().push_back ( ballotC );

            eligibleC->setBallot_options ( ballotsC );

            Eligible_option * eligibleC2 = new Eligible_option();

            eligibleC2->setCode ( "eo3" );
            eligibleC2->setParent_code ( "eo1" );
            eligibleC2->setBallot_name_key ( "" );

            Ballot_option ballotC2;
            ballotC2.setCode ( "bo3" );
            ballotC2.setTally_position ( 3 );
            ballotC2.setCategory ( Category::ELECTION_STAND_IN );

            Party partyC2;
            partyC2.setName ( "" );

            ballotC2.setParty ( partyC2 );

            Ballot_options ballotsC2;
            ballotsC2.getBallot_option().push_back ( ballotC2 );

            eligibleC2->setBallot_options ( ballotsC2 );

            electoralConfiguration.contestMap [ contest->getCode() ] = contest;
            electoralConfiguration.contestClassMap [ contestClass->getCode() ] = contestClass;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballot.getCode() ] = eligible;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballotC.getCode() ] = eligibleC;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballotC2.getCode() ] = eligibleC2;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 4 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "contest name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "party name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "last-name1#first-name1" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "last-name2#first-name2" ) ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 1 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( 1 == ( *it ).getPartyResults().size() );

            ContestResults::PartyResultsIterator partyit = ( *it ).getPartyResults().begin();

            CPPUNIT_ASSERT ( "eo1" == ( *partyit ).getCode() );
            CPPUNIT_ASSERT ( "party name" == ( *partyit ).getName() );
            CPPUNIT_ASSERT ( 1 == ( *partyit ).getTally_position() );
            CPPUNIT_ASSERT ( 9 == ( *partyit ).getTotal_preference_votes() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_votes() );
            CPPUNIT_ASSERT ( 2 == ( *partyit ).getList_votes() );
            CPPUNIT_ASSERT ( false == ( *partyit ).getCandidateResults().present() );
            CPPUNIT_ASSERT ( true == ( *partyit ).getSubstituteResults().present() );

            ItemsResults & substituteResults ( ( *partyit ).getSubstituteResults().get() );
            ItemsResults::CandidateSequence & substitutes ( substituteResults.getCandidate() );

            CPPUNIT_ASSERT ( 2 == substitutes.size() );

            ItemsResults::CandidateIterator substituteit = substitutes.begin();

            CPPUNIT_ASSERT ( "bo2" == ( *substituteit ).getCode() );
            CPPUNIT_ASSERT ( "first-name1" == ( *substituteit ).getName() );
            CPPUNIT_ASSERT ( "last-name1" == ( *substituteit ).getLastname() );
            CPPUNIT_ASSERT ( 2 == ( *substituteit ).getTally_position() );
            CPPUNIT_ASSERT ( 5 == ( *substituteit ).getPreference_votes() );

            ++substituteit;

            CPPUNIT_ASSERT ( "bo3" == ( *substituteit ).getCode() );
            CPPUNIT_ASSERT ( "first-name2" == ( *substituteit ).getName() );
            CPPUNIT_ASSERT ( "last-name2" == ( *substituteit ).getLastname() );
            CPPUNIT_ASSERT ( 3 == ( *substituteit ).getTally_position() );
            CPPUNIT_ASSERT ( 4 == ( *substituteit ).getPreference_votes() );

            resourceManager.verify();
        }

        void testGetsVoteResultsIfStationTallyList_OneContest_OneParty_OneCandidate_OneSubstitute()
        {
            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MockElectoralConfiguration electoralConfiguration;
            MockStationTallyWrapper stationTally;

            electoralConfiguration.nameList.push_back ( ElectoralNames ( "first-name1", "last-name1", "f" ) );
            electoralConfiguration.nameList.push_back ( ElectoralNames ( "first-name2", "last-name2", "f" ) );

            StationTally * st = new StationTally ();
            st->setContest ( "1" );

            Register reg;
            reg.setBallotOption ( "bo1" );
            reg.setTotal ( 2 );

            Register regC;
            regC.setBallotOption ( "bo2" );
            regC.setTotal ( 5 );

            Register regC2;
            regC2.setBallotOption ( "bo3" );
            regC2.setTotal ( 4 );

            st->getRegisters().push_back ( reg );
            st->getRegisters().push_back ( regC );
            st->getRegisters().push_back ( regC2 );

            stationTally.stationTallyList.push_back ( st );

            Contest * contest = new Contest();
            contest->setCode ( "1" );
            contest->setContest_class_code ( "cc1" );

            Contest_class * contestClass = new Contest_class ();
            contestClass->setCode ( "cc1" );

            Eligible_option * eligible = new Eligible_option();

            eligible->setCode ( "eo1" );
            eligible->setParent_code ( "" );
            eligible->setBallot_name_key ( "" );

            Ballot_option ballot;
            ballot.setCode ( "bo1" );
            ballot.setTally_position ( 1 );
            ballot.setCategory ( Category::ELECTION_LIST );

            Party party;
            party.setName ( "" );

            ballot.setParty ( party );

            Ballot_options ballots;
            ballots.getBallot_option().push_back ( ballot );

            eligible->setBallot_options ( ballots );

            Eligible_option * eligibleC = new Eligible_option();

            eligibleC->setCode ( "eo2" );
            eligibleC->setParent_code ( "eo1" );
            eligibleC->setBallot_name_key ( "" );

            Ballot_option ballotC;
            ballotC.setCode ( "bo2" );
            ballotC.setTally_position ( 2 );
            ballotC.setCategory ( Category::ELECTION_PRINCIPAL );

            Party partyC;
            partyC.setName ( "" );

            ballotC.setParty ( partyC );

            Ballot_options ballotsC;
            ballotsC.getBallot_option().push_back ( ballotC );

            eligibleC->setBallot_options ( ballotsC );

            Eligible_option * eligibleC2 = new Eligible_option();

            eligibleC2->setCode ( "eo3" );
            eligibleC2->setParent_code ( "eo1" );
            eligibleC2->setBallot_name_key ( "" );

            Ballot_option ballotC2;
            ballotC2.setCode ( "bo3" );
            ballotC2.setTally_position ( 3 );
            ballotC2.setCategory ( Category::ELECTION_STAND_IN );

            Party partyC2;
            partyC2.setName ( "" );

            ballotC2.setParty ( partyC2 );

            Ballot_options ballotsC2;
            ballotsC2.getBallot_option().push_back ( ballotC2 );

            eligibleC2->setBallot_options ( ballotsC2 );

            electoralConfiguration.contestMap [ contest->getCode() ] = contest;
            electoralConfiguration.contestClassMap [ contestClass->getCode() ] = contestClass;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballot.getCode() ] = eligible;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballotC.getCode() ] = eligibleC;
            electoralConfiguration.eoByBallotOptionCodeMap [ contest->getCode() ][ ballotC2.getCode() ] = eligibleC2;

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 4 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        new MOCKPP_NS::ReturnStub<std::string> ( "contest name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "party name" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "last-name1#first-name1" ),
                        new MOCKPP_NS::ReturnStub<std::string> ( "last-name2#first-name2" ) ) );

            VoteResultsWrapper voteResultsWrapper ( &electoralConfiguration, &stationTally );
            VoteResults voteResults = voteResultsWrapper.getVoteResults();
            VoteResults::ContestResultsSequence & seq ( voteResults.getContestResults() );

            CPPUNIT_ASSERT ( 1 == seq.size() );

            VoteResults::ContestResultsIterator it = seq.begin();

            CPPUNIT_ASSERT ( "1" == ( *it ).getCode() );
            CPPUNIT_ASSERT ( "contest name" == ( *it ).getContest_name() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getBlank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getNon_blank_votes() );
            CPPUNIT_ASSERT ( 0 == ( *it ).getTotal_votes() );
            CPPUNIT_ASSERT ( 1 == ( *it ).getPartyResults().size() );

            ContestResults::PartyResultsIterator partyit = ( *it ).getPartyResults().begin();

            CPPUNIT_ASSERT ( "eo1" == ( *partyit ).getCode() );
            CPPUNIT_ASSERT ( "party name" == ( *partyit ).getName() );
            CPPUNIT_ASSERT ( 1 == ( *partyit ).getTally_position() );
            CPPUNIT_ASSERT ( 9 == ( *partyit ).getTotal_preference_votes() );
            CPPUNIT_ASSERT ( 0 == ( *partyit ).getTotal_votes() );
            CPPUNIT_ASSERT ( 2 == ( *partyit ).getList_votes() );
            CPPUNIT_ASSERT ( true == ( *partyit ).getCandidateResults().present() );
            CPPUNIT_ASSERT ( true == ( *partyit ).getSubstituteResults().present() );

            ItemsResults & candidateResults ( ( *partyit ).getCandidateResults().get() );
            ItemsResults::CandidateSequence & candidates ( candidateResults.getCandidate() );

            ItemsResults & substituteResults ( ( *partyit ).getSubstituteResults().get() );
            ItemsResults::CandidateSequence & substitutes ( substituteResults.getCandidate() );

            CPPUNIT_ASSERT ( 1 == candidates.size() );
            CPPUNIT_ASSERT ( 1 == substitutes.size() );

            ItemsResults::CandidateIterator candidateit = candidates.begin();
            ItemsResults::CandidateIterator substituteit = substitutes.begin();

            CPPUNIT_ASSERT ( "bo2" == ( *candidateit ).getCode() );
            CPPUNIT_ASSERT ( "first-name1" == ( *candidateit ).getName() );
            CPPUNIT_ASSERT ( "last-name1" == ( *candidateit ).getLastname() );
            CPPUNIT_ASSERT ( 2 == ( *candidateit ).getTally_position() );
            CPPUNIT_ASSERT ( 5 == ( *candidateit ).getPreference_votes() );

            CPPUNIT_ASSERT ( "bo3" == ( *substituteit ).getCode() );
            CPPUNIT_ASSERT ( "first-name2" == ( *substituteit ).getName() );
            CPPUNIT_ASSERT ( "last-name2" == ( *substituteit ).getLastname() );
            CPPUNIT_ASSERT ( 3 == ( *substituteit ).getTally_position() );
            CPPUNIT_ASSERT ( 4 == ( *substituteit ).getPreference_votes() );

            resourceManager.verify();
        }

        CPPUNIT_TEST_SUITE ( VoteResultsWrapperTest );

        CPPUNIT_TEST ( testGetsVoteResultsIfElectoralConfiguration_Is_NULL );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTally_Is_NULL );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_Is_Empty );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_Is_Empty );

        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_OneContest );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_OneContest_SetVotes );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_TwoContest_SetVotes );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_OneContest_OneParty );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_OneContest_OneParty_SetValues );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_OneContest_TwoParty );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_OneContest_TwoParty_SortByTally );

        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_OneContest_OneParty_OneCandidate );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_OneContest_OneParty_OneSubstitute );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_OneContest_OneParty_TwoCandidate );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_OneContest_OneParty_TwoSubstitute );
        CPPUNIT_TEST ( testGetsVoteResultsIfStationTallyList_OneContest_OneParty_OneCandidate_OneSubstitute );

        CPPUNIT_TEST_SUITE_END();

    private:
        MockSaesConfigurationManager* m_saesConfigurationManager;
};

#endif /* ECUT_MAIN */

#endif /* TEST_VOTE_RESULTS_WRAPPER_TEST */
