#ifndef TEST_VALIDATEVOTETEST
#define TEST_VALIDATEVOTETEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Voting/Vote/VoteFactory.hxx>
#include <Voting/Vote/VoteValidate.hxx>

class ValidateVoteTest : public CPPUNIT_NS::TestFixture
{
    private:

        Smartmatic::SAES::Voting::Vote::Vote * vote;
        Smartmatic::SAES::Voting::Vote::Vote * vote2;

    public:

        ValidateVoteTest ()
        {
            vote = NULL;
            vote2 = NULL;
        }

        void setUp()
        {
            vote = Smartmatic::SAES::Voting::Vote::VoteFactory::createVote();
        }

        void tearDown()
        {
            if ( vote )
            {
                delete vote;
                vote = NULL;
            }

            if ( vote2 )
            {
                delete vote2;
                vote2 = NULL;
            }
        }

        void testValidateNullVote()
        {
            bool result = Smartmatic::SAES::Voting::Vote::VoteValidate::validateStructure ( NULL );
            CPPUNIT_ASSERT ( false == result );
        }

        void testValidateStructureVote()
        {
            bool result = Smartmatic::SAES::Voting::Vote::VoteValidate::validateStructure ( vote );
            CPPUNIT_ASSERT ( true == result );
        }

        void testVoteToBuffer()
        {
            Smartmatic::System::SafeBuffer buffer;
            bool result = Smartmatic::SAES::Voting::Vote::VoteFactory::voteToBuffer ( vote, buffer );

            CPPUNIT_ASSERT ( true == result );
            CPPUNIT_ASSERT ( 0 != buffer.GetSize() );
            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
        }

        void testRegressionVote()
        {
            Smartmatic::System::SafeBuffer buffer;
            std::string code = "ABCDEF";
            std::string lvg = "lvg";
            std::string vdc = "vdc";
            std::string mode = Smartmatic::SAES::Voting::Vote::VoteMode ( Smartmatic::SAES::Voting::Vote::VoteMode::VOTE_O );
            std::string bid = "xxyy";
            std::string sid = "yyxx";

            vote->setCode ( code );
            vote->setLogicalVoterGroup ( lvg );
            vote->setVotingDeviceCode ( vdc );
            vote->setMode ( mode );
            vote->setBallotID ( bid );
            vote->setSessionID ( sid );

            bool resultOne;
            bool resultTwo;

            resultOne = Smartmatic::SAES::Voting::Vote::VoteFactory::voteToBuffer ( vote, buffer );
            resultTwo = Smartmatic::SAES::Voting::Vote::VoteFactory::bufferToVote ( buffer, vote2 );

            CPPUNIT_ASSERT ( true == resultOne );
            CPPUNIT_ASSERT ( true == resultTwo );
            CPPUNIT_ASSERT ( code == vote2->getCode() );
            CPPUNIT_ASSERT ( lvg == vote2->getLogicalVoterGroup() );
            CPPUNIT_ASSERT ( vdc == vote2->getVotingDeviceCode() );
            CPPUNIT_ASSERT ( mode == vote2->getMode() );
            CPPUNIT_ASSERT ( bid == vote2->getBallotID() );
            CPPUNIT_ASSERT ( sid == vote2->getSessionID() );
        }

        void testRegressionVoteWithSelection()
        {
            Smartmatic::System::SafeBuffer buffer;
            std::string contestCode = "cx";
            std::string contestCS = "cs";

            Smartmatic::SAES::Voting::Vote::Selection s;
            s.setContest ( contestCode );
            s.setContestCodedSelections ( contestCS );

            vote->getSelections().push_back ( s );

            bool resultOne;
            bool resultTwo;

            resultOne = Smartmatic::SAES::Voting::Vote::VoteFactory::voteToBuffer ( vote, buffer );
            resultTwo = Smartmatic::SAES::Voting::Vote::VoteFactory::bufferToVote ( buffer, vote2 );

            CPPUNIT_ASSERT ( true == resultOne );
            CPPUNIT_ASSERT ( true == resultTwo );
            CPPUNIT_ASSERT ( 1 == vote2->getSelections().size() );
            CPPUNIT_ASSERT ( contestCode == vote2->getSelections() [0].getContest() );
            CPPUNIT_ASSERT ( true == vote2->getSelections() [0].getContestCodedSelections().present() );
            CPPUNIT_ASSERT ( contestCS == vote2->getSelections() [0].getContestCodedSelections().get() );
        }

        CPPUNIT_TEST_SUITE ( ValidateVoteTest );
        CPPUNIT_TEST ( testValidateNullVote );
        CPPUNIT_TEST ( testValidateStructureVote );
        CPPUNIT_TEST ( testVoteToBuffer );
        CPPUNIT_TEST ( testRegressionVote );
        CPPUNIT_TEST ( testRegressionVoteWithSelection );
        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_VALIDATEVOTETEST */
