#ifndef TEST_VOTE_OPTIMIZED_TEST
#define TEST_VOTE_OPTIMIZED_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Voting/Vote/VoteOptimized.hxx>
#include <Voting/Vote/VoteFactory.hxx>
#include "MockVoteOptimizedSelection.hxx"
#include "MockVoteOptimizedSigned.hxx"

class VoteOptimizedTest : public CPPUNIT_NS::TestFixture
{
    private:

        Smartmatic::SAES::Voting::Vote::Vote * vote;
        Smartmatic::SAES::Voting::Vote::Vote * vote2;

    public:

        VoteOptimizedTest ()
        {
            vote = NULL;
            vote2 = NULL;
        }

        void setUp()
        {
            vote = Smartmatic::SAES::Voting::Vote::VoteFactory::createVote();
        }

        void tearDown()
        {
            if ( vote )
            {
                delete vote;
                vote = NULL;
            }

            if ( vote2 )
            {
                delete vote2;
                vote2 = NULL;
            }
        }

        void testVoteToSizeOptimizedIfVoteNULL()
        {
            MockVoteOptimizedSelection selectionManager;
            MockVoteOptimizedSigned signedManager;

            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, signedBuffer, ext ) signedBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getChecksum, ext ) getChecksum_mock ( &selectionManager );

            signedBuffer_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue ( true ) );

            getChecksum_mock
            .expects ( MOCKPP_NS::never() );

            Smartmatic::System::SafeBuffer buffer;
            bool resultOne;

            resultOne = Smartmatic::SAES::Voting::Vote::VoteOptimized::voteToSizeOptimized ( NULL, buffer, &selectionManager, &signedManager );
            CPPUNIT_ASSERT ( false == resultOne );
            CPPUNIT_ASSERT ( 0 == buffer.GetSize() );

            signedManager.verify();
            selectionManager.verify();
        }

        void testVoteToSizeOptimizedIfFailSigned()
        {
            MockVoteOptimizedSelection selectionManager;
            MockVoteOptimizedSigned signedManager;

            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, signedBuffer, ext ) signedBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getChecksum, ext ) getChecksum_mock ( &selectionManager );

            getChecksum_mock
            .expects ( MOCKPP_NS::once() );

            signedBuffer_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( false ) );

            Smartmatic::System::SafeBuffer buffer;
            bool resultOne;

            resultOne = Smartmatic::SAES::Voting::Vote::VoteOptimized::voteToSizeOptimized ( vote, buffer, &selectionManager, &signedManager );
            CPPUNIT_ASSERT ( false == resultOne );

            signedManager.verify();
            selectionManager.verify();
        }

        void testVoteToSizeOptimized()
        {
            MockVoteOptimizedSelection selectionManager;
            MockVoteOptimizedSigned signedManager;

            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, signedBuffer, ext ) signedBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getChecksum, ext ) getChecksum_mock ( &selectionManager );

            getChecksum_mock
            .expects ( MOCKPP_NS::once() );

            signedBuffer_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( true ) );

            Smartmatic::System::SafeBuffer buffer;
            bool resultOne;

            resultOne = Smartmatic::SAES::Voting::Vote::VoteOptimized::voteToSizeOptimized ( vote, buffer, &selectionManager, &signedManager );
            CPPUNIT_ASSERT ( true == resultOne );
            CPPUNIT_ASSERT ( 0 != buffer.GetSize() );

            signedManager.verify();
            selectionManager.verify();
        }

        void testVoteToSizeOptimizedCallSignedNotSelection()
        {
            MockVoteOptimizedSelection selectionManager;
            MockVoteOptimizedSigned signedManager;

            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, signedBuffer, ext ) signedBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getChecksum, ext ) getChecksum_mock ( &selectionManager );

            getChecksum_mock
            .expects ( MOCKPP_NS::once() );

            signedBuffer_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( true ) );

            Smartmatic::System::SafeBuffer buffer;
            bool resultOne;

            resultOne = Smartmatic::SAES::Voting::Vote::VoteOptimized::voteToSizeOptimized ( vote, buffer, &selectionManager, &signedManager );
            CPPUNIT_ASSERT ( true == resultOne );
            CPPUNIT_ASSERT ( 0 != buffer.GetSize() );

            signedManager.verify();
            selectionManager.verify();
        }

        void testVoteToSizeOptimizedCallSignedAndChecksumWithSelection()
        {
            MockVoteOptimizedSelection selectionManager;
            MockVoteOptimizedSigned signedManager;

            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, signedBuffer, ext ) signedBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getChecksum, ext ) getChecksum_mock ( &selectionManager );

            getChecksum_mock
            .expects ( MOCKPP_NS::once() );

            signedBuffer_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( true ) );

            Smartmatic::System::SafeBuffer buffer;
            std::string contestCode = "cx";
            bool resultOne;

            Smartmatic::SAES::Voting::Vote::Selection s;
            s.setContest ( contestCode );

            vote->getSelections().push_back ( s );

            resultOne = Smartmatic::SAES::Voting::Vote::VoteOptimized::voteToSizeOptimized ( vote, buffer, &selectionManager, &signedManager );
            CPPUNIT_ASSERT ( true == resultOne );
            CPPUNIT_ASSERT ( 0 != buffer.GetSize() );

            signedManager.verify();
            selectionManager.verify();
        }

        void testRegretionSizeOptimized()
        {
            MockVoteOptimizedSelection selectionManager;
            MockVoteOptimizedSigned signedManager;

            Smartmatic::System::SafeBuffer buffer;

            bool resultOne;
            bool resultTwo;

            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, signedBuffer, ext ) signedBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, validateBuffer, ext ) validateBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getChecksum, ext ) getChecksum_mock ( &selectionManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getBallots, ext ) getBallots_mock ( &selectionManager );

            getChecksum_mock
            .expects ( MOCKPP_NS::once() );

            signedBuffer_mock.stubs()
            .will ( MOCKPP_NS::returnValue ( true ) );

            validateBuffer_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( true ) );

            getBallots_mock
            .expects ( MOCKPP_NS::once() );

            resultOne = Smartmatic::SAES::Voting::Vote::VoteOptimized::voteToSizeOptimized ( vote, buffer, &selectionManager, &signedManager );
            resultTwo = Smartmatic::SAES::Voting::Vote::VoteOptimized::sizeOptimizedToVote ( buffer, vote2, &selectionManager, &signedManager );

            CPPUNIT_ASSERT ( true == resultOne );
            CPPUNIT_ASSERT ( true == resultTwo );

            signedManager.verify();
            selectionManager.verify();
        }

        void testRegretionSizeOptimizedValidateFail()
        {
            MockVoteOptimizedSelection selectionManager;
            MockVoteOptimizedSigned signedManager;

            Smartmatic::System::SafeBuffer buffer;

            bool resultOne;
            bool resultTwo;

            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, signedBuffer, ext ) signedBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, validateBuffer, ext ) validateBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getChecksum, ext ) getChecksum_mock ( &selectionManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getBallots, ext ) getBallots_mock ( &selectionManager );

            getChecksum_mock
            .expects ( MOCKPP_NS::once() );

            signedBuffer_mock.stubs()
            .will ( MOCKPP_NS::returnValue ( true ) );

            validateBuffer_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( false ) );

            resultOne = Smartmatic::SAES::Voting::Vote::VoteOptimized::voteToSizeOptimized ( vote, buffer, &selectionManager, &signedManager );
            resultTwo = Smartmatic::SAES::Voting::Vote::VoteOptimized::sizeOptimizedToVote ( buffer, vote2, &selectionManager, &signedManager );

            CPPUNIT_ASSERT ( true == resultOne );
            CPPUNIT_ASSERT ( false == resultTwo );

            signedManager.verify();
            selectionManager.verify();
        }

        void testRegretionSizeOptimizedCheckValues()
        {
            MockVoteOptimizedSelection selectionManager;
            MockVoteOptimizedSigned signedManager;

            Smartmatic::System::SafeBuffer buffer;
            std::string code = "ABCDEF";
            std::string lvg = "lvg";
            std::string vdc = "vdc";
            std::string mode = Smartmatic::SAES::Voting::Vote::VoteMode ( Smartmatic::SAES::Voting::Vote::VoteMode::VOTE_O );
            std::string bid = "xxyy";
            std::string sid = "yyxx";

            vote->setCode ( code );
            vote->setLogicalVoterGroup ( lvg );
            vote->setVotingDeviceCode ( vdc );
            vote->setMode ( mode );
            vote->setBallotID ( bid );
            vote->setSessionID ( sid );

            bool resultOne;
            bool resultTwo;

            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, signedBuffer, ext ) signedBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, validateBuffer, ext ) validateBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getChecksum, ext ) getChecksum_mock ( &selectionManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getBallots, ext ) getBallots_mock ( &selectionManager );

            getChecksum_mock
            .expects ( MOCKPP_NS::once() );

            signedBuffer_mock.stubs()
            .will ( MOCKPP_NS::returnValue ( true ) );

            validateBuffer_mock.stubs()
            .will ( MOCKPP_NS::returnValue ( true ) );

            getBallots_mock
            .expects ( MOCKPP_NS::once() );

            resultOne = Smartmatic::SAES::Voting::Vote::VoteOptimized::voteToSizeOptimized ( vote, buffer, &selectionManager, &signedManager );
            resultTwo = Smartmatic::SAES::Voting::Vote::VoteOptimized::sizeOptimizedToVote ( buffer, vote2, &selectionManager, &signedManager );

            CPPUNIT_ASSERT ( true == resultOne );
            CPPUNIT_ASSERT ( true == resultTwo );

            CPPUNIT_ASSERT ( code == vote2->getCode() );
            CPPUNIT_ASSERT ( lvg == vote2->getLogicalVoterGroup() );
            CPPUNIT_ASSERT ( vdc == vote2->getVotingDeviceCode() );
            CPPUNIT_ASSERT ( mode == vote2->getMode() );
            CPPUNIT_ASSERT ( bid == vote2->getBallotID() );
            CPPUNIT_ASSERT ( sid == vote2->getSessionID() );

            selectionManager.verify();
        }

        void testRegretionSizeOptimizedWithSelection()
        {
            MockVoteOptimizedSelection selectionManager;
            MockVoteOptimizedSigned signedManager;

            Smartmatic::System::SafeBuffer buffer;
            std::string contestCode = "cx";

            Smartmatic::SAES::Voting::Vote::Selection s;
            s.setContest ( contestCode );

            vote->getSelections().push_back ( s );

            bool resultOne;
            bool resultTwo;

            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, signedBuffer, ext ) signedBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSigned, validateBuffer, ext ) validateBuffer_mock ( &signedManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getChecksum, ext ) getChecksum_mock ( &selectionManager );
            MOCKPP_CHAINER_FOR_EXT ( MockVoteOptimizedSelection, getBallots, ext ) getBallots_mock ( &selectionManager );

            getChecksum_mock
            .expects ( MOCKPP_NS::once() );

            getBallots_mock
            .expects ( MOCKPP_NS::once() );

            signedBuffer_mock.stubs()
            .will ( MOCKPP_NS::returnValue ( true ) );

            validateBuffer_mock.stubs()
            .will ( MOCKPP_NS::returnValue ( true ) );

            Smartmatic::SAES::Voting::Vote::Selection::BSequence seq;
            seq.push_back ( "abcd" );

            resultOne = Smartmatic::SAES::Voting::Vote::VoteOptimized::voteToSizeOptimized ( vote, buffer, &selectionManager, &signedManager );
            resultTwo = Smartmatic::SAES::Voting::Vote::VoteOptimized::sizeOptimizedToVote ( buffer, vote2, &selectionManager, &signedManager );

            CPPUNIT_ASSERT ( true == resultOne );
            CPPUNIT_ASSERT ( true == resultTwo );

            selectionManager.verify();
        }

        CPPUNIT_TEST_SUITE ( VoteOptimizedTest );
        CPPUNIT_TEST ( testVoteToSizeOptimizedIfVoteNULL );
        CPPUNIT_TEST ( testVoteToSizeOptimizedIfFailSigned );
        CPPUNIT_TEST ( testVoteToSizeOptimized );
        CPPUNIT_TEST ( testVoteToSizeOptimizedCallSignedNotSelection );
        CPPUNIT_TEST ( testVoteToSizeOptimizedCallSignedAndChecksumWithSelection );
        CPPUNIT_TEST ( testRegretionSizeOptimized );
        CPPUNIT_TEST ( testRegretionSizeOptimizedValidateFail );
        CPPUNIT_TEST ( testRegretionSizeOptimizedCheckValues );
        CPPUNIT_TEST ( testRegretionSizeOptimizedWithSelection );
        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_VOTE_OPTIMIZED_TEST */
