/**
 * @file GlobalPlatformModeGP211.cxx
 * @brief The global platform connection mode: GP_211
 * @author Yadickson Soto
 * @date 20/05/2014
 */

#include <Configuration/SmartcardConfigurationManager.hxx>
#include <Card/GlobalPlatformModeGP211.hxx>

using namespace Smartmatic::SAES::Card;
using namespace Smartmatic::SAES::Common::Configuration;

GlobalPlatformModeGP211::GlobalPlatformModeGP211 ( OPGP_CARD_INFO & cardInfo, OPGP_CARD_CONTEXT & cardContext )
    : GlobalPlatformMode ( cardInfo, cardContext )
{
    if ( !secureChannelEnabled )
    {
        securityLevel = 0x00;
        securityChannelProtocol = 0x00;
        securityChannelProtocolImpl = 0x00;
    }
    else
    {
        switch ( SmartcardConfigurationManager::getInstance()->getSecurityChannelProtocol() )
        {
            default:
            case SecurityChannelProtocol::CONFIGURATION_SCP01:
                securityChannelProtocol = GP211_SCP01;
                break;

            case SecurityChannelProtocol::CONFIGURATION_SCP02:
                securityChannelProtocol = GP211_SCP02;
                break;
        }

        switch ( SmartcardConfigurationManager::getInstance()->getSecurityChannelProtocolImpl() )
        {
            default:
            case SecurityChannelProtocolImpl::CONFIGURATION_SCP01_IMPL_I05:
                securityChannelProtocolImpl = GP211_SCP01_IMPL_i05;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP01_IMPL_I15:
                securityChannelProtocolImpl = GP211_SCP01_IMPL_i15;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I04:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i04;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I05:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i05;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I0A:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i0A;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I0B:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i0B;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I14:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i14;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I15:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i15;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I1A:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i1A;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I1B:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i1B;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I44:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i44;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I45:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i45;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I54:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i54;
                break;

            case SecurityChannelProtocolImpl::CONFIGURATION_SCP02_IMPL_I55:
                securityChannelProtocolImpl = GP211_SCP02_IMPL_i55;
                break;
        }

        switch ( SmartcardConfigurationManager::getInstance()->getSecurityLevel() )
        {
            default:
            case SecurityLevel::CONFIGURATION_C_MAC:
                securityLevel = ( securityChannelProtocol == GP211_SCP01 ? GP211_SCP01_SECURITY_LEVEL_C_MAC : GP211_SCP02_SECURITY_LEVEL_C_MAC );
                break;

            case SecurityLevel::CONFIGURATION_C_DEC_C_MAC:
                securityLevel = ( securityChannelProtocol == GP211_SCP01 ? GP211_SCP01_SECURITY_LEVEL_C_DEC_C_MAC : GP211_SCP02_SECURITY_LEVEL_C_DEC_C_MAC );
                break;

            case SecurityLevel::CONFIGURATION_R_MAC:
                securityLevel = GP211_SCP02_SECURITY_LEVEL_R_MAC;
                break;

            case SecurityLevel::CONFIGURATION_C_MAC_R_MAC:
                securityLevel = GP211_SCP02_SECURITY_LEVEL_C_MAC_R_MAC;
                break;

            case SecurityLevel::CONFIGURATION_C_DEC_C_MAC_R_MAC:
                securityLevel = GP211_SCP02_SECURITY_LEVEL_C_DEC_C_MAC_R_MAC;
                break;
        }
    }
}

GlobalPlatformModeGP211::~GlobalPlatformModeGP211()
{

}

OPGP_ERROR_STATUS GlobalPlatformModeGP211::setupSecureChannel()
{
    return GP211_mutual_authentication (
               cardContext,
               cardInfo,
               getSecurityKey(),
               getSecurityKey(),
               getSecurityKey(),
               getSecurityKey(),
               keySetVersion,
               keyIndex,
               securityChannelProtocol,
               securityChannelProtocolImpl,
               securityLevel,
               keyDerivation,
               &securityInfo );
}

OPGP_ERROR_STATUS GlobalPlatformModeGP211::processCommand ( const Smartmatic::System::SafeBuffer & command, unsigned char * response, unsigned long & length )
{
    return GP211_send_APDU ( cardContext, cardInfo,
                             ( !secureChannelEnabled ? NULL : & securityInfo ),
                             ( unsigned char * ) command.GetData(),
                             command.GetSize(),
                             response,
                             &length );
}

unsigned int GlobalPlatformModeGP211::getPlatformMode()
{
    return GP_211;
}
