/**
 * @file GlobalPlatformModeOP201.cxx
 * @brief The global platform connection mode: OP_201
 * @author Yadickson Soto
 * @date 20/05/2014
 */

#include <Card/GlobalPlatformModeOP201.hxx>

using namespace Smartmatic::SAES::Card;

GlobalPlatformModeOP201::GlobalPlatformModeOP201 ( OPGP_CARD_INFO & cardInfo, OPGP_CARD_CONTEXT & cardContext )
    : GlobalPlatformMode ( cardInfo, cardContext )
{

}

GlobalPlatformModeOP201::~GlobalPlatformModeOP201()
{

}

OPGP_ERROR_STATUS GlobalPlatformModeOP201::setupSecureChannel()
{
    return OP201_mutual_authentication (
               cardContext,
               cardInfo,
               getSecurityKey(),
               getSecurityKey(),
               getSecurityKey(),
               getSecurityKey(),
               keySetVersion,
               keyIndex,
               0,
               keyDerivation,
               &securityInfo );
}

OPGP_ERROR_STATUS GlobalPlatformModeOP201::processCommand ( const Smartmatic::System::SafeBuffer & command, unsigned char * response, unsigned long & length )
{
    return OP201_send_APDU ( cardContext, cardInfo,
                             ( !secureChannelEnabled ? NULL : & securityInfo ),
                             ( unsigned char * ) command.GetData(),
                             command.GetSize(),
                             response,
                             &length );
}

unsigned int GlobalPlatformModeOP201::getPlatformMode()
{
    return OP_201;
}
