/**
 * @file GlobalPlatformModeOP201.hxx
 * @brief The global platform connection mode: OP_201
 * @author Yadickson Soto
 * @date 20/05/2014
 */

#ifndef GLOBALPLATFORMMODEOP201_HXX_
#define GLOBALPLATFORMMODEOP201_HXX_

#include <Card/GlobalPlatformMode.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Card
        {
            /**
             * @class GlobalPlatformModeOP201
             * @brief The global platform connection mode: OP_201
             * @author Yadickson Soto
             * @date 20/05/2014
             */
            class GlobalPlatformModeOP201 : public GlobalPlatformMode
            {
                public:

                    /**
                     * @fn GlobalPlatformModeOP201();
                     * @brief Class constructor.
                     * @author Yadickson Soto
                     * @date 05/06/2014
                     * @param cardInfo Information describing the card
                     * @param cardContext Context for the card
                     */
                    GlobalPlatformModeOP201 ( OPGP_CARD_INFO & cardInfo, OPGP_CARD_CONTEXT & cardContext );

                    /**
                     * @fn virtual ~GlobalPlatformModeOP201();
                     * @brief Class destructor.
                     * @author Yadickson Soto
                     * @date 05/06/2014
                     */
                    virtual ~GlobalPlatformModeOP201();

                    /**
                     * @fn virtual unsigned int getPlatformMode() = 0;
                     * @brief Gets the platform mode value.
                     * @author Yadickson Soto
                     * @date 05/06/2014
                     * @return The platform mode value
                     */
                    virtual unsigned int getPlatformMode();

                protected:

                    /**
                     * @fn virtual OPGP_ERROR_STATUS setupSecureChannel();
                     * @brief Implements the mutual authentication.
                     * @author Yadickson Soto
                     * @date 05/06/2014
                     * @return result status code
                     */
                    virtual OPGP_ERROR_STATUS setupSecureChannel();

                    /**
                     * @fn virtual OPGP_ERROR_STATUS processCommand ( const Smartmatic::System::SafeBuffer & command, unsigned char * response, unsigned long & length );
                     * @brief Sends a command to the card reader and gets the response. Platform-mode specific implementation.
                     * @author Yadickson Soto
                     * @date 05/06/2014
                     * @param command Command sent by the reader to the card.
                     * @param response buffer for the response
                     * @param length response buffer length
                     * @return result status code
                     */
                    virtual OPGP_ERROR_STATUS processCommand ( const Smartmatic::System::SafeBuffer & command, unsigned char * response, unsigned long & length );

                private:

                    OP201_SECURITY_INFO securityInfo; ///< The first security information
            };

        } /* namespace Card */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* GLOBALPLATFORMMODEOP201_HXX_ */
