/**
 * @file SmartcardCodeManager.cxx
 * @brief Body class to save error code from smartcard reader
 * @date 10/01/2014
 * @author Yadickson Soto
 */

#include "SmartcardCodeManager.hxx"
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::SAES::Card;
using namespace Smartmatic::System::Utils;

SmartcardCodeManager * SmartcardCodeManager::instance = NULL;

SmartcardCodeManager::SmartcardCodeManager()
{
    stop();
}

SmartcardCodeManager::~SmartcardCodeManager()
{
    instance = NULL;
}

void SmartcardCodeManager::start()
{
    saveProcess = true;
}

void SmartcardCodeManager::add ( unsigned long code )
{
    if ( saveProcess )
    {
        codes.push_back ( "D" + StringUtils::toHexString ( code, "", 8 ) );
    }
}

const std::list < std::string > & SmartcardCodeManager::getCodes() const
{
    return codes;
}

void SmartcardCodeManager::clear()
{
    codes.clear();
}

void SmartcardCodeManager::stop()
{
    saveProcess = false;
}

SmartcardCodeManager * SmartcardCodeManager::getInstance()
{
    if ( instance == NULL )
    {
        instance = new SmartcardCodeManager();
    }

    return instance;
}
