/**
 * @file	SmartcardFactory.cxx
 * @brief	Implementation of the smartcard reader factory
 * @author	Yadickson Soto
 * @date	28/05/2014
 */

#include "SmartcardFactory.hxx"
#include <System/Utils/StringUtils.hxx>
#include <Configuration/SmartcardConfigurationManager.hxx>
#include <Card/JavaCardOperations.hxx>
#include <Card/GlobalPlatformConnectionBehavior.hxx>
#include <Card/Smartcard.hxx>
#include <Card/SimulatorSmartcard.hxx>
#include <Card/ISmartcardReaderPowerManager.hxx>

using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::SAES::Card;
using namespace Smartmatic::SAES::Security;
using namespace Smartmatic::System;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::System::Utils;

SmartcardInterface * SmartcardFactory::getSmartcard(ISmartcardReaderPowerManager* powerManager)
{
    if ( SmartcardConfigurationManager::getInstance()->simulationEnabled() )
    {
        delete powerManager;
        return getSimulatorSmartcard();
    }
    else
    {
        return getGlobalPlatformSmartcard(powerManager);
    }
}

SmartcardInterface * SmartcardFactory::getGlobalPlatformSmartcard(ISmartcardReaderPowerManager* powerManager)
{
    unsigned int numberOfTriesToRead = SmartcardConfigurationManager::getInstance()->getNumberOfTriesToRead();

    std::string aid;
    std::string pin;

    aid = SmartcardConfigurationManager::getInstance()->getAppletID();
    pin = SmartcardConfigurationManager::getInstance()->getGlobalPIN();

    SafeBuffer appletID;
    SafeBuffer globalPIN;

    StringUtils::stringToBufferHex ( aid, appletID );
    StringUtils::stringToBufferHex ( pin, globalPIN );

    ConnectionBehavior * connectionBehavior = new GlobalPlatformConnectionBehavior ( numberOfTriesToRead, NULL, powerManager );
    JavaCardOperations * operations = new JavaCardOperations ( connectionBehavior );

    return new Smartcard ( connectionBehavior, operations, appletID, globalPIN );
}

SmartcardInterface * SmartcardFactory::getSimulatorSmartcard()
{
    std::string eventFile = SmartcardConfigurationManager::getInstance()->getSimulatorEventFile();
    std::string contentFile = SmartcardConfigurationManager::getInstance()->getSimulatorContentFile();
    unsigned int timeAfterRead = SmartcardConfigurationManager::getInstance()->getSimulationTimeAfterReadContentFile();
    unsigned int timeBeforeWrite = SmartcardConfigurationManager::getInstance()->getSimulationTimeBeforeWriteContentFile();

    return new SimulatorSmartcard ( eventFile, contentFile, timeAfterRead, timeBeforeWrite );
}
