/**
 * @file	SmartcardFactory.hxx
 * @brief	Declaration of the smartcard reader factory
 * @author	Yadickson Soto
 * @date	28/05/2014
 */

#ifndef _SMARTCARD_FACTORY_HXX_
#define _SMARTCARD_FACTORY_HXX_

#include <Card/SmartcardInterface.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Card
        {
            class ISmartcardReaderPowerManager;

            /**
             * @class	SmartcardFactory
             * @brief	Smartcard Reader factory
             * @author	Yadickson Soto
             * @date	28/05/2014
             */
            class SmartcardFactory
            {
                public:

                    /**
                     * @fn     static SmartcardInterface * getSmartcard();
                     * @brief  Gets a properly configured smartcard.
                     * @author Yadickson Soto
                     * @date   30/05/2014
                     * @param  powerManager The power manager to use. Ownership of the object is transferred.
                     * @return An smartcard instance.
                     */
                    static SmartcardInterface * getSmartcard(ISmartcardReaderPowerManager* powerManager = NULL);

                private:

                    /**
                     * @fn	static SmartcardInterface * getGlobalPlatformSmartcard();
                     * @brief	Gets a Global Platform Smartcard reader.
                     * @author	Yadickson Soto
                     * @date	28/05/2014
                     * @return smartcard instance
                     */
                    static SmartcardInterface * getGlobalPlatformSmartcard(ISmartcardReaderPowerManager* powerManager);

                    /**
                     * @fn	static SmartcardInterface * getSimulatorSmartcard();
                     * @brief	Gets a Simulator Smartcard reader.
                     * @author	Yadickson Soto
                     * @date	13/05/2015
                     * @return smartcard instance
                     */
                    static SmartcardInterface * getSimulatorSmartcard();
            };
        }
    }
}

#endif /* _SMARTCARD_FACTORY_HXX_ */
