/**
 * @file	saes-common-language-controller.h
 * @brief	Declares the saes common language controller class.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#ifndef _SAES_COMMON_LANGUAGE_CONTROLLER_H_
#define _SAES_COMMON_LANGUAGE_CONTROLLER_H_

#include "Environment/Configurations/BaseLanguageConfiguration.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace Common
        {
            namespace Configuration
            {
                /**
                 * @class	SAESCommonLanguageController
                 * @brief	Saes common language controller.
                 * @author	Cesar.bonilla
                 * @date	4/28/2011
                 */
                class SAESCommonLanguageController: public Smartmatic::Environment::BaseLanguageConfiguration
                {
                    public:

                        /**
                         * @fn	std::string SAESCommonLanguageController::getPackageName();
                         * @brief	Gets the package name.
                         * @author	Cesar.bonilla
                         * @date	4/28/2011
                         * @return	The package name.
                         */
                        std::string getPackageName();

                        /**
                         * @fn	std::string SAESCommonLanguageController::getLocaleDir();
                         * @brief	Gets the locale dir.
                         * @author	Cesar.bonilla
                         * @date	4/28/2011
                         * @return	The locale dir.
                         */
                        std::string getLocaleDir();

                        /**
                         * @fn	SAESCommonLanguageController::SAESCommonLanguageController();
                         * @brief	Default constructor initializes an instance of the SAESCommonLanguageController class.
                         * @author	Cesar.bonilla
                         * @date	4/28/2011
                         */
                        SAESCommonLanguageController();

                        /**
                         * @fn	virtual SAESCommonLanguageController::~SAESCommonLanguageController();
                         * @brief	Finalizes the instance of the SAESCommonLanguageController class.
                         * @author	Cesar.bonilla
                         * @date	4/28/2011
                         */
                        virtual ~SAESCommonLanguageController();
                };
            }
        }
    }
}

#endif // _SAES_COMMON_LANGUAGE_CONTROLLER_H_
