/**
 * @file	CheckCODIResourceFiles.cxx
 * @brief	Implementation of the class that contains the verification of signature the resources.
 * @author	Yadickson Soto
 * @date	31/05/2013
 */

#include "CheckCODIResourceFiles.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Security/XmlSecResource.hxx>
#include <Configuration/s-a-e-s-common-conf-manager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation::Initiator;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Security;
using namespace Smartmatic::SAES::Common::Configuration;

ISMTTLog * CheckCODIResourceFiles::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Initiator.CheckCODIResourceFiles", GETTEXT_PACKAGE );

CheckCODIResourceFiles::CheckCODIResourceFiles ( Smartmatic::SAES::Common::Configuration::BasePathType type )
    : ICheckCondition ( N_ ( "Smartmatic.SAES.Operation.Initiator.CheckResourceFiles.CheckResourceFiles" ) )
{
    this->type = type;
}

CheckCODIResourceFiles::~CheckCODIResourceFiles()
{
}

TestStatus::Tests CheckCODIResourceFiles::check()
{
    bool success = true;
#if 0
    if ( SAESCommonConfigurationManager::getInstance()->getSecurityConfiguration().getVerifyCODIFolder() )
    {

        logger->Debug ( "Check CODI resource files in " + type );

        try
        {
            Smartmatic::SAES::Runtime::Environment::SaesDirectories directories;

            std::string path = directories.getCodiFilesFolderFullPath ( type );
            std::string file = directories.getSignatureCODIFileFullPath ( type );

            logger->Debug ( path + " " + file );

            success = XmlSecResource::getInstance()->validateResource ( path, file,
                      Smartmatic::SAES::Security::Encryption::INSTALL_FILE,
                      Smartmatic::SAES::Common::Configuration::KeyType::CONFIGURATION_SECURITY_KEY );
        }
        catch ( ... )
        {
            success = false;
        }

        std::string line = "CheckCODIResourceFiles result = ";
        logger->Debug ( line.append ( success ? "Success" : "Failed" ) );

        if ( !success )
        {
            logger->Audit ( N_ ( "Smartmatic.SAES.Operation.Initiator.CheckCODIResourceFiles.ErrorCheckSAESFolder" ) );
        }
    }
#endif
    return ( success ? TestStatus::Passed : TestStatus::Failed );
}
