/**
 * @file   CheckEmlResourceFiles.hxx
 * @brief  Declaration of CheckEmlResourceFiles class.
 * @author manuel.arguelles
 * @date   Feb  7, 2018
 */

#ifndef CHECK_EML_RESOURCE_FILES
#define CHECK_EML_RESOURCE_FILES

#include "ICheckCondition.hxx"
#include <Configuration/SaesCommonConfiguration-schema.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {

                /**
                 * @class  CheckEmlResourceFiles
                 * @brief  Checks the presence and validity of the EML files.
                 * @author manuel.arguelles
                 * @date   Feb  7, 2018
                 */
                class CheckEmlResourceFiles : public ICheckCondition
                {
                    public:

                        /**
                         * @brief  Creates an instance of the class.
                         * @author manuel.arguelles
                         * @date   Feb  7, 2018
                         * @param  type The base path type.
                         */
                        explicit CheckEmlResourceFiles(SAES::Common::Configuration::BasePathType type = \
                                                       SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM);

                        /**
                         * @brief  Destroys an instance of the class.
                         * @author manuel.arguelles
                         * @date   Feb  7, 2018
                         */
                        virtual ~CheckEmlResourceFiles();

                    public:

                        /**
                         * @brief  Checks the presence and validation of the EML files.
                         * @author manuel.arguelles
                         * @date   Feb  7, 2018
                         */
                        virtual TestStatus::Tests check();

                    private:

                        SAES::Common::Configuration::BasePathType m_type;
                        static Smartmatic::Log::ISMTTLog*         m_logger;
                };

            } /* namespace Initiator */
        } /* namespace Operation */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* CHECK_EML_RESOURCE_FILES */

