/**
 * @file CheckForMemoryComplete.cpp
 * @brief Implementation of the class that contains the file verifications such as ElectionStatus,
 *  IncidentReport ,Statistics and others.
 * @date 23/05/2011
 * @author Yadickson Soto
 */

#include "CheckForMemoryComplete.h"
#include <System/IO/File.h>
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation::Initiator;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::Log;

ISMTTLog * CheckForMemoryCompleteCondition::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Initiator.CheckForMemoryCompleteCondition", GETTEXT_PACKAGE );

CheckForMemoryCompleteCondition::CheckForMemoryCompleteCondition (
    Smartmatic::SAES::Runtime::Environment::SaesDirectories * directories,
    Smartmatic::SAES::Common::Configuration::BasePathType type ) :
    ICheckCondition ( N_ ( "Smartmatic.SAES.Operation.Initiator.CheckForMemoryCompleteCondition.CheckingMemoryCompleteCondition" ) )
{
    this->directories = directories;
    this->type = type;
}

CheckForMemoryCompleteCondition::~CheckForMemoryCompleteCondition()
{
}

TestStatus::Tests CheckForMemoryCompleteCondition::check()
{
    bool checkElectionStatusFile = File::getInstance()->canOpenFile ( directories->getElectionStatusFileFullPath ( type ) );
    bool checkActivatedCardStatisticFile = File::getInstance()->canOpenFile ( directories->getActivatedCardStatisticsFileFullPath ( type ) );
    bool checkMachineId = File::getInstance()->canOpenFile ( directories->getBackupFileFullPath ( type ) );

    logger->Debug ( "checkElectionStatusFile " + std::string ( checkElectionStatusFile ? "success" : "fail" ) + " in " + type );
    logger->Debug ( "checkActivatedCardStatisticFile " + std::string ( checkActivatedCardStatisticFile ? "success" : "fail" ) + " in " + type );
    logger->Debug ( "checkMachineId " + std::string ( checkMachineId ? "success" : "fail" ) + " in " + type );

    bool validate = checkElectionStatusFile &&
                    checkActivatedCardStatisticFile &&
                    checkMachineId;

    return validate ? TestStatus::Passed : TestStatus::Failed;
}
