/**
 * @file	CheckForUsedMemory.cpp
 * @brief	Declaration of the class that contains the file verifications such as ElectionStatus,
 * IncidentReport ,Statistics and others.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */


#include "CheckForUsedMemory.h"
#include <System/IO/File.h>
#include <System/IO/Directory.h>
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation::Initiator;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::Log;

ISMTTLog * CheckForUsedMemoryCondition::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Initiator.CheckForUsedMemoryCondition", GETTEXT_PACKAGE );

CheckForUsedMemoryCondition::CheckForUsedMemoryCondition (
    Smartmatic::SAES::Runtime::Environment::SaesDirectories * directories,
    Smartmatic::SAES::Common::Configuration::BasePathType type ) :
    ICheckCondition ( N_ ( "Smartmatic.SAES.Operation.Initiator.CheckForUsedMemoryCondition.CheckingCheckForUsedMemoryCondition" ) )
{
    this->directories = directories;
    this->type = type;
}

CheckForUsedMemoryCondition::~CheckForUsedMemoryCondition()
{
}

TestStatus::Tests CheckForUsedMemoryCondition::check()
{
    SaesDirectories directories;
    bool checkElectionStatusFile = File::getInstance()->canOpenFile ( directories.getElectionStatusFileFullPath ( type ) );
    bool checkActivatedCardStatisticFile = File::getInstance()->canOpenFile ( directories.getActivatedCardStatisticsFileFullPath ( type ) );
    bool checkMachineId = File::getInstance()->canOpenFile ( directories.getBackupFileFullPath ( type ) );
    std::vector<std::string> votes;

    Directory::getInstance()->GetFiles(directories.getVotesFolderFullPath(type), votes);
    bool checkVotesPresence = !votes.empty();

    logger->Debug ( "checkElectionStatusFile " + std::string ( checkElectionStatusFile ? "success" : "fail" ) + " in " + type );
    logger->Debug ( "checkActivatedCardStatisticFile " + std::string ( checkActivatedCardStatisticFile ? "success" : "fail" ) + " in " + type );
    logger->Debug ( "checkMachineId " + std::string ( checkMachineId ? "success" : "fail" ) + " in " + type );
    logger->Debug ( "checkVotesPresence " + std::string ( checkVotesPresence ? "present" : "no votes" ) + " in " + type);

    bool validate = checkElectionStatusFile ||
                    checkActivatedCardStatisticFile ||
                    checkMachineId ||
                    checkVotesPresence;

    return validate ? TestStatus::Passed : TestStatus::Failed;
}
