/**
 * @file	CheckSAESResourceFiles.hxx
 * @brief	Declaration of the class that contains the verify authenticity  for <tt>SAES</tt> directory.
 * @author	Yadickson Soto
 * @date	31/10/2012
 */

#ifndef _CHECK_SAES_RESOURCE_FILES_H_
#define _CHECK_SAES_RESOURCE_FILES_H_

#include "ICheckCondition.hxx"
#include <Configuration/SaesCommonConfiguration-schema.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {
                /**
                 * @class	CheckSAESResourceFiles
                 * @brief	Class validator to analyze the authenticity for <tt>SAES</tt> directory.
                 * @author	Yadickson Soto
                 * @date	03-03-2011
                 */
                class CheckSAESResourceFiles: public ICheckCondition
                {
                    public:
                        /**
                         * @fn	CheckSAESResourceFiles::CheckSAESResourceFiles(
                         * 			Smartmatic::SAES::Common::Configuration::BasePathType type =
                        			Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM);
                         * @brief	Default constructor initializes an instance of the CheckSAESResourceFiles class.
                         * @author	Yadickson Soto
                         * @date	31/10/2012
                         * @param	type	(optional) The type is the selection of the primary hierarchy which contains the file resources.
                         */
                        explicit CheckSAESResourceFiles ( Smartmatic::SAES::Common::Configuration::BasePathType type =
                                                          Smartmatic::SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM );

                        /**
                         * @fn	virtual CheckSAESResourceFiles::~CheckSAESResourceFiles();
                         * @brief	Finalizes the instance of the CheckSAESResourceFiles class.
                         * @author	Yadickson Soto
                         * @date	31/10/2012
                         */
                        virtual ~CheckSAESResourceFiles();

                        /**
                         * @fn	virtual TestStatus::Tests CheckSAESResourceFiles::check ();
                         * @brief Checks the authenticity the <tt>SAES</tt> directory against the security keys.
                         * @author	Yadickson Soto
                         * @date	31/10/2012
                         * @return <tt>TestStatus::Passed</tt> if checks successful; otherwise <tt>TestStatus::Failed</tt>.
                         */
                        virtual TestStatus::Tests check ();

                    private:

                        Smartmatic::SAES::Common::Configuration::BasePathType type; ///< The base selection of the primary hierarchy.
                        static Smartmatic::Log::ISMTTLog * logger; /**< The reference pointer of a logger instance.*/
                };
            }
        }
    }
}

#endif // _CHECK_SAES_RESOURCE_FILES_H_
