/**
 * @file   CheckSaesLocalResourceFiles.hxx
 * @brief  Declaration of CheckSaesLocalResourceFiles class.
 * @author manuel.arguelles
 * @date   Mar 23, 2018
 */

#ifndef CHECK_SAES_LOCAL_RESOURCE_FILES_HXX
#define CHECK_SAES_LOCAL_RESOURCE_FILES_HXX

#include "ICheckCondition.hxx"
#include <Configuration/SaesCommonConfiguration-schema.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {

                /**
                 * @class  CheckSaesLocalResourceFiles
                 * @brief  Checks the SAESLocal folder and files.
                 * @author manuel.arguelles
                 * @date   Mar 23, 2018
                 */
                class CheckSaesLocalResourceFiles : public ICheckCondition
                {
                    public:

                        /**
                         * @brief  Creates an instance of the class.
                         * @author manuel.arguelles
                         * @date   Mar 23, 2018
                         * @param  type The base path type.
                         */
                        explicit CheckSaesLocalResourceFiles(SAES::Common::Configuration::BasePathType type = \
                                                             SAES::Common::Configuration::BasePathType::CONFIGURATION_DOM);

                        /**
                         * @brief  Destroys an instance of the class.
                         * @author manuel.arguelles
                         * @date   Mar 23, 2018
                         */
                        virtual ~CheckSaesLocalResourceFiles();

                    public:

                        /**
                         * @brief  Checks the presence and validation of the SAESLocal files.
                         * @author manuel.arguelles
                         * @date   Mar 23, 2018
                         */
                        virtual TestStatus::Tests check();

                    private:

                        SAES::Common::Configuration::BasePathType m_type;
                        static Smartmatic::Log::ISMTTLog*         m_logger;
                };

            } /* namespace Initiator */
        } /* namespace Operation */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* CHECK_SAES_LOCAL_RESOURCE_FILES_HXX */
