/**
 * @file	DeviceMonitorFactory.hxx
 * @brief	Declaration of the monitor of devices factory
 * @author	Yadickson Soto
 * @date	21/05/2015
 */

#ifndef _DEVICE_MONITOR_FACTORY_HXX_
#define _DEVICE_MONITOR_FACTORY_HXX_

#include <Operation/Monitor/DeviceMonitorInterface.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Common
        {
            namespace Operation
            {
                namespace Monitor
                {
                    /**
                     * @class	DeviceMonitorFactory
                     * @brief	Monitor factory
                     * @author	Yadickson Soto
                     * @date	21/05/2015
                     */
                    class DeviceMonitorFactory
                    {
                        public:

                            /**
                             * @fn	static DeviceMonitorInterface * getMonitor();
                             * @brief	Gets a properly configured monitor.
                             * @author	Yadickson Soto
                             * @date	21/05/2015
                             * @return monitor instance
                             */
                            static DeviceMonitorInterface * getMonitor();

                        private:

                            /**
                             * @fn	static DeviceMonitorInterface * getSimulatorMonitor();
                             * @brief	Gets a Simulator Monitor reader.
                             * @author	Yadickson Soto
                             * @date	21/05/2015
                             * @return monitor instance
                             */
                            static DeviceMonitorInterface * getUdevMonitor();

                            /**
                             * @fn	static DeviceMonitorInterface * getSimulatorMonitor();
                             * @brief	Gets a Simulator Monitor reader.
                             * @author	Yadickson Soto
                             * @date	21/05/2015
                             * @return monitor instance
                             */
                            static DeviceMonitorInterface * getSimulatorMonitor();
                    };
                }
            }
        }
    }
}

#endif /* _DEVICE_MONITOR_FACTORY_HXX_ */
