/**
 * @file DeviceMonitorInterface.hxx
 * @brief Header for the DeviceMonitorInterface class which interacts with the events of plug, unplug and changes from device.
 * @date 21/05/2015
 * @author Yadickson Soto
 */

#ifndef DEVICE_MONITOR_INTERFACE_HXX_
#define DEVICE_MONITOR_INTERFACE_HXX_

#include <Operation/Monitor/MonitorInfo.hxx>
#include <System/SafeList.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Common
        {
            namespace Operation
            {
                namespace Monitor
                {
                    /**
                     * @class	DeviceMonitorInterface
                     * @brief   class which interacts with the events of plug, unplug and changes from device.
                     * @author	Yadickson Soto
                     * @date	21/05/2015
                     */
                    class DeviceMonitorInterface
                    {
                        public:

                            /**
                             * @brief Class destructor
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             */
                            virtual ~DeviceMonitorInterface() {};

                            /**
                             * @fn virtual bool initialize();
                             * @brief Initializes the daemon establishing the context.
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             * @return true if success
                             */
                            virtual bool initialize() = 0;

                            /**
                             * @fn virtual void dispose();
                             * @brief Dispose the daemon context.
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             */
                            virtual void dispose() = 0;

                            /**
                             * @fn virtual Smartmatic::System::SafeList < MonitorInfo * > searchDevices () = 0;
                             * @brief Method to search all devices
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             * @return list found devices
                             */
                            virtual Smartmatic::System::SafeList < MonitorInfo * > searchDevices () = 0;

                            /**
                             * @fn virtual Smartmatic::System::SafeList < MonitorInfo * > eventDevices() = 0;
                             * @brief Method to search for all devices
                             * @date 21/05/2015
                             * @author Yadickson Soto
                             * @return list event devices
                             */
                            virtual Smartmatic::System::SafeList < MonitorInfo * > eventDevices() = 0;
                    };
                }
            }
        }
    }
}

#endif /* DEVICE_MONITOR_INTERFACE_HXX_ */
