/**
 * @file SimulatorMonitor.cxx
 * @brief Body for the SimulatorMonitor class which interacts with the UDEV daemon.
 * @date 11/12/2012
 * @author Yadickson Soto
 */

#include "SimulatorMonitor.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/IO/File.h>
#include <System/Utils/StringUtils.hxx>
#include <System/Utils/SafeBufferUtils.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System;
using namespace Smartmatic::Log;

ISMTTLog * SimulatorMonitor::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Common.Operation.Monitor.SimulatorMonitor", GETTEXT_PACKAGE );

SimulatorMonitor::SimulatorMonitor ( const std::string & file )
    : file ( file )
{

}

SimulatorMonitor::~SimulatorMonitor()
{
    dispose();
}

bool SimulatorMonitor::initialize()
{
    return File::getInstance()->canOpenFile ( file );
}

void SimulatorMonitor::dispose()
{

}

SafeList < MonitorInfo * > SimulatorMonitor::searchDevices ()
{
    SafeList < MonitorInfo * > resultList;
    SafeBuffer dataFull;

    if ( !File::getInstance()->openFileToBuffer ( file, dataFull ) || dataFull.GetSize() == 0 )
    {
        return resultList;
    }

    SafeBufferUtils util ( dataFull );

    std::vector < SafeBuffer > lines = util.splitByEndLine();
    std::vector < SafeBuffer >::iterator it;

    for ( it = lines.begin();
            it != lines.end();
            ++it )
    {
        std::string line ( ( const char * ) ( *it ).GetData(), ( *it ).GetSize() );


        std::vector < std::string > steps;
        std::vector < std::string >::iterator its;

        StringUtils::splitToVector ( line, ",", steps );

        its = steps.begin();

        bool action = false;

        if ( !steps.empty() )
        {
            action = ( * its ) == "add";
        }

        MonitorInfo * info = new MonitorInfo ( action );

        if ( steps.size() >= 2 )
        {
            ++its;
        }

        for ( ;
                its != steps.end();
                ++its )
        {
            setProperty ( ( *its ), info );
        }

        resultList.push_back ( info );
    }

    return resultList;
}

SafeList < MonitorInfo * > SimulatorMonitor::eventDevices()
{
    return searchDevices ();
}

void SimulatorMonitor::setProperty ( const std::string & buffer, MonitorInfo * info )
{
    std::vector < std::string > property;
    std::vector < std::string >::iterator it;

    StringUtils::splitToVector ( buffer, ":", property );
    it = property.begin();

    if ( property.size() >= 2 )
    {
        std::string name = *it;
        ++it;
        std::string value = *it;

        info->push ( name, value );
    }
}
