/**
 * @file	saes-directories.cc
 * @brief	saes directories class.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */


#include "Runtime/Environment/saes-directories.h"
#include "Runtime/Environment/MemoryPathController.h"

#include <System/IO/Path.h>
#include <stdio.h>

using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::System::IO;

std::string SaesDirectories::getDevicePath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    std::string devicePath;

    switch ( type )
    {
        case BasePathType::CONFIGURATION_DOM:
            devicePath = getDOMMemoryBasePath();
            break;

        case BasePathType::CONFIGURATION_FLASH:
            devicePath = getFlashMemoryBasePath();
            break;

        case BasePathType::CONFIGURATION_BACKUP:
            devicePath = MemoryPathController::getInstance()->getBackupMemoryBasePath();
            break;

        default:
        case BasePathType::CONFIGURATION_LIVE:
            devicePath = MemoryPathController::getInstance()->getLiveFileSystemBasePath();
            break;
    }

    return devicePath;
}

std::string SaesDirectories::getBasePath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDevicePath ( type ), getWorkingDirectoryFolderName() );
}

std::string SaesDirectories::getLocalBasePath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDevicePath ( type ), workingDirectory );
}

std::string SaesDirectories::getWorkingDirectoryFolderName()
{
    return workingDirectory;
}

std::string SaesDirectories::getDOMMemoryBasePath()
{
    return MemoryPathController::getInstance()->getDomMemoryBasePath();
}

std::string SaesDirectories::getFlashMemoryBasePath()
{
    return MemoryPathController::getInstance()->getFlashMemoryBasePath();
}

std::string SaesDirectories::getElectionFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), ElectionFileName ) ;
}

std::string SaesDirectories::getDeviceParametersFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), DeviceParametersFileName ) ;
}

std::string SaesDirectories::getElectionReduceFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), ElectionReduceFileName ) ;
}

std::string SaesDirectories::getElectionStatusFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), ElectionStatusFileName ) ;
}

std::string SaesDirectories::getVotingCentersLocalFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), votingCentersFileName );
}

std::string SaesDirectories::getVotingCentersInstalationFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBaseInstallationPath ( type ), votingCentersFileName );
}

std::string SaesDirectories::getActivatedCardStatisticsFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), ActivatedCardStatisticsFileName ) ;
}

std::string SaesDirectories::getXMLImageFileName()
{
    return XMLImageFileName;
}

std::string SaesDirectories::getElectionResourcesFileName()
{
    return ElectionResourcesFileName ;
}

std::string SaesDirectories::getVotingDeviceFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), VotingDeviceFileName ) ;
}

std::string SaesDirectories::getElectoralResourceFullFolderPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), ElectoralResourcesFolderName ) ;
}

std::string SaesDirectories::getElectoralResourcesFolderName()
{
    return ElectoralResourcesFolderName;
}

std::string SaesDirectories::getElectoralImagesFullFolderPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), ElectoralImageFolderName ) ;
}

std::string SaesDirectories::getLocalElectoralImagesFullFolderPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getLocalSaesDataFolderFullPath ( type ), ElectoralImageFolderName );
}

std::string SaesDirectories::getImageElectoralResource ( std::string imageName )
{
    //get images resources
    return Path::Combine ( getElectoralImagesFullFolderPath() , imageName ) ;
}

std::string SaesDirectories::getElectoralSAESFullFolderPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ) , SaesDataFolderName ) ;
}

std::string SaesDirectories::getTemporaryFilesFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ) , TemporaryFilesFolderName ) ;
}

std::string SaesDirectories::getBaseInstallationPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDevicePath ( type ), projectName );
}

std::string SaesDirectories::getTemporaryFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    std::string filename = tmpnam ( NULL );
    return Path::Combine ( getTemporaryFilesFolderFullPath ( type ), Path::GetFileName ( filename ) ) ;
}

std::string SaesDirectories::getLanguageInstalationFileFullPath ()
{
    return Path::Combine ( getBaseInstallationPath(), languageFileName ) ;
}

std::string SaesDirectories::getLanguageLocalFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), languageFileName ) ;
}

std::string SaesDirectories::getSaesDataFolderName()
{
    return SaesDataFolderName;
}

std::string SaesDirectories::getSaesDataFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), SaesDataFolderName );
}

std::string SaesDirectories::getLocalSaesDataFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getLocalBasePath ( type ), SaesDataFolderName );
}

std::string SaesDirectories::getLanguageImageInstalationDirectoryFullPath ()
{
    return Path::Combine ( getBaseInstallationPath(), languageImageDirectory ) ;
}

std::string SaesDirectories::getLanguageImageDirectoryFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), languageImageDirectory );
}

std::string SaesDirectories::getBackupFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), backupFileName );
}

std::string SaesDirectories::getSecretKeyFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), secretKeyFileName );
}

std::string SaesDirectories::getUPKeyFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), upKeyFileName );
}

std::string SaesDirectories::getX7SSignedKeyCertifiedFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), X7SSignedKeyCertifiedFileName );
}

std::string SaesDirectories::getX7SSignedCertifiedFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), X7SSignedCertifiedFileName );
}

std::string SaesDirectories::getX7SCryptoKeystoreInstallationFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBaseInstallationPath ( type ), X7SCryptoKeystoreFileName );
}

std::string SaesDirectories::getX7SCryptoKeystoreFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), X7SCryptoKeystoreFileName );
}

std::string SaesDirectories::getMachineKeysFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), machineKeysFileName );
}

std::string SaesDirectories::getProjectName()
{
    return projectName;
}

std::string SaesDirectories::getIdHardwareFileFullPath()
{
    return IdHardwareFileFullPath;
}

std::string SaesDirectories::getVotingExperienceValidationFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDevicePath ( type ), votingExperienceValidationFolderName );
}

std::string SaesDirectories::getVotesFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), VotesFolder );
}

std::string SaesDirectories::getDocsFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), DocsFolder );
}

std::string SaesDirectories::getEmlFolderFullPath( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDevicePath ( type ), EmlFolder );
}

std::string SaesDirectories::getEmlTempFolderFullPath()
{
    return EmlTempFolder;
}

std::string SaesDirectories::getPVFormFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDocsFolderFullPath ( type ), PVFormFileName );
}

std::string SaesDirectories::getTransmissionPackagesFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDocsFolderFullPath ( type ), TransmissionPackageFileName );
}

std::string SaesDirectories::getTransmissionPackagesKeyFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDocsFolderFullPath ( type ), TransmissionPackageKeyFileName );
}

std::string SaesDirectories::getTransmissionPackagesCrtFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), TransmissionPackageCrtFileName );
}

std::string SaesDirectories::getTransmissionPackagesHashFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDocsFolderFullPath ( type ), TransmissionPackageHashFileName );
}

std::string SaesDirectories::getIssuerCertificatesFolderFullPath()
{
    return MemoryPathController::getInstance()->getIssuerCertificatesFolderFullPath();
}

std::string SaesDirectories::getRootCACertificateFileFullPath()
{
    return Path::Combine ( getIssuerCertificatesFolderFullPath(), RootCACertificateFileName );
}
std::string SaesDirectories::getIntermediateCACertificateFileFullPath()
{
    return Path::Combine ( getIssuerCertificatesFolderFullPath(), IntermediateCACertificateFileName );
}

std::string SaesDirectories::getPVTemplateFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), PVTemplateFolder );
}

std::string SaesDirectories::getGlobalPVTemplateFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getPVTemplateFolderFullPath ( type ), PVTemplateFileName );
}

std::string SaesDirectories::getTestPVTemplateFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getPVTemplateFolderFullPath ( type ), "PVTest.xslt" );
}

std::string SaesDirectories::getGeneratedPVReportFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDocsFolderFullPath ( type ), GeneratedPVReportFileName );
}

std::string SaesDirectories::getGeneratedPVReportTestFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDocsFolderFullPath ( type ), "PVTest.pdf" );
}

std::string SaesDirectories::getLogFolderName()
{
    return logFolderName;
}

std::string SaesDirectories::getLogFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), getLogFolderName() );
}

std::string SaesDirectories::getLogErrorFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getLogFolderFullPath ( type ), logErrorFileName );
}

std::string SaesDirectories::getLogAuditFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getLogFolderFullPath ( type ), logAuditFileName );
}

std::string SaesDirectories::getVoteStatisticsFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), VoteStatisticsFileName );
}

std::string SaesDirectories::getSignatureResourceFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), SignatureResourceFileName ) ;
}

std::string SaesDirectories::getSignatureRootFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBaseInstallationPath ( type ), SignatureRootFileName ) ;
}

std::string SaesDirectories::getSignatureEmlFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getEmlFilesFolderFullPath ( type ), SignatureEmlFileName ) ;
}

std::string SaesDirectories::getSignatureSaesLocalFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getLocalBasePath ( type ), SignatureSaesLocalFileName );
}

std::string SaesDirectories::getEmlFilesFolderFullPath(Smartmatic::SAES::Common::Configuration::BasePathType type)
{
    return Path::Combine(getDevicePath(type), EmlFilesFolder);
}

std::string SaesDirectories::getDiagnosticResultFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDevicePath ( type ), DiagnosticResultFolder );
}

std::string SaesDirectories::getMachineDateFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDevicePath ( type ), DateDiagnosticFile );
}

std::string SaesDirectories::getZipCodeFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDevicePath ( type ), ZipCodeFileName );
}

std::string SaesDirectories::getStatisticConfigFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), StatisticConfigFileName );
}

std::string SaesDirectories::getWizardConfigFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), WizardConfigFileName );
}

std::string SaesDirectories::getMenuConfigFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), MenuConfigFileName );
}

std::string SaesDirectories::getVotingExperienceConfigFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), VotingExperienceConfigFileName );
}

std::string SaesDirectories::getProcessStatusResultsFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDevicePath ( type ), ProcessStatusResultsFileName );
}

std::string SaesDirectories::getLoginKeyFileName ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), LoginKeyFileName );
}

std::string SaesDirectories::getRecountSecretKeyFileName ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), RecountSecretKeyFileName );
}

std::string SaesDirectories::getRecountUPKeyFileName ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), RecountUPKeyFileName );
}

std::string SaesDirectories::getVotingResultsFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getEmlFolderFullPath ( type ), VotingResultsFileName );
}

std::string SaesDirectories::getCheckListDiagnoseFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getDevicePath ( type ), CheckListDiagnoseFileName );
}

std::string SaesDirectories::getSkipCalibrationToolFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), SkipCalibrationToolFileName );
}

std::string SaesDirectories::getVotingResultsFilePlainFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getEmlFolderFullPath ( type ), VotingResultsFilePlainName );
}

std::string SaesDirectories::getNationalityDefinitionTypeFileFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getBasePath ( type ), NationalityDefinitionTypeFileName );
}

std::string SaesDirectories::getTextToSpeechVoicesFolderFullPath ( Smartmatic::SAES::Common::Configuration::BasePathType type )
{
    return Path::Combine ( getSaesDataFolderFullPath ( type ), TextToSpeechVoicesFolder );
}

std::string SaesDirectories::getElectionAudioResourcesFileName()
{
    return ElectionAudioResourcesFileName;
}

std::string SaesDirectories::getGeneralAudioResourcesFileName()
{
    return GeneralAudioResourcesFileName;
}

SaesDirectories::SaesDirectories()
{
    ConfigurationElectionFilesPath & configElectionFiles ( SAESCommonConfigurationManager::getInstance()->getConfiguration()->getConfigurationElectionFilesPath() );
    ConfigurationBasePath configBasePath = configElectionFiles.getConfigBasePath();
    workingDirectory = configBasePath.getWorkingDirectory();
    languageImageDirectory = configBasePath.getLanguageImageDirectory();
    backupFileName = configBasePath.getBackupFileName();
    projectName = configBasePath.getProjectName();
    votingExperienceValidationFolderName = configBasePath.getVotingExperienceValidationScreensDirectory();
    languageFileName = configElectionFiles.getLanguageFileName();
    votingCentersFileName = configElectionFiles.getVotingCentersFileName();
    SaesDataFolderName = configElectionFiles.getSAESFolder();
    ElectoralResourcesFolderName = configElectionFiles.getResourcesFolder();
    ElectoralImageFolderName = configElectionFiles.getImagesFolder();
    LiveFileSystem = configElectionFiles.getConfigBasePath().getLiveFileSystemBasePath();
    EmlFilesFolder = configElectionFiles.getEmlFilesFolder();
    VotesFolder = configElectionFiles.getVotesFolder();
    DocsFolder = configElectionFiles.getDocsFolder();
    EmlFolder = configElectionFiles.getEmlFolder();
    EmlTempFolder = configElectionFiles.getEmlTempFolder();
    DiagnosticResultFolder = configElectionFiles.getDiagnosticResultFolder();
    DateDiagnosticFile = configElectionFiles.getDateDiagnosticFileName();
    ZipCodeFileName = configElectionFiles.getZipCodeFileName();

    StatisticConfigFileName = configElectionFiles.getStatisticConfigFileName();
    WizardConfigFileName = configElectionFiles.getWizardConfigFileName();
    MenuConfigFileName = configElectionFiles.getMenuConfigFileName();
    VotingExperienceConfigFileName = configElectionFiles.getVotingExperienceConfigFileName();
    ProcessStatusResultsFileName = configElectionFiles.getProcessStatusResultsFileName();

    TransmissionPackageFileName = configElectionFiles.getTransmissionPackageFileName();
    TransmissionPackageHashFileName = configElectionFiles.getTransmissionPackageHashFileName();
    TransmissionPackageKeyFileName = configElectionFiles.getTransmissionPackageKeyFileName();
    TransmissionPackageCrtFileName = configElectionFiles.getTransmissionPackageCrtFileName();
    PVFormFileName = configElectionFiles.getPVFormFileName();
    ElectionFileName = configElectionFiles.getElectionFileName();
    DeviceParametersFileName = configElectionFiles.getDeviceParametersFileName();
    ActivatedCardStatisticsFileName = configElectionFiles.getActivatedCardStatisticsFileName();
    XMLImageFileName = configElectionFiles.getXMLImageFileName();
    ElectionStatusFileName = configElectionFiles.getElectionStatusFileName();
    ElectionResourcesFileName = configElectionFiles.getElectionResourcesFileName();
    IssuerCertificatesFolderName = configElectionFiles.getIssuerCertificatesFolderName();
    RootCACertificateFileName = configElectionFiles.getRootCACertificateFileName();
    IntermediateCACertificateFileName = configElectionFiles.getIntermediateCACertificateFileName();
    VoteStatisticsFileName = configElectionFiles.getVoteStatisticsFileName();
    SignatureResourceFileName = configElectionFiles.getSignatureResourceFileName();
    SignatureRootFileName = configElectionFiles.getSignatureRootFileName();
    SignatureEmlFileName = configElectionFiles.getSignatureEmlFileName();
    SignatureSaesLocalFileName = configElectionFiles.getSignatureSAESLocalFileName();

    VotingDeviceFileName = configElectionFiles.getVotingDeviceFileName();
    secretKeyFileName = configElectionFiles.getSecretKeyFile();
    upKeyFileName = configElectionFiles.getUPKeyFile();
    machineKeysFileName = configElectionFiles.getMachineKeysFile();
    OSConfigurationFiles & osConf ( SAESCommonConfigurationManager::getInstance()->getOSConfigurationFiles() );
    IdHardwareFileFullPath = osConf.getIdHardwareFileFullPath();
    logFolderName = configElectionFiles.getLogsFolderName();
    logErrorFileName = configElectionFiles.getLogErrorFileName();
    logAuditFileName = configElectionFiles.getLogAuditFileName();
    PVTemplateFileName = configElectionFiles.getPVTemplateFileName();
    PVTemplateFolder = configElectionFiles.getPVTemplateFolderName();
    GeneratedPVReportFileName = configElectionFiles.getGeneratedPVReportFileName();
    TemporaryFilesFolderName = "Temp";

    X7SSignedKeyCertifiedFileName = ( configElectionFiles.getX7SSignedKeyCertifiedFileName() != NULL ? configElectionFiles.getX7SSignedKeyCertifiedFileName().get() : "" );
    X7SSignedCertifiedFileName = ( configElectionFiles.getX7SSignedCertifiedFileName() != NULL ? configElectionFiles.getX7SSignedCertifiedFileName().get() : "" );
    X7SCryptoKeystoreFileName = ( configElectionFiles.getX7SCryptoKeystoreFileName() != NULL ? configElectionFiles.getX7SCryptoKeystoreFileName().get() : "" );

    LoginKeyFileName = configElectionFiles.getLoginKeyFileName();
    RecountSecretKeyFileName = configElectionFiles.getRecountSecretKeyFileName();
    RecountUPKeyFileName = configElectionFiles.getRecountUPKeyFileName();

    VotingResultsFileName = configElectionFiles.getVotingResultsFileName();
    CheckListDiagnoseFileName = configElectionFiles.getCheckListDiagnoseFileName();
    VotingResultsFilePlainName = configElectionFiles.getVotingResultsFilePlainName();
    NationalityDefinitionTypeFileName = configElectionFiles.getNationalityDefinitionTypeFileName();

    SkipCalibrationToolFileName = ( configElectionFiles.getSkipCalibrationToolFileName().present() ? configElectionFiles.getSkipCalibrationToolFileName().get() : "skip-calibration-tool" );
    ElectionReduceFileName = ( configElectionFiles.getElectionReduceFileName().present() ? configElectionFiles.getElectionReduceFileName().get() : "election-nc.xml" );

    TextToSpeechVoicesFolder = configElectionFiles.getTextToSpeechVoicesFolder();
    ElectionAudioResourcesFileName = configElectionFiles.getElectionAudioResourcesFileName();
    GeneralAudioResourcesFileName = configElectionFiles.getGeneralAudioResourcesFileName();
}

SaesDirectories::~SaesDirectories()
{
}
