/**
 * @file CryptoData.cxx
 * @brief Implementation of the abstract facade which mediates with crypto to encode and decode data.
 * @date 25/08/2011
 * @author Yadickson Soto
 */

#include "CryptoData.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Security;
using namespace Smartmatic::System;
using namespace Smartmatic::System::Security;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::Log;

ISMTTLog* CryptoData::m_logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Security.CryptoData", GETTEXT_PACKAGE );

CryptoData::CryptoData()
    : m_keySize(Smartmatic::System::Security::Crypto::KEY_AES_256)
    , m_mode(Smartmatic::System::Security::Crypto::MODE_AES_CBC)
{
}

CryptoData::CryptoData ( Smartmatic::System::SafeBuffer & pin, Smartmatic::System::SafeBuffer & key )
    : m_keySize(Smartmatic::System::Security::Crypto::KEY_AES_256)
    , m_mode(Smartmatic::System::Security::Crypto::MODE_AES_CBC)
{
    setPin ( pin );
    setKey ( key );
}

CryptoData::~CryptoData()
{
}

bool CryptoData::crypto ( Smartmatic::System::SafeBuffer & dataIn, Smartmatic::System::SafeBuffer & dataOut )
{
    Crypto objCrypto;
    objCrypto.init ( m_keySize, m_mode, true );

    try
    {
        dataOut.Clear();
        objCrypto.encryptBufferToBufferAndCreateIV ( dataIn, dataOut, m_key.GetData());
        return true;
    }
    catch ( CryptoException & ex )
    {
        m_logger->Debug ( "ERROR - crypto data" );
    }

    return false;
}

bool CryptoData::decrypto ( Smartmatic::System::SafeBuffer & dataIn, Smartmatic::System::SafeBuffer & dataOut )
{
    Crypto objCrypto;
    objCrypto.init ( m_keySize, m_mode, true );

    try
    {
        dataOut.Clear();
        objCrypto.decryptBufferToBufferAndGetIV ( dataIn, dataOut, m_key.GetData() );
        return true;
    }
    catch ( CryptoException & ex )
    {
        m_logger->Debug ( "ERROR - decrypto data" );
    }

    return false;
}

void CryptoData::setPin ( Smartmatic::System::SafeBuffer & pin )
{
    m_pin.Clear();
    m_pin.AddData ( pin );
}

void CryptoData::setKey ( Smartmatic::System::SafeBuffer & key )
{
    m_key.Clear();
    m_key.AddData ( key );
}

const Smartmatic::System::SafeBuffer & CryptoData::getPin()
{
    return m_pin;
}

const Smartmatic::System::SafeBuffer & CryptoData::getKey()
{
    return m_key;
}
