/*
 * Passphrase.cxx
 * @brief Implementation of the singleton entity that provides the cryto passphrase.
 *  Created on: 17/05/2013
 *      Author: soto
 */

#include "Passphrase.hxx"
#include <System/Encoding/Base64Encoder.h>
#include "KeyManager.hxx"

using namespace Smartmatic::SAES::Common::Security;

Passphrase * Passphrase::instance = NULL;

Passphrase::Passphrase()
{

}

Passphrase::~Passphrase()
{
    instance = NULL;
}

void Passphrase::setPlainPassphrase ( const std::string & plainPassphrase )
{
    Smartmatic::System::SafeBuffer buffer ( plainPassphrase );
    Smartmatic::System::Encoding::Base64Encoder::ConvertToBase64 ( buffer, passphrase );
}

std::string Passphrase::getPlainPassphrase()
{
    Smartmatic::System::SafeBuffer buffer;
    Smartmatic::System::Encoding::Base64Encoder::ConvertFromBase64 ( passphrase, buffer );

    std::string plain;
    plain.assign ( ( const char * ) buffer.GetData(), buffer.GetSize() );

    return plain;
}

bool Passphrase::getCryptoPassphrase ( Smartmatic::System::SafeBuffer & bufferOut )
{
    bool validate = false;

    bufferOut.Clear();

    try
    {
        if ( !passphrase.empty() )
        {
            Smartmatic::System::Security::Crypto crypto;
            crypto.init ( KeyManager::getInstance()->getKeySize(), KeyManager::getInstance()->getModeType(), true );

            Smartmatic::System::SafeBuffer pass ( getPlainPassphrase() );
            Smartmatic::System::SafeBuffer key;

            KeyManager::getInstance()->getKey ( Smartmatic::SAES::Common::Configuration::KeyType::CONFIGURATION_INIT_KEY, key );

            crypto.encryptBufferToBufferAndCreateIV ( pass, bufferOut, key.GetData());

            validate = true;
        }
    }
    catch ( Smartmatic::System::Exception::CryptoException & ex )
    {

    }

    return validate;
}

bool Passphrase::getDecryptPassphrase ( Smartmatic::System::SafeBuffer & bufferIn, std::string & pass )
{
    bool validate = false;

    pass.clear();

    try
    {
        Smartmatic::System::Security::Crypto crypto;
        crypto.init ( KeyManager::getInstance()->getKeySize(), KeyManager::getInstance()->getModeType(), true );

        Smartmatic::System::SafeBuffer password;
        Smartmatic::System::SafeBuffer key;

        KeyManager::getInstance()->getKey ( Smartmatic::SAES::Common::Configuration::KeyType::CONFIGURATION_INIT_KEY, key );

        crypto.decryptBufferToBufferAndGetIV ( bufferIn, password, key.GetData() );

        pass.assign ( ( const char * ) password.GetData(), password.GetSize() );

        validate = password.GetSize() > 0;
    }
    catch ( Smartmatic::System::Exception::CryptoException & ex )
    {

    }

    return validate;
}

Passphrase * Passphrase::getInstance()
{
    if ( !instance )
    {
        instance = new Passphrase();
    }

    return instance;
}
