/**
 * @file	XmlSecResource.cxx
 * @brief	Implementation of the singleton entity that validates the security resources.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */


#include "XmlSecResource.hxx"

#include <Log/SMTTLogManager.h>
#include <System/Security/XmlDigitalSignature/XmlDetachedSignature.hxx>
#include <Security/XmlFileSignature.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Security;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::System::Security;

ISMTTLog * XmlSecResource::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Security.XmlSecResource", GETTEXT_PACKAGE );
XmlSecResource * XmlSecResource::instance = NULL;

XmlSecResource::XmlSecResource()
{
}

XmlSecResource::~XmlSecResource()
{
    if ( instance )
    {
        delete instance;
        instance = NULL;
    }
}

bool XmlSecResource::validateResource ( std::string path, std::string signature,
                                        Smartmatic::SAES::Security::Encryption::ResourceFileType type,
                                        Smartmatic::SAES::Common::Configuration::KeyType ukt )
throw ( CryptoException,
        XmlException,
        FileSystemException )
{
    XmlDetachedSignature detachedSignature;

    Smartmatic::System::SafeBuffer buffer;
    Smartmatic::SAES::Security::Encryption::getInstance()->decryptoFileToBuffer (
        signature,
        buffer,
        type,
        ukt );

    logger->Debug ( "Validating file '" + signature + "''s signature certificate." );
    XmlFileSignature xmlFileSignature;
    xmlFileSignature.validateSignatureCertificate(buffer, true);

    logger->Debug ( path + " " + signature );

    return detachedSignature.verify(buffer, NULL, path);
}

XmlSecResource * XmlSecResource::getInstance()
{
    if ( instance == NULL )
    {
        instance = new XmlSecResource();
    }

    return instance;
}
