/**
 * @file	PCSCDManager.hxx
 * @brief	Declaration of PCSCD daemon control tool that executes the action such as: kill, restart, start, etc.
 * @author	Youssef.tourkmani
 * @date	30/10/2012
 */

#ifndef PCSCDMANAGER_HXX_
#define PCSCDMANAGER_HXX_

namespace Smartmatic
{
    namespace SAES
    {
        namespace PCSCD
        {
            /**
             * @class	PCSCDManager
             * @brief	Manager of the PCSCD daemon that provides the operations the start, stop, and others.
             * @author	Youssef.tourkmani
             * @date	30/10/2012
             */
            class PCSCDManager
            {
                public:

                    /**
                     * @fn	static void PCSCDManager::start(bool force = false);
                     * @brief Starts a new process of the pcscd daemon.
                     * @author	Youssef.tourkmani
                     * @date	30/10/2012
                     * @param	force	(optional) the force.
                     */
                    static void start ( bool force = false );
                    /**
                     * @fn	static void PCSCDManager::stop(bool force = false);
                     * @brief	Stops the process of the pcscd daemon.
                     * @author	Youssef.tourkmani
                     * @date	30/10/2012
                     * @param	force	(optional) the force.
                     */
                    static void stop ( bool force = false );
                    /**
                     * @fn	static void PCSCDManager::kill();
                     * @brief	Kills to all process related with name <tt>PCSCD</tt>; Will send the specified signal
                     * (by default SIGTERM) to each process.
                     * @author	Youssef.tourkmani
                     * @date	30/10/2012
                     */
                    static void kill();
                    /**
                     * @fn	static void PCSCDManager::runDebug();
                     * @brief	Runs the daemon with debug mode.
                     * @author	Yadickson Soto
                     * @date	25/02/2013
                     */
                    static void runDebug();
            };
        }
    }

}

#endif /* PCSCDMANAGER_HXX_ */
