#ifndef TEST_SMARTCARD_CODE_MANAGER_TEST
#define TEST_SMARTCARD_CODE_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Card/SmartcardCodeManager.hxx>

class SmartcardCodeManagerTest : public CPPUNIT_NS::TestFixture
{
    private:

        Smartmatic::SAES::Card::SmartcardCodeManager * manager;

    public:

        SmartcardCodeManagerTest ()
        {
            manager = NULL;
        }

        void setUp()
        {
            manager = Smartmatic::SAES::Card::SmartcardCodeManager::getInstance();
        }

        void tearDown()
        {
            if ( manager )
            {
                delete manager;
                manager = NULL;
            }
        }

        void testAddIfNotInitialize()
        {
            manager->add ( 10 );
            CPPUNIT_ASSERT ( true == manager->getCodes().empty() );
        }

        void testAddIfInitialize()
        {
            std::string result;

            manager->start();
            manager->add ( 10 );

            CPPUNIT_ASSERT ( false == manager->getCodes().empty() );
            CPPUNIT_ASSERT ( 1 == manager->getCodes().size() );

            result = * ( manager->getCodes().begin() );

            CPPUNIT_ASSERT ( "D0000000a" == result );
        }

        void testAddTwoCode()
        {
            std::string result;
            std::list < std::string >::const_iterator it;

            manager->start();
            manager->add ( 10 );
            manager->add ( 16 );

            CPPUNIT_ASSERT ( false == manager->getCodes().empty() );
            CPPUNIT_ASSERT ( 2 == manager->getCodes().size() );

            it = manager->getCodes().begin();

            result = * ( it );
            CPPUNIT_ASSERT ( "D0000000a" == result );

            ++it;

            result = * ( it );

            CPPUNIT_ASSERT ( "D00000010" == result );
        }

        void testAddTwoCodeStopBeforeSecond()
        {
            std::string result;
            std::list < std::string >::const_iterator it;

            manager->start();
            manager->add ( 10 );
            manager->stop();
            manager->add ( 16 );

            CPPUNIT_ASSERT ( false == manager->getCodes().empty() );
            CPPUNIT_ASSERT ( 1 == manager->getCodes().size() );

            it = manager->getCodes().begin();

            result = * ( it );
            CPPUNIT_ASSERT ( "D0000000a" == result );
        }

        void testAddTwoCodeClearAfterSecond()
        {
            manager->start();
            manager->add ( 10 );
            manager->add ( 16 );
            manager->clear();

            CPPUNIT_ASSERT ( true == manager->getCodes().empty() );
        }

        CPPUNIT_TEST_SUITE ( SmartcardCodeManagerTest );

        CPPUNIT_TEST ( testAddIfNotInitialize );
        CPPUNIT_TEST ( testAddIfInitialize );
        CPPUNIT_TEST ( testAddTwoCode );
        CPPUNIT_TEST ( testAddTwoCodeStopBeforeSecond );
        CPPUNIT_TEST ( testAddTwoCodeClearAfterSecond );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_SMARTCARD_CODE_MANAGER_TEST */
