/**
 * @file	AlarmConfigurationManager.cxx
 * @brief	Implementation of the alarm configuration manager.
 * @author	Yadickson Soto
 * @date	14/07/2015
 */

#include "AlarmConfigurationManager.hxx"
#include "s-a-e-s-functionality-conf-manager.h"

using namespace Smartmatic::SAES::Functionality::Configuration;

AlarmConfigurationManager * AlarmConfigurationManager::instance = NULL;

AlarmConfigurationManager::AlarmConfigurationManager()
{

}

AlarmConfigurationManager::~AlarmConfigurationManager()
{
    instance = NULL;
}

Alarm::AlarmCommandsSequence AlarmConfigurationManager::getCommandsOfAlarm ( const AlarmEnum & typeOfAlarm )
{
    AlarmsConfiguration::AlarmSequence alarms = getAlarmsConfiguration().getAlarm();
    AlarmsConfiguration::AlarmIterator it;

    Alarm::AlarmCommandsSequence list;

    for ( it = alarms.begin();
            it != alarms.end();
            ++it )
    {
        if ( ( *it ).getTypeOfAlarm() == typeOfAlarm )
        {
            return ( *it ).getAlarmCommands ();
        }
    }

    return list;
}

AlarmCategoryEnum AlarmConfigurationManager::getCategoryOfAlarm ( const AlarmEnum & typeOfAlarm )
{
    AlarmsConfiguration::AlarmSequence alarms = getAlarmsConfiguration().getAlarm();
    AlarmsConfiguration::AlarmIterator it;

    AlarmCategoryEnum alarmCategory ( AlarmCategoryEnum::CONFIGURATION_CRITICALALARM );

    for ( it = alarms.begin();
            it != alarms.end();
            ++it )
    {
        if ( ( *it ).getTypeOfAlarm() == typeOfAlarm )
        {
            return ( *it ).getAlarmCategory();
        }
    }

    return alarmCategory;
}

AlarmBehaviorEnum AlarmConfigurationManager::getBehaviorOfAlarm ( const AlarmEnum & typeOfAlarm )
{
    AlarmsConfiguration::AlarmSequence alarms = getAlarmsConfiguration().getAlarm();
    AlarmsConfiguration::AlarmIterator it;

    AlarmBehaviorEnum alarmBehavior ( AlarmBehaviorEnum::CONFIGURATION_GOAUTHENTICATION );

    for ( it = alarms.begin();
            it != alarms.end();
            ++it )
    {
        if ( ( *it ).getTypeOfAlarm() == typeOfAlarm )
        {
            return ( *it ).getAlarmBehavior();
        }
    }

    return alarmBehavior;
}

AlarmsConfiguration & AlarmConfigurationManager::getAlarmsConfiguration ()
{
    if ( ! SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getAlarmsConfiguration().present() )
    {
        AlarmsConfiguration config;
        SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->setAlarmsConfiguration ( config );
    }

    return SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getAlarmsConfiguration().get();
}

AlarmConfigurationManager * AlarmConfigurationManager::getInstance ( AlarmConfigurationManager * externManager )
{
    if ( ! instance )
    {
        instance = ( externManager == NULL ? new AlarmConfigurationManager() : externManager );
    }

    return instance;
}
