/**
 * @file	PrinterControllerConfigurationManager.hxx
 * @brief	Declaration of the printer controller configuration manager.
 * @author	Yadickson Soto
 * @date	23/04/2014
 */

#ifndef _PRINTER_CONTROLLER_CONFIGURATION_MANAGER_HXX_
#define _PRINTER_CONTROLLER_CONFIGURATION_MANAGER_HXX_

#include <string>
#include <Configuration/printer-controller-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Functionality
        {
            namespace Configuration
            {
                /**
                 * @class	PrinterControllerConfigurationManager
                 * @brief	The printer controller configuration manager.
                 * @author	Yadickson Soto
                 * @date	23/04/2014
                 */
                class PrinterControllerConfigurationManager
                {
                    public:

                        /**
                         * @fn	static PrinterControllerConfigurationManager * getInstance( PrinterControllerConfigurationManager * externManager = NULL );
                         * @brief	Gets the current Smartcard Configuration Manager.
                         * @author	Yadickson Soto
                         * @date	23/04/2014
                         * @param 	externManager external manager to unit test
                         * @return	instance of the class.
                         */
                        static PrinterControllerConfigurationManager * getInstance ( PrinterControllerConfigurationManager * externManager = NULL );

                        /**
                         * @fn	virtual bool isSkipPrinter();
                         * @brief	Whether to skip real printing process completely.
                         * @author	Yadickson Soto
                         * @date	23/04/2014
                         * @return	true if so.
                         */
                        virtual bool shouldSkipPrinter();

                        /**
                         * @fn	virtual unsigned int getTimeoutPrint();
                         * @brief	Getrs the timeout end printing.
                         * @author	Yadickson Soto
                         * @date	07/08/2015
                         * @return	The timeout.
                         */
                        virtual unsigned int getTimeoutPrint();

                        /**
                         * @fn	virtual std::string getResultPrintFile();
                         * @brief	Gets the result print full file to save buffer result print file.
                         * @author	Yadickson Soto
                         * @date	07/08/2015
                         * @return	The buffer result print file.
                         */
                        virtual std::string getResultPrintFile();

                        /**
                         * @fn	virtual std::string getStatusPrintFile();
                         * @brief	Gets the staatus print full file to end print file.
                         * @author	Yadickson Soto
                         * @date	07/08/2015
                         * @return	The status print file.
                         */
                        virtual std::string getStatusPrintFile();

                        /**
                         * @fn	virtual ~PrinterControllerConfigurationManager();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	23/04/2014
                         */
                        virtual ~PrinterControllerConfigurationManager();

                    protected:

                        /**
                         * @fn	PrinterControllerConfigurationManager();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	23/04/2014
                         */
                        PrinterControllerConfigurationManager();

                        /**
                         * @fn	virtual PrinterControllerConfiguration & getPrinterControllerConfiguration ();
                         * @brief	Gets a reference to the common context of the printer controller which contains the cryptographic data and the reader device settings.
                         * @author	Yadickson Soto
                         * @date	23/04/2014
                         * @return	The reference to the common context of the printer controller device
                         */
                        virtual PrinterControllerConfiguration & getPrinterControllerConfiguration ();

                    private:

                        static PrinterControllerConfigurationManager * instance; ///< The pointer to the singleton instance of the printer controller configuration manager
                };
            }
        }
    }
}

#endif // _PRINTER_CONTROLLER_CONFIGURATION_MANAGER_HXX_
