/**
 * @file	ResultsPackageTransmissionConfManager.cxx
 * @brief	Implementation of the results package transmission configuration manager.
 * @author	Yadickson Soto
 * @date	09/04/2014
 */

#include "ResultsPackageTransmissionConfManager.hxx"
#include "s-a-e-s-functionality-conf-manager.h"
#include <System/IO/Path.h>
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::SAES::Functionality::Configuration;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Utils;

ResultsPackageTransmissionConfManager * ResultsPackageTransmissionConfManager::instance = NULL;

ResultsPackageTransmissionConfManager::ResultsPackageTransmissionConfManager()
{

}

ResultsPackageTransmissionConfManager::~ResultsPackageTransmissionConfManager()
{
    instance = NULL;
}

std::string ResultsPackageTransmissionConfManager::getNetworkManagerScript()
{
    return getResultsPackageTransmissionConfiguration().getNetworkManagerScript();
}

std::string ResultsPackageTransmissionConfManager::getResultsTransmissionScript()
{
    return getResultsPackageTransmissionConfiguration().getResultsTransmissionScript();
}

bool ResultsPackageTransmissionConfManager::isUpDownInterfaceScriptNeeded()
{
    return getResultsPackageTransmissionConfiguration().getForceUpDown();
}

bool ResultsPackageTransmissionConfManager::isSendResultsPackageScriptNeeded()
{
    return getResultsPackageTransmissionConfiguration().getSendResults();
}

bool ResultsPackageTransmissionConfManager::useStaticIP()
{
    return !getResultsPackageTransmissionConfiguration().getDHCP();
}

std::string ResultsPackageTransmissionConfManager::getConfigFileName()
{
    return getResultsPackageTransmissionConfiguration().getConfigFileName();
}

std::string ResultsPackageTransmissionConfManager::getDebugFileName()
{
    return getResultsPackageTransmissionConfiguration().getDebugFileName();
}

std::string ResultsPackageTransmissionConfManager::getResultsFileName()
{
    return getResultsPackageTransmissionConfiguration().getResultsFileName();
}

std::string ResultsPackageTransmissionConfManager::getResponseFileName()
{
    return getResultsPackageTransmissionConfiguration().getResponseFileName();
}

std::string ResultsPackageTransmissionConfManager::getFileListToArchive ( const std::string & devicePath )
{
    std::string list;

    FileListToArchiveConfiguration::FileNameIterator it;
    FileListToArchiveConfiguration::FileNameSequence seq;

    seq = getResultsPackageTransmissionConfiguration().getFileListToArchive().getFileName();

    for ( it = seq.begin();
            it != seq.end();
            ++it )
    {
        list.append ( Path::Combine ( devicePath, ( *it ) ) );
        list.append ( " " );
    }

    return StringUtils::trim ( list );
}

std::string ResultsPackageTransmissionConfManager::getFullCommandToSendResults ( const std::string & centerName, const std::string & interface, const std::string & devicePath )
{
    std::stringstream command;

    std::string script = getResultsTransmissionScript();
    std::string configFile = getConfigFileName();
    std::string debugFile = getDebugFileName();
    std::string fileList = getFileListToArchive ( devicePath );
    std::string resultsFile = getResultsFileName();
    std::string responseFile = getResponseFileName();

    command << script;
    command << ( !centerName.empty() ? " -p " + centerName : "" );
    command << ( !interface.empty() ? " -i " + interface : "" );
    command << ( !fileList.empty() ? " -f \"" + fileList + "\"" : "" );
    command << ( !configFile.empty() ? " -c " + Path::Combine ( devicePath, configFile ) : "" );
    command << ( !debugFile.empty() ? " -d " + Path::Combine ( devicePath, debugFile ) : "" );
    command << ( !resultsFile.empty() ? " -r " + resultsFile : "" );
    command << ( !responseFile.empty() ? " -s " + responseFile : "" );
    command << ( useStaticIP() ? " -x" : "" );

    return command.str();
}

ResultsPackageTransmissionConfiguration & ResultsPackageTransmissionConfManager::getResultsPackageTransmissionConfiguration ()
{
    if ( !SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().present() )
    {
        FileListToArchiveConfiguration list;
        FileListToArchiveConfiguration::FileNameSequence seq;
        list.setFileName ( seq );

        ResultsPackageTransmissionConfiguration config (
            "network-script",
            "results-script",
            false,
            false,
            "config-file",
            "debug-file",
            list,
            "results-file",
            "response-file",
            true );

        SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->setResultsPackageTransmission ( config );
    }

    return SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get();
}

ResultsPackageTransmissionConfManager * ResultsPackageTransmissionConfManager::getInstance ( ResultsPackageTransmissionConfManager * externManager )
{
    if ( ! instance )
    {
        instance = ( externManager == NULL ? new ResultsPackageTransmissionConfManager() : externManager );
    }

    return instance;
}
