/**
 * @file	saes-functionality-manager.cc
 * @brief	saes functionality manager class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#include "saes-functionality-manager.h"
#include <Voting/VotingCenters/VotingCentersWrapper.hxx>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <System/IO/Path.h>
#include <System/IO/Directory.h>
#include <Runtime/Environment/saes-directories.h>

using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::Voting::VotingCenters;
using namespace Smartmatic::SAES::Functionality::Configuration;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::SAES::Runtime::Environment;

SaesFunctionalityManager * SaesFunctionalityManager::singleton_instance = NULL;

static Smartmatic::SAES::Voting::VotingCenters::RunningMode getVMRunningMode()
{
    SaesDirectories directories;
    std::string basePVFullFile = directories.getGeneratedPVReportFileFullPath();
    std::string basePVFileName = Path::GetFileNameWithOutExtension(basePVFullFile);
    std::vector<std::string> presentPVFiles;
    Smartmatic::SAES::Voting::VotingCenters::RunningMode mode = Smartmatic::SAES::Voting::VotingCenters::RunningMode::VOTING_CENTER_OFFICIAL;

    Directory::getInstance()->GetFiles(
        directories.getDocsFolderFullPath(),
        presentPVFiles);

    for (size_t i = 0;i < presentPVFiles.size(); ++i)
    {
        std::string checkFile = Path::GetFileNameWithOutExtension(presentPVFiles[i]);

        if (basePVFileName.compare(
                0,
                basePVFileName.size(),
                checkFile,
                0,
                basePVFileName.size()) == 0)
        {
            mode = Smartmatic::SAES::Voting::VotingCenters::RunningMode::VOTING_CENTER_PRINT;
            break;
        }
    }

    return mode;
}

SaesFunctionalityManager * SaesFunctionalityManager::getInstance()
{
    if ( !singleton_instance )
    {
        singleton_instance = new SaesFunctionalityManager();
    }

    return singleton_instance;
}

SaesFunctionalityManager::SaesFunctionalityManager()
{

}

SaesFunctionalityManager::~SaesFunctionalityManager()
{

}

void SaesFunctionalityManager::AddRunningSelectedModeForPM()
{
    std::list<Smartmatic::SAES::Functionality::Configuration::MenuOptionType> list;
    list = SAESFunctionalityConfigurationManager::getInstance()->getRunFunctionalityDescriptorsByMode ( VotingCentersWrapper::getInstance()->getRunningMode() );
    this->AddOptionList ( list );
}

void SaesFunctionalityManager::AddRunningSelectedModeForVM()
{
    std::list<Smartmatic::SAES::Functionality::Configuration::MenuOptionType> list;
    list = SAESFunctionalityConfigurationManager::getInstance()->getRunFunctionalityDescriptorsByMode(getVMRunningMode());
    this->AddOptionList ( list );
}
