/**
 * @file VMachineAuthenticator.hxx
 * @brief Declaration of the VMachineAuthenticator class.
 * @author Youssef.tourkmani
 * @date 01/11/2012
 */


#ifndef _VMACHINE_AUTHENTICATOR_H_
#define _VMACHINE_AUTHENTICATOR_H_

#include "IAuthenticator.hxx"
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Authenticator
            {
                /**
                 * @class VMachineAuthenticator
                 * @brief Represents a voting machine authenticator.
                 * @author Yadickson Soto
                 * @date 03-03-2011
                 */

                class VMachineAuthenticator: public IAuthenticator
                {
                    public:

                        /**
                         * @fn VMachineAuthenticator::VMachineAuthenticator ();
                         * @brief Default constructor for the VMachineAuthenticator class.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        VMachineAuthenticator ();

                        /**
                         * @fn virtual VMachineAuthenticator::~VMachineAuthenticator();
                         * @brief Finalizes an instance of the VMachineAuthenticator class.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        virtual ~VMachineAuthenticator();

                        /**
                         * @fn virtual AuthenticationResultType VMachineAuthenticator::validate ( std::string password );
                         * @brief Validates a given password
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         * @param password password to validate.
                         * @return Response for the validation of the given password.
                         */

                        virtual AuthenticationResultType validate ( std::string password );

                        /**
                         * @fn bool VMachineAuthenticator::ValidateRole ( const std::string& password );
                         * @brief Validates if the given password match the password for the menu.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         * @param password The password to validate.
                         * @return true if it succeeds, false if it fails.
                         */

                        bool ValidateRole ( const std::string& password );

                        /**
                         * @fn virtual void VMachineAuthenticator::dispose();
                         * @brief Disposes this instance of the VMachineAuthenticator class,
                         * cleaning up any resources it uses.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        virtual void dispose();

                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                };
            }
        }
    }
}

#endif // _VMACHINE_AUTHENTICATOR_H_
