/**
 * @file   IOBSmartcardReaderPowerManager.hxx
 * @brief  Declaration of IOBSmartcardReaderPowerManager class.
 * @author eduardo.fernandez
 * @date   Jan 2, 2018
 */

#ifndef IOB_SMARTCARD_READER_POWER_MANAGER_HXX
#define IOB_SMARTCARD_READER_POWER_MANAGER_HXX

#include <Card/ISmartcardReaderPowerManager.hxx>
#include <memory>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Devices
            {
                /**
                 * @class  IOBSmartcardReaderPowerManager
                 * @brief  Handles the power of the smartcard reader.
                 * @author eduardo.fernandez
                 * @date   Jan 2, 2018
                 */
                class IOBSmartcardReaderPowerManager : public SAES::Card::ISmartcardReaderPowerManager
                {
                    public:

                        /**
                         * @brief  Creates an instance of the class.
                         * @author eduardo.fernandez
                         * @date   Jan 2, 2018
                         */
                        IOBSmartcardReaderPowerManager();

                        /**
                         * @brief  Destroys an instance of the class.
                         * @author eduardo.fernandez
                         * @date   Jan 2, 2018
                         */
                        ~IOBSmartcardReaderPowerManager();

                    public:

                        /**
                         * @brief  Restart the reader with a full power cycle.
                         * @author eduardo.fernandez
                         * @date   Jan 2, 2018
                         */
                        virtual void doReaderPowerCycle();

                        /**
                         * @brief  Restarts the reader.
                         * @author eduardo.fernandez
                         * @date   Jan 2, 2018
                         * @param  background If the operation should be done asynchronous.
                         */
                        virtual void callRestartSmartcard(bool background = false);

                        /**
                         * @brief  Powers off the reader.
                         * @author eduardo.fernandez
                         * @date   Jan 2, 2018
                         */
                        virtual void callPowerOffSmartcard();

                        /**
                         * @brief  Powers on the reader.
                         * @author eduardo.fernandez
                         * @date   Jan 2, 2018
                         */
                        virtual void callPowerOnSmartcard();

                        /**
                         * @brief  Emitted when the power was cycled.
                         * @author eduardo.fernandez
                         * @date   Jan 2, 2018
                         */
                        virtual PowerCycledSignal signalPowerCycled();

                    private:

                        static Smartmatic::Log::ISMTTLog* m_logger;
                        PowerCycledSignal m_powerCycledSignal;
                };

            } /* namespace Devices */
        } /* namespace Operation */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* IOB_SMARTCARD_READER_POWER_MANAGER_HXX */
