/**
 * @file   LEDStripManagerFactory.cxx
 * @brief  Implementation of LEDStripManagerFactory.
 * @author manuel.arguelles
 * @date   Nov  2, 2017
 */

#include "LEDStripManagerFactory.hxx"
#include "A4517LEDStripManager.hxx"
#include "LEDStripDefaultManager.hxx"
#include <System/OptParser.hxx>
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::System;

IStripLEDManager* LEDStripManagerFactory::getLEDStripManager()
{
    std::string machineModel;
    IStripLEDManager* ledStripManager;

    OptParser::getInstance()->getArg(OptParser::MACHINE_MODEL, machineModel);

    if (StringUtils::toUpper(machineModel) == "PM-NOTEBOOK-A" ||
        StringUtils::toUpper(machineModel) == "PM-NOTEBOOK-B" ||
        StringUtils::toUpper(machineModel) == "PM-VIU805" ||
        StringUtils::toUpper(machineModel) == "VM-SAES3370")
    {
        ledStripManager = new LEDStripDefaultManager();
    }
    else
    {
        ledStripManager = new A4517LEDStripManager();
    }

    return ledStripManager;
}
