/**
 * @file A4517AbleDPolling.cxx
 * @brief Body class A4517 able-d monitor polling.
 * @author eduardo.fernandez
 * @date Jan 12, 2018
 */

#include "A4517AbleDPolling.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/A4517AbledController.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::HW::Operation;
using namespace Smartmatic::System;
using namespace Smartmatic::Log;

ISMTTLog * A4517AbleDPolling::m_logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Card.A4517AbleDPolling", GETTEXT_PACKAGE );
A4517AbleDPolling * A4517AbleDPolling::m_instance = NULL;

A4517AbleDPolling::A4517AbleDPolling()
{
    m_signalAbleDPressButton.getSyncSignal().connect ( sigc::mem_fun ( *this, &A4517AbleDPolling::onRawObject ) );
}

A4517AbleDPolling::~A4517AbleDPolling()
{
    m_instance = NULL;
}

void A4517AbleDPolling::preStart ()
{
    m_logger->Debug ( "Start" );
}

bool A4517AbleDPolling::process ()
{
    AbleDButtonState * state = A4517AbledController::getInstance()->getA4517AbleDButtonState();

    if ( state && state->isChanged() )
    {
        m_logger->Debug ( "Abled button pressed" );
        m_signalAbleDPressButton.emit ( state );
    }

    return true;
}

void A4517AbleDPolling::postStop ()
{
    m_logger->Debug ( "Stop" );
}

void A4517AbleDPolling::onRawObject ( void * object )
{
    AbleDButtonState * status = static_cast < AbleDButtonState * > ( object );
    m_pressButton.emit ( status );
}

A4517AbleDPolling::SignalPressButton A4517AbleDPolling::getSignalPressButton ()
{
    return m_pressButton;
}

A4517AbleDPolling * A4517AbleDPolling::getInstance()
{
    if ( !m_instance )
    {
        m_instance = new A4517AbleDPolling();
    }

    return m_instance;
}
