/**
 * @file A4517AbleDPolling.hxx
 * @brief Declaration of the A4517AbleDPolling class.
 * @date Jan 12, 2018
 * @author eduardo.fernandez
 */

#ifndef A4517_ABLED_POLLING_HXX
#define A4517_ABLED_POLLING_HXX

#include <System/SafeThread.hxx>
#include <System/SafeDispatcher.hxx>
#include <Operation/AbleDButtonState.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Devices
            {
                class A4517AbledController;

                /**
                 * @class A4517AbleDPolling
                 * @brief Class A4517AbleDPolling controller.
                 * @author eduardo.fernandez
                 * @date Jan 12, 2018
                 */
                class A4517AbleDPolling : public Smartmatic::System::SafeThread
                {
                    public:

                        typedef sigc::signal<void, SAES::HW::Operation::AbleDButtonState * > SignalPressButton; ///< typedef signal press button

                    protected:

                        /**
                         * @fn A4517AbleDPolling::A4517AbleDPolling();
                         * @brief Default constructor for the A4517AbleDPolling class.
                         * @author eduardo.fernandez
                         * @date Jan 12, 2018
                         */
                        A4517AbleDPolling();

                        /**
                         * @fn	    virtual void preStart ();
                         * @brief	Callback from thread before start thread.
                         * @author	eduardo.fernandez
                         * @date	Jan 12, 2018
                         */
                        virtual void preStart ();

                        /**
                         * @fn	virtual bool process ();
                         * @brief	Callback from thread any time.
                         * @author	eduardo.fernandez
                         * @date	Jan 12, 2018
                         * @return true to continue process
                         */
                        virtual bool process ();

                        /**
                         * @fn	    virtual void postStop ();
                         * @brief	Callback from thread after stop thread.
                         * @author	eduardo.fernandez
                         * @date	Jan 12, 2018
                         */
                        virtual void postStop ();

                        /**
                         * @fn	    void onRawObject ( void * object );
                         * @brief	Callback when emit sync signal.
                         * @author	eduardo.fernandez
                         * @date	Jan 12, 2018
                         * @param 	object The object to process
                         */
                        void onRawObject ( void * object );

                    public:

                        /**
                         * @fn virtual A4517AbleDPolling::~A4517AbleDPolling();
                         * @brief Finalizes an instance of the A4517AbleDPolling class.
                         * @author eduardo.fernandez
                         * @date Jan 12, 2018
                         */
                        virtual ~A4517AbleDPolling();

                        /**
                         * @fn	SignalPressButton getSignalPressButton ();
                         * @brief	Gets signal press button.
                         * @author	eduardo.fernandez
                         * @date	Jan 12, 2018
                         * @return	signal press button.
                         */
                        SignalPressButton getSignalPressButton ();

                        /**
                         * @fn static A4517AbleDPolling * A4517AbleDPolling::getInstance();
                         * @brief Gets the current instance of the A4517AbleDPolling.
                         * @author eduardo.fernandez
                         * @date Jan 12, 2018
                         * @return pointer to the current instance of the A4517AbleDPolling class.
                         */

                        static A4517AbleDPolling * getInstance();

                    private:

                        Smartmatic::System::SafeDispatcher m_signalAbleDPressButton;   ///< The signal alarm box disconnect
                        SignalPressButton m_pressButton; ///< The signal press button

                        static A4517AbleDPolling * m_instance; ///< instance
                        static Smartmatic::Log::ISMTTLog * m_logger;  ///< The logger

                        A4517AbledController * m_abled;
                };
            }
        }
    }
}

#endif /* A4517_ABLED_POLLING_HXX */
