/**
 * @file AbleDPolling.hxx
 * @brief Declaration of the AbleDPolling class.
 * @date 08/07/2015
 * @author Yadickson Soto
 */

#ifndef ABLED_POLLING_HXX_
#define ABLED_POLLING_HXX_

#include <System/SafeThread.hxx>
#include <System/SafeDispatcher.hxx>
#include <Operation/AbleDButtonState.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Devices
            {
                /**
                 * @class AbleDPolling
                 * @brief Class alarm controller.
                 * @author Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                 * @date 08/07/2015
                 */
                class AbleDPolling : public Smartmatic::System::SafeThread
                {
                    public:

                        typedef sigc::signal<void, Smartmatic::SAES::HW::Operation::AbleDButtonState * > SignalPressButton; ///< typedef signal press button

                    protected:

                        /**
                         * @fn AbleDPolling::AbleDPolling();
                         * @brief Default constructor for the AbleDPolling class.
                         * @author Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                         * @date 08/07/2015
                         */
                        AbleDPolling();

                        /**
                         * @fn	    virtual void preStart ();
                         * @brief	Callback from thread before start thread.
                         * @author	Yadickson Soto
                         * @date	04/08/2015
                         */
                        virtual void preStart ();

                        /**
                         * @fn	virtual bool process ();
                         * @brief	Callback from thread any time.
                         * @author	Yadickson Soto
                         * @date	08/07/2015
                         * @return true to continue process
                         */
                        virtual bool process ();

                        /**
                         * @fn	    virtual void postStop ();
                         * @brief	Callback from thread after stop thread.
                         * @author	Yadickson Soto
                         * @date	04/08/2015
                         */
                        virtual void postStop ();

                        /**
                         * @fn	    void onRawObject ( void * object );
                         * @brief	Callback when emit sync signal.
                         * @author	Yadickson Soto
                         * @date	01/08/2015
                         * @param 	object The object to process
                         */
                        void onRawObject ( void * object );

                    public:

                        /**
                         * @fn virtual AbleDPolling::~AbleDPolling();
                         * @brief Finalizes an instance of the AbleDPolling class.
                         * @author Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                         * @date 08/07/2015
                         */
                        virtual ~AbleDPolling();

                        /**
                         * @fn	SignalPressButton getSignalPressButton ();
                         * @brief	Gets signal press button.
                         * @author	Yadickson Soto
                         * @date	08/07/2015
                         * @return	signal press button.
                         */
                        SignalPressButton getSignalPressButton ();

                        /**
                         * @fn static AbleDPolling * AbleDPolling::getInstance();
                         * @brief Gets the current instance of the AbleDPolling.
                         * @author Yadickson Soto
                         * @date 08/07/2015
                         * @return pointer to the current instance of the AbleDPolling class.
                         */

                        static AbleDPolling * getInstance();

                    private:

                        Smartmatic::System::SafeDispatcher signalAbleDPressButton;   ///< The signal alarm box disconnect
                        SignalPressButton pressButton; ///< The signal press button

                        static AbleDPolling * instance; ///< instance
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif /* ABLED_POLLING_HXX_ */
