/**
 * @file AbledDiagnosis.hxx
 * @brief Declaration of the AbledDiagnosis class.
 * @author eduardo.fernandez
 * @date 02/02/2018
 */

#ifndef ABLED_DIAGNOSIS_HXX
#define ABLED_DIAGNOSIS_HXX

#include "IDiagnosis.hxx"
#include <Operation/Voting/AudioVoting/AudioVotingCheckUtility.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace Operation
        {
            namespace Diagnosis
            {
                /**
                 * @class AbledDiagnosis
                 * @brief Represents the diagnostic of the abled device.
                 * @author eduardo.fernandez
                 * @date 02/02/2018
                 */
                class AbledDiagnosis : public IDiagnosis
                {
                    public:

                        /**
                         * @fn AbledDiagnosis::AbledDiagnosis();
                         * @brief Default constructor for the AbledDiagnosis class.
                         * @author eduardo.fernandez
                         * @date 02/02/2018
                         */

                        AbledDiagnosis();

                        /**
                         * @fn virtual AbledDiagnosis::~AbledDiagnosis();
                         * @brief Finalizes an instance of the AbledDiagnosis class.
                         * @author eduardo.fernandez
                         * @date 02/02/2018
                         */

                        virtual ~AbledDiagnosis();

                    protected:

                        /**
                         * @fn virtual void AbledDiagnosis::run();
                         * @brief Runs the diagnostic for the abled device.
                         * @author eduardo.fernandez
                         * @date 02/02/2018
                         */

                        virtual void run();

                        /**
                         * @fn virtual void AbledDiagnosis::updateMessage();
                         * @brief Updates the status message of this diagnostic.
                         * @author eduardo.fernandez
                         * @date 02/02/2018
                         */

                        virtual void updateMessage();

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                        AudioVoting::AudioVotingCheckUtility m_audioVotingCheckUtility;
                        bool m_ableIsConnected;
                        bool m_able20Connected;
                };
            }
        }
    }
}

#endif /* ABLED_DIAGNOSIS_HXX */
