/**
 * @file AlarmBoxDiagnosis.cxx
 * @brief Implementation of the AlarmBoxDiagnosis class.
 * @date 20/10/2011
 * @author Yadickson Soto
 */

#include "AlarmBoxDiagnosis.hxx"
#include <Operation/Devices/AlarmController.hxx>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Operation::Diagnosis;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Voting::Status;

ISMTTLog * AlarmBoxDiagnosis::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Diagnosis.AlarmBoxDiagnosis", GETTEXT_PACKAGE );

AlarmBoxDiagnosis::AlarmBoxDiagnosis()
    : IDiagnosis ( Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_ALARMBOX )
{
    updateMessage();
}

AlarmBoxDiagnosis::~AlarmBoxDiagnosis()
{
}

void AlarmBoxDiagnosis::run()
{
    bool validate = AlarmController::getInstance()->test();

    setStatus ( validate ? VMStatus::VOTING_MACHINE_STATUS_OK : VMStatus::VOTING_MACHINE_STATUS_ERROR );
}

void AlarmBoxDiagnosis::updateMessage()
{
    setMessageFooter ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.AlarmBoxDiagnosis.Info" ) );

    switch ( getStatus() )
    {
        default:
        case VMStatus::VOTING_MACHINE_STATUS_NOTDIAGNOSED:
        case VMStatus::VOTING_MACHINE_STATUS_RUN:
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.AlarmBoxDiagnosis.InitializingDiagnostic" ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_OK:
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.AlarmBoxDiagnosis.DiagnosticSuccessful" ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_ERROR:
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.AlarmBoxDiagnosis.DiagnosticFailed" ) );
            break;
    }
}
