/**
 * @file AlarmBoxDiagnosis.hxx
 * @brief Declaration of the AlarmBoxDiagnosis class.
 * @author Youssef.tourkmani
 * @date 01/11/2012
 */

#ifndef ALARMBOXDIAGNOSIS_HXX_
#define ALARMBOXDIAGNOSIS_HXX_

#include "IDiagnosis.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace Operation
        {
            namespace Diagnosis
            {
                /**
                 * @class AlarmBoxDiagnosis
                 * @brief Represents the diagnostic of the alarm box device.
                 * @author Youssef.tourkmani
                 * @date 01/11/2012
                 */
                class AlarmBoxDiagnosis : public IDiagnosis
                {
                    public:

                        /**
                         * @fn AlarmBoxDiagnosis::AlarmBoxDiagnosis();
                         * @brief Default constructor for the AlarmBoxDiagnosis class.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        AlarmBoxDiagnosis();

                        /**
                         * @fn virtual AlarmBoxDiagnosis::~AlarmBoxDiagnosis();
                         * @brief Finalizes an instance of the AlarmBoxDiagnosis class.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        virtual ~AlarmBoxDiagnosis();

                    protected:

                        /**
                         * @fn virtual void AlarmBoxDiagnosis::run();
                         * @brief Runs the diagnostic for the alarm box device.
                         * @author Yadickson Soto
                         * @date 28/09/2012
                         */

                        virtual void run();

                        /**
                         * @fn virtual void AlarmBoxDiagnosis::updateMessage();
                         * @brief Updates the status message of this diagnostic.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        virtual void updateMessage();

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif /* ALARMBOXDIAGNOSIS_HXX_ */
