/**
 * @file ICalibrationDiagnosis.cxx
 * @brief Implementation of the ICalibrationDiagnosis class.
 * @date 20/10/2011
 * @author Yadickson Soto
 */

#include "ICalibrationDiagnosis.hxx"
#include <System/IO/File.h>
#include <System/Runtime/ProcessLauncher.h>
#include <Runtime/Environment/saes-directories.h>

using namespace Smartmatic::SAES::Operation::Diagnosis;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Runtime;
using namespace Smartmatic::SAES::Runtime::Environment;

ICalibrationDiagnosis::ICalibrationDiagnosis ( int numberPoints, bool skipConditional )
{
    this->numberPoints = numberPoints;
    this->skipConditional = skipConditional;
}

ICalibrationDiagnosis::~ICalibrationDiagnosis()
{
}

bool ICalibrationDiagnosis::calibrationTool()
{
    if ( getPenmountFileConditional() )
    {
        return false;
    }
    else if ( skipConditional && getSkipCalibrationToolConditional() )
    {
        return false;
    }

    return executeCalibrationTool ();
}

bool ICalibrationDiagnosis::executeCalibrationTool()
{
    std::stringstream ss;
    ss << numberPoints;
    std::string fullCommand ( "smtt-calibration " );
    fullCommand.append ( ss.str() );

    int result = ProcessLauncher::getInstance()->RunProcessThroughSystem ( fullCommand.c_str() );

    return result == 0;
}

bool ICalibrationDiagnosis::getPenmountFileConditional()
{
    return File::getInstance()->canOpenFile ( "/live/image/osconf/penmount.dat" );
}

bool ICalibrationDiagnosis::getSkipCalibrationToolConditional()
{
    SaesDirectories directories;
    std::string skipFile = directories.getSkipCalibrationToolFileFullPath ();
    return File::getInstance()->canOpenFile ( skipFile );
}
