/**
 * @file SmartcardReaderDiagnosis.cxx
 * @brief Implementation of the SmartcardReaderDiagnosis class.
 * @date 20/10/2011
 * @author Yadickson Soto
 */

#include "SmartcardReaderDiagnosis.hxx"
#include <Operation/Monitor/DeviceTypeMonitorPool.hxx>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation::Diagnosis;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::SAES::Operation::Monitor;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Voting::Status;
using namespace Smartmatic::SAES::Common::Configuration;

ISMTTLog * SmartcardReaderDiagnosis::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.Diagnosis.SmartcardReaderDiagnosis", GETTEXT_PACKAGE );

SmartcardReaderDiagnosis::SmartcardReaderDiagnosis()
    : IDiagnosis ( DeviceType::CONFIGURATION_SMARTCARD )
{
    updateMessage();
}

SmartcardReaderDiagnosis::~SmartcardReaderDiagnosis()
{
}

void SmartcardReaderDiagnosis::run()
{
    logger->Debug ( "Start Diagnostic" );

    bool validate = DeviceTypeMonitorPool::getInstance()->getNumberOfDevicesByType ( DeviceType::CONFIGURATION_SMARTCARD ) != 0;

    setStatus ( validate ? VMStatus::VOTING_MACHINE_STATUS_OK : VMStatus::VOTING_MACHINE_STATUS_ERROR );
}

void SmartcardReaderDiagnosis::updateMessage()
{
    const std::string messageFooter = N_ ( "Smartmatic.SAES.Operation.Diagnosis.SmartcardReaderDiagnosis.Info" );

    switch ( getStatus() )
    {
        default:
        case VMStatus::VOTING_MACHINE_STATUS_NOTDIAGNOSED:
        case VMStatus::VOTING_MACHINE_STATUS_RUN:
            setMessageFooter ( messageFooter );
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.SmartcardReaderDiagnosis.InitializingDiagnostic" ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_OK:
            setMessageFooter ( messageFooter );
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.SmartcardReaderDiagnosis.DiagnosticSuccessful" ) );
            break;

        case VMStatus::VOTING_MACHINE_STATUS_ERROR:
            setMessageFooter ( " " );
            setMessage ( N_ ( "Smartmatic.SAES.Operation.Diagnosis.SmartcardReaderDiagnosis.DiagnosticFailed" ) );
            break;
    }
}
