/**
 * @file InitiatorSignal.hxx
 * @brief Declares the InitiatorSignal interface.
 * @author Yadickson Soto
 * @date 03/08/2015
 */

#ifndef _INITIATOR_SIGNAL_H_
#define _INITIATOR_SIGNAL_H_

#include <Operation/Initiator/InitializationStatus.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Initiator
            {
                /**
                 * @class InitiatorSignal
                 * @brief Represents a machine initiator.
                 * @author Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                 * @date 03/08/2015
                 */

                class InitiatorSignal
                {
                    public:

                        /**
                         * @fn InitiatorSignal( const InitializationStatus & status, bool finished );
                         * @brief Default constructor for the InitiatorSignal class.
                         * @author Yadickson Soto
                         * @date 03/08/2015
                         */
                        InitiatorSignal ( const InitializationStatus & status, bool finished );

                        /**
                         * @fn virtual ~InitiatorSignal();
                         * @brief Finalizes an instance of the InitiatorSignal class.
                         * @author Yadickson Soto
                         * @date 03/08/2015
                         */
                        virtual ~InitiatorSignal();

                        /**
                         * @fn InitializationStatus getStatus();
                         * @brief Gets the initialization status.
                         * @author Yadickson Soto
                         * @date 03/08/2015
                         * @return The initialization status.
                         */
                        InitializationStatus getStatus();

                        /**
                         * @fn bool isFinished();
                         * @brief Gets if finished initiator.
                         * @author Yadickson Soto
                         * @date 03/08/2015
                         * @return True if finished.
                         */
                        bool isFinished();

                    private:

                        InitializationStatus status; ///< current status messages
                        bool finished; ///< true if finished process status
                };
            }
        }
    }
}

#endif // _INITIATOR_SIGNAL_H_
