/**
 * @file P168AMonitor.hxx
 * @brief Declaration of the P168AMonitor class.
 * @date 06/07/2015
 * @author Yadickson Soto
 */

#ifndef P168A_MONITOR_HXX_
#define P168A_MONITOR_HXX_

#include <Operation/Monitor/DeviceTypeMonitor.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Monitor
            {

                /**
                 * @class P168AMonitor
                 * @brief  Represents a p168a device monitor.
                 * @date 06/07/2015
                 * @author Yadickson Soto
                 */

                class P168AMonitor : public Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor
                {
                    public:

                        /**
                         * @fn P168AMonitor();
                         * @brief Constructor for the P168AMonitor class.
                         * @date 06/07/2015
                         * @author Yadickson Soto
                         */

                        P168AMonitor();

                        /**
                         * @fn virtual ~P168AMonitor();
                         * @brief Finalizes an instance of the P168AMonitor class.
                         * @date 06/07/2015
                         * @author Yadickson Soto
                         */

                        virtual ~P168AMonitor();

                        /**
                         * @fn	virtual void added ( const std::string & node );
                         * @brief	Notifies that a mouse reader device was added to the machine.
                         * @author	Yadickson Soto
                         * @date	06/07/2015
                         * @param 	node event device path
                         */
                        virtual void added ( const std::string & node );

                        /**
                         * @fn	virtual void removed ( const std::string & node );
                         * @brief	Notifies that a mouse reader device was removed from the machine.
                         * @author	Yadickson Soto
                         * @date	06/07/2015
                         * @param 	node event device path
                         */
                        virtual void removed ( const std::string & node );

                    protected:

                        /**
                         * @fn	virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );
                         * @brief	Gets when device mounted.
                         * @author	Yadickson Soto
                         * @date	09/07/2015
                         * @param 	node the node to check
                         * @param	customNode the custom node to check device
                         * @return  path device mounted
                         */
                        virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif /* P168A_MONITOR_HXX_ */
