/**
 * @file PrinterMonitor.hxx
 * @brief Declaration of the PrinterMonitor class.
 * @date 12/12/2012
 * @author Yadickson Soto
 */

#ifndef PRINTERMONITOR_HXX_
#define PRINTERMONITOR_HXX_

#include <Operation/Monitor/DeviceTypeMonitor.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Monitor
            {
                /**
                 * @class PrinterMonitor
                 * @brief Represents a printer device monitor.
                 * @date 12/12/2012
                 * @author Yadickson Soto
                 */
                class PrinterMonitor : public Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor
                {
                    public:

                        /**
                         * @fn PrinterMonitor();
                         * @brief Constructor for the PrinterMonitor class.
                         * @date 12/12/2012
                         * @author Yadickson Soto
                         */

                        PrinterMonitor();

                        /**
                         * @fn virtual ~PrinterMonitor();
                         * @brief Finalizes an instance of the PrinterMonitor class.
                         * @date 12/12/2012
                         * @author Yadickson Soto
                         */
                        virtual ~PrinterMonitor();

                        /**
                         * @fn	virtual void added ( const std::string & node );
                         * @brief	Notifies that a printer device was added to the machine.
                         * @author	Yadickson Soto
                         * @date	09/04/2014
                         * @param 	node event device path
                         */
                        virtual void added ( const std::string & node );

                        /**
                         * @fn	virtual void removed ( const std::string & node );
                         * @brief	Notifies that a printer device was removed from the machine.
                         * @author	Yadickson Soto
                         * @date	09/04/2014
                         * @param 	node event device path
                         */
                        virtual void removed ( const std::string & node );

                    protected:

                        /**
                         * @fn	virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );
                         * @brief	Gets when device mounted.
                         * @author	Yadickson Soto
                         * @date	09/07/2015
                         * @param 	node the node to check
                         * @param	customNode the custom node to check device
                         * @return  path device mounted
                         */
                        virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}
#endif /* PRINTERMONITOR_HXX_ */
