/**
 * @file SmartcardMonitor.cxx
 * @brief Implementation of the SmartcardMonitor class.
 * @date 12/12/2012
 * @author Yadickson Soto
 */

#include "SmartcardMonitor.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <unistd.h>
#include <Operation/Devices/CardController.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::Operation::Monitor;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::Log;

ISMTTLog * SmartcardMonitor::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.Operation.SmartcardMonitor", GETTEXT_PACKAGE );

SmartcardMonitor::SmartcardMonitor()
    : DeviceTypeMonitor ( Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_SMARTCARD )
{

}

SmartcardMonitor::~SmartcardMonitor()
{

}

void SmartcardMonitor::added ( const std::string & node )
{
    logger->Debug ( "Added" );
    CardController::getInstance()->open ( node );
}

void SmartcardMonitor::removed ( const std::string & node )
{
    logger->Debug ( "Removed" );

    CardController::getInstance()->close();
}

std::string SmartcardMonitor::getDeviceMounted ( const std::string & node, const std::string & customNode )
{
    usleep ( 250000 );
    return customNode;
}
