/**
 * @file USBStorageMonitor.hxx
 * @brief Declaration of the storage devices collection which contains the items monitored.
 * @date 10/06/2013
 * @author Yadickson Soto
 */

#ifndef USB_STORAGE_MONITOR_HXX_
#define USB_STORAGE_MONITOR_HXX_

#include <Operation/Monitor/DeviceTypeMonitor.hxx>
#include <glibmm.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace Operation
        {
            namespace Monitor
            {

                /**
                 * @class USBStorageMonitor
                 * @brief Represents an USB storage monitor.
                 * @date 10/06/2013
                 * @author Yadickson Soto
                 */
                class USBStorageMonitor : public Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor
                {
                    public:

                        /**
                         * @fn USBStorageMonitor();
                         * @brief Default constructor initializes an instance of the USBStorageMonitor class.
                         * @date 10/06/2013
                         * @author Yadickson Soto
                         */
                        USBStorageMonitor();

                        /**
                         * @fn virtual ~USBStorageMonitor();
                         * @brief Finalizes the instance of the USBStorageMonitor class.
                         * @date 10/06/2013
                         * @author Yadickson Soto
                         */
                        virtual ~USBStorageMonitor();

                        /**
                         * @fn	virtual void added ( const std::string & node );
                         * @brief	Notifies the machine operation manager that an USB storage device was added.
                         * @author	Yadickson Soto
                         * @date	02/06/2015
                         * @param 	node event device path
                         */
                        virtual void added ( const std::string & node );

                        /**
                         * @fn	virtual void removed ( const std::string & node );
                         * @brief	Notifies the machine operation manager that an USB storage device was removed.
                         * @author	Yadickson Soto
                         * @date	02/06/2015
                         * @param 	node event device path
                         */
                        virtual void removed ( const std::string & node );

                    protected:

                        /**
                         * @fn	virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );
                         * @brief	Gets when device mounted.
                         * @author	Yadickson Soto
                         * @date	09/07/2015
                         * @param 	node the node to check
                         * @param	customNode the custom node to check device
                         * @return  path device mounted
                         */
                        virtual std::string getDeviceMounted ( const std::string & node, const std::string & customNode );

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif /* USB_STORAGE_MONITOR_HXX_ */
