/**
 * @file ResultsPackageTransmissionManager.hxx
 * @brief Declaration of the entity that checks the network interface and sends the results package.
 * @date 09/04/2014
 * @author Yadickson Soto
 */

#ifndef RESULTSPACKAGETRANSMISSIONMANAGER_HXX_
#define RESULTSPACKAGETRANSMISSIONMANAGER_HXX_

#include <Operation/Monitor/DeviceTypeMonitor.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace Operation
        {
            /**
             * @class ResultsPackageTransmissionManager
             * @brief Entity that checks the network interface and sends the results package.
             * @date 09/04/2014
             * @author Yadickson Soto
             */
            class ResultsPackageTransmissionManager
            {
                public:

                    /**
                     * @fn	ResultsPackageTransmissionManager ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * networkInterface );
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	09/04/2014
                     * @param	networkInterface The network interface to monitor
                     */
                    explicit ResultsPackageTransmissionManager ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * networkInterface );

                    /**
                     * @fn	virtual ~ResultsPackageTransmissionManager();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	09/04/2014
                     */
                    virtual ~ResultsPackageTransmissionManager();

                    /**
                     * @fn virtual bool mountNetworkDevice ();
                     * @brief Mount the network interface
                     * @date 09/04/2014
                     * @author Yadickson Soto
                     * @return true if is success
                     */
                    virtual bool mountNetworkDevice ();

                    /**
                     * @fn virtual bool umountNetworkDevice ();
                     * @brief Umount the network interface
                     * @date 09/04/2014
                     * @author Yadickson Soto
                     * @return true if is success
                     */
                    virtual bool umountNetworkDevice ();

                    /**
                     * @fn bool sendResultsPackages ( const std::string & centerName, const std::string & devicePath, std::string & messageResponse );
                     * @brief Send all results packages.
                     * @date 07/04/2014
                     * @author Yadickson Soto
                     * @param centerName the center name
                     * @param fileNameList the file name list to send
                     * @param messageResponse Message of the response
                     * @return true if is success
                     */
                    bool sendResultsPackages ( const std::string & centerName, const std::string & devicePath, std::string & messageResponse );

                private:

                    Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * networkInterface; ///< The network interface
                    static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
            };

        } /* namespace Operation */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* RESULTSPACKAGETRANSMISSIONMANAGER_HXX_ */
