/**
 * @file CryptoSmartcard.hxx
 * @brief Declaration of the CryptoSmartcard class.
 * @author Youssef.tourkmani
 * @date 01/11/2012
 */

#ifndef CRYPTOSMARTCARD_HXX_
#define CRYPTOSMARTCARD_HXX_

#include <Security/CryptoData.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Security
            {
                /**
                 * @class CryptoSmartcard
                 * @brief Represents the cryptographic data to read and write data to a smartcard.
                 * @author Youssef.tourkmani
                 * @date 01/11/2012
                 */

                class CryptoSmartcard : public Smartmatic::SAES::Security::CryptoData
                {
                    public:

                        /**
                         * @fn CryptoSmartcard::CryptoSmartcard();
                         * @brief Default constructor for the CryptoSmartcard class.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        CryptoSmartcard();

                        /**
                         * @fn virtual CryptoSmartcard::~CryptoSmartcard();
                         * @brief Finalizes an instance of the CryptoSmartcard class.
                         * @author Youssef.tourkmani
                         * @date 01/11/2012
                         */

                        virtual ~CryptoSmartcard();

                        /**
                         * @fn virtual void generatePin();
                         * @brief Generates the secure key pin for the smartcard.
                         * @author Yadickson Soto
                         * @date 07/05/2013
                         */

                        virtual void generatePin();

                        /**
                         * @fn virtual void generateKeys();
                         * @brief Generate key and initialization vector for the smartcard.
                         * @author Yadickson Soto
                         * @date 07/05/2013
                         */

                        virtual void generateKeys();
                };
            }
        }
    }
}

#endif /* CRYPTOSMARTCARD_HXX_ */
