/**
 * @file   AudioVotingResources.hxx
 * @brief  Declaration of AudioVotingResources class.
 * Provides different resources according to the able device in use.
 * @author manuel.arguelles
 * @date   Apr 12, 2018
 */

#ifndef AUDIO_VOTING_RESOURCES_HXX
#define AUDIO_VOTING_RESOURCES_HXX

#include <string>
#include "AudioVotingCheckUtility.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace Resources
        {
            class GeneralAudioResourcesManager;
        }

        namespace Operation
        {
            namespace AudioVoting
            {
                /**
                 * @class  AudioVotingResources
                 * @brief  Provide the generic audio resource according to the
                 * able device in use.
                 * @author manuel.arguelles
                 * @date   Apr 12, 2018
                 */
                class AudioVotingResources
                {
                    public:

                        /**
                         * @brief  Creates an instance of the class.
                         * @author manuel.arguelles
                         * @date   Apr 12, 2018
                         */
                        AudioVotingResources();

                        /**
                         * @brief  Destroys an instance of the class.
                         * @author manuel.arguelles
                         * @date   Apr 12, 2018
                         */
                        ~AudioVotingResources();

                    public:

                        /**
                         * @brief  Gets the audio resource for the given key.
                         * Based on the Able Device. If the key is not found,
                         * fallback to the original key (without Able type).
                         * @author manuel.arguelles
                         * @date   Apr 12, 2018
                         * @param  key The resource key.
                         * @return The audio resource.
                         */
                        std::string getResource(const std::string& key);

                    private:

                        /**
                         * @brief  Include the able device type in the key.
                         * @author manuel.arguelles
                         * @date   Apr 12, 2018
                         * @param  key       The resource key.
                         * @return The key with for the able device.
                         */
                        std::string getKeyByAbled(const std::string& key);

                    private:

                        AudioVotingCheckUtility                        m_abledCheckUtility;
                        SAES::Resources::GeneralAudioResourcesManager* m_generalAudioResources;
                        AudioVotingCheckUtility::ABLED_CONNECTED       m_abledType;
                };

            } /* namespace AudioVoting */
        } /* namespace Operation */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* AUDIO_VOTING_RESOURCES_HXX */
