/**
 * @file	FillVote.hxx
 * @brief	fill vote class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef __FILL_VOTE_H__
#define __FILL_VOTE_H__

#include <Voting/ElectoralConfiguration.hxx>
#include <Voting/Vote/vote-schema.hxx>
#include "VotingMemento.hxx"
#include <vector>
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Operation
        {
            namespace Voting
            {
                /**
                 * @class	FillVote
                 * @brief	Header class FillVote.
                 * @author	Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
                 * @date	23-03-2011
                 */

                class FillVote
                {
                    public:

                        /**
                         * @fn	FillVote::FillVote ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration );
                         * @brief	class constructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	electoralConfiguration	electoral configuration.
                         */

                        explicit FillVote ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration );

                        /**
                         * @fn	virtual FillVote::~FillVote ();
                         * @brief	Finaliser.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */

                        virtual ~FillVote ();

                        /**
                         * @fn	void FillVote::fillNormalVote ( Smartmatic::SAES::Voting::Vote::Vote & vote,
                         * 			int & contestCount, int & ballotOptionCount,
                         * 			std::vector < Smartmatic::SAES::Operation::Voting::VotingMemento * > & caretaker ) throw ( Smartmatic::System::Exception::ElectionException );
                         * @brief	method to fill normal vote.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @exception	Smartmatic::System::Exception::ElectionException	Thrown when an election error
                         * 																															condition occurs.
                         * @param	vote						 	vote.
                         * @param	contestCount		 	contest count.
                         * @param	ballotOptionCount	count of ballot option of contest.
                         * @param	caretaker				 	list memento state
                         * 													@throw ElectionException.
                         */

                        void fillNormalVote ( Smartmatic::SAES::Voting::Vote::Vote & vote,
                                              int & contestCount,
                                              int & ballotOptionCount,
                                              std::vector < Smartmatic::SAES::Operation::Voting::VotingMemento * > & caretaker )
                        throw ( Smartmatic::System::Exception::ElectionException );

                    private:
                        static Smartmatic::Log::ISMTTLog * logger;	///< The logger
                        Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration;   ///< The electoral configuration
                };
            }
        }
    }
}

#endif /*__FILL_VOTE_H__*/
