/*
 * BeforeGeneratingResultsComplianceVerificator.hxx
 *
 *  Created on: Feb 14, 2018
 *      Author: eduardo.fernandez
 */

#ifndef BEFORE_GENERATING_RESULTS_COMPLIANCE_VERIFICATOR_HXX
#define BEFORE_GENERATING_RESULTS_COMPLIANCE_VERIFICATOR_HXX

#include <string>
#include <list>
#include <vector>
#include <map>
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace Voting
        {
            class ElectoralConfiguration;

            namespace Vote
            {
                class StationTallyWrapper;
            }

            namespace PBReports
            {
                class VoteResults;
                class VoteStatisticsWrapper;
            }

            namespace Eml
            {
                class EML;
            }
        }

        namespace Operation
        {
            namespace VoteCompliance
            {
                class VoteComplianceVerificationManager;

                /**
                 * @class	BeforeGeneratingResultsComplianceVerificator
                 * @brief	Header class BeforePrintingVoteComplianceVerificator.
                 * @author	eduardo.fernandez
                 * @date	Feb 14, 2018
                 */
                class BeforeGeneratingResultsComplianceVerificator
                {
                    public:

                        /**
                         * @fn	BeforeGeneratingResultsComplianceVerificator::BeforeGeneratingResultsComplianceVerificator ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration );
                         * @brief	Class constructor.
                         * @param	electoralConfiguration	electoral configuration.
                         * @author	eduardo.fernandez
                         * @date	Feb 14, 2018
                         */
                        explicit BeforeGeneratingResultsComplianceVerificator(Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration = NULL);

                        /**
                         * @fn	virtual BeforeGeneratingResultsComplianceVerificator::~BeforeGeneratingResultsComplianceVerificator();
                         * @brief	Finalizer.
                         * @author	eduardo.fernandez
                         * @date	Feb 14, 2018
                         */
                        virtual ~BeforeGeneratingResultsComplianceVerificator();


                        /**
                         * @fn  bool BeforeGeneratingResultsComplianceVerificator::checkTotalCumulativeSelections(const size_t totalVotes, const Smartmatic::SAES::Voting::PBReports::VoteResults &voteResults);
                         * @brief    Checks whether the cumulative number of categorized votes don't exceed the total number of votes.
                         * @param    voteResults The vote results.
                         * @param    totalVotes The total number of votes.
                         * @return   Whether the cumulative number of categorized votes don't exceed the total number of votes.
                         * @author   eduardo.fernandez
                         * @date     Feb 14, 2018
                         */
                        bool checkTotalCumulativeSelections(
                            const size_t totalVotes,
                            const Smartmatic::SAES::Voting::PBReports::VoteResults &voteResults);

                        /**
                         * @fn  bool BeforeGeneratingResultsComplianceVerificator::checkIndividualCumulativeSelections(const Smartmatic::SAES::Voting::PBReports::VoteResults &voteResults);
                         * @brief    Checks whether the cumulative number of categorized votes for a single list don't
                         *           exceed the total number of votes for that list.
                         * @param    voteResults The vote results.
                         * @return   Whether the cumulative number of categorized votes for a single list don't
                         *           exceed the total number of votes for that list.
                         * @author   eduardo.fernandez
                         * @date     Feb 15, 2018
                         */
                        bool checkIndividualCumulativeSelections(const Smartmatic::SAES::Voting::PBReports::VoteResults &voteResults);

                        /*
                         * @fn bool BeforeGeneratingResultsComplianceVerificator::checkEmlVotesDeposited(const std::map<std::string, Voting::Eml::EML>& plainEmlFiles);
                         * @brief   Checks whether the total votes deposited matches the sum of valid and invalid votes.
                         * @param   plainEmlFiles The map containing the plain EML files to verify.
                         * @return  Whether the total votes deposited matches the sum of valid and invalid votes.
                         * @author  eduardo.fernandez
                         * @date    Nov 13, 2018
                         */
                        bool checkEmlVotesDeposited(const std::map<std::string, Voting::Eml::EML>& plainEmlFiles);

                        /*
                         * @fn bool BeforeGeneratingResultsComplianceVerificator::checkEmlVotesByVoterType(const std::map<std::string, Voting::Eml::EML>& plainEmlFiles);
                         * @brief   Checks whether the sum of votes by voter type matches the total voters number.
                         * @param   plainEmlFiles The map containing the plain EML files to verify.
                         * @return  Whether the sum of votes by voter type matches the total voters number.
                         * @author  eduardo.fernandez
                         * @date    Nov 13, 2018
                         */
                        bool checkEmlVotesByVoterType(const std::map<std::string, Voting::Eml::EML>& plainEmlFiles);

                        /**
                         * @fn bool BeforeGeneratingResultsComplianceVerificator::checkEmlVotesCounter(const std::map<std::string, Voting::Eml::EML>& plainEmlFiles, Smartmatic::SAES::Voting::PBReports::VoteStatisticsWrapper * const voteStatisticsWrapper);
                         * @brief Checks whether the EML votes deposited match the vote statistics votes counter by contest.
                         * @param plainEmlFiles The map containing the plain EML files to verify.
                         * @param voteStatisticsWrapper Thw vote statistics wrapper.
                         */
                        bool checkEmlVotesCounter(
                            const std::map<std::string, Voting::Eml::EML>& plainEmlFiles,
                            Smartmatic::SAES::Voting::PBReports::VoteStatisticsWrapper * const voteStatisticsWrapper);

                    private:

                        static Smartmatic::Log::ISMTTLog * m_logger;	///< the logger
                        VoteComplianceVerificationManager * m_voteComplianceVerificationManager;
                };
            }
        }
    }
}

#endif /* BEFORE_GENERATING_RESULTS_COMPLIANCE_VERIFICATOR_HXX */
