#ifndef TEST_RESULTS_PACKAGE_TRANSMISSION_CONF_MANAGER_TEST
#define TEST_RESULTS_PACKAGE_TRANSMISSION_CONF_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include "MockBasicResultsPackageTransmissionConfManager.hxx"
#include <tests/MockSaesFunctionalityConfigurationManager.hxx>
#include <tests/MockConfigurationPersistenceManager.hxx>

class ResultsPackageTransmissionConfManagerTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::SAES::Functionality::Configuration::ResultsPackageTransmissionConfManager ResultsPackageTransmissionConfManager;
        typedef Smartmatic::SAES::Functionality::Configuration::SAESFunctionalityConfigurationManager SAESFunctionalityConfigurationManager;
        typedef Smartmatic::Configuration::ConfigurationPersistenceManager ConfigurationPersistenceManager;
        typedef Smartmatic::SAES::Functionality::Configuration::ResultsPackageTransmissionConfiguration ResultsPackageTransmissionConfiguration;

        ResultsPackageTransmissionConfManagerTest()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testResultsPackageTransmissionConfigurationIsPresent()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            CPPUNIT_ASSERT ( true == SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().present() );

            persistenceManager.verify();
        }

        void testResultsPackageTransmissionConfigurationDefault()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().reset();

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            CPPUNIT_ASSERT ( "network-script" == resultsPackageTransmissionManager->getNetworkManagerScript() );
            CPPUNIT_ASSERT ( "results-script" == resultsPackageTransmissionManager->getResultsTransmissionScript() );
            CPPUNIT_ASSERT ( "config-file" == resultsPackageTransmissionManager->getConfigFileName() );
            CPPUNIT_ASSERT ( "debug-file" == resultsPackageTransmissionManager->getDebugFileName() );
            CPPUNIT_ASSERT ( "results-file" == resultsPackageTransmissionManager->getResultsFileName() );
            CPPUNIT_ASSERT ( "response-file" == resultsPackageTransmissionManager->getResponseFileName() );
            CPPUNIT_ASSERT ( true == resultsPackageTransmissionManager->getFileListToArchive ( "" ).empty() );
            CPPUNIT_ASSERT ( false == resultsPackageTransmissionManager->isUpDownInterfaceScriptNeeded() );
            CPPUNIT_ASSERT ( false == resultsPackageTransmissionManager->isSendResultsPackageScriptNeeded() );
            CPPUNIT_ASSERT ( false == resultsPackageTransmissionManager->useStaticIP() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetNetworkManagerScriptPath()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.setNetworkManagerScript ( "smtt-network-manager-script" );
            CPPUNIT_ASSERT ( "smtt-network-manager-script" == resultsPackageTransmissionManager->getNetworkManagerScript() );

            config.setNetworkManagerScript ( "smtt-network-manager" );
            CPPUNIT_ASSERT ( "smtt-network-manager" == resultsPackageTransmissionManager->getNetworkManagerScript() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetResultsTransmissionScript()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.setResultsTransmissionScript ( "smtt-send-results-script" );
            CPPUNIT_ASSERT ( "smtt-send-results-script" == resultsPackageTransmissionManager->getResultsTransmissionScript() );

            config.setResultsTransmissionScript ( "smtt-send-results" );
            CPPUNIT_ASSERT ( "smtt-send-results" == resultsPackageTransmissionManager->getResultsTransmissionScript() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetForceExecuteNetworkManager()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.setForceUpDown ( true );
            CPPUNIT_ASSERT ( true == resultsPackageTransmissionManager->isUpDownInterfaceScriptNeeded() );

            config.setForceUpDown ( false );
            CPPUNIT_ASSERT ( false == resultsPackageTransmissionManager->isUpDownInterfaceScriptNeeded() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetSendResultsPackageTransmission()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.setSendResults ( true );
            CPPUNIT_ASSERT ( true == resultsPackageTransmissionManager->isSendResultsPackageScriptNeeded() );

            config.setSendResults ( false );
            CPPUNIT_ASSERT ( false == resultsPackageTransmissionManager->isSendResultsPackageScriptNeeded() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetConfigurationFileName()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.setConfigFileName ( "config-file" );
            CPPUNIT_ASSERT ( "config-file" == resultsPackageTransmissionManager->getConfigFileName() );

            config.setConfigFileName ( "other-config-file" );
            CPPUNIT_ASSERT ( "other-config-file" == resultsPackageTransmissionManager->getConfigFileName() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetDebugConfigurationFileName()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.setDebugFileName ( "debug-file" );
            CPPUNIT_ASSERT ( "debug-file" == resultsPackageTransmissionManager->getDebugFileName() );

            config.setDebugFileName ( "other-debug-file" );
            CPPUNIT_ASSERT ( "other-debug-file" == resultsPackageTransmissionManager->getDebugFileName() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetFileListToArchives_EmptyList()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.getFileListToArchive().getFileName().clear();
            CPPUNIT_ASSERT ( true == resultsPackageTransmissionManager->getFileListToArchive ( "/device/path" ).empty() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetFileListToArchives_OneElement()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.getFileListToArchive().getFileName().clear();
            config.getFileListToArchive().getFileName().push_back ( "SAESLocal" );

            std::string result = resultsPackageTransmissionManager->getFileListToArchive ( "/device/path" );
            std::string expected = "/device/path/SAESLocal";

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expected == result );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetFileListToArchives_TwoElements()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.getFileListToArchive().getFileName().clear();
            config.getFileListToArchive().getFileName().push_back ( "export" );
            config.getFileListToArchive().getFileName().push_back ( "SAESLocal/Docs" );

            std::string result = resultsPackageTransmissionManager->getFileListToArchive ( "/device/path" );
            std::string expected = "/device/path/export /device/path/SAESLocal/Docs";

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expected == result );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetResultsFileName()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.setResultsFileName ( "results-file" );
            CPPUNIT_ASSERT ( "results-file" == resultsPackageTransmissionManager->getResultsFileName() );

            config.setResultsFileName ( "other-results-file" );
            CPPUNIT_ASSERT ( "other-results-file" == resultsPackageTransmissionManager->getResultsFileName() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetResponseFileName()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.setResponseFileName ( "response-file" );
            CPPUNIT_ASSERT ( "response-file" == resultsPackageTransmissionManager->getResponseFileName() );

            config.setResponseFileName ( "other-response-file" );
            CPPUNIT_ASSERT ( "other-response-file" == resultsPackageTransmissionManager->getResponseFileName() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetUseStaticIP()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            config.setDHCP ( true );
            CPPUNIT_ASSERT ( false == resultsPackageTransmissionManager->useStaticIP() );

            config.setDHCP ( false );
            CPPUNIT_ASSERT ( true == resultsPackageTransmissionManager->useStaticIP() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testGetAllConfigurationValues()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesFunctionalityConfigurationManager configurationManager;
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            ResultsPackageTransmissionConfiguration & config ( SAESFunctionalityConfigurationManager::getInstance()->getConfiguration()->getResultsPackageTransmission().get() );
            config.setNetworkManagerScript ( "smtt-network-manager" );
            config.setResultsTransmissionScript ( "smtt-send-results" );
            config.setForceUpDown ( true );
            config.setSendResults ( false );

            ResultsPackageTransmissionConfManager * resultsPackageTransmissionManager = ResultsPackageTransmissionConfManager::getInstance();

            CPPUNIT_ASSERT ( "smtt-network-manager" == resultsPackageTransmissionManager->getNetworkManagerScript() );
            CPPUNIT_ASSERT ( "smtt-send-results" == resultsPackageTransmissionManager->getResultsTransmissionScript() );
            CPPUNIT_ASSERT ( true == resultsPackageTransmissionManager->isUpDownInterfaceScriptNeeded() );
            CPPUNIT_ASSERT ( false == resultsPackageTransmissionManager->isSendResultsPackageScriptNeeded() );

            delete resultsPackageTransmissionManager;

            persistenceManager.verify();
        }

        void testMockGetFulCommand_OnlyScript()
        {
            MockBasicResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, getResultsTransmissionScript ) getResultsTransmissionScript_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, getConfigFileName ) getConfigFileName_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, getDebugFileName ) getDebugFileName_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR_EXT ( MockBasicResultsPackageTransmissionConfManager, getFileListToArchive, ext ) getFileListToArchive_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, getResultsFileName ) getResultsFileName_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, getResponseFileName ) getResponseFileName_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, useStaticIP ) useStaticIP_mock ( &resultsPackageTransmissionManager );

            getResultsTransmissionScript_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            getConfigFileName_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "" ) );

            getDebugFileName_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "" ) );

            getFileListToArchive_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "" ) );

            getResultsFileName_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "" ) );

            getResponseFileName_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "" ) );

            useStaticIP_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( false ) );

            std::string response = resultsPackageTransmissionManager.getFullCommandToSendResults ( "", "", "/device/path" );
            std::string expected = "script";

            CPPUNIT_ASSERT ( false == response.empty() );
            CPPUNIT_ASSERT ( expected == response );

            resultsPackageTransmissionManager.verify();
        }

        void testMockGetFulCommand_AllParameters()
        {
            MockBasicResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, getResultsTransmissionScript ) getResultsTransmissionScript_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, getConfigFileName ) getConfigFileName_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, getDebugFileName ) getDebugFileName_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR_EXT ( MockBasicResultsPackageTransmissionConfManager, getFileListToArchive, ext ) getFileListToArchive_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, getResultsFileName ) getResultsFileName_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, getResponseFileName ) getResponseFileName_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockBasicResultsPackageTransmissionConfManager, useStaticIP ) useStaticIP_mock ( &resultsPackageTransmissionManager );

            getResultsTransmissionScript_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            getConfigFileName_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "config" ) );

            getDebugFileName_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "debug" ) );

            getFileListToArchive_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "export docs" ) );

            getResultsFileName_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "results" ) );

            getResponseFileName_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "response" ) );

            useStaticIP_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            std::string response = resultsPackageTransmissionManager.getFullCommandToSendResults ( "center", "eth0", "/device/path" );
            std::string expected = "script -p center -i eth0 -f \"export docs\" -c /device/path/config -d /device/path/debug -r results -s response -x";

            CPPUNIT_ASSERT ( false == response.empty() );
            CPPUNIT_ASSERT ( expected == response );

            resultsPackageTransmissionManager.verify();
        }

        CPPUNIT_TEST_SUITE ( ResultsPackageTransmissionConfManagerTest );

        CPPUNIT_TEST ( testResultsPackageTransmissionConfigurationIsPresent );
        CPPUNIT_TEST ( testResultsPackageTransmissionConfigurationDefault );
        CPPUNIT_TEST ( testGetNetworkManagerScriptPath );
        CPPUNIT_TEST ( testGetResultsTransmissionScript );
        CPPUNIT_TEST ( testGetForceExecuteNetworkManager );
        CPPUNIT_TEST ( testGetSendResultsPackageTransmission );
        CPPUNIT_TEST ( testGetConfigurationFileName );
        CPPUNIT_TEST ( testGetDebugConfigurationFileName );
        CPPUNIT_TEST ( testGetFileListToArchives_EmptyList );
        CPPUNIT_TEST ( testGetFileListToArchives_OneElement );
        CPPUNIT_TEST ( testGetFileListToArchives_TwoElements );
        CPPUNIT_TEST ( testGetResultsFileName );
        CPPUNIT_TEST ( testGetResponseFileName );
        CPPUNIT_TEST ( testGetUseStaticIP );
        CPPUNIT_TEST ( testGetAllConfigurationValues );

        CPPUNIT_TEST ( testMockGetFulCommand_OnlyScript );
        CPPUNIT_TEST ( testMockGetFulCommand_AllParameters );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_RESULTS_PACKAGE_TRANSMISSION_CONF_MANAGER_TEST */
