#ifndef AUDIO_VOTING_RESOURCES_TEST
#define AUDIO_VOTING_RESOURCES_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Operation/Voting/AudioVoting/AudioVotingResources.hxx>
#include <Configuration/s-a-e-s-common-conf-manager.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Resources/GeneralAudioResourcesManager.hxx>
#include <tests/MockSaesCommonConfigurationManager.hxx>
#include <tests/MockSaesFunctionalityConfigurationManager.hxx>
#include <tests/MockA4517AbledController.hxx>
#include <tests/MockGeneralAudioResourcesManager.hxx>
#include <tests/MockKeyManager.hxx>

using namespace Smartmatic::SAES::Functionality::Configuration;
using namespace Smartmatic::SAES::Operation::AudioVoting;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::SAES::Common::Security;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Resources;

class AudioVotingResourcesTest : public CPPUNIT_NS::TestFixture
{
    public:

        AudioVotingResourcesTest()
        {
            mockedKeyManager = new MockKeyManager();

            KeyManager::getInstance(mockedKeyManager);
        }

        ~AudioVotingResourcesTest()
        {
            delete mockedKeyManager;
        }

        void setUp()
        {
        }

        void tearDown()
        {
        }

    public:

        void testResourcesAble1()
        {
            std::string plainKey = "smartmatic.saes.operation.audiovoting.AudioVotingLanguageSelection.WelcomeMessage";
            std::string expectedKey = "smartmatic.saes.operation.audiovoting.AudioVotingLanguageSelection.Able1WelcomeMessage";
            std::string expectedResource = "Welcome Message Able 1";

            MockA4517AbledController abledController;
            MockGeneralAudioResourcesManager audioResources;
            MockSaesCommonConfigurationManager saesCommonConf;
            MockSaesFunctionalityConfigurationManager saesFunctionalityConf;

            SAESCommonConfigurationManager::getInstance(&saesCommonConf);
            SAESFunctionalityConfigurationManager::getInstance(&saesFunctionalityConf);
            A4517AbledController::getInstance(&abledController);
            GeneralAudioResourcesManager::getInstance(&audioResources);

            MOCKPP_CHAINER_FOR(MockA4517AbledController, isPresent) isPresent_mock(&abledController);

            isPresent_mock.expects(MOCKPP_NS::once()).will(MOCKPP_NS::returnValue<bool>(false));

            MOCKPP_CHAINER_FOR_EXT(
                MockGeneralAudioResourcesManager,
                getResource,
                ext) getResource_mock(&audioResources);

            getResource_mock
                .expects(MOCKPP_NS::once())
                .with(MOCKPP_NS::eq(expectedKey))
                .will(new MOCKPP_NS::ReturnStub<std::string>(expectedResource));

            AudioVotingResources res;

            std::string result = res.getResource(plainKey);

            CPPUNIT_ASSERT_EQUAL(expectedResource, result);
        }

        void testResourcesAble2()
        {
            std::string plainKey = "smartmatic.saes.operation.audiovoting.AudioVotingLanguageSelection.WelcomeMessage";
            std::string expectedKey = "smartmatic.saes.operation.audiovoting.AudioVotingLanguageSelection.Able2WelcomeMessage";
            std::string expectedResource = "Welcome Message Able 2";

            MockA4517AbledController abledController;
            MockGeneralAudioResourcesManager audioResources;
            MockSaesCommonConfigurationManager saesCommonConf;
            MockSaesFunctionalityConfigurationManager saesFunctionalityConf;

            SAESCommonConfigurationManager::getInstance(&saesCommonConf);
            SAESFunctionalityConfigurationManager::getInstance(&saesFunctionalityConf);
            A4517AbledController::getInstance(&abledController);
            GeneralAudioResourcesManager::getInstance(&audioResources);

            MOCKPP_CHAINER_FOR(MockA4517AbledController, isPresent) IsPresent_mock(&abledController);

            IsPresent_mock.expects(MOCKPP_NS::once()).will(MOCKPP_NS::returnValue<bool>(true));

            MOCKPP_CHAINER_FOR_EXT(
                MockGeneralAudioResourcesManager,
                getResource,
                ext) getResource_mock(&audioResources);

            getResource_mock
                .expects(MOCKPP_NS::once())
                .with(MOCKPP_NS::eq(expectedKey))
                .will(new MOCKPP_NS::ReturnStub<std::string>(expectedResource));

            AudioVotingResources res;

            std::string result = res.getResource(plainKey);

            CPPUNIT_ASSERT_EQUAL(expectedResource, result);

        }

        void testResourcesAble1Fallback()
        {
            std::string plainKey = "smartmatic.saes.operation.audiovoting.AudioVotingLanguageSelection.WelcomeMessage";
            std::string expectedKey = "smartmatic.saes.operation.audiovoting.AudioVotingLanguageSelection.Able1WelcomeMessage";
            std::string expectedResource = "Welcome Message";

            MockA4517AbledController abledController;
            MockGeneralAudioResourcesManager audioResources;
            MockSaesCommonConfigurationManager saesCommonConf;
            MockSaesFunctionalityConfigurationManager saesFunctionalityConf;

            SAESCommonConfigurationManager::getInstance(&saesCommonConf);
            SAESFunctionalityConfigurationManager::getInstance(&saesFunctionalityConf);
            A4517AbledController::getInstance(&abledController);
            GeneralAudioResourcesManager::getInstance(&audioResources);

            MOCKPP_CHAINER_FOR(MockA4517AbledController, isPresent) isPresent_mock(&abledController);

            isPresent_mock.expects(MOCKPP_NS::once()).will(MOCKPP_NS::returnValue<bool>(false));

            MOCKPP_CHAINER_FOR_EXT(
                MockGeneralAudioResourcesManager,
                getResource,
                ext) getResource_mock(&audioResources);

            getResource_mock
                .expects(MOCKPP_NS::once())
                .with(MOCKPP_NS::eq(expectedKey))
                .will(new MOCKPP_NS::ReturnStub<std::string>(expectedKey));

            getResource_mock
                .expects(MOCKPP_NS::once())
                .with(MOCKPP_NS::eq(plainKey))
                .will(new MOCKPP_NS::ReturnStub<std::string>(expectedResource));

            AudioVotingResources res;

            std::string result = res.getResource(plainKey);

            CPPUNIT_ASSERT_EQUAL(expectedResource, result);
        }

        void testResourcesAble2Fallback()
        {
            std::string plainKey = "smartmatic.saes.operation.audiovoting.AudioVotingLanguageSelection.WelcomeMessage";
            std::string expectedKey = "smartmatic.saes.operation.audiovoting.AudioVotingLanguageSelection.Able2WelcomeMessage";
            std::string expectedResource = "Welcome Message";

            MockA4517AbledController abledController;
            MockGeneralAudioResourcesManager audioResources;
            MockSaesCommonConfigurationManager saesCommonConf;
            MockSaesFunctionalityConfigurationManager saesFunctionalityConf;

            SAESCommonConfigurationManager::getInstance(&saesCommonConf);
            SAESFunctionalityConfigurationManager::getInstance(&saesFunctionalityConf);
            A4517AbledController::getInstance(&abledController);
            GeneralAudioResourcesManager::getInstance(&audioResources);

            MOCKPP_CHAINER_FOR(MockA4517AbledController, isPresent) IsPresent_mock(&abledController);

            IsPresent_mock.expects(MOCKPP_NS::once()).will(MOCKPP_NS::returnValue<bool>(true));

            MOCKPP_CHAINER_FOR_EXT(
                MockGeneralAudioResourcesManager,
                getResource,
                ext) getResource_mock(&audioResources);

            getResource_mock
                .expects(MOCKPP_NS::once())
                .with(MOCKPP_NS::eq(expectedKey))
                .will(new MOCKPP_NS::ReturnStub<std::string>(expectedKey));

            getResource_mock
                .expects(MOCKPP_NS::once())
                .with(MOCKPP_NS::eq(plainKey))
                .will(new MOCKPP_NS::ReturnStub<std::string>(expectedResource));

            AudioVotingResources res;

            std::string result = res.getResource(plainKey);

            CPPUNIT_ASSERT_EQUAL(expectedResource, result);
        }

        CPPUNIT_TEST_SUITE(AudioVotingResourcesTest);

        CPPUNIT_TEST(testResourcesAble1);
        CPPUNIT_TEST(testResourcesAble2);
        CPPUNIT_TEST(testResourcesAble1Fallback);
        CPPUNIT_TEST(testResourcesAble2Fallback);

        CPPUNIT_TEST_SUITE_END();

    private:

        MockKeyManager* mockedKeyManager;
};

#endif /* ECUT_MAIN */

#endif /* AUDIO_VOTING_RESOURCES_TEST */
