#ifndef TEST_FILE_KEY_LOGIN_MANAGER_TEST
#define TEST_FILE_KEY_LOGIN_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include "ChainMockFileKeyLoginManager.hxx"

class FileKeyLoginManagerTest : public CPPUNIT_NS::TestFixture
{
    public:

        FileKeyLoginManagerTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testAuthenticationNotInstallWrongPassword()
        {
            std::string pass;
            std::string rnd;
            std::string votingCenterCode;
            ChainMockFileKeyLoginManager mockLogin;

            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, isInstall ) isInstall_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadOfficialKey ) loadOfficialKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadRecountKey ) loadRecountKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, getMode ) getMode_mock ( &mockLogin );

            isInstall_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "isInstall" ) );

            loadOfficialKey_mock
            .expects ( MOCKPP_NS::once() )
            .after ( MOCKPP_PCHAR ( "isInstall" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "loadOfficialKey") );

            loadRecountKey_mock
            .expects ( MOCKPP_NS::once() )
            .after ( MOCKPP_PCHAR ( "loadOfficialKey" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "loadRecountKey" ) );

            getMode_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == mockLogin.authentication ( pass, votingCenterCode, rnd ) );
            mockLogin.verify();
        }

        void testAuthenticationNotInstallOfficialPassword()
        {
            std::string pass;
            std::string rnd;
            std::string votingCenterCode;
            ChainMockFileKeyLoginManager mockLogin;

            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, isInstall ) isInstall_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadOfficialKey ) loadOfficialKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadRecountKey ) loadRecountKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR_EXT ( ChainMockFileKeyLoginManager, setMode, ext ) setMode_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, getMode ) getMode_mock ( &mockLogin );

            isInstall_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "isInstall" ) );

            loadOfficialKey_mock
            .expects ( MOCKPP_NS::once() )
            .after ( MOCKPP_PCHAR ( "isInstall" ) )
            .will ( MOCKPP_NS::returnValue ( true ) );

            loadRecountKey_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue ( false ) );

            setMode_mock
            .expects ( MOCKPP_NS::once() );

            getMode_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == mockLogin.authentication ( pass, votingCenterCode, rnd ) );
            mockLogin.verify();
        }

        void testAuthenticationNotInstallRecountPassword()
        {
            std::string pass;
            std::string rnd;
            std::string votingCenterCode;
            ChainMockFileKeyLoginManager mockLogin;

            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, isInstall ) isInstall_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadOfficialKey ) loadOfficialKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadRecountKey ) loadRecountKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR_EXT ( ChainMockFileKeyLoginManager, setMode, ext ) setMode_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, getMode ) getMode_mock ( &mockLogin );

            isInstall_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "isInstall" ) );

            loadOfficialKey_mock
            .expects ( MOCKPP_NS::once() )
            .after ( MOCKPP_PCHAR ( "isInstall" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "loadOfficialKey" ) );

            loadRecountKey_mock
            .expects ( MOCKPP_NS::once() )
            .after ( MOCKPP_PCHAR ( "loadOfficialKey" ) )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "loadRecountKey" ) );

            setMode_mock
            .expects ( MOCKPP_NS::once() );

            getMode_mock
            .expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == mockLogin.authentication ( pass, votingCenterCode, rnd ) );
            mockLogin.verify();
        }

        void testAuthenticationIfInstallOfficialAndWrongPassword()
        {
            std::string pass;
            std::string rnd;
            std::string votingCenterCode;
            ChainMockFileKeyLoginManager mockLogin;

            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, isInstall ) isInstall_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadOfficialKey ) loadOfficialKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadRecountKey ) loadRecountKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR_EXT ( ChainMockFileKeyLoginManager, setMode, ext ) setMode_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, getMode ) getMode_mock ( &mockLogin );

            isInstall_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "isInstall" ) );

            loadOfficialKey_mock
            .expects ( MOCKPP_NS::once() )
            .after ( MOCKPP_PCHAR ( "isInstall" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "loadOfficialKey" ) );

            loadRecountKey_mock
            .expects ( MOCKPP_NS::never() )
            .after ( MOCKPP_PCHAR ( "isInstall" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "loadRecountKey" ) );

            setMode_mock
            .expects ( MOCKPP_NS::never() );

            getMode_mock
            .expects ( MOCKPP_NS::atLeastOnce() )
            .will ( new MOCKPP_NS::ReturnStub<Smartmatic::SAES::Voting::VotingCenters::RunningMode> ( Smartmatic::SAES::Voting::VotingCenters::RunningMode::VOTING_CENTER_OFFICIAL ) );

            CPPUNIT_ASSERT ( false == mockLogin.authentication ( pass, votingCenterCode, rnd  ) );
            mockLogin.verify();
        }

        void testAuthenticationIfInstallOfficialAndSuccessPassword()
        {
            std::string pass;
            std::string rnd;
            std::string votingCenterCode;
            ChainMockFileKeyLoginManager mockLogin;

            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, isInstall ) isInstall_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadOfficialKey ) loadOfficialKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadRecountKey ) loadRecountKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR_EXT ( ChainMockFileKeyLoginManager, setMode, ext ) setMode_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, getMode ) getMode_mock ( &mockLogin );

            isInstall_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "isInstall" ) );

            loadOfficialKey_mock
            .expects ( MOCKPP_NS::once() )
            .after ( MOCKPP_PCHAR ( "isInstall" ) )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "loadOfficialKey" ) );

            loadRecountKey_mock
            .expects ( MOCKPP_NS::never() )
            .after ( MOCKPP_PCHAR ( "isInstall" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "loadRecountKey" ) );

            setMode_mock
            .expects ( MOCKPP_NS::never() );

            getMode_mock
            .expects ( MOCKPP_NS::atLeastOnce() )
            .will ( new MOCKPP_NS::ReturnStub<Smartmatic::SAES::Voting::VotingCenters::RunningMode> ( Smartmatic::SAES::Voting::VotingCenters::RunningMode::VOTING_CENTER_OFFICIAL ) );

            CPPUNIT_ASSERT ( true == mockLogin.authentication ( pass, votingCenterCode, rnd ) );
            mockLogin.verify();
        }

        void testAuthenticationIfInstallRecountAndWrongPassword()
        {
            std::string pass;
            std::string rnd;
            std::string votingCenterCode;
            ChainMockFileKeyLoginManager mockLogin;

            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, isInstall ) isInstall_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadOfficialKey ) loadOfficialKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadRecountKey ) loadRecountKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR_EXT ( ChainMockFileKeyLoginManager, setMode, ext ) setMode_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, getMode ) getMode_mock ( &mockLogin );

            isInstall_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "isInstall" ) );

            loadOfficialKey_mock
            .expects ( MOCKPP_NS::never() )
            .after ( MOCKPP_PCHAR ( "isInstall" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "loadOfficialKey" ) );

            loadRecountKey_mock
            .expects ( MOCKPP_NS::once() )
            .after ( MOCKPP_PCHAR ( "isInstall" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "loadRecountKey" ) );

            setMode_mock
            .expects ( MOCKPP_NS::never() );

            getMode_mock
            .expects ( MOCKPP_NS::atLeastOnce() )
            .will ( new MOCKPP_NS::ReturnStub<Smartmatic::SAES::Voting::VotingCenters::RunningMode> ( Smartmatic::SAES::Voting::VotingCenters::RunningMode::VOTING_CENTER_RECOUNT ) );

            CPPUNIT_ASSERT ( false == mockLogin.authentication ( pass, votingCenterCode, rnd ) );
            mockLogin.verify();
        }

        void testAuthenticationIfInstallRecountAndSuccessPassword()
        {
            std::string pass;
            std::string rnd;
            std::string votingCenterCode;
            ChainMockFileKeyLoginManager mockLogin;

            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, isInstall ) isInstall_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadOfficialKey ) loadOfficialKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, loadRecountKey ) loadRecountKey_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR_EXT ( ChainMockFileKeyLoginManager, setMode, ext ) setMode_mock ( &mockLogin );
            MOCKPP_CHAINER_FOR ( ChainMockFileKeyLoginManager, getMode ) getMode_mock ( &mockLogin );

            isInstall_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "isInstall" ) );

            loadOfficialKey_mock
            .expects ( MOCKPP_NS::never() )
            .after ( MOCKPP_PCHAR ( "isInstall" ) )
            .will ( MOCKPP_NS::returnValue ( false ) )
            .id ( MOCKPP_PCHAR ( "loadOfficialKey" ) );

            loadRecountKey_mock
            .expects ( MOCKPP_NS::once() )
            .after ( MOCKPP_PCHAR ( "isInstall" ) )
            .will ( MOCKPP_NS::returnValue ( true ) )
            .id ( MOCKPP_PCHAR ( "loadRecountKey" ) );

            setMode_mock
            .expects ( MOCKPP_NS::never() );

            getMode_mock
            .expects ( MOCKPP_NS::atLeastOnce() )
            .will ( new MOCKPP_NS::ReturnStub<Smartmatic::SAES::Voting::VotingCenters::RunningMode> ( Smartmatic::SAES::Voting::VotingCenters::RunningMode::VOTING_CENTER_RECOUNT ) );

            CPPUNIT_ASSERT ( true == mockLogin.authentication ( pass, votingCenterCode, rnd ) );
            mockLogin.verify();
        }

        CPPUNIT_TEST_SUITE ( FileKeyLoginManagerTest );
        CPPUNIT_TEST ( testAuthenticationNotInstallWrongPassword );
        CPPUNIT_TEST ( testAuthenticationNotInstallOfficialPassword );
        CPPUNIT_TEST ( testAuthenticationNotInstallRecountPassword );
        CPPUNIT_TEST ( testAuthenticationIfInstallOfficialAndWrongPassword );
        CPPUNIT_TEST ( testAuthenticationIfInstallOfficialAndSuccessPassword );
        CPPUNIT_TEST ( testAuthenticationIfInstallRecountAndWrongPassword );
        CPPUNIT_TEST ( testAuthenticationIfInstallRecountAndSuccessPassword );
        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_FILE_KEY_LOGIN_MANAGER_TEST */
