#ifndef TEST_RESULTS_PACKAGE_TRANSMISSION_TEST
#define TEST_RESULTS_PACKAGE_TRANSMISSION_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include "MockResultsPackageTransmissionConfManager.hxx"
#include <tests/MockResultsPackageTransmissionManager.hxx>
#include <tests/MockEthernetMonitor.hxx>
#include <tests/MockProcessLauncher.hxx>
#include <tests/StoreMockProcessLauncher.hxx>

class ResultsTransmissionTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::SAES::Functionality::Configuration::ResultsPackageTransmissionConfManager ResultsPackageTransmissionConfManager;
        typedef Smartmatic::SAES::Operation::ResultsPackageTransmissionManager ResultsPackageTransmissionManager;
        typedef Smartmatic::System::Runtime::ProcessLauncher ProcessLauncher;

        ResultsTransmissionTest()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testMountNetworkInterface_IfUpDownFalse()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( false ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::never() );

            ResultsPackageTransmissionManager resultsPackageTransmission ( NULL );

            CPPUNIT_ASSERT ( true == resultsPackageTransmission.mountNetworkDevice() );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
        }

        void testMountNetworkInterface_IfUpDown_DeviceMonitorNull()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::never() );

            ResultsPackageTransmissionManager resultsPackageTransmission ( NULL );

            CPPUNIT_ASSERT ( false == resultsPackageTransmission.mountNetworkDevice() );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
        }

        void testMountNetworkInterface_IfUpDown_WithDeviceMonitorDisconnected_MountFail()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 1 ) );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <unsigned int> ( 0 ) );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            ResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            CPPUNIT_ASSERT ( false == resultsPackageTransmission.mountNetworkDevice() );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
            deviceMonitor.verify();
        }

        void testMountNetworkInterface_IfUpDown_WithDeviceMonitorDisconnected_RunScriptSuccess_MountFail()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 0 ) );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::returnValue <unsigned int> ( 0 ) );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            ResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            CPPUNIT_ASSERT ( false == resultsPackageTransmission.mountNetworkDevice() );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
            deviceMonitor.verify();
        }

        void testMountNetworkInterface_IfUpDown_WithDeviceMonitorDisconnected_RunScriptSuccess_MountSuccess()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 0 ) );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue <unsigned int> ( 0 ),
                        MOCKPP_NS::returnValue <unsigned int> ( 1 ) ) );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            ResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            CPPUNIT_ASSERT ( true == resultsPackageTransmission.mountNetworkDevice() );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
            deviceMonitor.verify();
        }

        void testMountNetworkInterface_IfUpDown_WithDeviceMonitorConnected_MountSuccess()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::never() );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <unsigned int> ( 1 ) );

            getInterface_mock
            .expects ( MOCKPP_NS::never() );

            ResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            CPPUNIT_ASSERT ( true == resultsPackageTransmission.mountNetworkDevice() );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
            deviceMonitor.verify();
        }

        void testMountNetworkInterface_IfUpDown_WithDeviceMonitorConnected_MountSuccess_GetRunCommand()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue <unsigned int> ( 0 ),
                        MOCKPP_NS::returnValue <unsigned int> ( 1 ) ) );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            ResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            CPPUNIT_ASSERT ( true == resultsPackageTransmission.mountNetworkDevice() );
            CPPUNIT_ASSERT ( "script eth0 up" == launcher.RunProcessThroughSystemCommandLine );
            CPPUNIT_ASSERT ( false == launcher.RunProcessThroughSystemBackground );

            resultsPackageTransmissionManager.verify();
            deviceMonitor.verify();
        }

        void testUmountNetworkInterface_IfUpDownFalse()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( false ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::never() );

            ResultsPackageTransmissionManager resultsPackageTransmission ( NULL );

            CPPUNIT_ASSERT ( true == resultsPackageTransmission.umountNetworkDevice() );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
        }

        void testUmountNetworkInterface_IfUpDown_DeviceMonitorNull()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::never() );

            ResultsPackageTransmissionManager resultsPackageTransmission ( NULL );

            CPPUNIT_ASSERT ( false == resultsPackageTransmission.umountNetworkDevice() );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
        }

        void testUmountNetworkInterface_IfUpDown_UmountFail()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 1 ) );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::never() );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            ResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            CPPUNIT_ASSERT ( false == resultsPackageTransmission.umountNetworkDevice() );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
            deviceMonitor.verify();
        }

        void testUmountNetworkInterface_IfUpDown_RunScriptSuccess_UmountFail()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 0 ) );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <unsigned int> ( 1 ) );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            ResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            CPPUNIT_ASSERT ( false == resultsPackageTransmission.umountNetworkDevice() );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
            deviceMonitor.verify();
        }

        void testUmountNetworkInterface_IfUpDown_UmountSuccess()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 0 ) );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <unsigned int> ( 0 ) );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            ResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            CPPUNIT_ASSERT ( true == resultsPackageTransmission.umountNetworkDevice() );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
            deviceMonitor.verify();
        }

        void testUmountNetworkInterface_IfUpDown_UmountSuccess_GetRunCommand()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isUpDownInterfaceScriptNeeded ) isUpDownInterfaceScriptNeeded_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, getNetworkManagerScript ) getNetworkManagerScript_mock ( &resultsPackageTransmissionManager );

            isUpDownInterfaceScriptNeeded_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            getNetworkManagerScript_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <unsigned int> ( 0 ) );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            ResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            CPPUNIT_ASSERT ( true == resultsPackageTransmission.umountNetworkDevice() );
            CPPUNIT_ASSERT ( "script eth0 down" == launcher.RunProcessThroughSystemCommandLine );
            CPPUNIT_ASSERT ( false == launcher.RunProcessThroughSystemBackground );

            resultsPackageTransmissionManager.verify();
            deviceMonitor.verify();
        }

        void testMockSendResultsPackageTransmission_IfSendFlagDisable_UmountFail()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR_EXT ( MockResultsPackageTransmissionConfManager, getFullCommandToSendResults, ext ) fullCommand_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isSendResultsPackageScriptNeeded ) sendResults_mock ( &resultsPackageTransmissionManager );

            fullCommand_mock
            .expects ( MOCKPP_NS::never() );

            sendResults_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( false ) );

            MockResultsPackageTransmissionManager resultsPackageTransmission ( NULL );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, mountNetworkDevice ) mountNetworkDevice_mock ( &resultsPackageTransmission );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, umountNetworkDevice ) umountNetworkDevice_mock ( &resultsPackageTransmission );

            mountNetworkDevice_mock
            .expects ( MOCKPP_NS::never() );

            umountNetworkDevice_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( false ) );

            std::string message;

            CPPUNIT_ASSERT ( false == resultsPackageTransmission.sendResultsPackages ( "", "", message ) );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
        }

        void testMockSendResultsPackageTransmission_IfSendFlagDisable_UmountSuccess()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR_EXT ( MockResultsPackageTransmissionConfManager, getFullCommandToSendResults, ext ) fullCommand_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isSendResultsPackageScriptNeeded ) sendResults_mock ( &resultsPackageTransmissionManager );

            fullCommand_mock
            .expects ( MOCKPP_NS::never() );

            sendResults_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( false ) );

            MockResultsPackageTransmissionManager resultsPackageTransmission ( NULL );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, mountNetworkDevice ) mountNetworkDevice_mock ( &resultsPackageTransmission );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, umountNetworkDevice ) umountNetworkDevice_mock ( &resultsPackageTransmission );

            mountNetworkDevice_mock
            .expects ( MOCKPP_NS::never() );

            umountNetworkDevice_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            std::string message;

            CPPUNIT_ASSERT ( true == resultsPackageTransmission.sendResultsPackages ( "", "", message ) );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
        }

        void testMockSendResultsPackageTransmission_IfSendFlag_DeviceMonitorNull()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 0 ) );

            MOCKPP_CHAINER_FOR_EXT ( MockResultsPackageTransmissionConfManager, getFullCommandToSendResults, ext ) fullCommand_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isSendResultsPackageScriptNeeded ) sendResults_mock ( &resultsPackageTransmissionManager );

            fullCommand_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            sendResults_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            MockResultsPackageTransmissionManager resultsPackageTransmission ( NULL );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, mountNetworkDevice ) mountNetworkDevice_mock ( &resultsPackageTransmission );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, umountNetworkDevice ) umountNetworkDevice_mock ( &resultsPackageTransmission );

            mountNetworkDevice_mock
            .expects ( MOCKPP_NS::never() );

            umountNetworkDevice_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            std::string message;

            CPPUNIT_ASSERT ( true == resultsPackageTransmission.sendResultsPackages ( "", "", message ) );

            resultsPackageTransmissionManager.verify();
            launcher.verify();
        }

        void testMockSendResultsPackageTransmission_IfSendFlag_WithDeviceMonitor_SendSuccess()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 0 ) );

            MOCKPP_CHAINER_FOR_EXT ( MockResultsPackageTransmissionConfManager, getFullCommandToSendResults, ext ) fullCommand_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isSendResultsPackageScriptNeeded ) sendResults_mock ( &resultsPackageTransmissionManager );

            fullCommand_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            sendResults_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::never() );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            MockResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, mountNetworkDevice ) mountNetworkDevice_mock ( &resultsPackageTransmission );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, umountNetworkDevice ) umountNetworkDevice_mock ( &resultsPackageTransmission );

            mountNetworkDevice_mock
            .expects ( MOCKPP_NS::never() );

            umountNetworkDevice_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            std::string message;

            CPPUNIT_ASSERT ( true == resultsPackageTransmission.sendResultsPackages ( "", "", message ) );

            resultsPackageTransmissionManager.verify();
            deviceMonitor.verify();
            launcher.verify();
        }

        void testMockSendResultsPackageTransmission_IfSendFlag_WithDeviceMonitor_SendError_ExitOne()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 1 ) );

            MOCKPP_CHAINER_FOR_EXT ( MockResultsPackageTransmissionConfManager, getFullCommandToSendResults, ext ) fullCommand_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isSendResultsPackageScriptNeeded ) sendResults_mock ( &resultsPackageTransmissionManager );

            fullCommand_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            sendResults_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::never() );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            MockResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, mountNetworkDevice ) mountNetworkDevice_mock ( &resultsPackageTransmission );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, umountNetworkDevice ) umountNetworkDevice_mock ( &resultsPackageTransmission );

            mountNetworkDevice_mock
            .expects ( MOCKPP_NS::never() );

            umountNetworkDevice_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            std::string message;

            CPPUNIT_ASSERT ( false == resultsPackageTransmission.sendResultsPackages ( "", "", message ) );

            resultsPackageTransmissionManager.verify();
            deviceMonitor.verify();
            launcher.verify();
        }

        void testMockSendResultsPackageTransmission_IfSendFlag_WithDeviceMonitor_SendError_ExitTwo()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 2 ) );

            MOCKPP_CHAINER_FOR_EXT ( MockResultsPackageTransmissionConfManager, getFullCommandToSendResults, ext ) fullCommand_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isSendResultsPackageScriptNeeded ) sendResults_mock ( &resultsPackageTransmissionManager );

            fullCommand_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            sendResults_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::never() );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            MockResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, mountNetworkDevice ) mountNetworkDevice_mock ( &resultsPackageTransmission );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, umountNetworkDevice ) umountNetworkDevice_mock ( &resultsPackageTransmission );

            mountNetworkDevice_mock
            .expects ( MOCKPP_NS::never() );

            umountNetworkDevice_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            std::string message;

            CPPUNIT_ASSERT ( false == resultsPackageTransmission.sendResultsPackages ( "", "", message ) );

            resultsPackageTransmissionManager.verify();
            deviceMonitor.verify();
            launcher.verify();
        }

        void testMockSendResultsPackageTransmission_IfSendFlag_WithDeviceMonitor_SendError_ExitOtherValue()
        {
            MockResultsPackageTransmissionConfManager resultsPackageTransmissionManager;
            ResultsPackageTransmissionConfManager::getInstance ( &resultsPackageTransmissionManager );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 3 ) );

            MOCKPP_CHAINER_FOR_EXT ( MockResultsPackageTransmissionConfManager, getFullCommandToSendResults, ext ) fullCommand_mock ( &resultsPackageTransmissionManager );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionConfManager, isSendResultsPackageScriptNeeded ) sendResults_mock ( &resultsPackageTransmissionManager );

            fullCommand_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "script" ) );

            sendResults_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            MockEthernetMonitor deviceMonitor;

            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getNumberOfDevices ) getNumberOfDevices_mock ( &deviceMonitor );
            MOCKPP_CHAINER_FOR ( MockEthernetMonitor, getInterface ) getInterface_mock ( &deviceMonitor );

            getNumberOfDevices_mock
            .expects ( MOCKPP_NS::never() );

            getInterface_mock
            .expects ( MOCKPP_NS::once() )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "eth0" ) );

            MockResultsPackageTransmissionManager resultsPackageTransmission ( &deviceMonitor );

            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, mountNetworkDevice ) mountNetworkDevice_mock ( &resultsPackageTransmission );
            MOCKPP_CHAINER_FOR ( MockResultsPackageTransmissionManager, umountNetworkDevice ) umountNetworkDevice_mock ( &resultsPackageTransmission );

            mountNetworkDevice_mock
            .expects ( MOCKPP_NS::never() );

            umountNetworkDevice_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <bool> ( true ) );

            std::string message;

            CPPUNIT_ASSERT ( false == resultsPackageTransmission.sendResultsPackages ( "", "", message ) );

            resultsPackageTransmissionManager.verify();
            deviceMonitor.verify();
            launcher.verify();
        }

        CPPUNIT_TEST_SUITE ( ResultsTransmissionTest );

        CPPUNIT_TEST ( testMountNetworkInterface_IfUpDownFalse );
        CPPUNIT_TEST ( testMountNetworkInterface_IfUpDown_DeviceMonitorNull );
        CPPUNIT_TEST ( testMountNetworkInterface_IfUpDown_WithDeviceMonitorDisconnected_MountFail );
        CPPUNIT_TEST ( testMountNetworkInterface_IfUpDown_WithDeviceMonitorDisconnected_RunScriptSuccess_MountFail );
        CPPUNIT_TEST ( testMountNetworkInterface_IfUpDown_WithDeviceMonitorDisconnected_RunScriptSuccess_MountSuccess );
        CPPUNIT_TEST ( testMountNetworkInterface_IfUpDown_WithDeviceMonitorConnected_MountSuccess );
        CPPUNIT_TEST ( testMountNetworkInterface_IfUpDown_WithDeviceMonitorConnected_MountSuccess_GetRunCommand );

        CPPUNIT_TEST ( testUmountNetworkInterface_IfUpDownFalse );
        CPPUNIT_TEST ( testUmountNetworkInterface_IfUpDown_DeviceMonitorNull );
        CPPUNIT_TEST ( testUmountNetworkInterface_IfUpDown_UmountFail );
        CPPUNIT_TEST ( testUmountNetworkInterface_IfUpDown_RunScriptSuccess_UmountFail );
        CPPUNIT_TEST ( testUmountNetworkInterface_IfUpDown_UmountSuccess );
        CPPUNIT_TEST ( testUmountNetworkInterface_IfUpDown_UmountSuccess_GetRunCommand );

        CPPUNIT_TEST ( testMockSendResultsPackageTransmission_IfSendFlagDisable_UmountFail );
        CPPUNIT_TEST ( testMockSendResultsPackageTransmission_IfSendFlagDisable_UmountSuccess );
        CPPUNIT_TEST ( testMockSendResultsPackageTransmission_IfSendFlag_DeviceMonitorNull );
        CPPUNIT_TEST ( testMockSendResultsPackageTransmission_IfSendFlag_WithDeviceMonitor_SendSuccess );
        CPPUNIT_TEST ( testMockSendResultsPackageTransmission_IfSendFlag_WithDeviceMonitor_SendError_ExitOne );
        CPPUNIT_TEST ( testMockSendResultsPackageTransmission_IfSendFlag_WithDeviceMonitor_SendError_ExitTwo );
        CPPUNIT_TEST ( testMockSendResultsPackageTransmission_IfSendFlag_WithDeviceMonitor_SendError_ExitOtherValue );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_RESULTS_PACKAGE_TRANSMISSION_TEST */
