#ifndef BEFORE_PRINTING_VOTE_VERIFICATION_TEST
#define BEFORE_PRINTING_VOTE_VERIFICATION_TEST

#ifdef ECUT_MAIN

#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <cppunit/extensions/HelperMacros.h>
#include <Operation/MachineOperationManager.hxx>
#include <Operation/Voting/VoteCompliance/VoteComplianceVerificator.hxx>
#include <Resources/election-string-resources-manager.h>
#include <tests/MockElectoralConfiguration.hxx>
#include <tests/MockElectionStringResourcesManager.hxx>
#include <tests/MockSaesFunctionalityConfigurationManager.hxx>
#include <Voting/Election/election-schema.hxx>
#include <Voting/Vote/vote-schema.hxx>
#include <Voting/Vote/VoteFactory.hxx>
#include <Voting/VotingDevice/logical-voter-group-schema.hxx>

using namespace Smartmatic::SAES::Functionality::Configuration;
using namespace Smartmatic::SAES::Operation::VoteCompliance;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::SAES::Voting::Election;
using namespace Smartmatic::SAES::Voting::Vote;
using namespace Smartmatic::SAES::Voting::VotingDevice;
using namespace Smartmatic::SAES::Voting;

static const std::string CONTEST_CODE                                           = "147";
static const std::string ALTERNATIVE_CONTEST_CODE                               = "148";
static const std::string PARTY_CODE                                             = "1712";
static const std::string ALTERNATIVE_PARTY_CODE                                 = "1718";
static const std::string PARTY_NAME                                             = "Mercure";
static const std::string ALTERNATIVE_PARTY_NAME                                 = "Sinasaapel";

static const std::string LOGICAL_VOTER_GROUP_CODE                               = "1";
static const std::string CONTEST_GROUP_CODE                                     = "458";

static const std::string BLANK_VOTE_PARTY_CODE                                  = "";
static const std::string BLANK_VOTE_BALLOT_OPTION_CODE                          = "";

static const std::string LIST_VOTE_ELIGIBLE_OPTION_CODE                         = "38248";
static const std::string ALTERNATIVE_LIST_VOTE_ELIGIBLE_OPTION_CODE             = "38249";
static const std::string LIST_VOTE_ELIGIBLE_OPTION_PARENT_CODE                  = "";
static const std::string LIST_VOTE_BALLOT_OPTION_CODE                           = "48241";
static const std::string ALTERNATIVE_LIST_VOTE_BALLOT_OPTION_CODE               = "48242";

static const std::string PRINCIPAL_VOTE_BALLOT_OPTION_CODE                      = "48359";
static const std::string ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE          = "48360";
static const std::string PRINCIPAL_VOTE_ELIGIBLE_OPTION_CODE                    = "38259";
static const std::string ALTERNATIVE_PRINCIPAL_VOTE_ELIGIBLE_OPTION_CODE        = "38260";
static const std::string PRINCIPAL_VOTE_ELIGIBLE_OPTION_PARENT_CODE             = "38242";
static const std::string ALTERNATIVE_PRINCIPAL_VOTE_ELIGIBLE_OPTION_PARENT_CODE = "38243";

static const std::string STAND_IN_VOTE_BALLOT_OPTION_CODE                       = "48364";
static const std::string ALTERNATIVE_STAND_IN_VOTE_BALLOT_OPTION_CODE           = "48365";
static const std::string STAND_IN_VOTE_ELIGIBLE_OPTION_CODE                     = "38254";
static const std::string ALTERNATIVE_STAND_IN_VOTE_ELIGIBLE_OPTION_CODE         = "38255";
static const std::string STAND_IN_VOTE_ELIGIBLE_OPTION_PARENT_CODE              = "38242";
static const std::string ALTERNATIVE_STAND_IN_VOTE_ELIGIBLE_OPTION_PARENT_CODE  = "38243";

class BeforePrintingVoteVerificationTest : public CPPUNIT_NS::TestFixture
{
    public:

        BeforePrintingVoteVerificationTest ()
        : m_vote(NULL)
        {

        }

        void setUp()
        {
            MockSaesFunctionalityConfigurationManager configurationManager;
            configurationManager.initialize();
            SAESFunctionalityConfigurationManager::getInstance ( &configurationManager );

            initializeMockElectoralConfiguration(m_mockElectoralConfiguration);
            m_selection.setContest(CONTEST_CODE);
            m_vote = VoteFactory::createVote();
            m_vote->getSelections().clear();
            m_ballotOptionsSequence.clear();
            m_selectionsSequence.clear();
        }

        void tearDown()
        {
            VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->dispose();
        }

        void checkMinimumNumberOfSelections_noSelections_invalidContest()
        {
            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkMinimumNumberOfSelections(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkMinimumNumberOfSelections_lessVoteContestsThanInLVG_invalidSelections()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( BLANK_VOTE_BALLOT_OPTION_CODE, BLANK_VOTE_PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(BLANK_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkMinimumNumberOfSelections(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkMinimumNumberOfSelections_moreVoteContestsThanInLVG_invalidSelections()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( BLANK_VOTE_BALLOT_OPTION_CODE, BLANK_VOTE_PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(BLANK_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_ballotOptionsSequence.clear();
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selection.setContest(ALTERNATIVE_CONTEST_CODE);
            m_selectionsSequence.push_back(m_selection);

            m_ballotOptionsSequence.clear();
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selection.setContest(CONTEST_CODE);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkMinimumNumberOfSelections(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkMinimumNumberOfSelections_blankVoteSelected_validContest()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( BLANK_VOTE_BALLOT_OPTION_CODE, BLANK_VOTE_PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(BLANK_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_ballotOptionsSequence.clear();
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selection.setContest(ALTERNATIVE_CONTEST_CODE);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkMinimumNumberOfSelections(*m_vote);

            CPPUNIT_ASSERT( check );
        }

        void checkMinimumNumberOfSelections_listVoteSelected_validContest()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( LIST_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(LIST_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_ballotOptionsSequence.clear();
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selection.setContest(ALTERNATIVE_CONTEST_CODE);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkMinimumNumberOfSelections(*m_vote);

            CPPUNIT_ASSERT( check );
        }

        void checkMinimumNumberOfSelections_principalCandidatesSelected_validContest()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_ballotOptionsSequence.clear();
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selection.setContest(ALTERNATIVE_CONTEST_CODE);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkMinimumNumberOfSelections(*m_vote);

            CPPUNIT_ASSERT( check );
        }

        void checkMinimumNumberOfSelections_standInCandidatesSelected_validContest()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( STAND_IN_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_ballotOptionsSequence.clear();
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selection.setContest(ALTERNATIVE_CONTEST_CODE);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkMinimumNumberOfSelections(*m_vote);

            CPPUNIT_ASSERT( check );
        }

        void checkSelectionsBelongToSameParty_selectionsDontBelongToSameParty_invalidContest()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( LIST_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, ALTERNATIVE_PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(LIST_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkSelectionsBelongToSameParty(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkSelectionsBelongToSameParty_selectionsBelongToSameParty_validContest()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( LIST_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( STAND_IN_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(LIST_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkSelectionsBelongToSameParty(*m_vote);

            CPPUNIT_ASSERT( check );
        }

        void checkSelectionsApplicableToConstituency_selectionsNotApplicableToConstituency_invalidContest()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( LIST_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, ALTERNATIVE_PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( STAND_IN_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(LIST_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkSelectionsApplicableToConstituency(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkSelectionsApplicableToConstituency_selectionsApplicableToConstituency_validContest()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( LIST_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( STAND_IN_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(LIST_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkSelectionsApplicableToConstituency(*m_vote);

            CPPUNIT_ASSERT( check );
        }

        void checkUniquenessInSelections_contestIsNotUnique_invalidVote()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( LIST_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( STAND_IN_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( ALTERNATIVE_LIST_VOTE_BALLOT_OPTION_CODE, ALTERNATIVE_PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE, ALTERNATIVE_PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( ALTERNATIVE_STAND_IN_VOTE_BALLOT_OPTION_CODE, ALTERNATIVE_PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(LIST_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_ballotOptionsSequence.clear();
            m_ballotOptionsSequence.push_back(ALTERNATIVE_LIST_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(ALTERNATIVE_STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkUniquenessInSelections(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkUniquenessInSelections_partyIsNotUnique_invalidVote()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( LIST_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( STAND_IN_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( ALTERNATIVE_LIST_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( ALTERNATIVE_STAND_IN_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(LIST_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_ballotOptionsSequence.clear();
            m_ballotOptionsSequence.push_back(ALTERNATIVE_LIST_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(ALTERNATIVE_STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(ALTERNATIVE_CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkUniquenessInSelections(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkUniquenessInSelections_listVoteIsNotUnique_invalidVote()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( LIST_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(LIST_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(LIST_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkUniquenessInSelections(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkUniquenessInSelections_principalVoteIsNotUnique_invalidVote()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkUniquenessInSelections(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkUniquenessInSelections_standInVoteIsNotUnique_invalidVote()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( STAND_IN_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkUniquenessInSelections(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkUniquenessInSelections_selectionsAreUnique_validVote()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( LIST_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( STAND_IN_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( ALTERNATIVE_LIST_VOTE_BALLOT_OPTION_CODE, ALTERNATIVE_PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE, ALTERNATIVE_PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( ALTERNATIVE_STAND_IN_VOTE_BALLOT_OPTION_CODE, ALTERNATIVE_PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(LIST_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_ballotOptionsSequence.clear();
            m_ballotOptionsSequence.push_back(ALTERNATIVE_LIST_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(ALTERNATIVE_STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(ALTERNATIVE_CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkUniquenessInSelections(*m_vote);

            CPPUNIT_ASSERT( check );
        }

        void checkCumulativeNumberOfSelections_principalSelectionsAreGreaterThanRegisteredCandidates_invalidContest()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkCumulativeNumberOfSelections(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkCumulativeNumberOfSelections_standInSelectionsAreGreaterThanRegisteredCandidates_invalidContest()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( STAND_IN_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkCumulativeNumberOfSelections(*m_vote);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkCumulativeNumberOfSelections_selectionsAreLessThanOrEqualToRegisteredCandidates_validContest()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( STAND_IN_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_ballotOptionsSequence.push_back(STAND_IN_VOTE_BALLOT_OPTION_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkCumulativeNumberOfSelections(*m_vote);

            CPPUNIT_ASSERT( check );
        }

        void checkListHeaderResourceCorrectness_listHeaderAreNotCorrect_invalidVote()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE, ALTERNATIVE_PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_ballotOptionsSequence.clear();
            m_ballotOptionsSequence.push_back(ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(ALTERNATIVE_CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            std::map < std::string, std::map < std::string, std::string > > textToPrintMap;
            textToPrintMap[ CONTEST_CODE ][ PRINCIPAL_VOTE_BALLOT_OPTION_CODE ] = PARTY_NAME;
            textToPrintMap[ ALTERNATIVE_CONTEST_CODE ][ ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE ] = ALTERNATIVE_PARTY_NAME;

            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 4 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                new MOCKPP_NS::ReturnStub<std::string> ( PARTY_NAME ),
                new MOCKPP_NS::ReturnStub<std::string> ( PARTY_NAME ),
                new MOCKPP_NS::ReturnStub<std::string> ( PARTY_NAME ),
                new MOCKPP_NS::ReturnStub<std::string> ( ALTERNATIVE_PARTY_NAME )) );

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkListHeaderResourceCorrectness(*m_vote, textToPrintMap);

            CPPUNIT_ASSERT_ASSERTION_FAIL( CPPUNIT_ASSERT( check ) );
        }

        void checkListHeaderResourceCorrectness_listHeaderAreCorrect_validVote()
        {
            std::map < std::string, std::string > partyCodeByBallotOptionCode;
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( PRINCIPAL_VOTE_BALLOT_OPTION_CODE, PARTY_CODE ) );
            partyCodeByBallotOptionCode.insert( std::pair < std::string, std::string > ( ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE, ALTERNATIVE_PARTY_CODE ) );
            m_mockElectoralConfiguration.setPartyCodeByBallotOptionCode(partyCodeByBallotOptionCode);

            m_ballotOptionsSequence.push_back(PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_ballotOptionsSequence.clear();
            m_ballotOptionsSequence.push_back(ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE);
            m_selection.setContest(ALTERNATIVE_CONTEST_CODE);
            m_selection.setBallotOptions(m_ballotOptionsSequence);
            m_selectionsSequence.push_back(m_selection);

            m_vote->setLogicalVoterGroup(LOGICAL_VOTER_GROUP_CODE);
            m_vote->setSelections(m_selectionsSequence);

            std::map < std::string, std::map < std::string, std::string > > textToPrintMap;
            textToPrintMap[ CONTEST_CODE ][ PRINCIPAL_VOTE_BALLOT_OPTION_CODE ] = PARTY_NAME;
            textToPrintMap[ ALTERNATIVE_CONTEST_CODE ][ ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE ] = ALTERNATIVE_PARTY_NAME;

            MockElectionStringResourcesManager resourceManager;
            ElectionStringResourcesManager::getInstance ( &resourceManager );

            MOCKPP_CHAINER_FOR_EXT ( MockElectionStringResourcesManager, getResource, ext ) getResource_mock ( &resourceManager );

            getResource_mock
            .expects ( MOCKPP_NS::exactly ( 4 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                new MOCKPP_NS::ReturnStub<std::string> ( PARTY_NAME ),
                new MOCKPP_NS::ReturnStub<std::string> ( PARTY_NAME ),
                new MOCKPP_NS::ReturnStub<std::string> ( ALTERNATIVE_PARTY_NAME ),
                new MOCKPP_NS::ReturnStub<std::string> ( ALTERNATIVE_PARTY_NAME ) ) );

            bool check = VoteComplianceVerificator::getInstance(&m_mockElectoralConfiguration)->checkListHeaderResourceCorrectness(*m_vote, textToPrintMap);

            CPPUNIT_ASSERT( check );
        }

        CPPUNIT_TEST_SUITE ( BeforePrintingVoteVerificationTest );

        CPPUNIT_TEST ( checkMinimumNumberOfSelections_noSelections_invalidContest );
        CPPUNIT_TEST ( checkMinimumNumberOfSelections_lessVoteContestsThanInLVG_invalidSelections );
        CPPUNIT_TEST ( checkMinimumNumberOfSelections_moreVoteContestsThanInLVG_invalidSelections );
        CPPUNIT_TEST ( checkMinimumNumberOfSelections_blankVoteSelected_validContest );
        CPPUNIT_TEST ( checkMinimumNumberOfSelections_listVoteSelected_validContest );
        CPPUNIT_TEST ( checkMinimumNumberOfSelections_principalCandidatesSelected_validContest );
        CPPUNIT_TEST ( checkMinimumNumberOfSelections_standInCandidatesSelected_validContest );

        CPPUNIT_TEST ( checkSelectionsBelongToSameParty_selectionsDontBelongToSameParty_invalidContest );
        CPPUNIT_TEST ( checkSelectionsBelongToSameParty_selectionsBelongToSameParty_validContest );

        CPPUNIT_TEST ( checkSelectionsApplicableToConstituency_selectionsNotApplicableToConstituency_invalidContest );
        CPPUNIT_TEST ( checkSelectionsApplicableToConstituency_selectionsApplicableToConstituency_validContest );

        CPPUNIT_TEST ( checkUniquenessInSelections_contestIsNotUnique_invalidVote );
        CPPUNIT_TEST ( checkUniquenessInSelections_partyIsNotUnique_invalidVote );
        CPPUNIT_TEST ( checkUniquenessInSelections_listVoteIsNotUnique_invalidVote );
        CPPUNIT_TEST ( checkUniquenessInSelections_principalVoteIsNotUnique_invalidVote );
        CPPUNIT_TEST ( checkUniquenessInSelections_standInVoteIsNotUnique_invalidVote );
        CPPUNIT_TEST ( checkUniquenessInSelections_selectionsAreUnique_validVote );

        CPPUNIT_TEST ( checkCumulativeNumberOfSelections_principalSelectionsAreGreaterThanRegisteredCandidates_invalidContest );
        CPPUNIT_TEST ( checkCumulativeNumberOfSelections_standInSelectionsAreGreaterThanRegisteredCandidates_invalidContest );
        CPPUNIT_TEST ( checkCumulativeNumberOfSelections_selectionsAreLessThanOrEqualToRegisteredCandidates_validContest );

        CPPUNIT_TEST ( checkListHeaderResourceCorrectness_listHeaderAreNotCorrect_invalidVote );
        CPPUNIT_TEST ( checkListHeaderResourceCorrectness_listHeaderAreCorrect_validVote );

        CPPUNIT_TEST_SUITE_END();

    private:

        Eligible_option *buildEligibleOption(
            const std::string &ballotOptionCode,
            const Category &category,
            const std::string &eligibleOptionCode,
            const std::string &eligibleOptionParentCode)
        {
            Ballot_option ballotOption;
            ballotOption.setCode(ballotOptionCode);
            ballotOption.setCategory(category);

            std::auto_ptr < Ballot_options > ballotOptionsList;
            ballotOptionsList.reset(new Ballot_options());
            Ballot_options::Ballot_optionSequence ballotOptionsSequence;
            ballotOptionsSequence.push_back(ballotOption);
            ballotOptionsList->setBallot_option(ballotOptionsSequence);

            Eligible_option *eligibleOption = new Eligible_option();
            eligibleOption->setCode(eligibleOptionCode);
            eligibleOption->setParent_code(eligibleOptionParentCode);
            eligibleOption->setBallot_options(ballotOptionsList);

            return eligibleOption;
        }

        Contest_group *buildContestGroup()
        {
            Contest_group::Contest_codeSequence contestsSequence;
            contestsSequence.push_back(CONTEST_CODE);
            contestsSequence.push_back(ALTERNATIVE_CONTEST_CODE);

            Contest_group *contestGroup = new Contest_group();
            contestGroup->setCode(CONTEST_GROUP_CODE);
            contestGroup->setContest_code(contestsSequence);

            return contestGroup;
        }

        Logical_voter_group *buildLogicalVoterGroup()
        {
            Logical_voter_group *logicalVoterGroup = new Logical_voter_group();
            logicalVoterGroup->setCode(LOGICAL_VOTER_GROUP_CODE);
            logicalVoterGroup->setContest_group_code(CONTEST_GROUP_CODE);

            return logicalVoterGroup;
        }

        void setListBallotOption(MockElectoralConfiguration &mockElectoralConfiguration)
        {
            Eligible_option *eligibleOption = buildEligibleOption(
                LIST_VOTE_BALLOT_OPTION_CODE,
                Category::ELECTION_PRINCIPAL,
                LIST_VOTE_ELIGIBLE_OPTION_CODE,
                LIST_VOTE_ELIGIBLE_OPTION_PARENT_CODE);

            std::map < std::string, std::map < std::string, std::list < Eligible_option * > > > mapEligibleOptionsListByContestParty;

            std::list < Eligible_option * > eligibleOptionsList;
            eligibleOptionsList.push_back(eligibleOption);

            std::map < std::string, std::list < Eligible_option * > > partyMap;
            partyMap.insert( std::pair< std::string, std::list < Eligible_option * > > ( PARTY_CODE, eligibleOptionsList ) );

            mapEligibleOptionsListByContestParty.insert(
                std::pair<std::string, std::map < std::string, std::list < Eligible_option * > > > ( CONTEST_CODE, partyMap ) );

            mockElectoralConfiguration.setEligibleOptionsListByContestParty(mapEligibleOptionsListByContestParty);
        }

        void setPrincipalBallotOptions(MockElectoralConfiguration &mockElectoralConfiguration)
        {
            std::map < std::string, std::map < std::string, std::list < Eligible_option * > > > mapEligibleOptionsPrincipalByContestParty;
            std::map < std::string, std::list < Eligible_option * > > partyMap;

            Eligible_option *eligibleOption = buildEligibleOption(
                PRINCIPAL_VOTE_BALLOT_OPTION_CODE,
                Category::ELECTION_PRINCIPAL,
                PRINCIPAL_VOTE_ELIGIBLE_OPTION_CODE,
                PRINCIPAL_VOTE_ELIGIBLE_OPTION_PARENT_CODE);

            std::list < Eligible_option * > eligibleOptionsList;
            eligibleOptionsList.push_back(eligibleOption);
            partyMap.insert( std::pair< std::string, std::list < Eligible_option * > > ( PARTY_CODE, eligibleOptionsList ) );
            mapEligibleOptionsPrincipalByContestParty.insert( std::pair<std::string, std::map < std::string, std::list < Eligible_option * > > > ( CONTEST_CODE, partyMap ) );

            eligibleOption = buildEligibleOption(
                ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE,
                Category::ELECTION_PRINCIPAL,
                ALTERNATIVE_PRINCIPAL_VOTE_ELIGIBLE_OPTION_CODE,
                ALTERNATIVE_PRINCIPAL_VOTE_ELIGIBLE_OPTION_PARENT_CODE);

            eligibleOptionsList.clear();
            eligibleOptionsList.push_back(eligibleOption);
            partyMap.clear();
            partyMap.insert( std::pair< std::string, std::list < Eligible_option * > > ( ALTERNATIVE_PARTY_CODE, eligibleOptionsList ) );
            mapEligibleOptionsPrincipalByContestParty.insert( std::pair<std::string, std::map < std::string, std::list < Eligible_option * > > > ( ALTERNATIVE_CONTEST_CODE, partyMap ) );

            mockElectoralConfiguration.setEligibleOptionsPrincipalByContestParty(mapEligibleOptionsPrincipalByContestParty);
        }

        void setStandInBallotOptions(MockElectoralConfiguration &mockElectoralConfiguration)
        {
            std::map < std::string, std::map < std::string, std::list < Eligible_option * > > > mapEligibleOptionsStandInByContestParty;
            std::map < std::string, std::list < Eligible_option * > > partyMap;

            Eligible_option *eligibleOption = buildEligibleOption(
                STAND_IN_VOTE_BALLOT_OPTION_CODE,
                Category::ELECTION_STAND_IN,
                STAND_IN_VOTE_ELIGIBLE_OPTION_CODE,
                STAND_IN_VOTE_ELIGIBLE_OPTION_PARENT_CODE);

            std::list < Eligible_option * > eligibleOptionsList;
            eligibleOptionsList.push_back(eligibleOption);
            partyMap.insert( std::pair< std::string, std::list < Eligible_option * > > ( PARTY_CODE, eligibleOptionsList ) );
            mapEligibleOptionsStandInByContestParty.insert( std::pair<std::string, std::map < std::string, std::list < Eligible_option * > > > ( CONTEST_CODE, partyMap ) );

            eligibleOption = buildEligibleOption(
                ALTERNATIVE_STAND_IN_VOTE_BALLOT_OPTION_CODE,
                Category::ELECTION_STAND_IN,
                ALTERNATIVE_STAND_IN_VOTE_ELIGIBLE_OPTION_CODE,
                ALTERNATIVE_STAND_IN_VOTE_ELIGIBLE_OPTION_PARENT_CODE);

            eligibleOptionsList.clear();
            eligibleOptionsList.push_back(eligibleOption);
            partyMap.clear();
            partyMap.insert( std::pair< std::string, std::list < Eligible_option * > > ( ALTERNATIVE_PARTY_CODE, eligibleOptionsList ) );
            mapEligibleOptionsStandInByContestParty.insert( std::pair<std::string, std::map < std::string, std::list < Eligible_option * > > > ( ALTERNATIVE_CONTEST_CODE, partyMap ) );

            mockElectoralConfiguration.setEligibleOptionsStandInByContestParty(mapEligibleOptionsStandInByContestParty);
        }

        void setEligibleOptionByBallotOptionCodeMap(MockElectoralConfiguration &mockElectoralConfiguration)
        {
            Eligible_option *eligibleOption = buildEligibleOption(
                LIST_VOTE_BALLOT_OPTION_CODE,
                Category::ELECTION_PRINCIPAL,
                LIST_VOTE_ELIGIBLE_OPTION_CODE,
                LIST_VOTE_ELIGIBLE_OPTION_PARENT_CODE);

            mockElectoralConfiguration.eoByBallotOptionCodeMap [ CONTEST_CODE ][ LIST_VOTE_BALLOT_OPTION_CODE ] = eligibleOption;

            eligibleOption = buildEligibleOption(
                ALTERNATIVE_LIST_VOTE_BALLOT_OPTION_CODE,
                Category::ELECTION_PRINCIPAL,
                ALTERNATIVE_LIST_VOTE_ELIGIBLE_OPTION_CODE,
                LIST_VOTE_ELIGIBLE_OPTION_PARENT_CODE);

            mockElectoralConfiguration.eoByBallotOptionCodeMap [ ALTERNATIVE_CONTEST_CODE ][ ALTERNATIVE_LIST_VOTE_BALLOT_OPTION_CODE ] = eligibleOption;

            eligibleOption = buildEligibleOption(
                PRINCIPAL_VOTE_BALLOT_OPTION_CODE,
                Category::ELECTION_PRINCIPAL,
                PRINCIPAL_VOTE_ELIGIBLE_OPTION_CODE,
                PRINCIPAL_VOTE_ELIGIBLE_OPTION_PARENT_CODE);

            mockElectoralConfiguration.eoByBallotOptionCodeMap [ CONTEST_CODE ][ PRINCIPAL_VOTE_BALLOT_OPTION_CODE ] = eligibleOption;

            eligibleOption = buildEligibleOption(
                ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE,
                Category::ELECTION_PRINCIPAL,
                ALTERNATIVE_PRINCIPAL_VOTE_ELIGIBLE_OPTION_CODE,
                ALTERNATIVE_PRINCIPAL_VOTE_ELIGIBLE_OPTION_PARENT_CODE);

            mockElectoralConfiguration.eoByBallotOptionCodeMap [ ALTERNATIVE_CONTEST_CODE ][ ALTERNATIVE_PRINCIPAL_VOTE_BALLOT_OPTION_CODE ] = eligibleOption;

            eligibleOption = buildEligibleOption(
                STAND_IN_VOTE_BALLOT_OPTION_CODE,
                Category::ELECTION_STAND_IN,
                STAND_IN_VOTE_ELIGIBLE_OPTION_CODE,
                STAND_IN_VOTE_ELIGIBLE_OPTION_PARENT_CODE);

            mockElectoralConfiguration.eoByBallotOptionCodeMap [ CONTEST_CODE ][ STAND_IN_VOTE_BALLOT_OPTION_CODE ] = eligibleOption;

            eligibleOption = buildEligibleOption(
                ALTERNATIVE_STAND_IN_VOTE_BALLOT_OPTION_CODE,
                Category::ELECTION_STAND_IN,
                ALTERNATIVE_STAND_IN_VOTE_ELIGIBLE_OPTION_CODE,
                ALTERNATIVE_STAND_IN_VOTE_ELIGIBLE_OPTION_PARENT_CODE);

            mockElectoralConfiguration.eoByBallotOptionCodeMap [ ALTERNATIVE_CONTEST_CODE ][ ALTERNATIVE_STAND_IN_VOTE_BALLOT_OPTION_CODE ] = eligibleOption;
        }

        void setMapContestParty(MockElectoralConfiguration &mockElectoralConfiguration)
        {
            std::map < std::string, std::list < Party * > > contestPartyMap;

            Party *party = new Party();
            party->setCode(PARTY_CODE);
            party->setName(PARTY_NAME);

            std::list < Party * > partyList;
            partyList.push_back(party);

            contestPartyMap.insert( std::pair < std::string, std::list < Party * > > ( CONTEST_CODE, partyList ) );

            party = new Party();
            party->setCode(ALTERNATIVE_PARTY_CODE);
            party->setName(ALTERNATIVE_PARTY_NAME);

            partyList.clear();
            partyList.push_back(party);

            contestPartyMap.insert( std::pair < std::string, std::list < Party * > > ( ALTERNATIVE_CONTEST_CODE, partyList ) );

            mockElectoralConfiguration.setMapContestParty(contestPartyMap);
        }

        void setContestGroupByCodeMap(MockElectoralConfiguration &mockElectoralConfiguration)
        {
            Contest_group *contestGroup = buildContestGroup();

            std::map < std::string, Contest_group * > contestGroupByCodeMap;
            contestGroupByCodeMap[contestGroup->getCode()] = contestGroup;

            mockElectoralConfiguration.setContestGroupByCodeMap(contestGroupByCodeMap);
        }

        void setLogicalVoterGroupsList(MockElectoralConfiguration &mockElectoralConfiguration)
        {
            std::list < Logical_voter_group * > logicalVoterGroupsList;
            logicalVoterGroupsList.push_back(buildLogicalVoterGroup());

            mockElectoralConfiguration.setLogicalVoterGroupsList(logicalVoterGroupsList);
        }

        void initializeMockElectoralConfiguration(MockElectoralConfiguration &mockElectoralConfiguration)
        {
            setListBallotOption(mockElectoralConfiguration);

            setPrincipalBallotOptions(mockElectoralConfiguration);

            setStandInBallotOptions(mockElectoralConfiguration);

            setEligibleOptionByBallotOptionCodeMap(mockElectoralConfiguration);

            setMapContestParty(mockElectoralConfiguration);

            setContestGroupByCodeMap(mockElectoralConfiguration);

            setLogicalVoterGroupsList(mockElectoralConfiguration);
        }

    private:

        MockElectoralConfiguration m_mockElectoralConfiguration;  ///< instance of object electoral configuration
        Smartmatic::SAES::Voting::Vote::Vote * m_vote;
        Selection::BSequence m_ballotOptionsSequence;
        Selection m_selection;
        Smartmatic::SAES::Voting::Vote::Vote::SSequence m_selectionsSequence;
};

#endif /* ECUT_MAIN */

#endif /* BEFORE_PRINTING_VOTE_VERIFICATION_TEST */
