/**
 * @file DeviceTypeMonitorWindowConfigurationManager.hxx
 * @brief Declaration of the device type monitor window configuration manager.
 * @date 12/05/2014
 * @author Yadickson Soto
 */

#ifndef DEVICE_TYPE_MONITOR_WINDOW_CONFIGURATION_MANAGER_HXX_
#define DEVICE_TYPE_MONITOR_WINDOW_CONFIGURATION_MANAGER_HXX_

#include <Configuration/device-monitor-window-configuration-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Configuration
            {
                /**
                 * @class	DeviceTypeMonitorWindowConfigurationManager
                 * @brief	The device type monitor window configuration manager.
                 * @author	Yadickson Soto
                 * @date 12/05/2014
                 */
                class DeviceTypeMonitorWindowConfigurationManager
                {
                    public:

                        /**
                         * @fn	static DeviceTypeMonitorWindowConfigurationManager * getInstance( DeviceTypeMonitorWindowConfigurationManager * externManager = NULL );
                         * @brief	Gets the current Device Monitor Window Configuration Manager.
                         * @author	Yadickson Soto
                         * @date	07/05/2014
                         * @param 	externManager external manager to unit test
                         * @return	instance of the class.
                         */
                        static DeviceTypeMonitorWindowConfigurationManager * getInstance ( DeviceTypeMonitorWindowConfigurationManager * externManager = NULL );

                        /**
                         * @fn	virtual ~DeviceTypeMonitorWindowConfigurationManager();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	07/05/2014
                         */
                        virtual ~DeviceTypeMonitorWindowConfigurationManager();

                        /**
                         * @fn	virtual bool isVisible();
                         * @brief	Whether the window should be shown on device change event.
                         * @author	Yadickson Soto
                         * @date	13/05/2014
                         * return true if the window should be shown on device change event.
                         */
                        virtual bool isVisible();

                        /**
                         * @fn	virtual unsigned int getTimeOut();
                         * @brief	Gets the timeout configured that triggers the close the screen.
                         * @author	Yadickson Soto
                         * @date	13/05/2014
                         * return the timeout value.
                         */
                        virtual unsigned int getTimeOut();

                        /**
                         * @fn	virtual unsigned int getOpacity();
                         * @brief	Gets the opacity of the window.
                         * @author	Yadickson Soto
                         * @date	13/05/2014
                         * return the opacitiy value.
                         */
                        virtual unsigned int getOpacity();

                        /**
                         * @fn	virtual unsigned int getIconWidth();
                         * @brief	Gets the natural width associated to device icon.
                         * @author	Yadickson Soto
                         * @date	13/05/2014
                         * return the icon width value.
                         */
                        virtual unsigned int getIconWidth();

                        /**
                         * @fn	virtual unsigned int getIconHeight();
                         * @brief	Gets the natural height associated to device icon.
                         * @author	Yadickson Soto
                         * @date	13/05/2014
                         * return the icon height value.
                         */
                        virtual unsigned int getIconHeight();

                        /**
                         * @fn	virtual Smartmatic::SAES::Configuration::PositionConfiguration & getPosition();
                         * @brief	Gets the position window configuration.
                         * @author	Yadickson Soto
                         * @date	13/05/2014
                         * return the position window configuration.
                         */
                        virtual Smartmatic::SAES::Configuration::PositionConfiguration & getPosition();

                        /**
                         * @fn	virtual unsigned int getBorder();
                         * @brief	Gets the border width associated to internal widget.
                         * @author	Yadickson Soto
                         * @date	13/05/2014
                         * return the icon height value.
                         */
                        virtual unsigned int getBorder();

                        /**
                         * @fn	virtual bool isDeviceWidgetShowing ( const Smartmatic::SAES::Common::Configuration::DeviceType & type );
                         * @brief	Gets whether device widget is visible in the Device Monitor Window.
                         * @date 12/05/2014
                         * @author Yadickson Soto
                         * @param	type The device type monitor to check
                         * @return	true if widget is visible in the GUI; otherwise false.
                         */
                        virtual bool isDeviceWidgetShowing ( const Smartmatic::SAES::Common::Configuration::DeviceType & type );

                    protected:

                        /**
                         * @fn	DeviceTypeMonitorWindowConfigurationManager();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	07/05/2014
                         */
                        DeviceTypeMonitorWindowConfigurationManager();

                        /**
                         * @fn	virtual Smartmatic::SAES::Configuration::DeviceTypeMonitorWindowConfiguration & getDeviceTypeMonitorWindowConfiguration ();
                         * @brief	Gets a reference of the device type monitor pool window configuration.
                         * @author	Yadickson Soto
                         * @date	07/05/2014
                         * @return	The reference to the common context of the device monitor device
                         */
                        virtual Smartmatic::SAES::Configuration::DeviceTypeMonitorWindowConfiguration & getDeviceTypeMonitorWindowConfiguration ();

                    private:

                        static DeviceTypeMonitorWindowConfigurationManager * instance; ///< The pointer to the singleton instance of the device type monitor pool window configuration manager

                };

            } /* namespace Configuration */
        } /* namespace GUI */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* DEVICE_MONITOR_WINDOW_CONFIGURATION_MANAGER_HXX_ */
