/**
 * @file	s-a-e-s-g-u-i-conf-manager.h
 * @brief	Declares the saes gui conf manager class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#ifndef _S_A_E_S_G_U_I_CONFIGURATION_MANAGER_H_
#define _S_A_E_S_G_U_I_CONFIGURATION_MANAGER_H_

#include <string>
#include <Configuration/SaesGUIConfiguration-schema.hxx>
#include <Gui/Widgets/Menu/menu-option.h>
#include <Configuration/menu-option-type-schema.hxx>
#include "Configuration/label-configuration.h"
#include <Gui/Widgets/Wizard/WizardConfiguration.h>
#include <Operation/MachineOperationManager.hxx>


namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Configuration
            {
                /**
                 * @class	SAESGUIConfigurationManager
                 * @brief	Manager that handles the configuration of all the actions realtes to the SAES GUI.
                 * @author	Fsilva
                 * @date	28/04/2011
                 */

                class SAESGUIConfigurationManager
                {
                    public:

                        /**
                         * @fn	static SAESGUIConfigurationManager * getInstance ( SAESGUIConfigurationManager * externManager = NULL );
                         * @brief	Gets the current configuration manager.
                         * @author	Yadickson Soto
                         * @date	15/04/2014
                         * @param 	externManager external manager to unit test
                         * @return	the current instance SAES GUI Configuration Manager.
                         */
                        static SAESGUIConfigurationManager * getInstance ( SAESGUIConfigurationManager * externManager = NULL );

                        /**
                         * @fn	void loadDefault();
                         * @brief	Loads the default configuration.
                         * @author	Yadickson Soto
                         * @date	15/04/2014
                         */
                        void loadDefault();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::InstallationWizardConfiguration & getInstallationWizardConfiguration();
                         * @brief	Gets the voting machine installation wizard configuration.
                         * @author	Yadickson Soto
                         * @date	21/05/2013
                         * @return	the voting machine installation wizard configuration.
                         */
                        Smartmatic::SAES::Configuration::InstallationWizardConfiguration & getInstallationWizardConfiguration();

                        /**
                         * @fn	std::vector<Smartmatic::SAES::GUI::Widgets::WizardConfiguration> GetFunctionalityWizardConfiguration();
                         * @brief	Gets the wizard widget configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The wizard widget configuration.
                         */
                        std::vector<Smartmatic::SAES::GUI::Widgets::WizardConfiguration> GetFunctionalityWizardConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::ChangeHourFunctionalityConfiguration SAESGUIConfigurationManager::GetChangeHourFunctionalitConfiguration();
                         * @brief	Gets change hour functionality configuration.
                         * @author	Juan Delgado
                         * @date	29/08/2011
                         * @return	Change hour functionality configuration.
                         */
                        Smartmatic::SAES::Configuration::ChangeHourFunctionalityConfiguration GetChangeHourFunctionalitConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::VoteDemoFunctionalityConfiguration SAESGUIConfigurationManager::getVoteDemoFunctionalityConfiguration();
                         * @brief	Gets the vote demo functionality configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	the vote demo functionality configuration.
                         */
                        Smartmatic::SAES::Configuration::VoteDemoFunctionalityConfiguration getVoteDemoFunctionalityConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::PrinterDiagnosisConfiguration SAESGUIConfigurationManager::getPrinterDiagnosisConfiguration();
                         * @brief	Gets the printer diagnosis configuration.
                         * @author	Juan Delgado
                         * @date	29/08/2011
                         * @return	The printer diagnosis configuration.
                         */

                        Smartmatic::SAES::Configuration::PrinterDiagnosisConfiguration getPrinterDiagnosisConfiguration();

                        /**
                         * @fn	bool SAESGUIConfigurationManager::getAssistedActivationBySelection();
                         * @brief	Gets the assisted activation by selection.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool getAssistedActivationBySelection();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::PrintPreviewFunctionalityConfiguration SAESGUIConfigurationManager::getPrintPreviewFunctionalityConfiguration();
                         * @brief	Gets the Print Preview Functionality configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	print preview funcionality configuration.
                         */
                        Smartmatic::SAES::Configuration::PrintPreviewFunctionalityConfiguration getPrintPreviewFunctionalityConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::BarcodeDiagnosisConfiguration SAESGUIConfigurationManager::getBarcodeDiagnosisConfiguration();
                         * @brief	Gets the barcode diagnosis configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The barcode diagnosis configuration.
                         */
                        Smartmatic::SAES::Configuration::BarcodeDiagnosisConfiguration getBarcodeDiagnosisConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::PMWidgetConfiguration & SAESGUIConfigurationManager::getPMInstallationWidgetConfig();
                         * @brief	Gets the PM widget configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The pm widget configuration.
                         */

                        Smartmatic::SAES::Configuration::PMWidgetConfiguration & getPMInstallationWidgetConfig();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::getCustomAttributesPresentation();
                         * @brief	Gets the custom attributes for the presentation.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The custom attributes presentation.
                         */

                        std::string getCustomAttributesPresentation();

                        /**
                         * @fn	bool SAESGUIConfigurationManager::getShowAudioCheckButton();
                         * @brief	Gets the boolean for show audio check button.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The boolean.
                         */
                        bool getShowAudioCheckButton();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::CardActivatorFunctionalityConfiguration * SAESGUIConfigurationManager::GetCardActivatorWidgetConfiguration();
                         * @brief	Gets the card activator widget configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	null if it fails, else the card activator widget configuration.
                         */

                        Smartmatic::SAES::Configuration::CardActivatorFunctionalityConfiguration * GetCardActivatorWidgetConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::ElectionBlockStatusList::ElectionStatusSequence SAESGUIConfigurationManager::getDisableStateList ( Smartmatic::SAES::Functionality::Configuration::MenuOptionType menuType );
                         * @brief	Get a list of disable state.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @param	menuType	The menu option type to perform the action.
                         * @return	The list of disable state.
                         */

                        Smartmatic::SAES::Configuration::ElectionBlockStatusList::ElectionStatusSequence getDisableStateList ( Smartmatic::SAES::Functionality::Configuration::MenuOptionType menuType );

                        /**
                         * @fn	Smartmatic::SAES::Configuration::HelpConfiguration SAESGUIConfigurationManager::getHelpConfiguration ( Smartmatic::SAES::Functionality::Configuration::MenuOptionType menuType );
                         * @brief	Get the help configuration for the functionality.
                         * @author	Gerardo Hernandez
                         * @date	02/06/2011
                         * @param	menuType	The menu option type to perform the action.
                         * @return	The help configuration for the functionality.
                         */
                        Smartmatic::SAES::Configuration::HelpConfiguration getHelpConfiguration ( Smartmatic::SAES::Functionality::Configuration::MenuOptionType menuType );

                        /**
                         * @fn	bool SAESGUIConfigurationManager::GetShowExitMessage ( Smartmatic::SAES::Functionality::Configuration::MenuOptionType menuOptionDescriptor );
                         * @brief	Gets if show exit message.
                         * @author	Juan.Delgado
                         * @date	15/08/2011
                         * @param	menuOptionDescriptor	The menu option type to perform the action.
                         * @return	true if show exit message.
                         */

                        bool GetShowExitMessage ( Smartmatic::SAES::Functionality::Configuration::MenuOptionType menuOptionDescriptor );

                        /**
                         * @fn	bool SAESGUIConfigurationManager::getViewPrevious();
                         * @brief	Gets the previous view.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool getViewPrevious();

                        /**
                         * @fn	unsigned int getWaitTimeByBasicImageType( Smartmatic::SAES::Voting::Screen::BasicImageType::type type );
                         * @brief	Gets the wait time by widget configuration.
                         * @author	Yadickson Soto
                         * @date	02/04/2013
                         * @return	The wait time.
                         */
                        unsigned int getWaitTimeByBasicImageType ( Smartmatic::SAES::Voting::Screen::BasicImageType type );

                        /**
                         * @fn	bool SAESGUIConfigurationManager::GetForceToLoadFrame ();
                         * @brief	Gets the time delay buttons.
                         * @author	Gerardo Hernandez
                         * @date	28/04/2011
                         * @return	the boolean value to indicate to the functionalities reload frame.
                         */
                        bool GetForceToLoadFrame ();

                        /**
                         * @fn	bool SAESGUIConfigurationManager::getMarkCardAsUsed();
                         * @brief	Gets mark card as used.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool getMarkCardAsUsed();

                        /**
                         * @fn	bool SAESGUIConfigurationManager::getShowConfirmationButtons();
                         * @brief	Gets the show confirmation buttons for activation.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool getShowConfirmationButtons();
                        /**
                         * @fn	int SAESGUIConfigurationManager::getCheckSumFailTimerMessage();
                         * @brief	Gets the check sum fail timer message.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The check sum fail timer message.
                         */

                        int getCheckSumFailTimerMessage();

                        /**
                         * @fn	SmartcardReaderDiagnosisConfiguration & getSmartcardReaderDiagnosisConfiguration();
                         * @brief	Gets the smartcard reader diagnose configuration.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	The smartcard reader diagnose configuration.
                         */

                        Smartmatic::SAES::Configuration::SmartcardReaderDiagnosisConfiguration & getSmartcardReaderDiagnosisConfiguration();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::getPMInstalationSound();
                         * @brief	Gets the pm instalation sound.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The pm instalation sound.
                         */

                        std::string getPMInstalationSound();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::getVMInstalationSound();
                         * @brief	Gets the voting machine instalation sound.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting machine instalation sound.
                         */

                        std::string getVMInstalationSound();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::getAuthenticationValidPasswordSound();
                         * @brief	Gets the authentication valid password sound.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The authentication valid password sound.
                         */

                        std::string getAuthenticationValidPasswordSound();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::getAuthenticationInvalidPasswordSound();
                         * @brief	Gets the authentication invalid password sound.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The authentication invalid password sound.
                         */

                        std::string getAuthenticationInvalidPasswordSound();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::getVotingExperienceSound();
                         * @brief	Gets the voting experience sound.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting experience sound.
                         */

                        std::string getVotingExperienceSound();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::getBallotOptionSelectSound();
                         * @brief	Gets the ballot option select sound.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The ballot option select sound.
                         */

                        std::string getBallotOptionSelectSound();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::getPartySelectSound();
                         * @brief	Gets the party select sound.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The party select sound.
                         */

                        std::string getPartySelectSound();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::getDiagnosisSound();
                         * @brief	Gets the diagnosis sound.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The diagnosis sound.
                         */

                        std::string getDiagnosisSound();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetOpenElectionPollWorkerLabelConfiguration();
                         * @brief	Gets the open election poll worker label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The open election poll worker label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetOpenElectionPollWorkerLabelConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::OpenElectionFunctionalityConfiguration & SAESGUIConfigurationManager::GetOpenElectionFunctionalityConfiguration();
                         * @brief	Gets the open election functionality configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The open election functionality configuration.
                         */

                        Smartmatic::SAES::Configuration::OpenElectionFunctionalityConfiguration & GetOpenElectionFunctionalityConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::CloseElectionFunctionalityConfiguration & SAESGUIConfigurationManager::GetCloseElectionFunctionalityConfiguration();
                         * @brief	Gets the close election functionality configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The close election functionality configuration.
                         */

                        Smartmatic::SAES::Configuration::CloseElectionFunctionalityConfiguration & GetCloseElectionFunctionalityConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::ActivationConsolidationFunctionalityConfiguration SAESGUIConfigurationManager::GetActivationConsolidationFunctionalityConfiguration();
                         * @brief	Gets the activaction consolidation functionality configuration.
                         * @author	Juan Delgado
                         * @date	06/09/2011
                         * @return	The activation consolidation functionality configuration.
                         */
                        Smartmatic::SAES::Configuration::ActivationConsolidationFunctionalityConfiguration GetActivationConsolidationFunctionalityConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::ScanVoteProcessConfiguration & SAESGUIConfigurationManager::getScanVoteProcessConfiguration();
                         * @brief	Gets scan vote process configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The scan vote process configuration.
                         */
                        Smartmatic::SAES::Configuration::ScanVoteProcessConfiguration & getScanVoteProcessConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::USBMonitorWindowConfiguration & getUSBMonitorWindowConfiguration();
                         * @brief	Gets usb monitor window configuration for voting machine.
                         * @author	Yadickson Soto
                         * @date	04/06/2013
                         * @return	usb monitor window configuration for voting machine.
                         */
                        Smartmatic::SAES::Configuration::USBMonitorWindowConfiguration & getUSBMonitorWindowConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::LogReportFunctionalityConfiguration SAESGUIConfigurationManager::GetLogReportFunctionalityConfiguration();
                         * @brief	Gets the log report functionality configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The log report functionality configuration.
                         */

                        Smartmatic::SAES::Configuration::LogReportFunctionalityConfiguration GetLogReportFunctionalityConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::VoteConsolidationFunctionalityConfiguration SAESGUIConfigurationManager::GetVoteConsolidationFunctionalityConfiguration();
                         * @brief	Gets the vote consolidation functionality configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The vote consolidation functionality configuration.
                         */

                        Smartmatic::SAES::Configuration::VoteConsolidationFunctionalityConfiguration GetVoteConsolidationFunctionalityConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::VotingExperienceValidationScreensFunctionalityConfiguration SAESGUIConfigurationManager::GetVotingExperienceValidationScreensFunctionalityConfiguration();
                         * @brief	Gets the voting experience validation screens functionality configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting experience validation screens functionality configuration.
                         */

                        Smartmatic::SAES::Configuration::VotingExperienceValidationScreensFunctionalityConfiguration GetVotingExperienceValidationScreensFunctionalityConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::ThemesConfiguration & SAESGUIConfigurationManager::GetThemesConfiguration();
                         * @brief	Gets the themes configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The themes configuration.
                         */

                        Smartmatic::SAES::Configuration::ThemesConfiguration & GetThemesConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::OfficialThemeConfiguration & SAESGUIConfigurationManager::GetOfficialThemeConfiguration();
                         * @brief	Gets the official theme configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The official theme configuration.
                         */

                        Smartmatic::SAES::Configuration::OfficialThemeConfiguration & GetOfficialThemeConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::DemoThemeConfiguration & SAESGUIConfigurationManager::GetDemoThemeConfiguration();
                         * @brief	Gets the demo theme configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The demo theme configuration.
                         */

                        Smartmatic::SAES::Configuration::DemoThemeConfiguration & GetDemoThemeConfiguration();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetVotingWindowButtonName();
                         * @brief	Gets the voting window button name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting window button name.
                         */

                        std::string GetVotingWindowButtonName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetVotingExperiencePartyEventboxName();
                         * @brief	Gets the voting experience party eventbox name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting experience party eventbox name.
                         */

                        std::string GetVotingExperiencePartyEventboxName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetVotingExperienceWindowName();
                         * @brief	Gets the voting experience window name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting experience window name.
                         */

                        std::string GetVotingExperienceWindowName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetVotingExperienceBallotOptionEventboxName();
                         * @brief	Gets the voting experience ballot option eventbox name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting experience ballot option eventbox name.
                         */

                        std::string GetVotingExperienceBallotOptionEventboxName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetCardActivatorFunctionalityMessageName();
                         * @brief	Gets the card activator functionality message name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The card activator functionality message name.
                         */

                        std::string GetCardActivatorFunctionalityMessageName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetCardActivatorMessageEventboxName();
                         * @brief	Gets the card activator message eventbox name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The card activator message eventbox name.
                         */

                        std::string GetCardActivatorMessageEventboxName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetCardActivatorFunctionalityEventboxName();
                         * @brief	Gets the card activator functionality eventbox name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The card activator functionality eventbox name.
                         */

                        std::string GetCardActivatorFunctionalityEventboxName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetCardActivatorValuesEventboxName();
                         * @brief	Gets the card activator values eventbox name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The card activator values eventbox name.
                         */

                        std::string GetCardActivatorValuesEventboxName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetCardActivatorFunctionalityCenterFrameName();
                         * @brief	Gets the card activator functionality center frame name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The card activator functionality center frame name.
                         */

                        std::string GetCardActivatorFunctionalityCenterFrameName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetEventboxStepBarcodeName();
                         * @brief	Gets the eventbox step barcode name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The eventbox step barcode name.
                         */

                        std::string GetEventboxStepBarcodeName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetEventboxStepBarcodeTitleName();
                         * @brief	Gets the eventbox step barcode title name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The eventbox step barcode title name.
                         */

                        std::string GetEventboxStepBarcodeTitleName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetEventboxStepCardTitleName();
                         * @brief	Gets the eventbox step card title name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The eventbox step card title name.
                         */

                        std::string GetEventboxStepCardTitleName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetVoteDemoFunctionalityMessageName();
                         * @brief	Gets the vote demo functionality message name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The vote demo functionality message name.
                         */

                        std::string GetVoteDemoFunctionalityMessageName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetStandInLabelLabelName();
                         * @brief	Gets the stand in label name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The stand in label name.
                         */

                        std::string GetStandInLabelLabelName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetStandInLabelEventName();
                         * @brief	Gets the stand in label event name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The stand in label event name.
                         */

                        std::string GetStandInLabelEventName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetVotingExperienceSelectBallotOptionWidgetName();
                         * @brief	Gets the voting experience select ballot option widget name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting experience select ballot option widget name.
                         */

                        std::string GetVotingExperienceSelectBallotOptionWidgetName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetChangeLanguageMessageWigdetEventboxName();
                         * @brief	Gets the change language message wigdet eventbox name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The change language message wigdet eventbox name.
                         */

                        std::string GetChangeLanguageMessageWigdetEventboxName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetCustomAttributeComboSelectionsWidgetTitleName();
                         * @brief	Gets the custom attribute combo selections widget title name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The custom attribute combo selections widget title name.
                         */

                        std::string GetCustomAttributeComboSelectionsWidgetTitleName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetCustomAttributeCounterWidgetTitleName();
                         * @brief	Gets the custom attribute counter widget title name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The custom attribute counter widget title name.
                         */

                        std::string GetCustomAttributeCounterWidgetTitleName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetEventboxChooseWidgetFrameName();
                         * @brief	Gets the eventbox choose widget frame name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The eventbox choose widget frame name.
                         */

                        std::string GetEventboxChooseWidgetFrameName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetVotingExperiencePartyWidgetName();
                         * @brief	Gets the voting experience party widget name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting experience party widget name.
                         */

                        std::string GetVotingExperiencePartyWidgetName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetPartyWidgetEventboxName();
                         * @brief	Gets the party widget eventbox name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The party widget eventbox name.
                         */

                        std::string GetPartyWidgetEventboxName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetEventboxImageStepInstallationWizardName();
                         * @brief	Gets the eventbox image step installation wizard name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The eventbox image step installation wizard name.
                         */

                        std::string GetEventboxImageStepInstallationWizardName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetEventboxStepInstallationWizardName();
                         * @brief	Gets the eventbox step installation wizard name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The eventbox step installation wizard name.
                         */

                        std::string GetEventboxStepInstallationWizardName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetParentKeypadEventboxName();
                         * @brief	Gets the parent keypad eventbox name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The parent keypad eventbox name.
                         */

                        std::string GetParentKeypadEventboxName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetInfoFrameName();
                         * @brief	Gets the information frame name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The information frame name.
                         */

                        std::string GetInfoFrameName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetVotingWindowButtonDemoName();
                         * @brief	Gets the voting window button demo name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting window button demo name.
                         */

                        std::string GetVotingWindowButtonDemoName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetVotingExperiencePartyEventboxDemoName();
                         * @brief	Gets the voting experience party eventbox demo name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting experience party eventbox demo name.
                         */

                        std::string GetVotingExperiencePartyEventboxDemoName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetVotingExperienceWindowDemoName();
                         * @brief	Gets the voting experience window demo name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting experience window demo name.
                         */

                        std::string GetVotingExperienceWindowDemoName();

                        /**
                         * @fn	std::string SAESGUIConfigurationManager::GetVotingExperienceBallotOptionEventboxDemoName();
                         * @brief	Gets the voting experience ballot option eventbox demo name.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting experience ballot option eventbox demo name.
                         */

                        std::string GetVotingExperienceBallotOptionEventboxDemoName();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::CheckSumFailOption::Value SAESGUIConfigurationManager::getCheckSumFailOption();
                         * @brief	Gets the check sum fail option.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The check sum fail option.
                         */

                        Smartmatic::SAES::Configuration::CheckSumFailOption::Value getCheckSumFailOption();

                        /**
                         * @fn	unsigned int SAESGUIConfigurationManager::getMinimumDemoCounterToAllowActivation();
                         * @brief	Gets the minimum demo counter to allow activation.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The minimum demo counter to allow activation.
                         */

                        unsigned int getMinimumDemoCounterToAllowActivation();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::TouchScreenCalibrationConfiguration & getTouchScreenCalibrationConfiguration();
                         * @brief	Gets the touch screen calibration configuration.
                         * @author	Yadickson Soto
                         * @date	10/09/2013
                         * @return	The touch screen calibration configuration.
                         */

                        Smartmatic::SAES::Configuration::TouchScreenCalibrationConfiguration & getTouchScreenCalibrationConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::DiagnosticType getAllDiagnosisDiagnosticType ( const Smartmatic::SAES::Configuration::DiagnosticType::DeviceType & type );
                         * @brief	Gets from all diagnosis on the diagnostic by type.
                         * @author	Yadickson Soto
                         * @date	28/11/2012
                         * @param type diagnostic type
                         * @return	diagnostic.
                         */

                        Smartmatic::SAES::Configuration::DiagnosticType getAllDiagnosisDiagnosticType ( const Smartmatic::SAES::Configuration::DiagnosticType::DeviceType & type );

                        /**
                         * @fn	Smartmatic::SAES::Configuration::DiagnosticType getAutoDiagnosisDiagnosticType ( const Smartmatic::SAES::Configuration::DiagnosticType::DeviceType & type );
                         * @brief	Gets from auto diagnosis on the diagnostic by type.
                         * @author	Yadickson Soto
                         * @date	28/11/2012
                         * @param type diagnostic type
                         * @return	diagnostic.
                         */

                        Smartmatic::SAES::Configuration::DiagnosticType getAutoDiagnosisDiagnosticType ( const Smartmatic::SAES::Configuration::DiagnosticType::DeviceType & type );

                        /**
                         * @fn	int getAllDiagnosisWaitTime( const Smartmatic::SAES::Configuration::DiagnosticType::DeviceType & type );
                         * @brief	Gets all diagnosis wait time by type.
                         * @author	Yadickson Soto
                         * @date	28/11/2012
                         * @param type diagnostic type
                         * @return	wait time.
                         */

                        int getAllDiagnosisWaitTime ( const Smartmatic::SAES::Configuration::DiagnosticType::DeviceType & type );

                        /**
                         * @fn	int getAutoDiagnosisWaitTime( const Smartmatic::SAES::Configuration::DiagnosticType::DeviceType & type );
                         * @brief	Gets auto diagnosis wait time by type.
                         * @author	Yadickson Soto
                         * @date	28/11/2012
                         * @param type diagnostic type
                         * @return	wait time.
                         */

                        int getAutoDiagnosisWaitTime ( const Smartmatic::SAES::Configuration::DiagnosticType::DeviceType & type );

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAllDiagnosisPrinterWaitTime();
                         * @brief	Gets all diagnosis printer wait time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	all diagnosis printer wait time.
                         */

                        int getAllDiagnosisPrinterWaitTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAllDiagnosisBarcodeWaitTime();
                         * @brief	Gets all diagnosis barcode wait time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	all diagnosis barcode wait time.
                         */

                        int getAllDiagnosisBarcodeWaitTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAllDiagnosisSmartcardWaitTime();
                         * @brief	Gets all diagnosis smartcard wait time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	all diagnosis smartcard wait time.
                         */

                        int getAllDiagnosisSmartcardWaitTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAllDiagnosisCalibrationWaitTime();
                         * @brief	Gets all diagnosis calibration wait time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	all diagnosis calibration wait time.
                         */

                        int getAllDiagnosisCalibrationWaitTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAllDiagnosisAlarmWaitTime();
                         * @brief	Gets all diagnosis alarm wait time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	all diagnosis alarm wait time.
                         */

                        int getAllDiagnosisAlarmWaitTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAllDiagnosisFlashWaitTime();
                         * @brief	Gets all diagnosis flash wait time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	all diagnosis flash wait time.
                         */

                        int getAllDiagnosisFlashWaitTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAllDiagnosisAbleWaitTime();
                         * @brief	Gets all diagnosis able wait time.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	all diagnosis able wait time.
                         */
                        int getAllDiagnosisAbleWaitTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAutoDiagnosisPrinterWaitTime();
                         * @brief	Gets the automatic diagnosis printer wait time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The automatic diagnosis printer wait time.
                         */

                        int getAutoDiagnosisPrinterWaitTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAutoDiagnosisBarcodeWaitTime();
                         * @brief	Gets the automatic diagnosis barcode wait time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The automatic diagnosis barcode wait time.
                         */

                        int getAutoDiagnosisBarcodeWaitTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAutoDiagnosisSmartcardWaitTime();
                         * @brief	Gets the automatic diagnosis smartcard wait time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The automatic diagnosis smartcard wait time.
                         */

                        int getAutoDiagnosisSmartcardWaitTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAutoDiagnosisAlarmWaitTime();
                         * @brief	Gets the automatic diagnosis alarm wait time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The automatic diagnosis alarm wait time.
                         */

                        int getAutoDiagnosisAlarmWaitTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getAutoDiagnosisFlashWaitTime();
                         * @brief	Gets the automatic diagnosis flash wait time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The automatic diagnosis flash wait time.
                         */

                        int getAutoDiagnosisFlashWaitTime();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::WaitingForCardWindowConfiguration SAESGUIConfigurationManager::getWaitingForCardWindowConfiguration();
                         * @brief	Gets waiting card widget configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	waiting card widget configuratio.
                         */
                        Smartmatic::SAES::Configuration::WaitingForCardWindowConfiguration getWaitingForCardWindowConfiguration();

                        /**
                         * @fn	bool SAESGUIConfigurationManager::getEnableGtkPrinting();
                         * @brief	Gets the enable gtk printing.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool getEnableGtkPrinting();

                        /**
                         * @fn	std::vector<Smartmatic::SAES::Configuration::DiagnosticType> SAESGUIConfigurationManager::getAllDiagnosisList();
                         * @brief	Gets all diagnosis list.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	all diagnosis list.
                         */

                        std::vector<Smartmatic::SAES::Configuration::DiagnosticType> getAllDiagnosisList();
                        //std::vector<std::string> getAutoDiagnosisList();

                        /**
                         * @fn	std::vector<Smartmatic::SAES::Configuration::DiagnosticType> SAESGUIConfigurationManager::getAutoDiagnosisList();
                         * @brief	Gets the automatic diagnosis list.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The automatic diagnosis list.
                         */

                        std::vector<Smartmatic::SAES::Configuration::DiagnosticType> getAutoDiagnosisList();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::ReportPrintingWidgetConfiguration SAESGUIConfigurationManager::GetPrintingWidgetConfiguration ();
                         * @brief	Gets the printing widget configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The printing widget configuration.
                         */

                        Smartmatic::SAES::Configuration::ReportPrintingWidgetConfiguration GetPrintingWidgetConfiguration ();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::CustomAtributtesWindowConfiguration & SAESGUIConfigurationManager::GetCustomAtributtesWindowConfiguration();
                         * @brief	Gets the custom atributtes window configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The custom atributtes window configuration.
                         */

                        Smartmatic::SAES::Configuration::CustomAtributtesWindowConfiguration & GetCustomAtributtesWindowConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::VotingExperienceLabelConfiguration & SAESGUIConfigurationManager::GetVotingExperienceLabelConfiguration();
                         * @brief	Gets the voting experience label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting experience label configuration.
                         */

                        Smartmatic::SAES::Configuration::VotingExperienceLabelConfiguration & GetVotingExperienceLabelConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::BallotOptionSelectionConfiguration & SAESGUIConfigurationManager::GetBallotOptionSelectionConfiguration();
                         * @brief	Gets the ballot option selection configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The ballot option selection configuration.
                         */

                        Smartmatic::SAES::Configuration::BallotOptionSelectionConfiguration & GetBallotOptionSelectionConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::ReferendumConfiguration & SAESGUIConfigurationManager::GetReferendumConfiguration();
                         * @brief	Gets the referendum selection configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The referendum selection configuration.
                         */

                        Smartmatic::SAES::Configuration::ReferendumConfiguration & GetReferendumConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::BallotOptionWidgetConfiguration & SAESGUIConfigurationManager::GetBallotOptionWidgetConfiguration();
                         * @brief	Gets the ballot option widget configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The ballot option widget configuration.
                         */

                        Smartmatic::SAES::Configuration::BallotOptionWidgetConfiguration & GetBallotOptionWidgetConfiguration();

                        /**
                         * @fn	bool SAESGUIConfigurationManager::getDetectCardExtraction();
                         * @brief	Gets the detect card extraction.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool getDetectCardExtraction();

                        /**
                         * @fn	unsigned int SAESGUIConfigurationManager::getNumberOfExtractionsBeforeStop();
                         * @brief	Gets the number of extractions before stop.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The number of extractions before stop.
                         */

                        unsigned int getNumberOfExtractionsBeforeStop();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::VotingWindowConfiguration & SAESGUIConfigurationManager::GetVotingWindowConfiguration();
                         * @brief	Gets the voting window configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting window configuration.
                         */

                        Smartmatic::SAES::Configuration::VotingWindowConfiguration & GetVotingWindowConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::PartyWidgetConfiguration & SAESGUIConfigurationManager::GetPartyWidgetConfiguration();
                         * @brief	Gets the party widget configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The party widget configuration.
                         */

                        Smartmatic::SAES::Configuration::PartyWidgetConfiguration & GetPartyWidgetConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::PartySelectionConfiguration & SAESGUIConfigurationManager::GetPartySelectionConfiguration();
                         * @brief	Gets the party selection configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The party selection configuration.
                         */

                        Smartmatic::SAES::Configuration::PartySelectionConfiguration & GetPartySelectionConfiguration();

                        /**
                         * @fn	std::vector<Smartmatic::SAES::GUI::Widgets::MenuOption> SAESGUIConfigurationManager::GetMenuOptionConfiguration();
                         * @brief	Gets a menu option configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The menu option configuration.
                         * ### param	type	The machine type.
                         */

                        std::vector<Smartmatic::SAES::GUI::Widgets::MenuOption> GetMenuOptionConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::GUI::Widgets::MenuOption SAESGUIConfigurationManager::GetSMMTMenuOptionFromXMLMenuOption ( Smartmatic::SAES::Configuration::MenuOption option );
                         * @brief	Gets a menu option configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @param	option	The xml menu option.
                         * @return	The menu option configuration.
                         */
                        Smartmatic::SAES::GUI::Widgets::MenuOption GetSMMTMenuOptionFromXMLMenuOption ( Smartmatic::SAES::Configuration::MenuOption option );

                        /**
                         * @fn	Smartmatic::SAES::Configuration::SaesGUIConfiguration * getConfiguration();
                         * @brief	Gets the configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	null if it fails, else the configuration.
                         */

                        Smartmatic::SAES::Configuration::SaesGUIConfiguration * getConfiguration();

                        /*Label configurations*/

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetCustomAtributtesWindowHeaderLabelConfiguration();
                         * @brief	Gets the custom atributtes window header label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The custom atributtes window header label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetCustomAtributtesWindowHeaderLabelConfiguration();//LISTO

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetCustomAtributtesWindowBottomLabelConfiguration();
                         * @brief	Gets the custom atributtes window bottom label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The custom atributtes window bottom label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetCustomAtributtesWindowBottomLabelConfiguration();//LISTO

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetCustomAtributtesWindowCenterLabelConfiguration();
                         * @brief	Gets the custom atributtes window center label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The custom atributtes window center label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetCustomAtributtesWindowCenterLabelConfiguration();//LISTO

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetPartySelectionWindowBottomLabelConfiguration();
                         * @brief	Gets the party selection window bottom label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The party selection window bottom label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetPartySelectionWindowBottomLabelConfiguration();//LISTO

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetPartySelectionWindowTitleLabelConfiguration();
                         * @brief	Gets the party selection window title label configuration.
                         * @author	Gabriel Jaimes
                         * @date	27/05/2022
                         * @return	The party selection window title label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetPartySelectionWindowTitleLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetPartySelectionWindowSubtitleLabelConfiguration();
                         * @brief	Gets the party selection window subtitle label configuration.
                         * @author	Gabriel Jaimes
                         * @date	27/05/2022
                         * @return	The party selection window subtitle label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetPartySelectionWindowSubtitleLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetBallotOptionSelectionWindowBottomLabelConfiguration();
                         * @brief	Gets the ballot option selection window bottom label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The ballot option selection window bottom label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetBallotOptionSelectionWindowBottomLabelConfiguration();//LISTO

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetBallotOptionSelectionWindowTitleLabelConfiguration();
                         * @brief	Gets the ballot option selection window title label configuration.
                         * @author	Gabriel Jaimes
                         * @date	27/05/2022
                         * @return	The ballot option selection window title label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetBallotOptionSelectionWindowTitleLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetBallotOptionSelectionWindowSubtitleLabelConfiguration();
                         * @brief	Gets the ballot option selection window subtitle label configuration.
                         * @author	Gabriel Jaimes
                         * @date	27/05/2022
                         * @return	The ballot option selection window subtitle label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetBallotOptionSelectionWindowSubtitleLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetSelectionLanguageHeaderLabelConfiguration();
                         * @brief	Gets the selection language header label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The selection language header label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetSelectionLanguageHeaderLabelConfiguration(); //LISTO

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetSelectionLanguageBottomLabelConfiguration();
                         * @brief	Gets the selection language bottom label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The selection language bottom label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetSelectionLanguageBottomLabelConfiguration(); //LISTO

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetSelectionLanguageConfirmationHeaderLabelConfiguration();
                         * @brief	Gets the selection language confirmation header label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The selection language confirmation header label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetSelectionLanguageConfirmationHeaderLabelConfiguration();//LISTO

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetSelectionLanguageConfirmationBottomLabelConfiguration();
                         * @brief	Gets the selection language confirmation bottom label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The selection language confirmation bottom label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetSelectionLanguageConfirmationBottomLabelConfiguration();//LISTO

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetSelectionLanguageConfirmationCenterLabelConfiguration();
                         * @brief	Gets the selection language confirmation center label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The selection language confirmation center label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetSelectionLanguageConfirmationCenterLabelConfiguration(); //LISTO

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetCardActivatorStatisticsTitleLabelConfiguration();
                         * @brief	Gets the Title label configuration for card activator statistics.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	the Title label configuration for card activator statistics.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetCardActivatorStatisticsTitleLabelConfiguration();

                        /*Label configurations*/

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetPreviewVoteLabelConfiguration();
                         * @brief	Gets the preview vote upper label in waiting card widget .
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The preview vote upper label in waiting card widget.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetPreviewVoteLabelConfiguration();//LISTO

                        /**
                         * @fn	Smartmatic::SAES::Configuration::ButtonConfiguration SAESGUIConfigurationManager::getPreviewVoteButtonConfiguration();
                         * @brief	Gets preview vote button configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The preview vote button configuration.
                         */
                        Smartmatic::SAES::Configuration::ButtonConfiguration getPreviewVoteButtonConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetWelcomeContestCenterLabelConfiguration();
                         * @brief	Gets the welcome contest center label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The welcome contest center label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetWelcomeContestCenterLabelConfiguration();//LISTO

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetDiagnosisLabelConfiguration();
                         * @brief	Gets the diagnosis label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The diagnosis label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetDiagnosisLabelConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getDiagnosisFooterLabelConfiguration();
                         * @brief	Method getter diagnostic footer config.
                         * @author	Yadickson Soto
                         * @date	08/05/2012
                         * @return	diagnostic footer config.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getDiagnosisFooterLabelConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getResultErrorLabelConfiguration();
                         * @brief	Method getter diagnostic result error config.
                         * @author	Yadickson Soto
                         * @date	08/05/2012
                         * @return	diagnostic result error config.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getResultErrorLabelConfiguration();
                        /**
                         * @fn	bool SAESGUIConfigurationManager::getShowFooterInAutoDiagnosis();
                         * @brief	Method getter is show footer in auto diagnosis.
                         * @author	Yadickson Soto
                         * @date	08/05/2012
                         * @return	true is show footer in auto diagnosis.
                         */
                        bool getShowFooterInAutoDiagnosis();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetExitMessageLabelConfiguration();
                         * @brief	Gets the exit message label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The exit message label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration  GetExitMessageLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetLoadingBallotsLabelConfiguration();
                         * @brief	Gets the loading ballots label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The loading ballots label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetLoadingBallotsLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetCheckSumLabelConfiguration();
                         * @brief	Gets the check sum label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The check sum label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetCheckSumLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetInterrupVotingExperienceMessageLabelConfiguration();
                         * @brief	Gets the Interrupt voting experience message label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The Interrupt voting experience message label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration GetInterrupVotingExperienceMessageLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetInterrupVotingExperienceCancelLabelConfiguration();
                         * @brief	Gets the Interrupt voting experience cancel label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The Interrupt voting experience cancel label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration GetInterrupVotingExperienceCancelLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetReportListTitleLabelConfiguration();
                         * @brief	Gets the report list title label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The report list title label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetReportListTitleLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetProgressLabelConfiguration();
                         * @brief	Gets the progress label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The progress label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetProgressLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetCompositeMsgLabelConfiguration();
                         * @brief	Gets the composite message label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The composite message label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetCompositeMsgLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetFileItemLabelConfiguration();
                         * @brief	Gets the file item label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The file item label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetFileItemLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getAuthenticationPasswordLabelConfiguration();
                         * @brief	Method getter the authentication password label configuration.
                         * @author	Yadickson Soto
                         * @date	24/04/2012
                         * @return	The authentication password label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getAuthenticationPasswordLabelConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getAuthenticationAlarmLabelConfiguration();
                         * @brief	Method getter the authentication alarm label configuration.
                         * @author	Yadickson Soto
                         * @date	24/04/2012
                         * @return	The authentication alarm label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getAuthenticationAlarmLabelConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getAuthenticationInfoLabelConfiguration();
                         * @brief	Method getter the authentication info label configuration.
                         * @author	Yadickson Soto
                         * @date	24/04/2012
                         * @return	The authentication info label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getAuthenticationInfoLabelConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getAuthenticationVotingInfoLabelConfiguration();
                         * @brief	Method getter the authentication voting info label configuration.
                         * @author	Yadickson Soto
                         * @date	24/04/2012
                         * @return	The authentication voting info label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getAuthenticationVotingInfoLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration & SAESGUIConfigurationManager::GetVotingWidgetLabelChildLabelConfiguration();
                         * @brief	Gets the voting widget label child label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting widget label child label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration & GetVotingWidgetLabelChildLabelConfiguration(); //Listo

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration & SAESGUIConfigurationManager::GetVotingWidgetTopChildLabelConfiguration();
                         * @brief	Gets the voting widget top child label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting widget top child label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration & GetVotingWidgetTopChildLabelConfiguration(); //listo

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration & SAESGUIConfigurationManager::GetVotingWidgetBottomChildLabelConfiguration();
                         * @brief	Gets the voting widget bottom child label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting widget bottom child label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration & GetVotingWidgetBottomChildLabelConfiguration(); //listo

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration & SAESGUIConfigurationManager::GetVotingWidgetNumberChildLabelConfiguration();
                         * @brief	Gets the voting widget number child label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting widget number child label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration & GetVotingWidgetNumberChildLabelConfiguration(); //Listo

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration & SAESGUIConfigurationManager::GetVotingWidgetPartySelectionLabelChildLabelConfiguration();
                         * @brief	Gets the voting widget party selection label child label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting widget party selection label child label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration & GetVotingWidgetPartySelectionLabelChildLabelConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration & SAESGUIConfigurationManager::GetVotingWindowEndMessagelabelConfig();
                         * @brief	Gets the voting window end messagelabel configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting window end messagelabel configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration & GetVotingWindowEndMessagelabelConfig();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetVMLogingMessageLabel();
                         * @brief	Gets the voting machine loging message label.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The voting machine loging message label.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetVMLogingMessageLabel();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration & SAESGUIConfigurationManager::GetPartyNullLabelConfiguration();
                         * @brief	Gets the party null label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The party null label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration & GetPartyNullLabelConfiguration();

                        /*Form common control*/

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetEmptyWindowTitleFormConfiguration();
                         * @brief	Gets the empty window title form configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The empty window title form configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetEmptyWindowTitleFormConfiguration();

                        /**
                         * @fn	::Smartmatic::SAES::Configuration::FormsTitleLabelConfigurations & SAESGUIConfigurationManager::GetFormTitlesLabelsConfiguration();
                         * @brief	Gets the form titles labels configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return the form titles labels configuration.
                         */

                        ::Smartmatic::SAES::Configuration::FormsTitleLabelConfigurations & GetFormTitlesLabelsConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetUnableFunctionalityLabelConfiguration();
                         * @brief	Gets the unable functionality label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The unable functionality label configuration.
                         */

                        Smartmatic::GUI::Configuration::LabelConfiguration GetUnableFunctionalityLabelConfiguration();

                        /**
                         * @fn	int SAESGUIConfigurationManager::GetUnableMessageCloseTime();
                         * @brief	Gets the unable message close time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The unable message close time.
                         */

                        int GetUnableMessageCloseTime();

                        /**
                         * @fn	int SAESGUIConfigurationManager::GetExitFunctionalityMessageCloseTime();
                         * @brief	Gets the exit functionality message close time.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The exit functionality message close time.
                         */

                        int GetExitFunctionalityMessageCloseTime();

                        /**
                         * @fn	::Smartmatic::SAES::Configuration::FormsMessagesLabelConfigurations & SAESGUIConfigurationManager::GetFormMessagesLabelsConfiguration();
                         * @brief	Gets the form messages labels configuration.
                         * @author	Juan Delgado, Yadickson Soto
                         * @date	28/04/2011
                         * @return the form messages labels configuration.
                         */

                        ::Smartmatic::SAES::Configuration::FormsMessagesLabelConfigurations & GetFormMessagesLabelsConfiguration();

                        /**
                         * @fn	::Smartmatic::SAES::Configuration::FormsCommonControlsConfigurations & SAESGUIConfigurationManager::GetCommonControlsFormConfiguration();
                         * @brief	Gets the common controls form configuration.
                         * @author	Juan Delgado, Yadickson Soto
                         * @date	28/04/2011
                         * @return the common controls form configuration.
                         */

                        ::Smartmatic::SAES::Configuration::FormsCommonControlsConfigurations & GetCommonControlsFormConfiguration();

                        /**
                         * @fn	::Smartmatic::SAES::Configuration::ActivatedCardStatisticsConfiguration SAESGUIConfigurationManager::getCardActivationStatisticsConfiguration();
                         * @brief	Gets the Activated card statistics for the Card Activator Functionality.
                         * @author	Juan Delgado, Yadickson Soto
                         * @date	28/04/2011
                         * @return the Activated card statistics for the Card Activator Functionality.
                         */
                        ::Smartmatic::SAES::Configuration::ActivatedCardStatisticsConfiguration getCardActivationStatisticsConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::ColorConfiguration SAESGUIConfigurationManager::getCardActivatorStatisticsTitleColor();
                         * @brief	Gets the Color Configuration for the Card Activator statistics title.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @return	The Color Configuration for the Card Activator statistics title.
                         */
                        Smartmatic::SAES::Configuration::ColorConfiguration getCardActivatorStatisticsTitleColor();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::VMInstallationWidgetConfiguration SAESGUIConfigurationManager::GetVMInstallationConfiguration();
                         * @brief	Gets voting machine installation configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The voting machine installation configuration.
                         */
                        Smartmatic::SAES::Configuration::VMInstallationWidgetConfiguration GetVMInstallationConfiguration();

                        /**
                         * @fn	bool SAESGUIConfigurationManager::GetPMInstallationWidgetShowPrintPasswordButton();
                         * @brief	Gets pm installation widget show print password button.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	true if it succeeds, false if it fails.
                         */
                        bool GetPMInstallationWidgetShowPrintPasswordButton();

                        /**
                         * @fn	int SAESGUIConfigurationManager::getCloseVotationMinimumOfficialsActivationForConfirmation();
                         * @brief	Gets close votation minimum officials activation for confirmation.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The close votation minimum officials activation for confirmation.
                         */
                        int getCloseVotationMinimumOfficialsActivationForConfirmation();

                        /**
                         * @fn	bool SAESGUIConfigurationManager::getCloseVotationShowConfirmationMessageWhenClosing();
                         * @brief	Gets close votation show confirmation message when closing.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	true if it succeeds, false if it fails.
                         */
                        bool getCloseVotationShowConfirmationMessageWhenClosing();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::MemoryStateWidgetConfiguration & SAESGUIConfigurationManager::getMemoryStateWidgetConfiguration();
                         * @brief	Gets memory state widget configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The memory state widget configuration.
                         */
                        Smartmatic::SAES::Configuration::MemoryStateWidgetConfiguration & getMemoryStateWidgetConfiguration();

                        /**
                         * @fn  Smartmatic::SAES::Configuration::ExternalPrintWizardWidgetConfiguration & SAESGUIConfigurationManager::getExternalPrintWizardWidgetConfiguration();
                         * @brief   Gets external print wizard widget configuration.
                         * @author  eduardo.fernandez
                         * @date    18/09/2017
                         * @return  The external print wizard widget configuration.
                         */
                        Smartmatic::SAES::Configuration::ExternalPrintWizardWidgetConfiguration & getExternalPrintWizardWidgetConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getMemoryStateWidgetTextConfiguration();
                         * @brief	Gets memory state widget text configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The memory state widget text configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getMemoryStateWidgetTextConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::HelpWidgetConfiguration & SAESGUIConfigurationManager::getHelpWidgetConfiguration();
                         * @brief	Gets help widget configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The help widget configuration.
                         */
                        Smartmatic::SAES::Configuration::HelpWidgetConfiguration & getHelpWidgetConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::NecessaryDevicesConfiguration::DeviceConfigurationSequence SAESGUIConfigurationManager::getDeviceConfiguration ( Smartmatic::SAES::Functionality::Configuration::MenuOptionType menuType );
                         * @brief	Gets device configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	menuType	Type of the menu.
                         * @return	The device configuration.
                         */
                        Smartmatic::SAES::Configuration::NecessaryDevicesConfiguration::DeviceConfigurationSequence getDeviceConfiguration ( Smartmatic::SAES::Functionality::Configuration::MenuOptionType menuType );

                        /**
                         * @fn	Smartmatic::SAES::Configuration::AutomaticWindowConfigurationForOfficialMode & SAESGUIConfigurationManager::GetAutomaticWindowConfigurationForOfficialMode();
                         * @brief	Gets the Automatic Diagnostic Configuration.
                         * @author	Freddy Gomez
                         * @date	21/05/2011
                         * @return	The reference to the Automatic Diagnostic Configuration.
                         */
                        Smartmatic::SAES::Configuration::AutomaticWindowConfigurationForOfficialMode & GetAutomaticWindowConfigurationForOfficialMode();

                        /**
                         * @fn  Smartmatic::SAES::Configuration::AutomaticWindowConfigurationForRecountMode & SAESGUIConfigurationManager::GetAutomaticWindowConfigurationForRecountMode();
                         * @brief   Gets the Automatic Diagnostic Configuration.
                         * @author  Eduardo Fernández
                         * @date    09/08/2017
                         * @return  The reference to the Automatic Diagnostic Configuration.
                         */
                        Smartmatic::SAES::Configuration::AutomaticWindowConfigurationForRecountMode & GetAutomaticWindowConfigurationForRecountMode();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::AllDiagnosisConfiguration & SAESGUIConfigurationManager::getAllDiagnosisConfiguration();
                         * @brief	Gets all diagnosis configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	all diagnosis configuration.
                         */
                        Smartmatic::SAES::Configuration::AllDiagnosisConfiguration & getAllDiagnosisConfiguration();
                        /**
                         * @fn	Smartmatic::SAES::Configuration::DeviceDiagnosticResultConfiguration & SAESGUIConfigurationManager::getDeviceDiagnosticResultConfiguration();
                         * @brief	Gets device diagnostic result configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The device diagnostic result configuration.
                         */
                        Smartmatic::SAES::Configuration::DeviceDiagnosticResultConfiguration & getDeviceDiagnosticResultConfiguration();
                        /**
                         * @fn	Smartmatic::SAES::Configuration::SerialNumberConfiguration & SAESGUIConfigurationManager::getSerialNumberConfiguration();
                         * @brief	Gets serial number configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The serial number configuration.
                         */
                        Smartmatic::SAES::Configuration::SerialNumberConfiguration & getSerialNumberConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getSerialNumberTitleConfiguration();
                         * @brief	Gets serial number title configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The serial number title configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getSerialNumberTitleConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getSerialNumberInfoConfiguration();
                         * @brief	Gets serial number information configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The serial number information configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getSerialNumberInfoConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getSerialNumberMessageConfiguration();
                         * @brief	Gets serial number message configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The serial number message configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getSerialNumberMessageConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::ZipCodeConfiguration & SAESGUIConfigurationManager::getZipCodeConfiguration();
                         * @brief	Gets zip code configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The zip code configuration.
                         */
                        Smartmatic::SAES::Configuration::ZipCodeConfiguration & getZipCodeConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getZipCodeTitleConfiguration();
                         * @brief	Gets zip code title configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The zip code title configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getZipCodeTitleConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getZipCodeInfoConfiguration();
                         * @brief	Gets zip code information configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The zip code information configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getZipCodeInfoConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getZipCodeMessageConfiguration();
                         * @brief	Gets zip code message configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The zip code message configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getZipCodeMessageConfiguration();

                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetReferendumHeaderLabelConfiguration();
                         * @brief	Gets referendum header label configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The referendum header label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration GetReferendumHeaderLabelConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetReferendumBottomLabelConfiguration();
                         * @brief	Gets referendum bottom label configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The referendum bottom label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration GetReferendumBottomLabelConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetReferendumQuestionLabelConfiguration();
                         * @brief	Gets referendum question label configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The referendum question label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration GetReferendumQuestionLabelConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::GetReferendumBallotsLabelConfiguration();
                         * @brief	Gets referendum ballots label configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The referendum ballots label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration GetReferendumBallotsLabelConfiguration();

                        /**
                         * @fn	static Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::ConvertToLabelConfiguration ( Smartmatic::SAES::Configuration::XMLLabelConfiguration xmlLabelConfiguration );
                         * @brief	Converts an xmlLabelConfiguration to a label configuration.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @param	xmlLabelConfiguration	The xml label configuration.
                         * @return	The given data converted to a label configuration.
                         */

                        static Smartmatic::GUI::Configuration::LabelConfiguration ConvertToLabelConfiguration ( Smartmatic::SAES::Configuration::XMLLabelConfiguration xmlLabelConfiguration );

                        /**
                         * @fn	static Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::ConvertToLabelConfiguration ( Smartmatic::SAES::Voting::Election::AlignmentConfiguration alignmentConfiguration );
                         * @brief	Converts an AlignmentConfiguration to a LabelAlignmentEnum.
                         * @author	Gabriel Jaimes
                         * @date	01/07/2022
                         * @param	alignmentConfiguration	The alignment configuration.
                         * @return	The given AlignmentConfiguration converted to a LabelAlignmentEnum.
                         */

                        static Smartmatic::GUI::Configuration::LabelAlignmentEnum ConvertToLabelConfiguration ( Smartmatic::SAES::Voting::Election::AlignmentConfiguration alignmentConfiguration );
                        /**
                         * @fn	static Gdk::Color ConvertToGdkColor ( Smartmatic::SAES::Configuration::ColorConfiguration colorConfiguration );
                         * @brief	Converts an color configuration to gdk color
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @param	colorConfiguration	The color configuration.
                         * @return	gdk color.
                         */

                        static Gdk::Color ConvertToGdkColor ( Smartmatic::SAES::Configuration::ColorConfiguration colorConfiguration );

                        /**
                         * @fn	Smartmatic::SAES::Configuration::PollingCardConfiguration & SAESGUIConfigurationManager::getPollingCardConfiguration();
                         * @brief	Method getter polling card configuration.
                         * @author	Yadickson Soto
                         * @date	16/05/2012
                         * @return	polling card configuration.
                         */
                        Smartmatic::SAES::Configuration::PollingCardConfiguration & getPollingCardConfiguration();
                        /**
                         * @fn	Smartmatic::SAES::Configuration::AlarmBoxMonitorConfiguration & SAESGUIConfigurationManager::getAlarmBoxMonitorConfiguration();
                         * @brief	Method getter alarm box monitor configuration.
                         * @author	Yadickson Soto
                         * @date	16/05/2012
                         * @return	alarm box monitor configuration.
                         */
                        Smartmatic::SAES::Configuration::AlarmBoxMonitorConfiguration & getAlarmBoxMonitorConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::StartConfiguration & SAESGUIConfigurationManager::getStartConfiguration();
                         * @brief	Gets start configuration.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The start configuration.
                         */
                        Smartmatic::SAES::Configuration::StartConfiguration & getStartConfiguration();

                        /**
                         * @fn	void SAESGUIConfigurationManager::addSkipAutoDiagnosis ( Smartmatic::SAES::Configuration::DiagnosticType type );
                         * @brief	Adds a skip automatic diagnosis.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	type	The type.
                         */
                        void addSkipAutoDiagnosis ( Smartmatic::SAES::Configuration::DiagnosticType type );
                        /**
                         * @fn	Smartmatic::SAES::Configuration::DataUtilsValidatorFunctionalityConfiguration & SAESGUIConfigurationManager::getDataUtilsValidatorFunctionalityConfiguration();
                         * @brief	method getter data utils validator functionality configuration.
                         * @author	Yadickson Soto
                         * @date	18/07/2012
                         * @return	data utils validator functionality configuration.
                         */
                        Smartmatic::SAES::Configuration::DataUtilsValidatorFunctionalityConfiguration & getDataUtilsValidatorFunctionalityConfiguration();
                        /**
                         * @fn	Smartmatic::GUI::Configuration::LabelConfiguration SAESGUIConfigurationManager::getBlockDiagnosticTitle();
                         * @brief	method getter block diagnosis config.
                         * @author	Yadickson Soto
                         * @date	12/06/2012
                         * @return	label configuration.
                         */
                        Smartmatic::GUI::Configuration::LabelConfiguration getBlockDiagnosticTitle();
                        /**
                         * @fn	Smartmatic::SAES::Configuration::VotingExperienceConfiguration & SAESGUIConfigurationManager::getVotingExperienceConfiguration();
                         * @brief	method getter voting experience configuration.
                         * @author	Yadickson Soto
                         * @date	14/06/2012
                         * @return	voting experience configuration.
                         */
                        Smartmatic::SAES::Configuration::VotingExperienceConfiguration & getVotingExperienceConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::AbleWidgetConfiguration & SAESGUIConfigurationManager::getAbleWidgetConfiguration();
                         * @brief	Method getter able widget configuration.
                         * @author	Yadickson Soto
                         * @date	10/09/2012
                         * @return	Able Widget Configuration.
                         */
                        Smartmatic::SAES::Configuration::AbleWidgetConfiguration & getAbleWidgetConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::DateDiagnosticWidgetConfiguration & SAESGUIConfigurationManager::getDateDiagnosticWidgetConfiguration();
                         * @brief	Method getter date diagnostic configuration.
                         * @author	Daniel Ampuero
                         * @date	19/09/2012
                         * @return	Date Diagnostic Configuration.
                         */
                        Smartmatic::SAES::Configuration::DateDiagnosticWidgetConfiguration & getDateDiagnosticWidgetConfiguration();
                        /**
                         * @fn	Smartmatic::SAES::Configuration::ProcessResultWidgetConfiguration & getProcessResultWidgetConfiguration();
                         * @brief	Gets process result widget configuration.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         * @return	The process result widget configuration.
                         */
                        Smartmatic::SAES::Configuration::ProcessResultWidgetConfiguration & getProcessResultWidgetConfiguration();
                        /**
                         * @fn	Smartmatic::SAES::Configuration::ProcessStatusResultsShutdownFunctionalityConfiguration & getProcessStatusResultsShutdownFunctionalityConfiguration();
                         * @brief	Gets process status result shutdown functionality configuration.
                         * @author	Yadickson Soto
                         * @date	09/11/2012
                         * @return	The process status result shutdown functionality configuration.
                         */
                        Smartmatic::SAES::Configuration::ProcessStatusResultsShutdownFunctionalityConfiguration & getProcessStatusResultsShutdownFunctionalityConfiguration();
                        /**
                         * @fn	Smartmatic::SAES::Configuration::SelectionWidgetConfiguration & getLanguageSelectionWidgetConfiguration();
                         * @brief	Gets language selection widget configuration.
                         * @author	Yadickson Soto
                         * @date	13/11/2012
                         * @return	The language selection widget configuration.
                         */
                        Smartmatic::SAES::Configuration::SelectionWidgetConfiguration & getLanguageSelectionWidgetConfiguration();
                        /**
                         * @fn	Smartmatic::SAES::Configuration::SelectionWidgetConfiguration & getCustomAttributeSelectionWidgetConfiguration();
                         * @brief	Gets custom attribute selection widget configuration.
                         * @author	Yadickson Soto
                         * @date	13/11/2012
                         * @return	The custom attribute selection widget configuration.
                         */
                        Smartmatic::SAES::Configuration::SelectionWidgetConfiguration & getCustomAttributeSelectionWidgetConfiguration();

                        /**
                         * @fn	bool getForceExecuteFunctionality();
                         * @brief
                         * @author	Yadickson Soto
                         * @date	13/11/2012
                         * @return	The custom attribute selection widget configuration.
                         */
                        bool getForceExecuteFunctionality();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::GenericWidgetConfiguration & getGenericWidgetConfiguration();
                         * @brief	Gets generic widget configuration
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @return	The config
                         */
                        Smartmatic::SAES::Configuration::GenericWidgetConfiguration & getGenericWidgetConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::AlarmBoxDiagnosisConfiguration & getAlarmBoxDiagnosisConfiguration();
                         * @brief	Gets alarmbox diagnostic configuration
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @return	The config
                         */
                        Smartmatic::SAES::Configuration::AlarmBoxDiagnosisConfiguration & getAlarmBoxDiagnosisConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::EurnDiagnosisConfiguration & getEurnDiagnosisConfiguration();
                         * @brief	Gets eUrn diagnostic configuration
                         * @author	Juan Valera
                         * @date	07/11/2017
                         * @return	The config
                         */
                        Smartmatic::SAES::Configuration::EurnDiagnosisConfiguration & getEurnDiagnosisConfiguration();

                        /**
                        * @fn  Smartmatic::SAES::Configuration::LedStripDiagnosisConfiguration & getLedStripDiagnosisConfiguration();
                        * @brief   Gets Led Strip diagnostic configuration
                        * @author  Juan Valera
                        * @date    07/11/2017
                        * @return  The config
                        */
                       Smartmatic::SAES::Configuration::LedStripDiagnosisConfiguration & getLedStripDiagnosisConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::RecountFunctionalityConfiguration & getRecountFunctionalityConfiguration();
                         * @brief	Getter recount functionality configuration.
                         * @author	Yadickson Soto
                         * @date	17/05/2013
                         * @return the recount functionality configuration.
                         */
                        Smartmatic::SAES::Configuration::RecountFunctionalityConfiguration & getRecountFunctionalityConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::CustomRemarkDiagnoseConfiguration & getCustomRemarkDiagnoseConfiguration();
                         * @brief	Getter custom remark diagnose configuration.
                         * @author	Yadickson Soto
                         * @date	18/09/2013
                         * @return the custom remark diagnose configuration.
                         */
                        Smartmatic::SAES::Configuration::CustomRemarkDiagnoseConfiguration & getCustomRemarkDiagnoseConfiguration();

                        /**
                         * @fn  Smartmatic::GUI::Configuration::SaesGUIMachineModelConfiguration::MachineModelType getCurrentMachineModelConfiguration ();
                         * @brief   Getter gui machine model configuration components.
                         * @author  Eduardo Fernández
                         * @date    07/09/2017
                         * @return  gui machine model configuration components.
                         */
                        Smartmatic::SAES::Configuration::MachineModelType getCurrentMachineModelConfiguration ();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::MenuWidgetConfiguration & getMenuWidgetConfiguration();
                         * @brief	Method getter menu widget configuration
                         * @author	Yadickson Soto
                         * @date	15/01/2013
                         * @return menu widget configuration
                         */
                        Smartmatic::SAES::Configuration::MenuWidgetConfiguration & getMenuWidgetConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::GeneralDiagnosisConfiguration & getGeneralDiagnosisConfiguration();
                         * @brief	Getter method: general diagnosis configuration
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         * @return general diagnosis configuration
                         */
                        Smartmatic::SAES::Configuration::GeneralDiagnosisConfiguration & getGeneralDiagnosisConfiguration();

                        /**
                         * @fn	virtual SAESGUIConfigurationManager::~SAESGUIConfigurationManager();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	15/04/2014
                         */
                        virtual ~SAESGUIConfigurationManager();

                    protected:

                        /**
                         * @fn	SAESGUIConfigurationManager::SAESGUIConfigurationManager();
                         * @brief	Default constructor.
                         * @author	Fsilva
                         * @date	28/04/2011
                         */
                        SAESGUIConfigurationManager();

                        /**
                         * @fn	virtual void initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	15/04/2014
                         */
                        virtual void initialize();

                        Smartmatic::SAES::Configuration::SaesGUIConfiguration * configuration;	///< The configuration

                        /**
                         * @fn	std::vector<Smartmatic::SAES::GUI::Widgets::MenuOption> SAESGUIConfigurationManager::GetInnerOptions ( Smartmatic::SAES::Configuration::MenuOption xmlMenuOption );
                         * @brief	Gets an inner options with the given xml.
                         * @author	Fsilva
                         * @date	28/04/2011
                         * @param	xmlMenuOption	The xml menu option.
                         * @return	The inner options.
                         */

                        std::vector<Smartmatic::SAES::GUI::Widgets::MenuOption> GetInnerOptions ( Smartmatic::SAES::Configuration::MenuOption xmlMenuOption );

                        Smartmatic::GUI::Configuration::LabelConfiguration  votingWidgetLabelChildLabelConfiguration;   ///< The voting widget label child label configuration
                        Smartmatic::GUI::Configuration::LabelConfiguration  votingWidgetTopChildLabelConfiguration; ///< The voting widget top child label configuration
                        Smartmatic::GUI::Configuration::LabelConfiguration  votingWidgetBottomChildLabelConfiguration;  ///< The voting widget bottom child label configuration
                        Smartmatic::GUI::Configuration::LabelConfiguration  votingWidgetNumberChildLabelConfiguration;  ///< The voting widget number child label configuration
                        Smartmatic::GUI::Configuration::LabelConfiguration  votingWidgetPartySelectionLabelChildLabelConfiguration; ///< The voting widget party selection label child label configuration
                        Smartmatic::GUI::Configuration::LabelConfiguration partyNullLabelConfiguration; ///< The party null label configuration
                        Smartmatic::GUI::Configuration::LabelConfiguration votingWindowEndMessagelabelConfig;   ///< The voting window end messagelabel configuration

                        Smartmatic::SAES::Configuration::VotingExperienceLabelConfiguration votingExperienceLabelConfiguration; ///< The voting experience label configuration

                        /**
                         * @fn	Smartmatic::SAES::Configuration::MenuOptionsConfiguration & getMenuOptionsConfiguration();
                         * @brief	Method getter menu options configuration
                         * @author	Yadickson Soto
                         * @date	15/01/2013
                         * @return menu options configuration
                         */
                        Smartmatic::SAES::Configuration::MenuOptionsConfiguration & getMenuOptionsConfiguration();

                    private:

                        /**
                         * @fn	Smartmatic::SAES::Configuration::FunctionalityWizardFlowConfiguration & getFunctionalityWizardConfiguration();
                         * @brief	Method getter functionality wizard flow configuration
                         * @author	Yadickson Soto
                         * @date	15/01/2013
                         * @return functionality wizard flow configuration
                         */
                        Smartmatic::SAES::Configuration::FunctionalityWizardFlowConfiguration & getFunctionalityWizardConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::VotingExperienceGUIConfiguration & getVotingExperienceGUIConfiguration();
                         * @brief	Method getter voting experience gui configuration
                         * @author	Yadickson Soto
                         * @date	15/01/2013
                         * @return voting experience gui configuration
                         */
                        Smartmatic::SAES::Configuration::VotingExperienceGUIConfiguration & getVotingExperienceGUIConfiguration();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::FormsCommonControlsConfigurations SAESGUIConfigurationManager::createCommonControlsConfigurations();
                         * @brief	Creates the common controls configurations.
                         * @author	Juan Delgado, Yadickson Soto
                         * @date	28/04/2011
                         * @return the common controls configurations.
                         */

                        Smartmatic::SAES::Configuration::FormsCommonControlsConfigurations createCommonControlsConfigurations();

                        /**
                         * @fn	Smartmatic::SAES::Configuration::FunctionalityWizardFlowConfiguration SAESGUIConfigurationManager::createFunctionalityWizardConfig();
                         * @brief	Creates the functionality wizard.
                         * @author	Juan Delgado, Yadickson Soto
                         * @date	01/11/2012
                         * @return the functionality wizard.
                         */
                        Smartmatic::SAES::Configuration::FunctionalityWizardFlowConfiguration createFunctionalityWizardConfig();


                        Smartmatic::SAES::Configuration::MenuOptionsConfiguration menuOptionsConfiguration; ///< menu options configuration
                        Smartmatic::SAES::Configuration::MenuWidgetConfiguration menuWidgetConfiguration; ///< menu widget configuration
                        Smartmatic::SAES::Configuration::FunctionalityWizardFlowConfiguration functionalityWizardFlowConfiguration; ///< functionality wizard flow configuration
                        Smartmatic::SAES::Configuration::VotingExperienceGUIConfiguration votingExperienceGUIConfiguration; ///< voting experience gui configuration

                        std::vector<Smartmatic::SAES::Configuration::DiagnosticType> skipDiagnosis; ///< The skip diagnosis
                        static SAESGUIConfigurationManager * instance;	///< The singleton instance
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                };
            }
        }
    }
}

#endif // _S_A_E_S_G_U_I_CONFIGURATION_MANAGER_H_
