/**
 * @file AbleDiagnosticFunctionality.cxx
 * @brief Body class able diagnostic functionality
 * @date 05/09/2012
 * @author Yadickson Soto
 */

#include "AbleDiagnosticFunctionality.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::Functionality;

ISMTTLog * AbleDiagnosticFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.AbleDiagnosticFunctionality", GETTEXT_PACKAGE );

AbleDiagnosticFunctionality * AbleDiagnosticFunctionality::instance = NULL;

AbleDiagnosticFunctionality::AbleDiagnosticFunctionality()
{
    ableDiagnosticWidget = NULL;
}

AbleDiagnosticFunctionality::~AbleDiagnosticFunctionality()
{
    deleteElements();
}

AbleDiagnosticFunctionality * AbleDiagnosticFunctionality::getInstance()
{
    if ( !instance )
    {
        instance = new AbleDiagnosticFunctionality();
    }

    return instance;
}

std::string AbleDiagnosticFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AbleDiagnosticFunctionality.Title" );
}

Smartmatic::Log::ISMTTLog * AbleDiagnosticFunctionality::getLogger()
{
    return logger;
}

Glib::ustring AbleDiagnosticFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AbleDiagnosticFunctionality.LogStartFunctionality" );
}

Glib::ustring AbleDiagnosticFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AbleDiagnosticFunctionality.LogCloseFunctionality" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType AbleDiagnosticFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMABLEDIAGNOSTICFUNCTIONALITY;
}

Gtk::Widget * AbleDiagnosticFunctionality::GetFrame()
{
    ableDiagnosticWidget = new AbleDiagnosticWidget ();
    return ableDiagnosticWidget;
}

void AbleDiagnosticFunctionality::Dispose()
{
    ableDiagnosticWidget->Dispose();
    connDiag.disconnect();
}

void AbleDiagnosticFunctionality::Initialize()
{
    ableDiagnosticWidget->initialize();
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.AbleDiagnosticFunctionality.FinalMessage" ) );
    disableExitButton();
    connDiag.disconnect();
    connDiag = ableDiagnosticWidget->getSignalEnd().connect ( sigc::mem_fun ( this, &AbleDiagnosticFunctionality::endDiagnosis ) );
}

void AbleDiagnosticFunctionality::endDiagnosis()
{
    enableExitButton();
    logger->Audit ( N_ ( "Smartmatic.SAES.GUI.Functionality.AbleDiagnosticFunctionality.AbleDiagnosisExecuted" ) );
    ExitFunctionality();
}

void AbleDiagnosticFunctionality::deleteElements()
{
    if ( ableDiagnosticWidget )
    {
        delete ableDiagnosticWidget;
        ableDiagnosticWidget = NULL;
    }
}

void AbleDiagnosticFunctionality::block()
{
    logger->Debug ( "Block functionality" );
}

void AbleDiagnosticFunctionality::partial()
{
    logger->Debug ( "Partial functionality" );
}

void AbleDiagnosticFunctionality::resume()
{
    logger->Debug ( "Resume functionality" );
}
