/**
 * @file AuthenticatorFunctionality.cxx
 * @brief Body auto diagnostic functionality class
 * @date 04/10/2012
 * @author Yadickson Soto
 */

#include "AuthenticatorFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Functionalities/saes-functionality-manager.h>
#include <Gui/Windows/VoteProcessWindow.hxx>
#include <Gui/Windows/BarcodeReconfigureWindow.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Windows;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;

ISMTTLog * AuthenticatorFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.AuthenticatorFunctionality", GETTEXT_PACKAGE );

AuthenticatorFunctionality * AuthenticatorFunctionality::current_instance = NULL;
AuthenticatorFunctionality * AuthenticatorFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new AuthenticatorFunctionality();
    }

    return current_instance;
}

AuthenticatorFunctionality::AuthenticatorFunctionality()
{
    widget = NULL;
}

void AuthenticatorFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void AuthenticatorFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.AuthenticatorFunctionality.ExitFunctionality" ) );
    widget->getSignalEnd().connect ( sigc::mem_fun ( *this, &AuthenticatorFunctionality::end ) );
    widget->getSignalRunMenu().connect ( sigc::mem_fun ( *this, &AuthenticatorFunctionality::runMenu ) );
    widget->getSignalRunMachine().connect ( sigc::mem_fun ( *this, &AuthenticatorFunctionality::runProcess ) );
    widget->initialize();
    disableExitButton();

    runProcess();
}

Gtk::Widget * AuthenticatorFunctionality::GetFrame()
{
    widget = AbstractFactoryWidget::createAuthenticationWidget();
    return widget;
}

std::string AuthenticatorFunctionality::GetWindowTitle()
{
    return widget->getTitleText();
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType AuthenticatorFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMAUTHENTICATORFUNCTIONALITY;
}

void AuthenticatorFunctionality::Dispose()
{
}

void AuthenticatorFunctionality::end()
{
    widget->stop();
    ExitFunctionality();
}

void AuthenticatorFunctionality::runMenu()
{
    widget->stop();
    logger->Debug ( "Run menu" );
    SaesFunctionalityManager::getInstance()->ExecuteOptionSelected ( Smartmatic::SAES::Functionality::Configuration::MenuOptionType::CONFIGURATION_XMLMENU );
}

void AuthenticatorFunctionality::runProcess()
{
    widget->stop();

    switch ( SAESGUIConfigurationManager::getInstance()->getStartConfiguration().getInfoMachine() )
    {
        case InfoMachineConfiguration::CONFIGURATION_PM:
            logger->Debug ( "Run wizard" );
            SaesFunctionalityManager::getInstance()->ExecuteOptionSelected ( Smartmatic::SAES::Functionality::Configuration::MenuOptionType::CONFIGURATION_XMLMWIZARDFUNCTIONALITY );
            break;

        default:
        case InfoMachineConfiguration::CONFIGURATION_VM:
            logger->Debug ( "Run voting experience" );
            SaesFunctionalityManager::getInstance()->ExecuteOptionSelected ( Smartmatic::SAES::Functionality::Configuration::MenuOptionType::CONFIGURATION_XMLMWAITINGVOTINGEXPERIENCEFUNCTIONALITY );
            break;
    }
}

AuthenticatorFunctionality::~AuthenticatorFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * AuthenticatorFunctionality::getLogger()
{
    return logger;
}

Glib::ustring AuthenticatorFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AuthenticatorFunctionality.LogStartFunctionality" );
}

Glib::ustring AuthenticatorFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AuthenticatorFunctionality.LogCloseFunctionality" );
}

void AuthenticatorFunctionality::refresh()
{
    VoteProcessWindow::getInstance()->stop();
    BarcodeReconfigureWindow::getInstance()->stop();
    widget->refresh();
    baseWindow->set_name ( "" );
    GraphicDisplayFunctionality::refresh();
}

bool AuthenticatorFunctionality::ShowWindowTitle()
{
    return true;
}
