/**
 * @file AuthenticatorFunctionality.hxx
 * @brief Header authenticator functionality class
 * @date 04/10/2012
 * @author Yadickson Soto
 */

#ifndef _AUTHENTICATOR_FUNCTIONALITY_HXX
#define _AUTHENTICATOR_FUNCTIONALITY_HXX

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/AuthenticationWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	AuthenticatorFunctionality
                 * @brief	authenticator functionality class.
                 * @author	Yadickson Soto
                 * @date	04/10/2012
                 */
                class AuthenticatorFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual AuthenticatorFunctionality::~AuthenticatorFunctionality();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         */
                        virtual ~AuthenticatorFunctionality();
                        /**
                         * @fn	static AuthenticatorFunctionality * AuthenticatorFunctionality::getInstance();
                         * @brief	Singleton instance getter method.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         * @return	instance of class.
                         */
                        static AuthenticatorFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * AuthenticatorFunctionality::getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring AuthenticatorFunctionality::getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring AuthenticatorFunctionality::getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void AuthenticatorFunctionality::refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         */
                        virtual void refresh();

                    private:

                        static AuthenticatorFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::AuthenticationWidget * widget; ///< The widget

                        /**
                         * @fn	AuthenticatorFunctionality::AuthenticatorFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         */
                        AuthenticatorFunctionality();
                        /**
                         * @fn	void AuthenticatorFunctionality::Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void AuthenticatorFunctionality::Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * AuthenticatorFunctionality::GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	std::string AuthenticatorFunctionality::GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         * @return	the window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType AuthenticatorFunctionality::GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	void AuthenticatorFunctionality::end();
                         * @brief	method end diagnostic.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         */
                        void end();
                        /**
                         * @fn	void AuthenticatorFunctionality::runMenu();
                         * @brief	method run menu.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         */
                        void runMenu();
                        /**
                         * @fn	void AuthenticatorFunctionality::runProcess();
                         * @brief	method run machine process (wizard or voting)
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         */
                        void runProcess();
                        /**
                         * @fn	virtual void AuthenticatorFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual bool AuthenticatorFunctionality::ShowWindowTitle();
                         * @brief	Gets whether window title is visible.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();

                };
            }
        }
    }
}

#endif // _AUTHENTICATOR_FUNCTIONALITY_HXX
