/**
 * @file AutoPrinterDiagnosisFunctionality.cxx
 * @brief Body auto printer diagnosis functionality class
 * @date 20/06/2013
 * @author Yadickson Soto
 */

#include "AutoPrinterDiagnosisFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;

ISMTTLog * AutoPrinterDiagnosisFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.AutoPrinterDiagnosisFunctionality", GETTEXT_PACKAGE );

AutoPrinterDiagnosisFunctionality * AutoPrinterDiagnosisFunctionality::current_instance = NULL;
AutoPrinterDiagnosisFunctionality * AutoPrinterDiagnosisFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new AutoPrinterDiagnosisFunctionality();
    }

    return current_instance;
}

AutoPrinterDiagnosisFunctionality::AutoPrinterDiagnosisFunctionality()
{
    widget = NULL;
}

void AutoPrinterDiagnosisFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void AutoPrinterDiagnosisFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.AutoPrinterDiagnosisFunctionality.ExitFunctionality" ) );
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &AutoPrinterDiagnosisFunctionality::end ) );
    widget->initialize();
    disableExitButton();
}

Gtk::Widget * AutoPrinterDiagnosisFunctionality::GetFrame()
{
    widget = AbstractFactoryWidget::createAutoPrinterDiagnosisWidget();
    return widget;
}

std::string AutoPrinterDiagnosisFunctionality::GetWindowTitle()
{
    return widget->getTitleText();
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType AutoPrinterDiagnosisFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMAUTOPRINTERDIAGNOSISFUNCTIONALITY;
}

void AutoPrinterDiagnosisFunctionality::Dispose()
{
}

void AutoPrinterDiagnosisFunctionality::end()
{
    ExitFunctionality();
}

AutoPrinterDiagnosisFunctionality::~AutoPrinterDiagnosisFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * AutoPrinterDiagnosisFunctionality::getLogger()
{
    return logger;
}

Glib::ustring AutoPrinterDiagnosisFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AutoPrinterDiagnosisFunctionality.LogStartFunctionality" );
}

Glib::ustring AutoPrinterDiagnosisFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.AutoPrinterDiagnosisFunctionality.LogCloseFunctionality" );
}

bool AutoPrinterDiagnosisFunctionality::ForceExecute()
{
    return true;
}
