/**
 * @file CheckEmlFilesFunctionality.cxx
 * @brief Body class check Eml files functionality
 * @date 05/09/2012
 * @author Yadickson Soto
 */

#include "CheckEmlFilesFunctionality.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::Operation;

ISMTTLog * CheckEmlFilesFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.CheckEmlFilesFunctionality", GETTEXT_PACKAGE );

CheckEmlFilesFunctionality * CheckEmlFilesFunctionality::instance = NULL;

CheckEmlFilesFunctionality::CheckEmlFilesFunctionality()
{
    widget = NULL;
    isInterrupted = false;
}

CheckEmlFilesFunctionality::~CheckEmlFilesFunctionality()
{
    deleteElements();
}

CheckEmlFilesFunctionality * CheckEmlFilesFunctionality::getInstance()
{
    if ( !instance )
    {
        instance = new CheckEmlFilesFunctionality();
    }

    return instance;
}

std::string CheckEmlFilesFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CheckEmlFilesFunctionality.Title" );
}

Smartmatic::Log::ISMTTLog * CheckEmlFilesFunctionality::getLogger()
{
    return logger;
}

Glib::ustring CheckEmlFilesFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CheckEmlFilesFunctionality.LogStartFunctionality" );
}

Glib::ustring CheckEmlFilesFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CheckEmlFilesFunctionality.LogCloseFunctionality" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType CheckEmlFilesFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMCHECKEMLFILESFUNCTIONALITY;
}

Gtk::Widget * CheckEmlFilesFunctionality::GetFrame()
{
    widget = AbstractFactoryWidget::createValidateEmlSignatureWidget();
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &CheckEmlFilesFunctionality::ExitFunctionality ) );
    widget->getSignalError().connect ( sigc::mem_fun (this, &CheckEmlFilesFunctionality::onError ) );
    return widget;
}

void CheckEmlFilesFunctionality::Dispose()
{

}

void CheckEmlFilesFunctionality::Initialize()
{
    if ( MachineOperationManager::getInstance()->isCloseElection() )
    {
        logger->Debug ( "Could not perform functionality in a closed election." );
        ExitFunctionality();
        return;
    }

    disableExitButton();
    widget->initialize ();
}

void CheckEmlFilesFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void CheckEmlFilesFunctionality::block()
{
    logger->Debug ( "Block functionality" );
    isInterrupted = true;
}

void CheckEmlFilesFunctionality::partial()
{
    logger->Debug ( "Partial functionality" );
}

void CheckEmlFilesFunctionality::resume()
{
    logger->Debug ( "Resume functionality" );
    isInterrupted = false;
}

void CheckEmlFilesFunctionality::onError()
{
    Glib::signal_timeout().connect ( sigc::mem_fun ( this, &CheckEmlFilesFunctionality::checkResume ), 500 );
}

bool CheckEmlFilesFunctionality::checkResume()
{
    bool keepChecking = true;

    if (!isInterrupted)
    {
        keepChecking = false;
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( this, &CheckEmlFilesFunctionality::Initialize ), 100 );
    }

    return keepChecking;
}
