/**
 * @file CheckEmlFilesFunctionality.hxx
 * @brief Header class check Eml files functionality
 * @date 15/06/2013
 * @author Yadickson Soto
 */

#ifndef CHECK_EML_FILES_FUNCTIONALITY_HXX_
#define CHECK_EML_FILES_FUNCTIONALITY_HXX_

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/ValidateEmlSignatureWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	CheckEmlFilesFunctionality
                 * @brief	Class check Eml files functionality.
                 * @author	Yadickson Soto
                 * @date	15/06/2013
                 */
                class CheckEmlFilesFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        CheckEmlFilesFunctionality();

                        /**
                         * @brief  Occurs when the functionality fails.
                         * @author manuel.arguelles
                         * @date   15/08/2022
                         */
                        void onError();

                        /**
                         * @brief  Checks if the functionality should be resumed.
                         * @author manuel.arguelles
                         * @date   15/08/2022
                         * @return True to continue checking; otherwise, false.
                         */
                        bool checkResume();

                        static CheckEmlFilesFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::ValidateEmlSignatureWidget * widget; ///< validate eml signature
                        bool isInterrupted;

                    protected:

                        /**
                         * @brief	Gets the window title.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();

                        /**
                         * @brief	Gets the menu option type.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();

                        /**
                         * @brief	Gets the frame.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();

                        /**
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        void Dispose();

                        /**
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        void Initialize();

                        /**
                         * @brief	Gets the logger.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();

                        /**
                         * @brief	Gets the start log message.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();

                        /**
                         * @brief	Gets the finish log message.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();

                        /**
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void deleteElements();

                        /**
                         * @brief	method block functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void block();

                        /**
                         * @brief	method partial functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void partial();

                        /**
                         * @brief	method resume functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void resume();

                    public:
                        /**
                         * @brief	Method getter instance.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	instance of class.
                         */
                        static CheckEmlFilesFunctionality * getInstance();

                        /**
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual ~CheckEmlFilesFunctionality();
                };
            }
        }
    }
}
#endif /* CHECK_EML_FILES_FUNCTIONALITY_HXX_ */
