/**
 * @file CloseElectionStatusFunctionality.cxx
 * @brief Body class close election status functionality
 * @date 05/09/2012
 * @author Yadickson Soto
 */

#include "CloseElectionStatusFunctionality.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::Operation;

ISMTTLog * CloseElectionStatusFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.CloseElectionStatusFunctionality", GETTEXT_PACKAGE );

CloseElectionStatusFunctionality * CloseElectionStatusFunctionality::instance = NULL;

CloseElectionStatusFunctionality::CloseElectionStatusFunctionality()
{
    widget = NULL;
    isInterrupted = false;
}

CloseElectionStatusFunctionality::~CloseElectionStatusFunctionality()
{
    deleteElements();
}

CloseElectionStatusFunctionality * CloseElectionStatusFunctionality::getInstance()
{
    if ( !instance )
    {
        instance = new CloseElectionStatusFunctionality();
    }

    return instance;
}

std::string CloseElectionStatusFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CloseElectionStatusFunctionality.Title" );
}

Smartmatic::Log::ISMTTLog * CloseElectionStatusFunctionality::getLogger()
{
    return logger;
}

Glib::ustring CloseElectionStatusFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CloseElectionStatusFunctionality.LogStartFunctionality" );
}

Glib::ustring CloseElectionStatusFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CloseElectionStatusFunctionality.LogCloseFunctionality" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType CloseElectionStatusFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMCLOSEELECTIONSTATUSFUNCTIONALITY;
}

Gtk::Widget * CloseElectionStatusFunctionality::GetFrame()
{
    widget = AbstractFactoryWidget::createCloseElectionStatusWidget();
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &CloseElectionStatusFunctionality::verifyExitFunctionality ) );
    widget->getSignalError().connect ( sigc::mem_fun ( this, &CloseElectionStatusFunctionality::onError ) );
    return widget;
}

void CloseElectionStatusFunctionality::Dispose()
{

}

void CloseElectionStatusFunctionality::Initialize()
{
    if ( MachineOperationManager::getInstance()->isCloseElection() )
    {
        logger->Debug ( "Could not perform functionality in a closed election." );
        ExitFunctionality();
        return;
    }

    disableExitButton();
    widget->initialize ();
}

void CloseElectionStatusFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void CloseElectionStatusFunctionality::block()
{
    logger->Debug ( "Block functionality" );
    isInterrupted = true;
}

void CloseElectionStatusFunctionality::partial()
{
    logger->Debug ( "Partial functionality" );
}

void CloseElectionStatusFunctionality::resume()
{
    logger->Debug ( "Resume functionality" );
    isInterrupted = false;
}

void CloseElectionStatusFunctionality::onError()
{
    Glib::signal_timeout().connect ( sigc::mem_fun ( this, &CloseElectionStatusFunctionality::checkResume ), 500 );
}

void CloseElectionStatusFunctionality::verifyExitFunctionality()
{
    if (isInterrupted)
        Glib::signal_timeout().connect ( sigc::mem_fun ( this, &CloseElectionStatusFunctionality::checkResume ), 500 );
    else
        ExitFunctionality();
}

bool CloseElectionStatusFunctionality::checkResume()
{
    bool keepChecking = true;

    if (!isInterrupted)
    {
        keepChecking = false;
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( this, &CloseElectionStatusFunctionality::Initialize ), 100 );
    }

    return keepChecking;
}
