/**
 * @file CloseElectionStatusFunctionality.hxx
 * @brief Header class close election status functionality
 * @date 15/06/2013
 * @author Yadickson Soto
 */

#ifndef CLOSE_ELECTION_STATUS_FUNCTIONALITY_HXX_
#define CLOSE_ELECTION_STATUS_FUNCTIONALITY_HXX_

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/close-election-status-widget.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	CloseElectionStatusFunctionality
                 * @brief	Class close election status functionality.
                 * @author	Yadickson Soto
                 * @date	15/06/2013
                 */
                class CloseElectionStatusFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @fn	CloseElectionStatusFunctionality::CloseElectionStatusFunctionality();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        CloseElectionStatusFunctionality();

                        /**
                         * @brief  Occurs when the functionality fails.
                         * @author manuel.arguelles
                         * @date   15/08/2022
                         */
                        void onError();

                        /**
                         * @brief  Verifies that the functionality can be exited.
                         * @author manuel.arguelles
                         * @date   24/08/2022
                         */
                        void verifyExitFunctionality();

                        /**
                         * @brief  Checks if the functionality should be resumed.
                         * @author manuel.arguelles
                         * @date   15/08/2022
                         * @return True to continue checking; otherwise, false.
                         */
                        bool checkResume();

                        static CloseElectionStatusFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::CloseElectionStatusWidget * widget; ///< close election status
                        bool isInterrupted;

                    protected:

                        /**
                         * @fn	std::string CloseElectionStatusFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType CloseElectionStatusFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	Gtk::Widget * CloseElectionStatusFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	void CloseElectionStatusFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        void Dispose();
                        /**
                         * @fn	void CloseElectionStatusFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        void Initialize();
                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * CloseElectionStatusFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring CloseElectionStatusFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring CloseElectionStatusFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void CloseElectionStatusFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual void CloseElectionStatusFunctionality::block();
                         * @brief	method block functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void block();
                        /**
                         * @fn	virtual void CloseElectionStatusFunctionality::partial();
                         * @brief	method partial functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void partial();
                        /**
                         * @fn	virtual void CloseElectionStatusFunctionality::resume();
                         * @brief	method resume functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void resume();

                    public:
                        /**
                         * @fn	static CloseElectionStatusFunctionality * CloseElectionStatusFunctionality::getInstance();
                         * @brief	Method getter instance.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	instance of class.
                         */
                        static CloseElectionStatusFunctionality * getInstance();
                        /**
                         * @fn	virtual CloseElectionStatusFunctionality::~CloseElectionStatusFunctionality();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual ~CloseElectionStatusFunctionality();
                };
            }
        }
    }
}
#endif /* CLOSE_ELECTION_STATUS_FUNCTIONALITY_HXX_ */
