/**
 * @file ClosingElectionStatusFunctionality.cxx
 * @brief Body class closing election status functionality
 * @author eduardo.fernandez
 * @date 11/12/2018
 */

#include "ClosingElectionStatusFunctionality.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::Operation;

ISMTTLog * ClosingElectionStatusFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.ClosingElectionStatusFunctionality", GETTEXT_PACKAGE );

ClosingElectionStatusFunctionality * ClosingElectionStatusFunctionality::instance = NULL;

ClosingElectionStatusFunctionality::ClosingElectionStatusFunctionality()
{
    widget = NULL;
}

ClosingElectionStatusFunctionality::~ClosingElectionStatusFunctionality()
{
    deleteElements();
}

ClosingElectionStatusFunctionality * ClosingElectionStatusFunctionality::getInstance()
{
    if ( !instance )
    {
        instance = new ClosingElectionStatusFunctionality();
    }

    return instance;
}

std::string ClosingElectionStatusFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.ClosingElectionStatusFunctionality.WindowTitle" );
}

Smartmatic::Log::ISMTTLog * ClosingElectionStatusFunctionality::getLogger()
{
    return logger;
}

Glib::ustring ClosingElectionStatusFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.ClosingElectionStatusFunctionality.LogStartFunctionality" );
}

Glib::ustring ClosingElectionStatusFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.ClosingElectionStatusFunctionality.LogCloseFunctionality" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType ClosingElectionStatusFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMCLOSINGELECTIONSTATUSFUNCTIONALITY;
}

Gtk::Widget * ClosingElectionStatusFunctionality::GetFrame()
{
    widget = AbstractFactoryWidget::createClosingElectionStatusWidget();
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &ClosingElectionStatusFunctionality::ExitFunctionality ) );
    widget->getSignalError().connect ( sigc::mem_fun ( this, &ClosingElectionStatusFunctionality::Initialize ) );
    return widget;
}

void ClosingElectionStatusFunctionality::Dispose()
{

}

void ClosingElectionStatusFunctionality::Initialize()
{
    if ( MachineOperationManager::getInstance()->isCloseElection() )
    {
        logger->Debug ( "Could not perform functionality in a closed election." );
        ExitFunctionality();
        return;
    }

    disableExitButton();
    widget->initialize ();
}

void ClosingElectionStatusFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void ClosingElectionStatusFunctionality::block()
{
    logger->Debug ( "Block functionality" );
}

void ClosingElectionStatusFunctionality::partial()
{
    logger->Debug ( "Partial functionality" );
}

void ClosingElectionStatusFunctionality::resume()
{
    logger->Debug ( "Resume functionality" );
}
