/**
 * @file CustomRemarkDiagnoseFunctionality.cxx
 * @brief Body class check vote files functionality
 * @date 05/09/2012
 * @author Yadickson Soto
 */

#include "CustomRemarkDiagnoseFunctionality.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Gui/Widgets/FactoryMethodWidget.hxx>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::Operation;

ISMTTLog * CustomRemarkDiagnoseFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.CustomRemarkDiagnoseFunctionality", GETTEXT_PACKAGE );

CustomRemarkDiagnoseFunctionality * CustomRemarkDiagnoseFunctionality::instance = NULL;

CustomRemarkDiagnoseFunctionality::CustomRemarkDiagnoseFunctionality()
{
    widget = NULL;
}

CustomRemarkDiagnoseFunctionality::~CustomRemarkDiagnoseFunctionality()
{
    deleteElements();
}

CustomRemarkDiagnoseFunctionality * CustomRemarkDiagnoseFunctionality::getInstance()
{
    if ( !instance )
    {
        instance = new CustomRemarkDiagnoseFunctionality();
    }

    return instance;
}

std::string CustomRemarkDiagnoseFunctionality::GetWindowTitle()
{
    return N_ ( "Custom Remark Diagnose Title" );
}

Smartmatic::Log::ISMTTLog * CustomRemarkDiagnoseFunctionality::getLogger()
{
    return logger;
}

Glib::ustring CustomRemarkDiagnoseFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CustomRemarkDiagnoseFunctionality.LogStartFunctionality" );
}

Glib::ustring CustomRemarkDiagnoseFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CustomRemarkDiagnoseFunctionality.LogCloseFunctionality" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType CustomRemarkDiagnoseFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMCUSTOMREMARKDIAGNOSEFUNCTIONALITY;
}

Gtk::Widget * CustomRemarkDiagnoseFunctionality::GetFrame()
{
    widget = FactoryMethodWidget::createCustomRemarkDiagnoseWidget();
    return widget;
}

void CustomRemarkDiagnoseFunctionality::Dispose()
{

}

void CustomRemarkDiagnoseFunctionality::Initialize()
{
    disableExitButton();
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &CustomRemarkDiagnoseFunctionality::ExitFunctionality ) );
    widget->initialize ();
}

void CustomRemarkDiagnoseFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void CustomRemarkDiagnoseFunctionality::block()
{
    logger->Debug ( "Block functionality" );
}

void CustomRemarkDiagnoseFunctionality::partial()
{
    logger->Debug ( "Partial functionality" );
}

void CustomRemarkDiagnoseFunctionality::resume()
{
    logger->Debug ( "Resume functionality" );
}
