/**
 * @file CustomRemarkDiagnoseFunctionality.hxx
 * @brief Header custom remark diagnose functionality
 * @date 12/09/2013
 * @author Yadickson Soto
 */

#ifndef CUSTON_REMARK_DIAGNOSE_FUNCTIONALITY_HXX_
#define CUSTON_REMARK_DIAGNOSE_FUNCTIONALITY_HXX_

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/Diagnose/CustomRemarkDiagnoseWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	CustomRemarkDiagnoseFunctionality
                 * @brief	Class custom remark diagnose functionality
                 * @author	Yadickson Soto
                 * @date	12/09/2013
                 */
                class CustomRemarkDiagnoseFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @fn	CustomRemarkDiagnoseFunctionality::CustomRemarkDiagnoseFunctionality();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        CustomRemarkDiagnoseFunctionality();

                        static CustomRemarkDiagnoseFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::CustomRemarkDiagnoseWidget * widget; ///< custom remark diagnose

                    protected:

                        /**
                         * @fn	std::string CustomRemarkDiagnoseFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType CustomRemarkDiagnoseFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	Gtk::Widget * CustomRemarkDiagnoseFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	void CustomRemarkDiagnoseFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        void Dispose();
                        /**
                         * @fn	void CustomRemarkDiagnoseFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        void Initialize();
                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * CustomRemarkDiagnoseFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring CustomRemarkDiagnoseFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring CustomRemarkDiagnoseFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void CustomRemarkDiagnoseFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual void CustomRemarkDiagnoseFunctionality::block();
                         * @brief	method block functionality.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        virtual void block();
                        /**
                         * @fn	virtual void CustomRemarkDiagnoseFunctionality::partial();
                         * @brief	method partial functionality.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        virtual void partial();
                        /**
                         * @fn	virtual void CustomRemarkDiagnoseFunctionality::resume();
                         * @brief	method resume functionality.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        virtual void resume();

                    public:
                        /**
                         * @fn	static CustomRemarkDiagnoseFunctionality * CustomRemarkDiagnoseFunctionality::getInstance();
                         * @brief	Method getter instance.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	instance of class.
                         */
                        static CustomRemarkDiagnoseFunctionality * getInstance();
                        /**
                         * @fn	virtual CustomRemarkDiagnoseFunctionality::~CustomRemarkDiagnoseFunctionality();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        virtual ~CustomRemarkDiagnoseFunctionality();
                };
            }
        }
    }
}
#endif /* CUSTON_REMARK_DIAGNOSE_FUNCTIONALITY_HXX_ */
