/**
 * @file CustomizableCheckListDiagnoseFunctionality.cxx
 * @brief Body customizable check list functionality class
 * @date 17/09/2013
 * @author Yadickson Soto
 */

#include "CustomizableCheckListDiagnoseFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <System/IO/File.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;

ISMTTLog * CustomizableCheckListDiagnoseFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.CustomizableCheckListDiagnoseFunctionality", GETTEXT_PACKAGE );

CustomizableCheckListDiagnoseFunctionality * CustomizableCheckListDiagnoseFunctionality::current_instance = NULL;
CustomizableCheckListDiagnoseFunctionality * CustomizableCheckListDiagnoseFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new CustomizableCheckListDiagnoseFunctionality();
    }

    return current_instance;
}

CustomizableCheckListDiagnoseFunctionality::CustomizableCheckListDiagnoseFunctionality()
{
    widget = NULL;
}

void CustomizableCheckListDiagnoseFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void CustomizableCheckListDiagnoseFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.CustomizableCheckListDiagnoseFunctionality.ExitFunctionality" ) );
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &CustomizableCheckListDiagnoseFunctionality::ExitFunctionality ) );
    widget->initialize();

    enableExitButton();
}

Gtk::Widget * CustomizableCheckListDiagnoseFunctionality::GetFrame()
{
    widget = new CheckListDiagnoseWidget ();
    return widget;
}

std::string CustomizableCheckListDiagnoseFunctionality::GetWindowTitle()
{
    return N_ ( "Customizable Check List Diagnose Title" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType CustomizableCheckListDiagnoseFunctionality::GetMenuOptionType()
{
    return Smartmatic::SAES::Functionality::Configuration::MenuOptionType::CONFIGURATION_XMLMCUSTOMIZABLECHECKLISTDIAGNOSEFUNCTIONALITY;
}

void CustomizableCheckListDiagnoseFunctionality::Dispose()
{
}

CustomizableCheckListDiagnoseFunctionality::~CustomizableCheckListDiagnoseFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * CustomizableCheckListDiagnoseFunctionality::getLogger()
{
    return logger;
}

Glib::ustring CustomizableCheckListDiagnoseFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CustomizableCheckListDiagnoseFunctionality.LogStartFunctionality" );
}

Glib::ustring CustomizableCheckListDiagnoseFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.CustomizableCheckListDiagnoseFunctionality.LogCloseFunctionality" );
}
