/**
 * @file DateDiagnosticFunctionality.cxx
 * @brief Body pm setup functionality class
 * @date 19/09/2012
 * @author Daniel Ampuero
 */

#include "DateDiagnosticFunctionality.hxx"
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <System/IO/File.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Environment/Configurations/base-language-controller.h>
#include <Gui/Widgets/Diagnose/DateDiagnosticWidget.hxx>
#include <System/Runtime/ProcessLauncher.h>
#include <Operation/MachineDate.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Runtime;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::Configuration;

ISMTTLog * DateDiagnosticFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.DateDiagnosticFunctionality", GETTEXT_PACKAGE );

DateDiagnosticFunctionality * DateDiagnosticFunctionality::current_instance = NULL;
DateDiagnosticFunctionality * DateDiagnosticFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new DateDiagnosticFunctionality();
    }

    return current_instance;
}

DateDiagnosticFunctionality::DateDiagnosticFunctionality()
{
    widget = NULL;
}

void DateDiagnosticFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void DateDiagnosticFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.DateDiagnosticFunctionality.ExitFunctionality" ) );
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &DateDiagnosticFunctionality::ProcessDate ) );
    enableExitButton();
}

Gtk::Widget * DateDiagnosticFunctionality::GetFrame()
{
    widget = new Smartmatic::SAES::GUI::Widgets::DateDiagnosticWidget ( Smartmatic::SAES::GUI::Configuration::SAESGUIConfigurationManager::getInstance()->getDateDiagnosticWidgetConfiguration() );
    return widget;
}

std::string DateDiagnosticFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.DateDiagnosticFunctionality.Title" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType DateDiagnosticFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMDATEDIAGNOSTICFUNCTIONALITY;
}

void DateDiagnosticFunctionality::Dispose()
{
}

DateDiagnosticFunctionality::~DateDiagnosticFunctionality()
{
    deleteElements();
}

Smartmatic::Log::ISMTTLog * DateDiagnosticFunctionality::getLogger()
{
    return logger;
}

Glib::ustring DateDiagnosticFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.DateDiagnosticFunctionality.LogStartFunctionality" );
}

Glib::ustring DateDiagnosticFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.DateDiagnosticFunctionality.LogCloseFunctionality" );
}

bool DateDiagnosticFunctionality::ShowWindowTitle()
{
    return BaseLanguageController::isSetLanguage();
}

void DateDiagnosticFunctionality::ProcessDate()
{
    std::string day;
    widget->getDayText ( day );
    std::string month;
    widget->getMonthText ( month );
    std::string year;
    widget->getYearText ( year );
    std::string date = day + "/" + month + "/" + year;
    logger->Debug ( "Saving date: " + date );
    Smartmatic::SAES::Operation::MachineDate::setMachineDate ( date );
    ExitFunctionality();
    logger->Debug ( "Date successfully saved" );
}
