/**
 * @file   DeviceDiagnosticResultListOnlyFunctionality.hxx
 * @brief  Declaration of DeviceDiagnosticDisplayFunctionality class.
 * @author manuel.arguelles
 * @date   Sep  4, 2017
 */

#ifndef DEVICE_DIAGNOSTIC_RESULT_LIST_ONLY_FUNCTIONALITY_HXX
#define DEVICE_DIAGNOSTIC_RESULT_LIST_ONLY_FUNCTIONALITY_HXX

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/Diagnose/DiagnosticResultWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class  DeviceDiagnosticResultListOnlyFunctionality
                 * @brief  Displays a list with the result of the diagnostics without user interaction.
                 * @author manuel.arguelles
                 * @date   Sep  5, 2017
                 */
                class DeviceDiagnosticResultListOnlyFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @brief  Gets and instance of the class.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         * @return The object of the class.
                         */
                        static DeviceDiagnosticResultListOnlyFunctionality* getInstance();

                    public:

                        /**
                         * @brief  Destructs and instance of the class.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         */
                        virtual ~DeviceDiagnosticResultListOnlyFunctionality();

                    protected:

                        /**
                         * @brief  Returns the logger.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         * @return The logger object.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();

                        /**
                         * @brief  Gets the log message for starting the functionality.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         * @return The message indicating the start of the functionality.
                         */
                        Glib::ustring getStartLogMessage();

                        /**
                         * @brief  Gets the log message for ending the functionality.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         * @return The message indicating the end of the functionality.
                         */
                        Glib::ustring getFinishLogMessage();

                    private:

                        /**
                         * @brief  Initializes an instance of the class.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         */
                        DeviceDiagnosticResultListOnlyFunctionality();

                        /**
                         * @brief  Dispose the elements of the class.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         */
                        void Dispose();

                        /**
                         * @brief  Initialize the object.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         */
                        void Initialize();

                        /**
                         * @brief  Gets the main frame to display.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         * @return The widget to show.
                         */
                        Gtk::Widget* GetFrame();

                        /**
                         * @brief  Gets the title of the window.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         * @return The title of the window.
                         */
                        std::string GetWindowTitle();

                        /**
                         * @brief  Gets the type of the functionality.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         * @return The MenuOptionType of this functionality.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();

                        /**
                         * @brief  Gets if the title should be displayed or not.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         * @return True if the title must be shown, false if not.
                         */
                        virtual bool ShowWindowTitle();

                        /**
                         * @brief  Deletes the elements of the object.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         */
                        virtual void deleteElements();

                        /**
                         * @brief  Shows the result of the diagnostics.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         */
                        void endShowResult();

                        /**
                         * @brief  Gets if the executing should run regarding of the status.
                         * @author manuel.arguelles
                         * @date   Sep  5, 2017
                         * @return True if it should run, false if not.
                         */
                        virtual bool ForceExecute();

                    private:

                        Smartmatic::SAES::GUI::Widgets::DiagnosticResultWidget* m_widget;
                        static DeviceDiagnosticResultListOnlyFunctionality*     m_currentInstance;
                        static Smartmatic::Log::ISMTTLog*                       m_logger;
                };

            } /* namespace Functionality */
        } /* namespace GUI */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* DEVICE_DIAGNOSTIC_RESULT_LIST_ONLY_FUNCTIONALITY_HXX */
