/**
 * @file DeviceDiagnosticSaveFunctionality.hxx
 * @brief Header device diagnostic save functionality class
 * @date 19/09/2012
 * @author Yadickson Soto
 */

#ifndef _DEVICE_DIAGNOSTIC_SAVE_FUNCTIONALITY_H_
#define _DEVICE_DIAGNOSTIC_SAVE_FUNCTIONALITY_H_

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/ProgressWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	DeviceDiagnosticSaveFunctionality
                 * @brief	device diagnostic save functionality class.
                 * @author	Yadickson Soto
                 * @date	19/09/2012
                 */
                class DeviceDiagnosticSaveFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual DeviceDiagnosticSaveFunctionality::~DeviceDiagnosticSaveFunctionality();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        virtual ~DeviceDiagnosticSaveFunctionality();
                        /**
                         * @fn	static DeviceDiagnosticSaveFunctionality * DeviceDiagnosticSaveFunctionality::getInstance();
                         * @brief	Singleton instance getter method.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	instance of class.
                         */
                        static DeviceDiagnosticSaveFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * DeviceDiagnosticSaveFunctionality::getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring DeviceDiagnosticSaveFunctionality::getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring DeviceDiagnosticSaveFunctionality::getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();

                    private:

                        static DeviceDiagnosticSaveFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * widget; ///< The widget
                        Glib::Thread* m_exportThread; ///< Export thread

                        /**
                         * @fn	DeviceDiagnosticSaveFunctionality::DeviceDiagnosticSaveFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        DeviceDiagnosticSaveFunctionality();
                        /**
                         * @fn	void DeviceDiagnosticSaveFunctionality::Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void DeviceDiagnosticSaveFunctionality::Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * DeviceDiagnosticSaveFunctionality::GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	std::string DeviceDiagnosticSaveFunctionality::GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	the window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType DeviceDiagnosticSaveFunctionality::GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	virtual bool DeviceDiagnosticSaveFunctionality::ShowWindowTitle();
                         * @brief	Gets whether window title is visible.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();
                        /**
                         * @fn	virtual void DeviceDiagnosticSaveFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();

                        /**
                         * @brief  Thread where the results are exported.
                         * @author manuel.arguelles
                         * @date   Dec  4, 2017
                         */
                        void exportResults();
                };
            }
        }
    }
}

#endif // _DEVICE_DIAGNOSTIC_SAVE_FUNCTIONALITY_H_
