/*
 * EurnDiagnosisFunctionality.hxx
 *
 *  Created on: Nov 8, 2017
 *      Author: juanvalera
 */

#ifndef EURNDIAGNOSISFUNCTIONALITY_HXX_
#define EURNDIAGNOSISFUNCTIONALITY_HXX_

#include <gtkmm.h>
#include <string>
#include <Gui/Widgets/Menu/menu-option.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Widgets/smartmatic-button.h>
#include <Gui/Widgets/Diagnose/EurnDiagnoseWidget.hxx>
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	EurnDiagnosisFunctionality
                 * @brief	Alarm box diagnosis functionality.
                 * @author	Juan Valera
                 * @date	08/11/2017
                 */
                class EurnDiagnosisFunctionality: public GraphicDisplayFunctionality
                {

                    public:

                        /**
                         * @fn	bool EurnDiagnosisFunctionality::DontAllowHelp();
                         * @brief	Gets the dont allow help.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool DontAllowHelp();

                        /**
                         * @fn	std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> EurnDiagnosisFunctionality::getHelpSeqKey();
                         * @brief	Gets the help sequence key.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	The help sequence key.
                         */

                        std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> getHelpSeqKey();

                        /**
                         * @fn	bool EurnDiagnosisFunctionality::DontAllowExit();
                         * @brief	Gets the dont allow exit.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool DontAllowExit();

                        /**
                         * @fn	std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> EurnDiagnosisFunctionality::getSeqKey();
                         * @brief	Gets the sequence key.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	The sequence key.
                         */

                        std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> getSeqKey();

                        /**
                         * @fn	static EurnDiagnosisFunctionality * EurnDiagnosisFunctionality::getInstance();
                         * @brief	Gets the current.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	null if it fails, else.
                         */

                        static EurnDiagnosisFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * EurnDiagnosisFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	null if it fails, else the logger.
                         */

                        Smartmatic::Log::ISMTTLog * getLogger();

                        /**
                         * @fn	Glib::ustring EurnDiagnosisFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	The start log message.
                         */

                        Glib::ustring getStartLogMessage();

                        /**
                         * @fn	Glib::ustring EurnDiagnosisFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	The finish log message.
                         */

                        Glib::ustring getFinishLogMessage();

                    private:

                        Smartmatic::SAES::GUI::Widgets::EurnDiagnoseWidget * eurnWidget;  ///< The eUrn widget
                        sigc::connection connFinishDiagnosis;	///< The connection finish diagnosis
                        static EurnDiagnosisFunctionality * current_instance;	///< The current instance

                        /**
                         * @fn	EurnDiagnosisFunctionality::EurnDiagnosisFunctionality();
                         * @brief	Default constructor.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         */

                        EurnDiagnosisFunctionality();

                        /**
                         * @fn	virtual EurnDiagnosisFunctionality::~EurnDiagnosisFunctionality();
                         * @brief	Finaliser.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         */

                        virtual ~EurnDiagnosisFunctionality();

                        /**
                         * @fn	virtual void EurnDiagnosisFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         */
                        virtual void deleteElements();

                        /**
                         * @fn	void EurnDiagnosisFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         */

                        void Dispose();

                        /**
                         * @fn	void EurnDiagnosisFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         */

                        void Initialize();

                        /**
                         * @fn	Gtk::Widget * EurnDiagnosisFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	null if it fails, else the frame.
                         */

                        Gtk::Widget * GetFrame();

                        /**
                         * @fn	std::string EurnDiagnosisFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	The window title.
                         */

                        std::string GetWindowTitle();

                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType EurnDiagnosisFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	The menu option type.
                         */

                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	void EurnDiagnosisFunctionality::endDiagnosis();
                         * @brief	method end diagnosis.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         */
                        void endDiagnosis();

                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                };
            }
        }
    }
}
#endif /* EURNDIAGNOSISFUNCTIONALITY_HXX_ */
