/**
 * @file   ExternalPrintfunctionality.cxx
 * @brief  Implementation of ExternalPrintFunctionality class.
 * @author manuel.arguelles
 * @date   Jun  6, 2017
 */

#include "ExternalPrintFunctionality.hxx"
#include <Configuration/menu-option-type-schema.hxx>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Gui/Widgets/ExternalPrintWizardWidget.hxx>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String)
#else
#define _(String) (String)
#endif

#define N_(String) (String)

using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;

ISMTTLog * ExternalPrintFunctionality::m_logger = SMTTLogManager::GetLogger(
    "Smartmatic.SAES.GUI.Functionality.ExternalPrintFunctionality",
    GETTEXT_PACKAGE);
ExternalPrintFunctionality* ExternalPrintFunctionality::m_currentInstance = NULL;

ExternalPrintFunctionality::ExternalPrintFunctionality()
    : m_widget(NULL)
{
}

ExternalPrintFunctionality::~ExternalPrintFunctionality()
{
}

ExternalPrintFunctionality* ExternalPrintFunctionality::getInstance()
{
    if (!m_currentInstance)
    {
        m_currentInstance = new ExternalPrintFunctionality();
    }

    return m_currentInstance;
}

void ExternalPrintFunctionality::hideOnFinish()
{
    ExitFunctionality();
}

void ExternalPrintFunctionality::Dispose()
{
}

void ExternalPrintFunctionality::Initialize()
{
    enableHelpButton();
    disableExitButton();
    m_widget->Initialize();
}

Gtk::Widget* ExternalPrintFunctionality::GetFrame()
{
    m_widget = AbstractFactoryWidget::createExternalPrintWizardWidget();
    m_widget->getFinishSignal().connect(sigc::mem_fun(
                                            *this,
                                            &ExternalPrintFunctionality::hideOnFinish));

    return this->m_widget;
}

std::string ExternalPrintFunctionality::GetWindowTitle()
{
    return _("Print the Election Report");
}

MenuOptionType ExternalPrintFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMEXTERNALPRINTFUNCTIONALITY;
}

Smartmatic::Log::ISMTTLog* ExternalPrintFunctionality::getLogger()
{
    return m_logger;
}

Glib::ustring ExternalPrintFunctionality::getStartLogMessage()
{
    return N_("Smartmatic.SAES.GUI.Functionality.ExternalPrintFunctionality.LogStartFunctionality");
}

Glib::ustring ExternalPrintFunctionality::getFinishLogMessage()
{
    return N_("Smartmatic.SAES.GUI.Functionality.ExternalPrintFunctionality.LogCloseFunctionality");
}

void ExternalPrintFunctionality::deleteElements()
{
    if (m_widget)
    {
        delete m_widget;
        m_widget = NULL;
    }
}
