/**
 * @file   ExternalPrintFunctionality.hxx
 * @brief  Declaration of ExternalPrintFunctionality class.
 * @author manuel.arguelles
 * @date   Jun  6, 2017
 */

#ifndef _EXTERNAL_PRINT_FUNCTIONALITY_H_
#define _EXTERNAL_PRINT_FUNCTIONALITY_H_

#include <Functionalities/graphic-display-functionality.h>
#include <gtkmm.h>
#include <string>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace Functionality
        {
            namespace Configuration
            {
                class MenuOptionType;
            }
        }
        namespace GUI
        {
            namespace Widgets
            {
                class ExternalPrintWizardWidget;
            }
            namespace Functionality
            {
                /**
                 * @class  ExternalPrintFunctionality
                 * @brief  External print functionality.
                 * @author manuel.arguelles
                 * @date   Jun  6, 2017
                 */
                class ExternalPrintFunctionality : public GraphicDisplayFunctionality
                {
                    public:
                        /**
                         * @brief  Class destructor.
                         * @author manuel.arguelles
                         * @date   Jun  6, 2017
                         */
                        virtual ~ExternalPrintFunctionality();

                        /**
                         * @brief  Get instance of class.
                         * @author manuel.arguelles
                         * @date   Jun  6, 2017
                         * @return The instance of the class.
                         */
                        static ExternalPrintFunctionality* getInstance();

                        /**
                         * @brief  Get the logger.
                         * @author manuel.arguelles
                         * @date   Jun  6, 2017
                         * @return The logger.
                         */
                        virtual Smartmatic::Log::ISMTTLog* getLogger();

                        /**
                         * @brief  Get the start log message.
                         * @author manuel.arguelles
                         * @date   Jun  6, 2017
                         * @return The string with the message to log.
                         */
                        virtual Glib::ustring getStartLogMessage();

                        /**
                         * @brief  Get the finish log message.
                         * @author manuel.arguelles
                         * @date   Jun  6, 2017
                         * @return The string with the message to log.
                         */
                        virtual Glib::ustring getFinishLogMessage();

                        /**
                         * @brief  Get the menu option type.
                         * @author manuel.arguelles
                         * @date   Jun  6, 2017
                         * @return The type of the menu option.
                         */
                        virtual SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();

                        /**
                         * @brief  Get the frame.
                         * @author manuel.arguelles
                         * @date   Jun  6, 2017
                         * @return The widget frame.
                         */
                        virtual Gtk::Widget* GetFrame();

                        /**
                         * @brief  Get the window title.
                         * @author manuel.arguelles
                         * @date   Jun  7, 2017
                         * @return A string with the window title.
                         */
                        virtual std::string GetWindowTitle();

                        /**
                         * @brief  Initialize the functionality.
                         * @author manuel.arguelles
                         * @date   Jun  6, 2017
                         */
                        virtual void Initialize();

                        /**
                         * @brief  Dispose the functionality.
                         * @author manuel.arguelles
                         * @date   Jun  6, 2017
                         */
                        virtual void Dispose();

                        /**
                         * @brief  Deletes all the elements.
                         * @author manuel.arguelles
                         * @date   Jun  6, 2017
                         */
                        virtual void deleteElements();

                    protected:
                        /**
                         * @brief  Default constructor.
                         * @author manuel.arguelles
                         * @date   Jun  7, 2017
                         */
                        ExternalPrintFunctionality();

                    private:
                        /**
                         * @brief  Hides the functionality.
                         * @author manuel.arguelles
                         * @date   Jun  6, 2017
                         */
                        void hideOnFinish ();

                    private:
                        Widgets::ExternalPrintWizardWidget* m_widget;
                        static Smartmatic::Log::ISMTTLog*   m_logger;
                        static ExternalPrintFunctionality*  m_currentInstance;

                };
            }
        }
    }
}

#endif /* _EXTERNAL_PRINT_FUNCTIONALITY_H_ */
