/**
 * @file GenerateAllResultFunctionality.cxx
 * @brief Body class generate transmission package, codi and pv functionality
 * @date 05/09/2012
 * @author Yadickson Soto
 */

#include "GenerateAllResultFunctionality.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::Functionality;
using namespace Smartmatic::SAES::Operation;

ISMTTLog * GenerateAllResultFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.GenerateAllResultFunctionality", GETTEXT_PACKAGE );

GenerateAllResultFunctionality * GenerateAllResultFunctionality::instance = NULL;

GenerateAllResultFunctionality::GenerateAllResultFunctionality()
    : widget ( NULL )
    , isInterrupted ( false )
    , wasInterruptedLast ( false )
{
}

GenerateAllResultFunctionality::~GenerateAllResultFunctionality()
{
    deleteElements();
}

GenerateAllResultFunctionality * GenerateAllResultFunctionality::getInstance()
{
    if ( !instance )
    {
        instance = new GenerateAllResultFunctionality();
    }

    return instance;
}

std::string GenerateAllResultFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.GenerateAllResultFunctionality.Title" );
}

Smartmatic::Log::ISMTTLog * GenerateAllResultFunctionality::getLogger()
{
    return logger;
}

Glib::ustring GenerateAllResultFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.GenerateAllResultFunctionality.LogStartFunctionality" );
}

Glib::ustring GenerateAllResultFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.GenerateAllResultFunctionality.LogCloseFunctionality" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType GenerateAllResultFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMGENERATEALLRESULTFUNCTIONALITY;
}

Gtk::Widget * GenerateAllResultFunctionality::GetFrame()
{
    widget = AbstractFactoryWidget::createPersistAllResultWidget();
    widget->getSignalEnd().connect ( sigc::mem_fun ( this, &GenerateAllResultFunctionality::evaluateExit) );
    widget->getSignalError().connect ( sigc::mem_fun (this, &GenerateAllResultFunctionality::onError ) );
    return widget;
}

void GenerateAllResultFunctionality::Dispose()
{

}

void GenerateAllResultFunctionality::Initialize()
{
    if ( MachineOperationManager::getInstance()->isCloseElection() )
    {
        logger->Debug ( "Could not perform functionality in a closed election." );
        ExitFunctionality();
        return;
    }

    logger->Debug("Initializing generate all results functionality.");

    disableExitButton();
    wasInterruptedLast = false;
    widget->initialize();
}

void GenerateAllResultFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void GenerateAllResultFunctionality::block()
{
    logger->Debug ( "Block functionality" );
    isInterrupted = true;
    wasInterruptedLast = true;
}

void GenerateAllResultFunctionality::partial()
{
    logger->Debug ( "Partial functionality" );
}

void GenerateAllResultFunctionality::resume()
{
    logger->Debug ( "Resume functionality" );
    isInterrupted = false;
}

void GenerateAllResultFunctionality::onError()
{
    logger->Debug ( "Functionality ended with error, checking for interruptions" );

    if (wasInterruptedLast)
        Glib::signal_timeout().connect ( sigc::mem_fun ( this, &GenerateAllResultFunctionality::checkResume ), 500 );
    else
        ExitFunctionality();
}

bool GenerateAllResultFunctionality::checkResume()
{
    bool keepChecking = true;

    if (!isInterrupted)
    {
        keepChecking = false;
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( this, &GenerateAllResultFunctionality::Initialize ), 100 );
    }
    else
        logger->Debug ( "Waiting to have both memories...");

    return keepChecking;
}

void GenerateAllResultFunctionality::evaluateExit()
{
    if (wasInterruptedLast)
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( this, &GenerateAllResultFunctionality::Initialize ), 100 );
    else
        ExitFunctionality();
}
