/**
 * @file GenerateAllResultFunctionality.hxx
 * @brief Header class generate transmission package, codi and pv functionality
 * @date 15/06/2013
 * @author Yadickson Soto
 */

#ifndef GENERATE_ALL_RESULT_FUNCTIONALITY_HXX_
#define GENERATE_ALL_RESULT_FUNCTIONALITY_HXX_

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/PersistAllResultWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	GenerateAllResultFunctionality
                 * @brief	Class generate transmission package, codi and pv functionality.
                 * @author	Yadickson Soto
                 * @date	15/06/2013
                 */
                class GenerateAllResultFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @fn	GenerateAllResultFunctionality::GenerateAllResultFunctionality();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        GenerateAllResultFunctionality();

                        /**
                         * @brief  Occurs when the functionality fails.
                         * @author manuel.arguelles
                         * @date   15/08/2022
                         */
                        void onError();

                        /**
                         * @brief  Checks if the functionality should be resumed.
                         * @author manuel.arguelles
                         * @date   15/08/2022
                         * @return True to continue checking; otherwise, false.
                         */
                        bool checkResume();

                        /**
                         * @brief  Evaluate if the functionality should exit or restart.
                         * @author manuel.arguelles
                         * @date   15/08/2022
                         */
                        void evaluateExit();

                        static GenerateAllResultFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::PersistAllResultWidget * widget; ///< persist all result
                        bool isInterrupted;
                        bool wasInterruptedLast;

                    protected:

                        /**
                         * @fn	std::string GenerateAllResultFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType GenerateAllResultFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	Gtk::Widget * GenerateAllResultFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	void GenerateAllResultFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        void Dispose();
                        /**
                         * @fn	void GenerateAllResultFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        void Initialize();
                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * GenerateAllResultFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring GenerateAllResultFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring GenerateAllResultFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void GenerateAllResultFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual void GenerateAllResultFunctionality::block();
                         * @brief	method block functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void block();
                        /**
                         * @fn	virtual void GenerateAllResultFunctionality::partial();
                         * @brief	method partial functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void partial();
                        /**
                         * @fn	virtual void GenerateAllResultFunctionality::resume();
                         * @brief	method resume functionality.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual void resume();

                    public:
                        /**
                         * @fn	static GenerateAllResultFunctionality * GenerateAllResultFunctionality::getInstance();
                         * @brief	Method getter instance.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         * @return	instance of class.
                         */
                        static GenerateAllResultFunctionality * getInstance();
                        /**
                         * @fn	virtual GenerateAllResultFunctionality::~GenerateAllResultFunctionality();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	15/06/2013
                         */
                        virtual ~GenerateAllResultFunctionality();
                };
            }
        }
    }
}
#endif /* GENERATE_ALL_RESULT_FUNCTIONALITY_HXX_ */
