/**
 * @file InfoLoginFunctionality.hxx
 * @brief Header class info login functionality
 * @date 27/05/2013
 * @author Yadickson Soto
 */

#ifndef INFO_LOGIN_FUNCTIONALITY_HXX_
#define INFO_LOGIN_FUNCTIONALITY_HXX_

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/VMInstallationConfirmation.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	InfoLoginFunctionality
                 * @brief	Class info login functionality.
                 * @author	Yadickson Soto
                 * @date	27/05/2013
                 */
                class InfoLoginFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @fn	InfoLoginFunctionality::InfoLoginFunctionality();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        InfoLoginFunctionality();

                        static InfoLoginFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::VMInstallationConfirmation * infoMessage; ///< Message describing the information

                    protected:

                        /**
                         * @fn	std::string InfoLoginFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType InfoLoginFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	Gtk::Widget * InfoLoginFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	void InfoLoginFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        void Dispose();
                        /**
                         * @fn	void InfoLoginFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        void Initialize();
                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * InfoLoginFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring InfoLoginFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring InfoLoginFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void InfoLoginFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual void InfoLoginFunctionality::block();
                         * @brief	method block functionality.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        virtual void block();
                        /**
                         * @fn	virtual void InfoLoginFunctionality::partial();
                         * @brief	method partial functionality.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        virtual void partial();
                        /**
                         * @fn	virtual void InfoLoginFunctionality::resume();
                         * @brief	method resume functionality.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        virtual void resume();
                        /**
                         * @fn	virtual void InfoLoginFunctionality::refresh();
                         * @brief	method refresh functionality.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        virtual void refresh();
                        /**
                         * @fn	void InfoLoginFunctionality::endFunctionality();
                         * @brief	method end functionality.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        void endFunctionality();

                    public:
                        /**
                         * @fn	static InfoLoginFunctionality * InfoLoginFunctionality::getInstance();
                         * @brief	Method getter instance.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	instance of class.
                         */
                        static InfoLoginFunctionality * getInstance();
                        /**
                         * @fn	virtual InfoLoginFunctionality::~InfoLoginFunctionality();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        virtual ~InfoLoginFunctionality();
                };
            }
        }
    }
}
#endif /* INFO_LOGIN_FUNCTIONALITY_HXX_ */
