/**
 * @file InitiatorFunctionality.hxx
 * @brief Header initiator functionality class
 * @date 03/10/2012
 * @author Yadickson Soto
 */

#ifndef _INITIATOR_FUNCTIONALITY_HXX
#define _INITIATOR_FUNCTIONALITY_HXX

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/InitiatorWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	InitiatorFunctionality
                 * @brief	initiator functionality class.
                 * @author	Yadickson Soto
                 * @date	03/10/2012
                 */
                class InitiatorFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual InitiatorFunctionality::~InitiatorFunctionality();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        virtual ~InitiatorFunctionality();
                        /**
                         * @fn	static InitiatorFunctionality * InitiatorFunctionality::getInstance();
                         * @brief	Singleton instance getter method.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         * @return	instance of class.
                         */
                        static InitiatorFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * InitiatorFunctionality::getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring InitiatorFunctionality::getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring InitiatorFunctionality::getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual bool ForceExecute();
                         * @brief	Method force execute functionality
                         * @author	Yadickson Soto
                         * @date	16/11/2012
                         * @return	true if force execute
                         */
                        virtual bool ForceExecute();

                    private:

                        static InitiatorFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                        Smartmatic::SAES::GUI::Widgets::InitiatorWidget * widget; ///< The widget
                        std::string serial; ///< current serial

                        /**
                         * @fn	InitiatorFunctionality::InitiatorFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        InitiatorFunctionality();
                        /**
                         * @fn	void InitiatorFunctionality::Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void InitiatorFunctionality::Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * InitiatorFunctionality::GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	std::string InitiatorFunctionality::GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         * @return	the window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType InitiatorFunctionality::GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	void InitiatorFunctionality::end();
                         * @brief	method end diagnostic.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        void end();
                        /**
                         * @fn	virtual void InitiatorFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/10/2012
                         */
                        virtual void deleteElements();
                };
            }
        }
    }
}

#endif // _INITIATOR_FUNCTIONALITY_HXX
