/**
 * @file	LogReportFunctionality.h
 * @brief	Declares the log report functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _REPORTLOGFUNCTIONALITY_H_

#define _REPORTLOGFUNCTIONALITY_H_

#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/ReportLogWidget.h>
#include <Log/LogReader.h>
#include <Gui/Widgets/GenericPrintingWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	LogReportFunctionality
                 * @brief	Log report functionality.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class LogReportFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	static LogReportFunctionality * LogReportFunctionality::getInstance();
                         * @brief	Gets the current.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else.
                         */

                        static LogReportFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * LogReportFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the logger.
                         */

                        Smartmatic::Log::ISMTTLog * getLogger();

                        /**
                         * @fn	Glib::ustring LogReportFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The start log message.
                         */

                        Glib::ustring getStartLogMessage();

                        /**
                         * @fn	Glib::ustring LogReportFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The finish log message.
                         */

                        Glib::ustring getFinishLogMessage();

                    private:

                        Smartmatic::SAES::GUI::Widgets::ReportLogWidget * reportLogWidget;  ///< The report log widget
                        Smartmatic::SAES::GUI::Widgets::GenericPrintingWidget * genericPrintingWidget; ///< generic printing widget

                        static LogReportFunctionality * current_instance;	///< The current instance
                        Smartmatic::SAES::Log::LogReader * logReaderAudit;  ///< The log reader audit
                        Smartmatic::SAES::Log::LogReader * logReaderError;  ///< The log reader error

                        /**
                         * @fn	LogReportFunctionality::LogReportFunctionality();
                         * @brief	Default constructor.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        LogReportFunctionality();

                        /**
                         * @fn	virtual LogReportFunctionality::~LogReportFunctionality();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        virtual ~LogReportFunctionality();


                        /**
                         * @fn	void LogReportFunctionality::on_close_clicked();
                         * @brief	Handles close clicked signals.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void on_close_clicked();

                        /**
                         * @fn	void LogReportFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Dispose();

                        /**
                         * @fn	void LogReportFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Initialize();

                        /**
                         * @fn	Gtk::Widget * LogReportFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the frame.
                         */

                        Gtk::Widget * GetFrame();

                        /**
                         * @fn	std::string LogReportFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The window title.
                         */

                        std::string GetWindowTitle();

                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType LogReportFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The menu option type.
                         */

                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();

                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger

                        unsigned int pageSize;  ///< Size of the page

                        /**
                         * @fn	virtual void LogReportFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();

                        /**
                         * @fn	void LogReportFunctionality::on_disable_exit();
                         * @brief	Handles disable exit signals.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void on_disable_exit();

                        /**
                         * @fn	void LogReportFunctionality::on_enable_exit();
                         * @brief	Handles enable exit signals.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void on_enable_exit();

                };
            }
        }
    }
}

#endif // _REPORTLOGFUNCTIONALITY_H_
