/**
 * @file LoginFunctionality.hxx
 * @brief Header login machine functionality class
 * @date 24/09/2012
 * @author Yadickson Soto
 */

#ifndef _LOGIN_FUNCTIONALITY_HXX
#define _LOGIN_FUNCTIONALITY_HXX

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/InstallMachineWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	LoginFunctionality
                 * @brief	login machine functionality class.
                 * @author	Yadickson Soto
                 * @date	24/09/2012
                 */
                class LoginFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual LoginFunctionality::~LoginFunctionality();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         */
                        virtual ~LoginFunctionality();
                        /**
                         * @fn	static LoginFunctionality * LoginFunctionality::getInstance();
                         * @brief	Singleton instance getter method.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         * @return	instance of class.
                         */
                        static LoginFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * LoginFunctionality::getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring LoginFunctionality::getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring LoginFunctionality::getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();

                    private:

                        static LoginFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::InstallMachineWidget * widget; ///< The widget

                        /**
                         * @fn	LoginFunctionality::LoginFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         */
                        LoginFunctionality();
                        /**
                         * @fn	void LoginFunctionality::Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void LoginFunctionality::Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * LoginFunctionality::GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	std::string LoginFunctionality::GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         * @return	the window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType LoginFunctionality::GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	void LoginFunctionality::end();
                         * @brief	method end login machine.
                         * @author	Yadickson Soto
                         * @date	24/09/2012
                         */
                        void end();
                        /**
                         * @fn	virtual void LoginFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual bool LoginFunctionality::ShowWindowTitle();
                         * @brief	Gets whether window title is visible.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();

                        /**
                         * @fn	virtual bool ForceExecute();
                         * @brief	Method force execute functionality
                         * @author	Yadickson Soto
                         * @date	16/11/2012
                         * @return	true if force execute
                         */
                        virtual bool ForceExecute();
                };
            }
        }
    }
}

#endif // _LOGIN_FUNCTIONALITY_HXX
