/**
 * @file MenuFunctionality.hxx
 * @brief Header menu functionality class
 * @date 21/09/2012
 * @author Yadickson Soto
 */

#ifndef _MENU_FUNCTIONALITY_H_
#define _MENU_FUNCTIONALITY_H_

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/Menu/MenuWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class MenuFunctionality
                 * @brief menu functionality class
                 * @date 21/09/2012
                 * @author Yadickson Soto
                 */
                class MenuFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual MenuFunctionality::~MenuFunctionality();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         */
                        virtual ~MenuFunctionality();
                        /**
                         * @fn	static MenuFunctionality * MenuFunctionality::getInstance();
                         * @brief	Singleton instance getter method.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         * @return	instance of class.
                         */
                        static MenuFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * MenuFunctionality::getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring MenuFunctionality::getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring MenuFunctionality::getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void MenuFunctionality::refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         */
                        virtual void refresh();

                        /**
                         * @fn	virtual void onSetKey( Smartmatic::GUI::Widgets::KeysActionsCode value);
                         * @brief	Sets a key.
                         * @author	Yadickson Soto
                         * @date	20/11/2012
                         * @param	value	The value.
                         */
                        virtual void onSetKey ( Smartmatic::GUI::Widgets::KeysActionsCode value );

                    private:

                        static MenuFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                        Smartmatic::SAES::GUI::Widgets::MenuWidget * widget; ///< The widget

                        /**
                         * @fn	MenuFunctionality::MenuFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         */
                        MenuFunctionality();
                        /**
                         * @fn	void MenuFunctionality::Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void MenuFunctionality::Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * MenuFunctionality::GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	std::string MenuFunctionality::GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         * @return	the window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType MenuFunctionality::GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	21/09/2012
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	virtual void MenuFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();
                };
            }
        }
    }
}

#endif // _MENU_FUNCTIONALITY_H_
