/*
 * RecountFunctionality.cpp
 *
 *  Created on: Apr 24, 2013
 *      Author: Georgi Demirchev
 */

#include "RecountFunctionality.h"

#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Gui/Widgets/FactoryMethodWidget.hxx>
#include "Resources/election-string-resources-manager.h"
#include <Resources/election-string-resources-manager.h>
#include <Voting/VotingDevice/voting-devices-schema.hxx>
#include <Operation/MachineOperationManager.hxx>
#include <Configuration/SaesGUIConfiguration-schema.hxx>
#include <Gui/Widgets/RecountWidget.h>

using namespace Smartmatic::Functionality;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::SAES::Voting::VotingDevice;
using namespace Smartmatic::SAES::Resources;

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;

RecountFunctionality * RecountFunctionality::current_instance = NULL;
ISMTTLog * logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.RecountFunctionality",	GETTEXT_PACKAGE );

RecountFunctionality * RecountFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new RecountFunctionality();
    }

    return current_instance;
}

RecountFunctionality::RecountFunctionality()
{
    widget = NULL;
}

RecountFunctionality::~RecountFunctionality()
{
    deleteElements();
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType RecountFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMRECOUNTFUNCTIONALITY;
}

Gtk::Widget * RecountFunctionality::GetFrame()
{
    widget = new RecountWidget ( MachineOperationManager::getInstance()->getRecountVoteStatistics()->GetVoterTypes() );
    widget->getSignalEnd().connect ( sigc::mem_fun ( *this, &RecountFunctionality::Exit ) );
    widget->resumeSignal().connect(sigc::mem_fun(controller, &RecountFunctionalityController::resume));
    widget->pauseSignal().connect(sigc::mem_fun(controller, &RecountFunctionalityController::pause));
    return widget;
}

void RecountFunctionality::Dispose()
{
}

void RecountFunctionality::Initialize()
{
    getLogger()->Debug ( MachineOperationManager::getInstance()->getOperationStatus()->getElectionStatusWrapper()->getEletionState() );

    if ( MachineOperationManager::getInstance()->getOperationStatus()->getElectionStatusWrapper()->getClosedElection() )
    {
        ExitFunctionality();
        return;
    }

    controller = RecountFunctionalityController(widget);
    controller.Initialize();
    enableExitButton();

}

Smartmatic::Log::ISMTTLog * RecountFunctionality::getLogger()
{
    return logger;
}

Glib::ustring RecountFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.RecountFunctionality.LogStartFunctionality" );
}

Glib::ustring RecountFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.RecountFunctionality.LogCloseFunctionality" );
}

void RecountFunctionality::deleteElements()
{
    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

std::string RecountFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.RecountFunctionality.Title" );
}

void RecountFunctionality::Exit()
{
    controller.Stop();
    GraphicDisplayFunctionality::ExitFunctionality();
}
