/**
 * @file RemoveUSBFunctionality.hxx
 * @brief Header class remove USB functionality
 * @date 27/05/2013
 * @author Yadickson Soto
 */

#ifndef REMOVE_USB_FUNCTIONALITY_HXX_
#define REMOVE_USB_FUNCTIONALITY_HXX_

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/RemoveUSBWidget.hxx>
#include <Operation/Monitor/DeviceTypeMonitor.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	RemoveUSBFunctionality
                 * @brief	Class remove USB functionality. The class have logic for block Machine if not removed USB key.
                 * @author	Yadickson Soto
                 * @date	27/05/2013
                 */
                class RemoveUSBFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @fn	RemoveUSBFunctionality::RemoveUSBFunctionality();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        RemoveUSBFunctionality();

                        static RemoveUSBFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::RemoveUSBWidget * removeUSBWidget; ///< remove USB widget
                        sigc::connection connRemoved;	///< connection removed usb

                    protected:

                        /**
                         * @fn	std::string RemoveUSBFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType RemoveUSBFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	Gtk::Widget * RemoveUSBFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	void RemoveUSBFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        void Dispose();
                        /**
                         * @fn	void RemoveUSBFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        void Initialize();
                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * RemoveUSBFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring RemoveUSBFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring RemoveUSBFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void RemoveUSBFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual void RemoveUSBFunctionality::block();
                         * @brief	method block functionality.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        virtual void block();
                        /**
                         * @fn	virtual void RemoveUSBFunctionality::partial();
                         * @brief	method partial functionality.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        virtual void partial();
                        /**
                         * @fn	virtual void RemoveUSBFunctionality::resume();
                         * @brief	method resume functionality.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        virtual void resume();
                        /**
                         * @fn	void RemoveUSBFunctionality::endFunctionality();
                         * @brief	method end functionality, call this method if not have present the USB.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        void endFunctionality();
                        /**
                         * @fn	void deviceChange( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * deviceTypeMonitor );
                         * @brief	getter device monitor change
                         * @author	Yadickson Soto
                         * @date	27/06/2013
                         * @param 	deviceTypeMonitor device change
                         */
                        void deviceChange ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * deviceTypeMonitor );
                        /**
                         * @fn	virtual bool ShowWindowTitle()
                         * @brief	getter isshow window title.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();

                    public:
                        /**
                         * @fn	static RemoveUSBFunctionality * RemoveUSBFunctionality::getInstance();
                         * @brief	Method getter instance.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	instance of class.
                         */
                        static RemoveUSBFunctionality * getInstance();
                        /**
                         * @fn	virtual RemoveUSBFunctionality::~RemoveUSBFunctionality();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         */
                        virtual ~RemoveUSBFunctionality();
                };
            }
        }
    }
}
#endif /* REMOVE_USB_FUNCTIONALITY_HXX_ */
