/**
 * @file ReportInstallFunctionality.hxx
 * @brief Header report install functionality class
 * @date 15/11/2012
 * @author Yadickson Soto
 */

#ifndef _REPORT_INSTALL_FUNCTIONALITY_HXX
#define _REPORT_INSTALL_FUNCTIONALITY_HXX

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/ReportInstallWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	ReportInstallFunctionality
                 * @brief	report install functionality class.
                 * @author	Yadickson Soto
                 * @date	15/11/2012
                 */
                class ReportInstallFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual ReportInstallFunctionality::~ReportInstallFunctionality();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         */
                        virtual ~ReportInstallFunctionality();
                        /**
                         * @fn	static ReportInstallFunctionality * ReportInstallFunctionality::getInstance();
                         * @brief	Singleton instance getter method.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         * @return	instance of class.
                         */
                        static ReportInstallFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * ReportInstallFunctionality::getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring ReportInstallFunctionality::getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring ReportInstallFunctionality::getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();

                    private:

                        static ReportInstallFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::ReportInstallWidget * widget; ///< The widget

                        /**
                         * @fn	ReportInstallFunctionality::ReportInstallFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         */
                        ReportInstallFunctionality();
                        /**
                         * @fn	void ReportInstallFunctionality::Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void ReportInstallFunctionality::Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * ReportInstallFunctionality::GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	std::string ReportInstallFunctionality::GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         * @return	the window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType ReportInstallFunctionality::GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	void ReportInstallFunctionality::end();
                         * @brief	method end functionality
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         */
                        void end();
                        /**
                         * @fn	virtual void ReportInstallFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	15/11/2012
                         */
                        virtual void deleteElements();
                };
            }
        }
    }
}

#endif // _REPORT_INSTALL_FUNCTIONALITY_HXX
