/**
 * @file   ReportPrintingVMFunctionality.hxx
 * @brief  Declaration of ReportPrintingVMFunctionality class.
 * @author manuel.arguelles
 * @date   Jun 13, 2017
 */

#ifndef _REPORT_PRINTING_VM_FUNCTIONALITY_H_
#define _REPORT_PRINTING_VM_FUNCTIONALITY_H_

#include <Functionalities/graphic-display-functionality.h>
#include <gtkmm.h>
#include <string>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                class ReportPrintingVMWidget;
            }
            namespace Functionality
            {
                /**
                 * @class  ReportPrintingVMFunctionality
                 * @brief  Report printing in the vm funcionality.
                 * @author manuel.arguelles
                 * @date   Jun 13, 2017
                 */
                class ReportPrintingVMFunctionality : public GraphicDisplayFunctionality
                {
                    public:
                        /**
                         * @brief  Class destructor.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         */
                        virtual ~ReportPrintingVMFunctionality();

                        /**
                         * @brief  Gets instance of the class.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         * @return The instance of the class.
                         */
                        static ReportPrintingVMFunctionality* getInstance();

                        /**
                         * @brief  Get the logger.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         * @return The logger.
                         */
                        virtual Smartmatic::Log::ISMTTLog* getLogger();

                        /**
                         * @brief  Get the start log message.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         * @return The string with the message to log.
                         */
                        virtual Glib::ustring getStartLogMessage();

                        /**
                         * @brief  Get the finish log message.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         * @return The string with the message to log.
                         */
                        virtual Glib::ustring getFinishLogMessage();

                        /**
                         * @brief  Get the menu option type.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         * @return The type of the menu option.
                         */
                        virtual SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();

                        /**
                         * @brief  Get the frame.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         * @return The widget frame.
                         */
                        virtual Gtk::Widget* GetFrame();

                        /**
                         * @brief  Get the window title.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         * @return A string with the window title.
                         */
                        virtual std::string GetWindowTitle();

                        /**
                         * @brief  Initialize the functionality.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         */
                        virtual void Initialize();

                        /**
                         * @brief  Dispose the functionality.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         */
                        virtual void Dispose();

                        /**
                         * @brief  Deletes all the elements.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         */
                        virtual void deleteElements();

                    private:
                        /**
                         * @brief  Default constructor.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         */
                        ReportPrintingVMFunctionality();

                    private:
                        Smartmatic::SAES::GUI::Widgets::ReportPrintingVMWidget* m_widget;
                        static Smartmatic::Log::ISMTTLog*                       m_logger;
                        static ReportPrintingVMFunctionality*                   m_currentInstance;
                };
            }
        }
    }
}

#endif /* _REPORT_PRINTING_VM_FUNCTIONALITY_H_ */
