/**
 * @file	ShutdownMachineFunctionality.h
 * @brief	Declares the shutdown machine functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#ifndef SHUTDOWNMACHINEFUNCTIONALITY_H_
#define SHUTDOWNMACHINEFUNCTIONALITY_H_

#include <gtkmm.h>
#include <string>
#include <Widgets/smartmatic-button.h>
#include <Log/ISMTTLog.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	ShutdownMachineFunctionality
                 * @brief	Shutdown machine functionality.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class ShutdownMachineFunctionality : public GraphicDisplayFunctionality
                {
                    public:
                        /**
                         * @fn	static ShutdownMachineFunctionality * ShutdownMachineFunctionality::getInstance();
                         * @brief	Gets the current.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else.
                         */

                        static ShutdownMachineFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * ShutdownMachineFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the logger.
                         */

                        Smartmatic::Log::ISMTTLog * getLogger();

                        /**
                         * @fn	Glib::ustring ShutdownMachineFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The start log message.
                         */

                        Glib::ustring getStartLogMessage();

                        /**
                         * @fn	Glib::ustring ShutdownMachineFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The finish log message.
                         */

                        Glib::ustring getFinishLogMessage();

                        /**
                         * @fn	virtual void ShutdownMachineFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();

                    private:
                        static ShutdownMachineFunctionality * current_instance; ///< The current instance

                        Gtk::Frame * externalFrame; ///< The external frame
                        Gtk::Label * titleLabel;	///< The title label

                        /**
                         * @fn	ShutdownMachineFunctionality::ShutdownMachineFunctionality();
                         * @brief	Default constructor.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        ShutdownMachineFunctionality();

                        /**
                         * @fn	Gtk::Widget * ShutdownMachineFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the frame.
                         */

                        Gtk::Widget * GetFrame();

                        /**
                         * @fn	void ShutdownMachineFunctionality::Dispose();
                         * @brief	Performs application-defined tasks associated with freeing, releasing, or resetting
                         * 				unmanaged resources.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void Dispose();

                        /**
                         * @fn	void ShutdownMachineFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Initialize();

                        /**
                         * @fn	std::string ShutdownMachineFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The window title.
                         */

                        std::string GetWindowTitle();

                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType ShutdownMachineFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The menu option type.
                         */

                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();

                        /**
                         * @fn	virtual void ShutdownMachineFunctionality::ExcuteBackgroundProcess();
                         * @brief	Execute background process for close votation functionality.
                         * @author	Gerardo.Hernandez
                         * @date	10/06/2011
                         */
                        virtual void ExcuteBackgroundProcess();

                        static Smartmatic::Log::ISMTTLog * logger;	///< The logger
                };
            }
        }
    }
}

#endif /* SHUTDOWNMACHINEFUNCTIONALITY_H_ */
