/**
 * @file VotingMachineProcessStatusFunctionality.hxx
 * @brief Header voting machine process status functionality class
 * @date 08/11/2012
 * @author Yadickson Soto
 */

#ifndef _VOTING_MACHINE_PROCESS_STATUS_FUNCTIONALITY_HXX
#define _VOTING_MACHINE_PROCESS_STATUS_FUNCTIONALITY_HXX

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/ProcessResultWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	VotingMachineProcessStatusFunctionality
                 * @brief	voting machine process status functionality class
                 * @author	Yadickson Soto
                 * @date	08/11/2012
                 */
                class VotingMachineProcessStatusFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual VotingMachineProcessStatusFunctionality::~VotingMachineProcessStatusFunctionality();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         */
                        virtual ~VotingMachineProcessStatusFunctionality();
                        /**
                         * @fn	static VotingMachineProcessStatusFunctionality * VotingMachineProcessStatusFunctionality::getInstance();
                         * @brief	Singleton instance getter method.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         * @return	instance of class.
                         */
                        static VotingMachineProcessStatusFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * VotingMachineProcessStatusFunctionality::getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring VotingMachineProcessStatusFunctionality::getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring VotingMachineProcessStatusFunctionality::getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();

                    private:

                        static VotingMachineProcessStatusFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                        Smartmatic::SAES::GUI::Widgets::ProcessResultWidget * widget; ///< The widget

                        /**
                         * @fn	VotingMachineProcessStatusFunctionality::VotingMachineProcessStatusFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         */
                        VotingMachineProcessStatusFunctionality();
                        /**
                         * @fn	void VotingMachineProcessStatusFunctionality::Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void VotingMachineProcessStatusFunctionality::Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * VotingMachineProcessStatusFunctionality::GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	std::string VotingMachineProcessStatusFunctionality::GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         * @return	the window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	virtual bool VotingMachineProcessStatusFunctionality::ShowWindowTitle()
                         * @brief	getter isshow window title.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType VotingMachineProcessStatusFunctionality::GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	void VotingMachineProcessStatusFunctionality::end();
                         * @brief	method end diagnostic.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         */
                        void end();
                        /**
                         * @fn	virtual void VotingMachineProcessStatusFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         */
                        virtual void deleteElements();

                        /**
                         * @fn	virtual bool ForceExecute();
                         * @brief	Method force execute functionality
                         * @author	Yadickson Soto
                         * @date	16/11/2012
                         * @return	true if force execute
                         */
                        virtual bool ForceExecute();
                };
            }
        }
    }
}

#endif // _VOTING_MACHINE_PROCESS_STATUS_FUNCTIONALITY_HXX
