/**
 * @file WaitingVotingExperienceFunctionality.hxx
 * @brief Header class waiting voting experience functionality
 * @date 17/10/2012
 * @author Yadickson Soto
 */

#ifndef WAITINGVOTINGEXPERIENCEFUNCTIONALITY_HXX_
#define WAITINGVOTINGEXPERIENCEFUNCTIONALITY_HXX_

#include <gtkmm.h>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/MachineVotingWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	WaitingVotingExperienceFunctionality
                 * @brief	Class voting experience functionality.
                 * @author	Yadickson Soto
                 * @date	17/10/2012
                 */
                class WaitingVotingExperienceFunctionality : public GraphicDisplayFunctionality
                {
                    private:
                        /**
                         * @fn	WaitingVotingExperienceFunctionality::WaitingVotingExperienceFunctionality();
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        WaitingVotingExperienceFunctionality();

                        static WaitingVotingExperienceFunctionality * instance; ///< instance of class
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                        Smartmatic::SAES::GUI::Widgets::MachineVotingWidget * widget; ///< voting widget

                    protected:

                        /**
                         * @fn	std::string WaitingVotingExperienceFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	The window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType WaitingVotingExperienceFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	The menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	Gtk::Widget * WaitingVotingExperienceFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	null if it fails, else the frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	void WaitingVotingExperienceFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void WaitingVotingExperienceFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * WaitingVotingExperienceFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	null if it fails, else the logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring WaitingVotingExperienceFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	The start log message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring WaitingVotingExperienceFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	The finish log message.
                         */
                        Glib::ustring getFinishLogMessage();
                        /**
                         * @fn	virtual void WaitingVotingExperienceFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual bool WaitingVotingExperienceFunctionality::ShowWindowTitle();
                         * @brief	Gets whether window title is visible.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();
                        /**
                         * @fn	virtual void WaitingVotingExperienceFunctionality::refresh();
                         * @brief	refresh widget method.
                         * @author	Yadickson Soto
                         * @date	04/10/2012
                         */
                        virtual void refresh();
                        /**
                         * @fn	void WaitingVotingExperienceFunctionality::end();
                         * @brief	method end diagnostic.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        void end();

                    public:
                        /**
                         * @fn	static WaitingVotingExperienceFunctionality * WaitingVotingExperienceFunctionality::getInstance();
                         * @brief	Method getter instance.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         * @return	instance of class.
                         */
                        static WaitingVotingExperienceFunctionality * getInstance();
                        /**
                         * @fn	virtual WaitingVotingExperienceFunctionality::~WaitingVotingExperienceFunctionality();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	17/10/2012
                         */
                        virtual ~WaitingVotingExperienceFunctionality();
                };
            }
        }
    }
}
#endif /* WAITINGVOTINGEXPERIENCEFUNCTIONALITY_HXX_ */
