/**
 * @file ZipCodeFunctionality.hxx
 * @brief Header zip code functionality class
 * @date 27/09/2012
 * @author Yadickson Soto
 */

#ifndef _ZIP_CODE_FUNCTIONALITY_HXX
#define _ZIP_CODE_FUNCTIONALITY_HXX

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include <Gui/Widgets/Diagnose/ZipCodeWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	ZipCodeFunctionality
                 * @brief	zip code functionality class.
                 * @author	Yadickson Soto
                 * @date	27/09/2012
                 */
                class ZipCodeFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	virtual ZipCodeFunctionality::~ZipCodeFunctionality();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         */
                        virtual ~ZipCodeFunctionality();
                        /**
                         * @fn	static ZipCodeFunctionality * ZipCodeFunctionality::getInstance();
                         * @brief	Singleton instance getter method.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @return	instance of class.
                         */
                        static ZipCodeFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * ZipCodeFunctionality::getLogger();
                         * @brief	Logger getter method.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @return	logger.
                         */
                        Smartmatic::Log::ISMTTLog * getLogger();
                        /**
                         * @fn	Glib::ustring ZipCodeFunctionality::getStartLogMessage();
                         * @brief	Gets the logger starting message.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @return	message.
                         */
                        Glib::ustring getStartLogMessage();
                        /**
                         * @fn	Glib::ustring ZipCodeFunctionality::getFinishLogMessage();
                         * @brief	Gets the logger ending message.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @return	message.
                         */
                        Glib::ustring getFinishLogMessage();

                    private:

                        static ZipCodeFunctionality * current_instance;  ///< The current instance
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                        Smartmatic::SAES::GUI::Widgets::ZipCodeWidget * widget; ///< The widget

                        /**
                         * @fn	ZipCodeFunctionality::ZipCodeFunctionality();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         */
                        ZipCodeFunctionality();
                        /**
                         * @fn	void ZipCodeFunctionality::Dispose();
                         * @brief	method dispose.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         */
                        void Dispose();
                        /**
                         * @fn	void ZipCodeFunctionality::Initialize();
                         * @brief	method initialize.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         */
                        void Initialize();
                        /**
                         * @fn	Gtk::Widget * ZipCodeFunctionality::GetFrame();
                         * @brief	Frame getter method.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @return	new frame.
                         */
                        Gtk::Widget * GetFrame();
                        /**
                         * @fn	std::string ZipCodeFunctionality::GetWindowTitle();
                         * @brief	Window title getter method.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @return	the window title.
                         */
                        std::string GetWindowTitle();
                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType ZipCodeFunctionality::GetMenuOptionType();
                         * @brief	Menu option type getter method.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         * @return	the menu option type.
                         */
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();
                        /**
                         * @fn	void ZipCodeFunctionality::setZipCode();
                         * @brief	method set zip code.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         */
                        void setZipCode();
                        /**
                         * @fn	void ZipCodeFunctionality::saveZipCode();
                         * @brief	method save zip code.
                         * @author	Yadickson Soto
                         * @date	27/09/2012
                         */
                        void saveZipCode();
                        /**
                         * @fn	virtual void ZipCodeFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();
                };
            }
        }
    }
}

#endif // _ZIP_CODE_FUNCTIONALITY_HXX
