/**
 * @file	change-language-functionality.h
 * @brief	Declares the change language functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _CHANGE_LANGUAGE_FUNCTIONALITY_H_
#define _CHANGE_LANGUAGE_FUNCTIONALITY_H_

#include <gtkmm.h>
#include <string>
#include <Functionalities/graphic-display-functionality.h>
#include "Gui/Widgets/change-language-widget.h"
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	ChangeLanguageFunctionality
                 * @brief	Change language functionality.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class ChangeLanguageFunctionality : public GraphicDisplayFunctionality
                {
                    public:

                        /**
                         * @fn	static ChangeLanguageFunctionality * ChangeLanguageFunctionality::getInstance();
                         * @brief	Gets the current.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else.
                         */

                        static ChangeLanguageFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * ChangeLanguageFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the logger.
                         */

                        Smartmatic::Log::ISMTTLog * getLogger();

                        /**
                         * @fn	Glib::ustring ChangeLanguageFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The start log message.
                         */

                        Glib::ustring getStartLogMessage();

                        /**
                         * @fn	Glib::ustring ChangeLanguageFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The finish log message.
                         */

                        Glib::ustring getFinishLogMessage();

                    private:

                        Smartmatic::SAES::GUI::Widgets::ChangeLanguageWidget * changeLanguageWidget;	///< The change language widget

                        /**
                         * @fn	ChangeLanguageFunctionality::ChangeLanguageFunctionality();
                         * @brief	Default constructor.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        ChangeLanguageFunctionality();

                        /**
                         * @fn	virtual ChangeLanguageFunctionality::~ChangeLanguageFunctionality();
                         * @brief	Finaliser.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        virtual ~ChangeLanguageFunctionality();

                        static ChangeLanguageFunctionality * current_instance;	///< The current instance

                        /**
                         * @fn	void ChangeLanguageFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Dispose();

                        /**
                         * @fn	void ChangeLanguageFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Initialize();

                        /**
                         * @fn	Gtk::Widget * ChangeLanguageFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the frame.
                         */

                        Gtk::Widget * GetFrame();

                        /**
                         * @fn	std::string ChangeLanguageFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The window title.
                         */

                        std::string GetWindowTitle();

                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType ChangeLanguageFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The menu option type.
                         */

                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();

                        /**
                         * @fn	void ChangeLanguageFunctionality::OnLanguageChange();
                         * @brief	Executes the language change action.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void OnLanguageChange();

                        /**
                         * @fn	virtual void ChangeLanguageFunctionality::deleteElements();
                         * @brief	Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();
                        /**
                         * @fn	virtual bool ChangeLanguageFunctionality::ShowWindowTitle();
                         * @brief	Gets whether window title is visible.
                         * @author	Yadickson Soto
                         * @date	18/09/2012
                         * @return	true is show window title.
                         */
                        virtual bool ShowWindowTitle();

                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                };
            }
        }
    }
}

#endif // _CHANGE_LANGUAGE_FUNCTIONALITY_H_
