/**
 * @file	open-election-functionality.cc
 * @brief	open election functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#include <Log/SMTTLogManager.h>
#include "open-election-functionality.h"
#include <Voting/OperationStatus.hxx>
#include <Voting/Status/ElectionStatusWrapper.hxx>
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Configuration/SaesGUIConfiguration-schema.hxx>
#include <glibmm/timeval.h>
#include <Log/SMTTLogManager.h>
#include <Operation/MachineOperationManager.hxx>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Functionality;
using namespace Smartmatic::Functionality;
using namespace Gtk;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Voting::Status;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Functionality;

OpenElectionFunctionality * OpenElectionFunctionality::current_instance = NULL;

ISMTTLog * OpenElectionFunctionality::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Functionality.OpenElectionFunctionality", GETTEXT_PACKAGE );

OpenElectionFunctionality * OpenElectionFunctionality::getInstance()
{
    if ( !current_instance )
    {
        current_instance = new OpenElectionFunctionality();
    }

    return current_instance;
}

OpenElectionFunctionality::OpenElectionFunctionality()
{
    openFrame = NULL;
    openElectionWidget = NULL;
    manager = NULL;
}

OpenElectionFunctionality::~OpenElectionFunctionality()
{
    deleteElements();
}

void OpenElectionFunctionality::deleteElements()
{
    wizardVector.clear();

    if ( openElectionWidget )
    {
        delete openElectionWidget;
        openElectionWidget = NULL;
    }

    if ( manager )
    {
        delete manager;
        manager = NULL;
    }

    if ( openFrame )
    {
        delete openFrame;
        openFrame = NULL;
    }
}

void OpenElectionFunctionality::Initialize()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.OpenElectionFunctionality.ElectionWasNotOpen" ) );
    enableExitButton();

    if ( manager )
    {
        manager->Start();
    }
}

Gtk::Widget * OpenElectionFunctionality::GetFrame()
{
    openFrame = new Gtk::Frame();

    openElectionWidget = AbstractFactoryWidget::createOpenElectionStatusWidget();
    openElectionWidget->on_stop_signal_emit().connect ( sigc::mem_fun ( *this, &OpenElectionFunctionality::errorHappen ) );
    openElectionWidget->on_disable_close_signal_emit().connect ( sigc::mem_fun ( *this, &OpenElectionFunctionality::disableExitButton ) );
    wizardVector.push_back ( openElectionWidget );

    manager = new WizardWidgetManager ( wizardVector );
    manager->on_finish_signal_emit().connect ( sigc::mem_fun ( *this, &OpenElectionFunctionality::finish ) );
    openFrame->remove();
    openFrame->add ( *manager );
    openFrame->set_shadow_type ( SHADOW_NONE );
    openFrame->show_all_children();
    openFrame->show();
    return openFrame;
}

void OpenElectionFunctionality::finish()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.OpenElectionFunctionality.ElectionWasOpen" ) );
    ExitFunctionality();
}

void OpenElectionFunctionality::errorHappen()
{
    exitWidget.setInfo ( N_ ( "Smartmatic.SAES.GUI.Functionality.OpenElectionFunctionality.ErrorOpenElection" ) );
    ExitFunctionality();
}

std::string OpenElectionFunctionality::GetWindowTitle()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.OpenElectionFunctionality.OpenElection" );
}

Smartmatic::SAES::Functionality::Configuration::MenuOptionType OpenElectionFunctionality::GetMenuOptionType()
{
    return MenuOptionType::CONFIGURATION_XMLMOPENELECTIONFUNCTIONALITY;
}

void OpenElectionFunctionality::Dispose()
{

}

Smartmatic::Log::ISMTTLog * OpenElectionFunctionality::getLogger()
{
    return logger;
}

Glib::ustring OpenElectionFunctionality::getStartLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.OpenElectionFunctionality.LogStartFunctionality" );
}

Glib::ustring OpenElectionFunctionality::getFinishLogMessage()
{
    return N_ ( "Smartmatic.SAES.GUI.Functionality.OpenElectionFunctionality.LogCloseFunctionality" );
}
