/**
 * @file	s-c-reader-diagnosis-functionality.h
 * @brief	Declares the reader diagnosis functionality class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _S_C_READER_DIAGNOSIS_FUNCTIONALITY_H_
#define _S_C_READER_DIAGNOSIS_FUNCTIONALITY_H_

#include <gtkmm.h>
#include <string>
#include <Gui/Widgets/Diagnose/SmartcardDiagnosisWidget.hxx>
#include <Functionalities/graphic-display-functionality.h>
#include <Log/ISMTTLog.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Functionality
            {
                /**
                 * @class	SCReaderDiagnosisFunctionality
                 * @brief	Screen reader diagnosis functionality.
                 * @author	Youssef.tourkmani
                 * @date	05/11/2012
                 */
                class SCReaderDiagnosisFunctionality: public GraphicDisplayFunctionality
                {

                    public:

                        /**
                         * @fn	bool SCReaderDiagnosisFunctionality::DontAllowHelp();
                         * @brief	Gets the dont allow help.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool DontAllowHelp();

                        /**
                         * @fn	std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> SCReaderDiagnosisFunctionality::getHelpSeqKey();
                         * @brief	Gets the help sequence key.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The help sequence key.
                         */

                        std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> getHelpSeqKey();

                        /**
                         * @fn	bool SCReaderDiagnosisFunctionality::DontAllowExit();
                         * @brief	Gets the dont allow exit.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	true if it succeeds, false if it fails.
                         */

                        bool DontAllowExit();

                        /**
                         * @fn	std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> SCReaderDiagnosisFunctionality::getSeqKey();
                         * @brief	Gets the sequence key.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The sequence key.
                         */

                        std::vector<Smartmatic::GUI::Widgets::KeysActionsCode> getSeqKey();

                        /**
                         * @fn	static SCReaderDiagnosisFunctionality * SCReaderDiagnosisFunctionality::getInstance();
                         * @brief	Gets the current.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else.
                         */

                        static SCReaderDiagnosisFunctionality * getInstance();

                    protected:

                        /**
                         * @fn	Smartmatic::Log::ISMTTLog * SCReaderDiagnosisFunctionality::getLogger();
                         * @brief	Gets the logger.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the logger.
                         */

                        Smartmatic::Log::ISMTTLog * getLogger();

                        /**
                         * @fn	Glib::ustring SCReaderDiagnosisFunctionality::getStartLogMessage();
                         * @brief	Gets the start log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The start log message.
                         */

                        Glib::ustring getStartLogMessage();

                        /**
                         * @fn	Glib::ustring SCReaderDiagnosisFunctionality::getFinishLogMessage();
                         * @brief	Gets the finish log message.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The finish log message.
                         */

                        Glib::ustring getFinishLogMessage();

                        /**
                         * @fn	virtual void SCReaderDiagnosisFunctionality::deleteElements();
                         * @brief	virtual Deletes all elements.
                         * @author	Yadickson Soto
                         * @date	03/04/2012
                         */
                        virtual void deleteElements();

                    private:

                        static SCReaderDiagnosisFunctionality * current_instance; ///< The current instance

                        /**
                         * @fn	SCReaderDiagnosisFunctionality::SCReaderDiagnosisFunctionality();
                         * @brief	Default constructor.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        SCReaderDiagnosisFunctionality();

                        /**
                         * @fn	virtual SCReaderDiagnosisFunctionality::~SCReaderDiagnosisFunctionality();
                         * @brief	Finaliser.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        virtual ~SCReaderDiagnosisFunctionality();

                        Smartmatic::SAES::GUI::Widgets::SmartcardDiagnosisWidget * readerWidget;	///< The reader widget

                        /**
                         * @fn	void SCReaderDiagnosisFunctionality::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Dispose();

                        /**
                         * @fn	void SCReaderDiagnosisFunctionality::Initialize();
                         * @brief	Initializes this object.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         */

                        void Initialize();

                        /**
                         * @fn	Gtk::Widget * SCReaderDiagnosisFunctionality::GetFrame();
                         * @brief	Gets the frame.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	null if it fails, else the frame.
                         */

                        Gtk::Widget * GetFrame();

                        /**
                         * @fn	std::string SCReaderDiagnosisFunctionality::GetWindowTitle();
                         * @brief	Gets the window title.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The window title.
                         */

                        std::string GetWindowTitle();

                        /**
                         * @fn	Smartmatic::SAES::Functionality::Configuration::MenuOptionType SCReaderDiagnosisFunctionality::GetMenuOptionType();
                         * @brief	Gets the menu option type.
                         * @author	Luiggi.mendez
                         * @date	28/04/2011
                         * @return	The menu option type.
                         */

                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType GetMenuOptionType();

                        sigc::connection connSCDiag;	///< The connection screen diagram
                        /**
                         * @fn	void SCReaderDiagnosisFunctionality::on_SCDiagFinished();
                         * @brief	Handles screen diagram finished signals.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void on_SCDiagFinished();

                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                };
            }
        }
    }
}


#endif // _S_C_READER_DIAGNOSIS_FUNCTIONALITY_H_
