/**
 * @file AbstractFactoryWidget.cxx
 * @brief Body class for creating the widget
 * @date 03/11/2011
 * @author Yadickson Soto
 */

#include "AbstractFactoryWidget.hxx"
#include "AuthenticationWidget.hxx"
#include "BallotOptionTableWidget.hxx"
#include "BarcodeDetectionWidget.h"
#include "DataUtilsValidatorWidget.hxx"
#include "ExternalPrintWizardWidget.hxx"
#include "FactoryMethodWidget.hxx"
#include "GenericPrintingWidget.hxx"
#include "GenericWidget.hxx"
#include "HelpWidget.hxx"
#include "IconShutdownWidget.hxx"
#include "InitiatorWidget.hxx"
#include "InstallMachineWidget.hxx"
#include "MachineWizardWidget.hxx"
#include "MemoryStateWidget.hxx"
#include "OpenElectionStatusWidget.hxx"
#include "PersistAllResultWidget.hxx"
#include "ReferendumTableWidget.hxx"
#include "RemoveUSBWidget.hxx"
#include "SystemFilesIntegrityCheckWidget.hxx"
#include "ReportInstallWidget.hxx"
#include "ReportPrintingVMWidget.hxx"
#include "VMInstallationConfirmation.hxx"
#include "ValidateEmlSignatureWidget.hxx"
#include "ValidateVotesWidget.hxx"
#include "ClosingElectionStatusWidget.h"
#include "close-election-status-widget.h"
#include <Gui/Widgets/Diagnose/EurnDetectedWidget.hxx>
#include <Gui/Widgets/Diagnose/EurnEndDiagnoseWidget.hxx>
#include <Gui/Widgets/Diagnose/AlarmBoxDetectedWidget.hxx>
#include <Gui/Widgets/Diagnose/AlarmBoxEndDiagnoseWidget.hxx>
#include <Gui/Widgets/Diagnose/AppCalibrationWidget.hxx>
#include <Gui/Widgets/Diagnose/AutoBarcodeDiagnosisWidget.hxx>
#include <Gui/Widgets/Diagnose/AutoPrinterDiagnosisWidget.hxx>
#include <Gui/Widgets/Diagnose/AutomaticDiagnosticWidget.hxx>
#include <Gui/Widgets/Diagnose/BarcodeReaderDetectedWidget.hxx>
#include <Gui/Widgets/Diagnose/BarcodeReaderPrintingWidget.hxx>
#include <Gui/Widgets/Diagnose/BarcodeReaderReconfigureWidget.hxx>
#include <Gui/Widgets/Diagnose/BarcodeReaderScanWidget.hxx>
#include <Gui/Widgets/Diagnose/BarcodeReaderSerialNumberWidget.hxx>
#include <Gui/Widgets/Diagnose/DeviceDiagnosticPrintWidget.hxx>
#include <Gui/Widgets/Diagnose/DiagnosisBlockedWidget.hxx>
#include <Gui/Widgets/Diagnose/LedStripActionsWidget.hxx>
#include <Gui/Widgets/Diagnose/SmartcardActionsWidget.hxx>
#include <Gui/Widgets/Diagnose/SmartcardDetectedWidget.hxx>
#include <Gui/Widgets/Diagnose/SmartcardPowerWidget.hxx>
#include <Gui/Widgets/Transmission/CheckNetworkWidget.hxx>
#include <Gui/Widgets/Transmission/SendResultsPackageWidget.hxx>
#include <Gui/Widgets/VotingMachineInstallationWizardWidget.hxx>

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;

InstallMachineWidget * AbstractFactoryWidget::createInstallMachineWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    PollingPlaceInfoWidget * pollingPlaceInfo = FactoryMethodWidget::createPollingPlaceInfoWidget();
    InstallMachineWidget * widget = FactoryMethodWidget::createInstallMachineWidget ( progress, pollingPlaceInfo );
    return widget;
}

AutomaticDiagnosticWidget * AbstractFactoryWidget::createAutomaticDiagnosticWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    AutomaticDiagnosticWidget * widget = new AutomaticDiagnosticWidget ( progress );
    return widget;
}

InitiatorWidget * AbstractFactoryWidget::createInitiatorWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    InitiatorWidget * widget = FactoryMethodWidget::createInitiatorWidget ( progress );
    return widget;
}

ReportInstallWidget * AbstractFactoryWidget::createReportInstallWidget()
{
    GenericPrintingWidget * genericWidget = createGenericPrintingWidget();
    ReportInstallWidget * widget = new ReportInstallWidget ( genericWidget );
    return widget;
}

ClosingElectionStatusWidget * AbstractFactoryWidget::createClosingElectionStatusWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    ClosingElectionStatusWidget * widget = new ClosingElectionStatusWidget(progress);
    return widget;
}

CloseElectionStatusWidget * AbstractFactoryWidget::createCloseElectionStatusWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    CloseElectionStatusWidget * widget = new CloseElectionStatusWidget ( progress );
    return widget;
}

OpenElectionStatusWidget * AbstractFactoryWidget::createOpenElectionStatusWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    OpenElectionStatusWidget * widget = new OpenElectionStatusWidget ( progress );
    return widget;
}

PersistAllResultWidget * AbstractFactoryWidget::createPersistAllResultWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    PersistAllResultWidget * widget = new PersistAllResultWidget ( progress );
    return widget;
}

BarcodeDetectionWidget * AbstractFactoryWidget::createBarcodeDetectionWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    BarcodeDetectionWidget * widget = new BarcodeDetectionWidget ( progress );
    return widget;
}

BallotOptionTableWidget * AbstractFactoryWidget::createBallotOptionTableWidget()
{
    TableBoxSelectionWidget * table = FactoryMethodWidget::createBallotOptionTableBoxSelectionWidget();
    FillTableWidget * fillTable = FactoryMethodWidget::createBallotOptionFillTableWidget ( table );
    BallotOptionTableWidget * widget = new BallotOptionTableWidget ( fillTable );
    return widget;
}

MemoryStateWidget * AbstractFactoryWidget::createMemoryStateWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    MemoryStateWidget * widget = new MemoryStateWidget ( progress );
    return widget;
}

AuthenticationWidget * AbstractFactoryWidget::createAuthenticationWidget()
{
    PollingPlaceInfoWidget * info = FactoryMethodWidget::createAuthenticationPollingPlaceInfoWidget();
    AuthenticationWidget * widget = FactoryMethodWidget::createAuthenticationWidget ( info );
    return widget;
}

DiagnosisBlockedWidget * AbstractFactoryWidget::createDiagnosisBlockedWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    DiagnosisBlockedWidget * widget = new DiagnosisBlockedWidget ( progress );
    return widget;
}

DataUtilsValidatorWidget * AbstractFactoryWidget::createDataUtilsValidatorWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    DataUtilsValidatorWidget * widget = new DataUtilsValidatorWidget ( progress );
    return widget;
}

ReferendumTableWidget * AbstractFactoryWidget::createReferendumTableWidget()
{
    TableBoxSelectionWidget * table = new TableBoxSelectionWidget ( false );
    ReferendumTableWidget * widget = new ReferendumTableWidget ( table );
    return widget;
}

IconShutdownWidget * AbstractFactoryWidget::createIconShutdownWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    IconShutdownWidget * widget = new IconShutdownWidget ( progress );
    return widget;
}

GenericWidget * AbstractFactoryWidget::createGenericWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    GenericButtonWidget * buttonsWidget = FactoryMethodWidget::createGenericButtonWidget();
    GenericWidget * widget = new GenericWidget ( progress, buttonsWidget );
    return widget;
}

GenericPrintingWidget * AbstractFactoryWidget::createGenericPrintingWidget()
{
    GenericWidget * genericWidget = createGenericWidget();
    GenericPrintingWidget * widget = new GenericPrintingWidget ( genericWidget );
    return widget;
}

DeviceDiagnosticPrintWidget * AbstractFactoryWidget::createDeviceDiagnosticPrintWidget()
{
    GenericPrintingWidget * genericWidget = createGenericPrintingWidget();
    DeviceDiagnosticPrintWidget * widget = new DeviceDiagnosticPrintWidget ( genericWidget );
    return widget;
}

MachineWizardWidget * AbstractFactoryWidget::createMachineWizardWidget()
{
    HelpWidget * helpWidget = new HelpWidget();
    MachineWizardWidget * widget = new MachineWizardWidget ( helpWidget );
    return widget;
}

RemoveUSBWidget * AbstractFactoryWidget::createRemoveUSBWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    RemoveUSBWidget * widget = new RemoveUSBWidget ( progress );
    return widget;
}

SystemFilesIntegrityCheckWidget * AbstractFactoryWidget::createSystemFilesIntegrityCheckWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    SystemFilesIntegrityCheckWidget * widget = new SystemFilesIntegrityCheckWidget ( progress );
    return widget;
}

VMInstallationConfirmation * AbstractFactoryWidget::createVMInstallationConfirmation()
{
    PollingPlaceInfoWidget * info = FactoryMethodWidget::createPollingPlaceInfoWidget();
    VMInstallationConfirmation * widget = new VMInstallationConfirmation ( info );
    return widget;
}

ValidateEmlSignatureWidget * AbstractFactoryWidget::createValidateEmlSignatureWidget ()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    ValidateEmlSignatureWidget * widget = new ValidateEmlSignatureWidget ( progress );
    return widget;
}

ValidateVotesWidget * AbstractFactoryWidget::createValidateVotesWidget ()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    ValidateVotesWidget * widget = new ValidateVotesWidget ( progress );
    return widget;
}

AutoBarcodeDiagnosisWidget * AbstractFactoryWidget::createAutoBarcodeDiagnosisWidget ()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    AutoBarcodeDiagnosisWidget * widget = new AutoBarcodeDiagnosisWidget ( progress );
    return widget;
}

AutoPrinterDiagnosisWidget * AbstractFactoryWidget::createAutoPrinterDiagnosisWidget ()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    AutoPrinterDiagnosisWidget * widget = new AutoPrinterDiagnosisWidget ( progress );
    return widget;
}

BarcodeReaderPrintingWidget * AbstractFactoryWidget::createBarcodeReaderPrintingWidget()
{
    GenericPrintingWidget * generic = createGenericPrintingWidget();
    BarcodeReaderPrintingWidget * widget = new BarcodeReaderPrintingWidget ( generic );
    return widget;
}

BarcodeReaderReconfigureWidget * AbstractFactoryWidget::createBarcodeReaderReconfigureWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    BarcodeReaderReconfigureWidget * widget = new BarcodeReaderReconfigureWidget ( progress );
    return widget;
}

BarcodeReaderScanWidget * AbstractFactoryWidget::createBarcodeReaderScanWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    BarcodeReaderScanWidget * widget = new BarcodeReaderScanWidget ( progress );
    return widget;
}

BarcodeReaderDetectedWidget * AbstractFactoryWidget::createBarcodeReaderDetectedWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    BarcodeReaderDetectedWidget * widget = new BarcodeReaderDetectedWidget ( progress );
    return widget;
}

BarcodeReaderSerialNumberWidget * AbstractFactoryWidget::createBarcodeReaderSerialNumberWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    BarcodeReaderSerialNumberWidget * widget = new BarcodeReaderSerialNumberWidget ( progress );
    return widget;
}

EurnDetectedWidget * AbstractFactoryWidget::createEurnDetectedWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    EurnDetectedWidget * widget = new EurnDetectedWidget ( progress );
    return widget;
}

AlarmBoxDetectedWidget * AbstractFactoryWidget::createAlarmBoxDetectedWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    AlarmBoxDetectedWidget * widget = new AlarmBoxDetectedWidget ( progress );
    return widget;
}

AlarmBoxEndDiagnoseWidget * AbstractFactoryWidget::createAlarmBoxEndDiagnoseWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    AlarmBoxEndDiagnoseWidget * widget = new AlarmBoxEndDiagnoseWidget ( progress );
    return widget;
}

EurnEndDiagnoseWidget * AbstractFactoryWidget::createEurnEndDiagnoseWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    EurnEndDiagnoseWidget * widget = new EurnEndDiagnoseWidget ( progress );
    return widget;
}

SmartcardDetectedWidget * AbstractFactoryWidget::createSmartcardDetectedWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    SmartcardDetectedWidget * widget = new SmartcardDetectedWidget ( progress );
    return widget;
}

SmartcardActionsWidget * AbstractFactoryWidget::createSmartcardActionsWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    SmartcardActionsWidget * widget = new SmartcardActionsWidget ( progress );
    return widget;
}

LedStripActionsWidget * AbstractFactoryWidget::createSmartcardLedStripActionsWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    LedStripActionsWidget * widget = new LedStripActionsWidget ( progress );
    return widget;
}

SmartcardPowerWidget * AbstractFactoryWidget::createSmartcardPowerWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    SmartcardPowerWidget * widget = new SmartcardPowerWidget ( progress );
    return widget;
}

VotingMachineInstallationWizardWidget * AbstractFactoryWidget::createVotingMachineInstallationWizardWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    VotingMachineInstallationWizardWidget * widget = new VotingMachineInstallationWizardWidget ( progress );
    return widget;
}

CheckNetworkWidget * AbstractFactoryWidget::createCheckNetworkWidget()
{
    GenericWidget * progress = createGenericWidget();
    CheckNetworkWidget * widget = new CheckNetworkWidget ( progress );
    return widget;
}

SendResultsPackageWidget * AbstractFactoryWidget::createSendResultsPackageWidget()
{
    GenericWidget * progress = createGenericWidget();
    SendResultsPackageWidget * widget = new SendResultsPackageWidget ( progress );
    return widget;
}

AppCalibrationWidget * AbstractFactoryWidget::createAppCalibrationWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    AppCalibrationWidget * widget = new AppCalibrationWidget ( progress );
    return widget;
}

AppCalibrationWidget * AbstractFactoryWidget::createInitialCalibrationWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    AppCalibrationWidget * widget = new AppCalibrationWidget ( progress, true );
    return widget;
}

ExternalPrintWizardWidget * AbstractFactoryWidget::createExternalPrintWizardWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    ExternalPrintWizardWidget * widget = new ExternalPrintWizardWidget ( progress );
    return widget;
}

ReportPrintingVMWidget * AbstractFactoryWidget::createReportPrintingVMWidget()
{
    ProgressWidget * progress = FactoryMethodWidget::createProgressWidget();
    ReportPrintingVMWidget * widget = new ReportPrintingVMWidget ( progress );
    return widget;
}

