/**
 * @file AbstractFactoryWidget.hxx
 * @brief Header class for creating the widget
 * @date 03/11/2011
 * @author Yadickson Soto
 */

#ifndef ABSTRACTFACTORYWIDGET_HXX_
#define ABSTRACTFACTORYWIDGET_HXX_

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                class InstallMachineWidget;
                class AutomaticDiagnosticWidget;
                class InitiatorWidget;
                class ReportInstallWidget;
                class ClosingElectionStatusWidget;
                class CloseElectionStatusWidget;
                class PersistAllResultWidget;
                class BarcodeDetectionWidget;
                class BallotOptionTableWidget;
                class MemoryStateWidget;
                class AuthenticationWidget;
                class OpenElectionStatusWidget;
                class DiagnosisBlockedWidget;
                class DataUtilsValidatorWidget;
                class ReferendumTableWidget;
                class IconShutdownWidget;
                class GenericWidget;
                class GenericPrintingWidget;
                class DeviceDiagnosticPrintWidget;
                class MachineWizardWidget;
                class RemoveUSBWidget;
                class SystemFilesIntegrityCheckWidget;
                class VMInstallationConfirmation;
                class ValidateEmlSignatureWidget;
                class ValidateVotesWidget;
                class AutoBarcodeDiagnosisWidget;
                class AutoPrinterDiagnosisWidget;
                class BarcodeReaderPrintingWidget;
                class BarcodeReaderReconfigureWidget;
                class BarcodeReaderScanWidget;
                class BarcodeReaderDetectedWidget;
                class BarcodeReaderSerialNumberWidget;
                class EurnDetectedWidget;
                class EurnEndDiagnoseWidget;
                class AlarmBoxDetectedWidget;
                class AlarmBoxEndDiagnoseWidget;
                class LedStripActionsWidget;
                class SmartcardDetectedWidget;
                class SmartcardActionsWidget;
                class SmartcardPowerWidget;
                class VotingMachineInstallationWizardWidget;
                class CheckNetworkWidget;
                class SendResultsPackageWidget;
                class AppCalibrationWidget;
                class AppCalibrationWidget;
                class ExternalPrintWizardWidget;
                class ReportPrintingVMWidget;

                /**
                 * @class	AbstractFactoryWidget
                 * @brief	Class for creating the widget.
                 * @author	Yadickson Soto
                 * @date	03/11/2011
                 */
                class AbstractFactoryWidget
                {
                    public:
                        /**
                         * @fn	static InstallMachineWidget * AbstractFactoryWidget::createInstallMachineWidget();
                         * @brief	Method for creating the install machine widget.
                         * @author	Yadickson Soto
                         * @date	03/11/2011
                         * @return	new widget.
                         */
                        static InstallMachineWidget * createInstallMachineWidget();
                        /**
                         * @fn	static AutomaticDiagnosticWidget * AbstractFactoryWidget::createAutomaticDiagnosticWidget();
                         * @brief	Method for creating the automatic diagnostic widget.
                         * @author	Yadickson Soto
                         * @date	03/11/2011
                         * @return	new widget.
                         */
                        static AutomaticDiagnosticWidget * createAutomaticDiagnosticWidget();
                        /**
                         * @fn	static InitiatorWidget * AbstractFactoryWidget::createInitiatorWidget();
                         * @brief	Method for creating the initiator widget.
                         * @author	Yadickson Soto
                         * @date	03/11/2011
                         * @return	new widget.
                         */
                        static InitiatorWidget * createInitiatorWidget();
                        /**
                         * @fn	static ReportInstallWidget * AbstractFactoryWidget::createReportInstallWidget();
                         * @brief	Method for creating the report install widget.
                         * @author	Yadickson Soto
                         * @date	03/11/2011
                         * @return	new widget.
                         */
                        static ReportInstallWidget * createReportInstallWidget();
                        /**
                         * @fn static StartClosingElectionStatusWidget * AbstractFactoryWidget::createClosingElectionStatusWidget();
                         * @brief Method for creating the closing election status widget.
                         * @author eduardo.fernandez
                         * @date   10/12/2018
                         * @return new widget.
                         */
                        static ClosingElectionStatusWidget * createClosingElectionStatusWidget();
                        /**
                         * @fn	static CloseElectionStatusWidget * AbstractFactoryWidget::createCloseElectionStatusWidget();
                         * @brief	Method for creating the close election status widget.
                         * @author	Yadickson Soto
                         * @date	16/02/2012
                         * @return	new widget.
                         */
                        static CloseElectionStatusWidget * createCloseElectionStatusWidget();
                        /**
                         * @fn	static PersistAllResultWidget * AbstractFactoryWidget::createPersistAllResultWidget();
                         * @brief	Method for creating the persist all result widget.
                         * @author	Yadickson Soto
                         * @date	17/02/2012
                         * @return	new widget.
                         */
                        static PersistAllResultWidget * createPersistAllResultWidget();
                        /**
                         * @fn	static BarcodeDetectionWidget * AbstractFactoryWidget::createBarcodeDetectionWidget();
                         * @brief	Method for creating the barcode detection widget.
                         * @author	Yadickson Soto
                         * @date	07/03/2012
                         * @return	new widget.
                         */
                        static BarcodeDetectionWidget * createBarcodeDetectionWidget();
                        /**
                         * @fn	static BallotOptionTableWidget * AbstractFactoryWidget::createBallotOptionTableWidget();
                         * @brief	Method for creating the ballot option table widget.
                         * @author	Yadickson Soto
                         * @date	13/03/2012
                         * @return	ballot option table widget.
                         */
                        static BallotOptionTableWidget * createBallotOptionTableWidget();
                        /**
                         * @fn	static MemoryStateWidget * AbstractFactoryWidget::createMemoryStateWidget();
                         * @brief	Method for creating the memory state widget.
                         * @author	Yadickson Soto
                         * @date	29/03/2012
                         * @return	memory state widget.
                         */
                        static MemoryStateWidget * createMemoryStateWidget();
                        /**
                         * @fn	static AuthenticationWidget * AbstractFactoryWidget::createAuthenticationWidget();
                         * @brief	Method for creating the authentication widget.
                         * @author	Yadickson Soto
                         * @date	31/03/2012
                         * @return	authentication widget.
                         */
                        static AuthenticationWidget * createAuthenticationWidget();
                        /**
                         * @fn	static OpenElectionStatusWidget * AbstractFactoryWidget::createOpenElectionStatusWidget();
                         * @brief	Method for creating the open election status widget.
                         * @author	Yadickson Soto
                         * @date	10/05/2012
                         * @return	new widget.
                         */
                        static OpenElectionStatusWidget * createOpenElectionStatusWidget();
                        /**
                         * @fn	static DiagnosisBlockedWidget * AbstractFactoryWidget::createDiagnosisBlockedWidget();
                         * @brief	Method for creating the diagnosis blocked widget.
                         * @author	Yadickson Soto
                         * @date	12/06/2012
                         * @return	new widget.
                         */
                        static DiagnosisBlockedWidget * createDiagnosisBlockedWidget();
                        /**
                         * @fn	static DataUtilsValidatorWidget * AbstractFactoryWidget::createDataUtilsValidatorWidget();
                         * @brief	Method for creating the data utils validator widget.
                         * @author	Yadickson Soto
                         * @date	24/07/2012
                         * @return	new widget.
                         */
                        static DataUtilsValidatorWidget * createDataUtilsValidatorWidget();
                        /**
                         * @fn	static ReferendumTableWidget * AbstractFactoryWidget::createReferendumTableWidget();
                         * @brief	Method for creating the referendum table widget.
                         * @author	Yadickson Soto
                         * @date	16/10/2012
                         * @return	referendum table widget.
                         */
                        static ReferendumTableWidget * createReferendumTableWidget();
                        /**
                         * @fn	static IconShutdownWidget * AbstractFactoryWidget::createIconShutdownWidget();
                         * @brief	Method for creating the icon shutdown widget.
                         * @author	Yadickson Soto
                         * @date	08/11/2012
                         * @return	icon shutdown widget.
                         */
                        static IconShutdownWidget * createIconShutdownWidget();
                        /**
                         * @fn	static GenericWidget * AbstractFactoryWidget::createGenericWidget();
                         * @brief	Method for creating the generic widget.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @return	new widget.
                         */
                        static GenericWidget * createGenericWidget();
                        /**
                         * @fn	static GenericPrintingWidget * AbstractFactoryWidget::createGenericPrintingWidget();
                         * @brief	Method for creating the generic printing widget.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @return	new widget.
                         */
                        static GenericPrintingWidget * createGenericPrintingWidget();
                        /**
                         * @fn	static DeviceDiagnosticPrintWidget * AbstractFactoryWidget::createDeviceDiagnosticPrintWidget();
                         * @brief	Method for creating the device diagnostic printing widget.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @return	new widget.
                         */
                        static DeviceDiagnosticPrintWidget * createDeviceDiagnosticPrintWidget();
                        /**
                         * @fn	static MachineWizardWidget * AbstractFactoryWidget::createMachineWizardWidget();
                         * @brief	Method for creating the machine wizard widget.
                         * @author	Yadickson Soto
                         * @date	05/12/2012
                         * @return	new widget.
                         */
                        static MachineWizardWidget * createMachineWizardWidget();
                        /**
                         * @fn	static RemoveUSBWidget * createRemoveUSBWidget();
                         * @brief	Method for creating the remove usb widget.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	remove usb widget.
                         */
                        static RemoveUSBWidget * createRemoveUSBWidget();
                        /**
                         * @fn  static SystemFilesIntegrityCheckWidget * createSystemFilesIntegrityCheckWidget();
                         * @brief   Method for creating the system files integrity check widget.
                         * @author  eduardo.fernandez
                         * @date    15/01/2019
                         * @return  system files integrity check widget.
                         */
                        static SystemFilesIntegrityCheckWidget * createSystemFilesIntegrityCheckWidget();
                        /**
                         * @fn	static VMInstallationConfirmation * createVMInstallationConfirmation();
                         * @brief	Method for creating the installation message confirmation widget.
                         * @author	Yadickson Soto
                         * @date	27/05/2013
                         * @return	installation message confirmation widget.
                         */
                        static VMInstallationConfirmation * createVMInstallationConfirmation();
                        /**
                         * @fn	static ValidateEmlSignatureWidget * createValidateEmlSignatureWidget ();
                         * @brief	Method for creating the validate EML signature widget.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         * @return	validate signature widget.
                         */
                        static ValidateEmlSignatureWidget * createValidateEmlSignatureWidget ();
                        /**
                         * @fn	static ValidateVotesWidget * createValidateVotesWidget ();
                         * @brief	Method for creating the validate votes widget.
                         * @author	Yadickson Soto
                         * @date	03/06/2013
                         * @return	validate votes widget.
                         */
                        static ValidateVotesWidget * createValidateVotesWidget ();
                        /**
                         * @fn	static AutoBarcodeDiagnosisWidget * createAutoBarcodeDiagnosisWidget ();
                         * @brief	Method for creating the auto barcode diagnosis widget.
                         * @author	Yadickson Soto
                         * @date	20/06/2013
                         * @return	new widget.
                         */
                        static AutoBarcodeDiagnosisWidget * createAutoBarcodeDiagnosisWidget ();
                        /**
                         * @fn	static AutoPrinterDiagnosisWidget * createAutoPrinterDiagnosisWidget ();
                         * @brief	Method for creating the auto printer diagnosis widget.
                         * @author	Yadickson Soto
                         * @date	20/06/2013
                         * @return	new widget.
                         */
                        static AutoPrinterDiagnosisWidget * createAutoPrinterDiagnosisWidget ();
                        /**
                         * @fn	static BarcodeReaderPrintingWidget * createBarcodeReaderPrintingWidget();
                         * @brief	Method for creating the barcode reader printing widget.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         * @return	new widget.
                         */
                        static BarcodeReaderPrintingWidget * createBarcodeReaderPrintingWidget();
                        /**
                         * @fn	static BarcodeReaderReconfigureWidget * createBarcodeReaderReconfigureWidget();
                         * @brief	Method for creating the barcode reader reconfigure widget.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         * @return	new widget.
                         */
                        static BarcodeReaderReconfigureWidget * createBarcodeReaderReconfigureWidget();
                        /**
                         * @fn	static BarcodeReaderScanWidget * createBarcodeReaderScanWidget()
                         * @brief	Method for creating the barcode reader scan widget.
                         * @author	Yadickson Soto
                         * @date	05/09/2013
                         * @return	new widget.
                         */
                        static BarcodeReaderScanWidget * createBarcodeReaderScanWidget();
                        /**
                         * @fn	static BarcodeReaderDetectedWidget * createBarcodeReaderDetectedWidget();
                         * @brief	Method for creating the barcode reader detected widget.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         * @return	new widget.
                         */
                        static BarcodeReaderDetectedWidget * createBarcodeReaderDetectedWidget();
                        /**
                         * @fn	static BarcodeReaderSerialNumberWidget * createBarcodeReaderSerialNumberWidget();
                         * @brief	Method for creating the widget which sets the serial number of a barcode reader device.
                         * @author	Yadickson Soto
                         * @date	28/01/2014
                         * @return	new widget.
                         */
                        static BarcodeReaderSerialNumberWidget * createBarcodeReaderSerialNumberWidget();
                        /**
                         * @fn	static AlarmBoxDetectedWidget * createAlarmBoxDetectedWidget();
                         * @brief	Method for creating the alarmbox detected widget.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         * @return	new widget.
                         */
                        static AlarmBoxDetectedWidget * createAlarmBoxDetectedWidget();
                        /**
                         * @fn	static EurnDetectedWidget * createEurnDetectedWidget();
                         * @brief	Method for creating the eUrn detected widget.
                         * @author	Juan Valera
                         * @date	07/11/2017
                         * @return	new widget.
                         */
                         static EurnDetectedWidget * createEurnDetectedWidget();
                        /**
                         * @fn	static AlarmBoxEndDiagnoseWidget * createAlarmBoxEndDiagnoseWidget();
                         * @brief	Method for creating the alarmbox end diagnose widget.
                         * @author	Yadickson Soto
                         * @date	09/09/2013
                         * @return	new widget.
                         */
                        static AlarmBoxEndDiagnoseWidget * createAlarmBoxEndDiagnoseWidget();
                        /**
                         * @fn	static EurnEndDiagnoseWidget * createEurnEndDiagnoseWidget();
                         * @brief	Method for creating the eUrn end diagnose widget.
                         * @author	Juan Valera
                         * @date	08/11/2017
                         * @return	new widget.
                         */
                        static EurnEndDiagnoseWidget * createEurnEndDiagnoseWidget();
                        /**
                         * @fn	static SmartcardDetectedWidget * createSmartcardDetectedWidget();
                         * @brief	Method for creating the smartcard reader detected diagnose widget.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	new widget.
                         */
                        static SmartcardDetectedWidget * createSmartcardDetectedWidget();
                        /**
                         * @fn	static SmartcardActionsWidget * createSmartcardActionsWidget();
                         * @brief	Method for creating the smartcard reader write and read diagnose widget.
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         * @return	new widget.
                         */
                        static SmartcardActionsWidget * createSmartcardActionsWidget();
                        /**
                         * @fn	static LedStripActionsWidget * createSmartcardLedStripActionsWidget();
                         * @brief	Method for creating the LED strip for the A4517 SCR diagnose widget.
                         * @author	Marcel Mancini
                         * @date	12/09/2017
                         * @return	new widget.
                         */
                        static LedStripActionsWidget * createSmartcardLedStripActionsWidget();
                        /**
                         * @fn  static SmartcardPowerWidget * createSmartcardPowerWidget();
                         * @brief   Method for creating the smartcard reader power ON/OFF diagnose widget.
                         * @author  Yadickson Soto
                         * @date    12/09/2013
                         * @return  new widget.
                         */
                        static SmartcardPowerWidget * createSmartcardPowerWidget();
                        /**
                         * @fn	static VotingMachineInstallationWizardWidget * createVotingMachineInstallationWizardWidget();
                         * @brief	Method for creating the voting machine install widget.
                         * @author	Yadickson Soto
                         * @date	24/03/2014
                         * @return	new widget.
                         */
                        static VotingMachineInstallationWizardWidget * createVotingMachineInstallationWizardWidget();
                        /**
                         * @fn	static CheckNetworkWidget * createCheckNetworkWidget();
                         * @brief	Method for creating the check network device widget.
                         * @author	Yadickson Soto
                         * @date	08/04/2014
                         * @return	new widget.
                         */
                        static CheckNetworkWidget * createCheckNetworkWidget();
                        /**
                         * @fn	static SendResultsPackageWidget * createSendResultsPackageWidget();
                         * @brief	Method for creating the send results package widget.
                         * @author	Yadickson Soto
                         * @date	07/04/2014
                         * @return	new widget.
                         */
                        static SendResultsPackageWidget * createSendResultsPackageWidget();
                        /**
                         * @fn	static AppCalibrationWidget * createAppCalibrationWidget();
                         * @brief	Method for creating the application calibration widget.
                         * @author	Yadickson Soto
                         * @date	28/05/2015
                         * @return	new widget.
                         */
                        static AppCalibrationWidget * createAppCalibrationWidget();
                        /**
                         * @fn	static AppCalibrationWidget * createInitialCalibrationWidget();
                         * @brief	Method for creating the initial calibration widget.
                         * @author	Yadickson Soto
                         * @date	28/05/2015
                         * @return	new widget.
                         */
                        static AppCalibrationWidget * createInitialCalibrationWidget();

                        /**
                         * @brief  Method for creating an external wizard widget.
                         * @author manuel.arguelles
                         * @date   Jun  7, 2017
                         * @return A new widget.
                         */
                        static ExternalPrintWizardWidget * createExternalPrintWizardWidget();

                        /*
                         * @brief  Method for creating a report printing vm widget.
                         * @author manuel.arguelles
                         * @date   Jun 13, 2017
                         * @return New widget.
                         */
                        static ReportPrintingVMWidget * createReportPrintingVMWidget();
                };
            }
        }
    }
}

#endif /* ABSTRACTFACTORYWIDGET_HXX_ */
