/**
 * @file EndAudioVotingSequenceWidget.hxx
 * @brief Header class end audio voting sequence widget
 * @date 17/11/2017
 * @author Eduardo Fernández
 */

#ifndef ENDAUDIOVOTINGSEQUENCEWIDGET_HXX_
#define ENDAUDIOVOTINGSEQUENCEWIDGET_HXX_

#include <Widgets/StepWidget.hxx>
#include <Widgets/wizard-widget-manager.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {

                    /**
                     * @class	EndAudioVotingSequenceWidget
                     * @brief	class end audio voting sequence widget
                     * @author	Eduardo Fernández
                     * @date	17/11/2017
                     */

                    class EndAudioVotingSequenceWidget : public Smartmatic::GUI::Widgets::StepWidget
                    {
                        public:

                            typedef sigc::signal<void, std::string> SignalPlayAudio;

                            /**
                             * @fn	EndAudioVotingSequenceWidget();
                             * @brief	Default constructor.
                             * @author	Eduardo Fernández
                             * @date	17/11/2017
                             */

                            EndAudioVotingSequenceWidget();

                            /**
                             * @fn	virtual ~EndAudioVotingSequenceWidget();
                             * @brief	Class destructor.
                             * @author	Eduardo Fernández
                             * @date	17/11/2017
                             */
                            virtual ~EndAudioVotingSequenceWidget();
                            /**
                             * @fn	void start();
                             * @brief	method start sequence.
                             * @author	Eduardo Fernández
                             * @date	17/11/2017
                             */
                            void start();
                            /**
                             * @fn	sigc::signal<void> getSignalError();
                             * @brief	method getter signal error.
                             * @author	Eduardo Fernández
                             * @date	17/11/2017
                             * @return	signal error.
                             */
                            sigc::signal<void> getSignalError();
                            /**
                             * @fn  sigc::signal<void, std::string> getSignalPlayAudio;
                             * @brief   method getter signal play audio.
                             * @author  Eduardo Fernández
                             * @date    18/11/2017
                             * @return  signal play audio.
                             */
                            SignalPlayAudio getSignalPlayAudio();

                        protected:

                            /**
                             * @fn	virtual void refresh();
                             * @brief	refresh widget method.
                             * @author	Eduardo Fernández
                             * @date	17/11/2017
                             */
                            virtual void refresh();

                            /**
                             * @fn	virtual void dispose();
                             * @brief	method dispose widget.
                             * @author	Eduardo Fernández
                             * @date	17/11/2017
                             */
                            virtual void dispose();

                            /**
                             * @fn	void endSequence();
                             * @brief	method end sequence.
                             * @author	Eduardo Fernández
                             * @date	17/11/2017
                             */
                            void endSequence();

                            /**
                             * @fn	void errorSequence();
                             * @brief	method error sequence.
                             * @author	Eduardo Fernández
                             * @date	17/11/2017
                             */
                            void errorSequence();

                            /**
                             * @fn  void playAudio();
                             * @brief   method play audio.
                             * @author  Eduardo Fernández
                             * @date    18/11/2017
                             */
                            void playAudio(const std::string& messageKey);

                        private:

                            bool errorDetected; ///< error detected
                            sigc::signal<void> signalError; ///< signal error
                            SignalPlayAudio m_signalPlayAudio; ///< signal play audio
                            Smartmatic::GUI::Widgets::WizardWidgetManager * manager; ///< wizard widgets
                            std::vector < Smartmatic::GUI::Widgets::WizardWidgetBase * > wizardVector; ///< The wizard vector
                            static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                    };

                }
            }
        }
    }
}
#endif /* ENDAUDIOVOTINGSEQUENCEWIDGET_HXX_ */
