/**
 * @file	BallotOptionInfoWidget.hxx
 * @brief	Declares the ballot option info widget class.
 * @author	Yadickson Soto
 * @date	26/02/2014
 */

#ifndef _BALLOT_OPTION_INFO_WIDGET_H_
#define _BALLOT_OPTION_INFO_WIDGET_H_

#include <Widgets/BoxSelectionWidget.hxx>
#include <Voting/Election/election-schema.hxx>
#include <Runtime/Environment/saes-directories.h>
#include <Configuration/voting-experience-configuration-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	BallotOptionInfoWidget
                 * @brief	Ballot option widget.
                 * @author	Yadickson Soto
                 * @date	26/02/2014
                 */

                class BallotOptionInfoWidget: public Smartmatic::GUI::Widgets::BoxSelectionWidget
                {
                    public:
                        /**
                         * @fn	BallotOptionInfoWidget ( const Smartmatic::SAES::Voting::Election::Eligible_option & elegibleOption,
                         *                   Smartmatic::SAES::Runtime::Environment::SaesDirectories & saesDir,
                         *                   bool enableClick, bool showBorder );
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	26/02/2014
                         * @param	elegibleOption	ballot option to be displayed.
                         * @param	saesDir			The saes directory, used to retrieve image files.
                         * @param	enableClick		true to enable click and change selection color.
                         * @param	showBorder		true to show border widget.
                         */
                        BallotOptionInfoWidget ( const Smartmatic::SAES::Voting::Election::Eligible_option & elegibleOption,
                                                 Smartmatic::SAES::Runtime::Environment::SaesDirectories & saesDir,
                                                 bool enableClick, bool showBorder );

                        /**
                         * @fn	virtual ~BallotOptionInfoWidget();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	26/02/2014
                         */
                        virtual ~BallotOptionInfoWidget();

                        /**
                         * @fn	virtual Smartmatic::SAES::Voting::Election::Category getCategory();
                         * @brief	Gets category type of ballot.
                         * @author	Yadickson Soto
                         * @date	26/02/2014
                         * @return	if ballot is principal.
                         */
                        virtual Smartmatic::SAES::Voting::Election::Category getCategory();

                    protected:

                        Smartmatic::SAES::Voting::Election::Ballot_option ballotOption; ///< The ballot option

                        std::string labelFullName; ///< The ballot full name
                        std::string labelNumber; ///< The tally position number

                        std::string imagePath; ///< The full image path file
                        std::string labelFirstName; ///< The ballot first name
                        std::string labelLastName; ///< The ballot last name

                        int numberWidth; ///< The number width configuration value
                        int paddingConfig; ///< The padding configuration value

                        Smartmatic::SAES::Configuration::WidgetDisplayType displayConfig; ///< The display configuration value
                };
            }
        }
    }
}

#endif // _BALLOT_OPTION_WIDGET_H_
