/**
 * @file BallotOptionTableWidget.hxx
 * @brief Header class ballot option table widget
 * @date 15/03/2012
 * @author Yadickson Soto
 */

#ifndef BALLOTOPTIONTABLEWIDGET_HXX_
#define BALLOTOPTIONTABLEWIDGET_HXX_

#include <gtkmm.h>
#include <Voting/Election/election-schema.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/TableBoxSelectionWidget.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                class FillTableWidget;

                /**
                 * @class	BallotOptionTableWidget
                 * @brief	Class BallotOptionTableWidget.
                 * @author	Yadickson Soto
                 * @date	15/03/2012
                 */
                class BallotOptionTableWidget : public Smartmatic::GUI::Widgets::SmartmaticBasicEventBox
                {
                    public:
                        /**
                         * @fn	BallotOptionTableWidget::BallotOptionTableWidget ( FillTableWidget * fillTableWidget );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	15/03/2012
                         * @param	fillTableWidget	fill mode table widget.
                         */
                        explicit BallotOptionTableWidget ( FillTableWidget * fillTableWidget );
                        /**
                         * @fn	virtual BallotOptionTableWidget::~BallotOptionTableWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	15/03/2012
                         */
                        virtual ~BallotOptionTableWidget();
                        /**
                         * @fn	void BallotOptionTableWidget::addPrincipal ( Smartmatic::GUI::Widgets::ISizeWidget * ballotOptionWidget );
                         * @brief	method add principal.
                         * @author	Yadickson Soto
                         * @date	15/03/2012
                         * @param [in,out]	ballotOptionWidget	If non-null, the ballot option widget.
                         */
                        void addPrincipal ( Smartmatic::GUI::Widgets::ISizeWidget * ballotOptionWidget );
                        /**
                         * @fn	void BallotOptionTableWidget::addStandIn ( Smartmatic::GUI::Widgets::ISizeWidget * ballotOptionWidget );
                         * @brief	method add stand in.
                         * @author	Yadickson Soto
                         * @date	15/03/2012
                         * @param	ballotOptionWidget	new widget.
                         */
                        void addStandIn ( Smartmatic::GUI::Widgets::ISizeWidget * ballotOptionWidget );
                        /**
                         * @fn	void BallotOptionTableWidget::fill ( Smartmatic::SAES::Voting::Election::Contest * contest,
                         * 			int totalW, int totalH );
                         * @brief	method fill table.
                         * @author	Yadickson Soto
                         * @date	16/03/2012
                         * @param	contest	contest info.
                         * @param	totalW 	total width.
                         * @param	totalH 	total height.
                         */
                        void fill ( Smartmatic::SAES::Voting::Election::Contest * contest, int totalW, int totalH );
                        /**
                         * @fn	void BallotOptionTableWidget::clear();
                         * @brief	method clear.
                         * @author	Yadickson Soto
                         * @date	15/03/2012
                         */
                        void clear();
                        /**
                         * @fn	void BallotOptionTableWidget::update();
                         * @brief	method update.
                         * @author	Yadickson Soto
                         * @date	15/03/2012
                         */
                        void update();
                        /**
                         * @fn	void clearSelections();
                         * @brief	Clear selections items.
                         * @author	Yadickson Soto
                         * @date	25/02/2014
                         */
                        void clearSelections();
                        /**
                         * @fn Smartmatic::GUI::Widgets::TableBoxSelectionWidget * getTableWidget();
                         * @brief Gets table box selection widget
                         * @date 25/02/2014
                         * @author Yadickson Soto
                         * @return table box selection widget
                         */
                        Smartmatic::GUI::Widgets::TableBoxSelectionWidget * getTableWidget();

                    protected:
                        FillTableWidget * fillTableWidget; ///< fill table mode widget
                };
            }
        }
    }
}

#endif /* BALLOTOPTIONTABLEWIDGET_HXX_ */
