/**
 * @file DataUtilsValidatorWidget.hxx
 * @brief Header class data util validator
 * @date 24/07/2012
 * @author Yadickson Soto
 */

#ifndef DATAUTILSVALIDATORWIDGET_HXX_
#define DATAUTILSVALIDATORWIDGET_HXX_

#include <Widgets/StepWidget.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	DataUtilsValidatorWidget
                 * @brief	Data utilities validator widget.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class DataUtilsValidatorWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:
                        /**
                         * @fn	DataUtilsValidatorWidget::DataUtilsValidatorWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget );
                         * @brief	Constructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param [in,out]	progressWidget	If non-null, the progress widget.
                         */
                        explicit DataUtilsValidatorWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget );
                        /**
                         * @fn	virtual DataUtilsValidatorWidget::~DataUtilsValidatorWidget();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        virtual ~DataUtilsValidatorWidget();

                        /**
                         * @fn	void DataUtilsValidatorWidget::showProgress ( std::string center, int current, int total );
                         * @brief	Shows the progress.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	center 	The center.
                         * @param	current	The current.
                         * @param	total	 	Number of.
                         */
                        void showProgress ( std::string center, int current, int total );
                        /**
                         * @fn	void DataUtilsValidatorWidget::showError ( std::string key );
                         * @brief	Shows the error.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	key	The key.
                         */
                        void showError ( std::string key );
                        /**
                         * @fn	void DataUtilsValidatorWidget::showValidateFiles();
                         * @brief	Shows validate files
                         * @author	Yadickson Soto
                         * @date	02/11/2012
                         */
                        void showValidateFiles ( );
                        /**
                         * @fn	void DataUtilsValidatorWidget::showStatusValidateFiles ( bool status )
                         * @brief	Shows status validate files
                         * @param status status to show
                         * @author	Yadickson Soto
                         * @date	02/11/2012
                         */
                        void showStatusValidateFiles ( bool status );
                        /**
                         * @fn	void DataUtilsValidatorWidget::showProgress();
                         * @brief	Shows the init progress.
                         * @author	Yadickson Soto
                         * @date	02/11/2012
                         */
                        void showProgress ( );

                    protected:

                        /**
                          * @fn	void DataUtilsValidatorWidget::onSignalEnd();
                          * @brief	Method on signal end
                          * @author	Yadickson Soto
                          * @date	06/11/2012
                          */
                        void onSignalEnd ( );

                    private:

                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget; ///< progress widget
                };
            }
        }
    }
}

#endif /* DATAUTILSVALIDATORWIDGET_HXX_ */
