/**
 * @file	DeviceMonitorWidget.cxx
 * @brief	device monitor result widget class.
 * @author	Yadickson Soto
 * @date	13/12/2012
 */

#include "DeviceMonitorWidget.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/ImageResourcePath.hxx>
#include <Runtime/Environment/MemoryPathController.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Operation;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Runtime::Environment;

ISMTTLog * DeviceMonitorWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.DeviceMonitorWidget", GETTEXT_PACKAGE );

DeviceMonitorWidget::DeviceMonitorWidget ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * device, int width, int height )
    : StepWidget()
{
    this->showFlag = false;
    this->device = device;
    this->width = width;
    this->height = height;
    this->image = NULL;
    this->initialize();
    setWidget ( image );
}

DeviceMonitorWidget::~DeviceMonitorWidget()
{
    dispose();
}

void DeviceMonitorWidget::initialize()
{
    dispose();
    image = new Gtk::Image ();
    image->set_size_request ( width, height );
}

void DeviceMonitorWidget::dispose()
{
    this->remove();

    if ( image )
    {
        delete image;
        image = NULL;
    }
}

Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * DeviceMonitorWidget::getDeviceTypeMonitor()
{
    return device;
}

void DeviceMonitorWidget::update()
{
    std::string iconFile;
    bool con = device->getNumberOfDevices() != 0;

    switch ( device->getType() )
    {
        case DeviceType::CONFIGURATION_BARCODE:
            iconFile = ImageResourcePath::getPath ( con ? ImageResourcePath::BARCODE_CONNECTED : ImageResourcePath::BARCODE_DISCONNECTED );
            break;

        case DeviceType::CONFIGURATION_PRINTER:
            iconFile = ImageResourcePath::getPath ( con ? ImageResourcePath::PRINTER_CONNECTED : ImageResourcePath::PRINTER_DISCONNECTED );
            break;

        case DeviceType::CONFIGURATION_SMARTCARD:
            iconFile = ImageResourcePath::getPath ( con ? ImageResourcePath::SMARTCARD_CONNECTED : ImageResourcePath::SMARTCARD_DISCONNECTED );
            break;

        case DeviceType::CONFIGURATION_FLASH:
            con = con && MemoryPathController::getInstance()->isAllDevices();
            iconFile = ImageResourcePath::getPath ( con ? ImageResourcePath::FLASH_CONNECTED : ImageResourcePath::FLASH_DISCONNECTED );
            break;

        case DeviceType::CONFIGURATION_ETHERNET:
            iconFile = ImageResourcePath::getPath ( con ? ImageResourcePath::ETHERNET_CONNECTED : ImageResourcePath::ETHERNET_DISCONNECTED );
            break;

        case DeviceType::CONFIGURATION_MOUSE:
            iconFile = ImageResourcePath::getPath ( con ? ImageResourcePath::MOUSE_CONNECTED : ImageResourcePath::MOUSE_DISCONNECTED );
            break;

        case DeviceType::CONFIGURATION_USBSTORAGEMOUNTED:

            if ( device->getNumberOfDevices() == 1 )
            {
                iconFile = ImageResourcePath::getPath ( ImageResourcePath::ONE_USB_CONNECTED );
            }
            else if ( device->getNumberOfDevices() >= 2 )
            {
                iconFile = ImageResourcePath::getPath ( ImageResourcePath::TWO_USB_CONNECTED );
            }
            else
            {
                iconFile = ImageResourcePath::getPath ( ImageResourcePath::TWO_USB_DISCONNECTED );
            }

            break;

        case DeviceType::CONFIGURATION_EURN:
            iconFile = ImageResourcePath::getPath ( con ? ImageResourcePath::SMARTCARD_CONNECTED : ImageResourcePath::SMARTCARD_DISCONNECTED );
            break;

        case DeviceType::CONFIGURATION_ALARMBOX:
        case DeviceType::CONFIGURATION_TOUCHSCREENCALIBRATION:
        case DeviceType::CONFIGURATION_P168A:
        case DeviceType::CONFIGURATION_KEYBOARD:
        case DeviceType::CONFIGURATION_ABLED:
        case DeviceType::CONFIGURATION_UNKNOWN:
        default:
            break;
    }

    try
    {
        pixbuf = Gdk::Pixbuf::create_from_file ( iconFile );
        pixbuf = pixbuf->scale_simple ( width, height, Gdk::INTERP_HYPER );
        image->set ( pixbuf );
    }
    catch ( ... )
    {

    }
}

void DeviceMonitorWidget::showWidget ( bool show )
{
    this->showFlag = show;
    this->set_visible ( show );
}

bool DeviceMonitorWidget::isShowWidget()
{
    return showFlag;
}
