/**
 * @file	AlarmBoxActionsWidget.hxx
 * @brief	Declares the alarm box actions diagnosis widget class.
 * @author	Yadickson Soto
 * @date	06/09/2013
 */

#ifndef _ALARM_BOX_ACTIONS_WIDGET_H_
#define _ALARM_BOX_ACTIONS_WIDGET_H_

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include <Gui/Widgets/Diagnose/AlarmBoxEndDiagnoseWidget.hxx>
#include <Gui/Widgets/Diagnose/AlarmBoxDiagnoseStepWidget.hxx>
#include <Widgets/SmartmaticBasicFrame.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <Widgets/smartmatic-button.h>
#include <Operation/Devices/Polling/AlarmPolling.hxx>
#include <set>
#include <System/SafeThread.hxx>
#include <System/SafeDispatcher.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	AlarmBoxActionsWidget
                 * @brief	Alarm box actions diagnosis widget.
                 * @author	Yadickson Soto
                 * @date	06/09/2013
                 */

                class AlarmBoxActionsWidget: public BasicDiagnosticWidget, private Smartmatic::System::SafeThread
                {
                    public:

                        /**
                         * @fn	AlarmBoxActionsWidget::AlarmBoxActionsWidget ();
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        AlarmBoxActionsWidget ();

                        /**
                         * @fn	virtual ~AlarmBoxActionsWidget();
                         * @brief	Destroy.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        virtual ~AlarmBoxActionsWidget();

                        /**
                         * @fn	void AlarmBoxActionsWidget::initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        void initialize();
                        /**
                         * @fn	virtual void dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        virtual void dispose();

                    private:

                        /**
                         * @fn	enum ButtonStateTest
                         * @brief	Button action ON or OFF
                         * @author	Yadickson Soto
                         * @date	09/09/2013
                         */
                        enum ButtonStateTest
                        {
                            ON,
                            OFF
                        };

                        int timeOk;   ///< The time diagnose successfully
                        int timeFail;   ///< The time diagnose fail

                        Smartmatic::GUI::Widgets::SmartmaticBasicFrame * frame; ///< The principal frame
                        Gtk::Alignment * alignment; ///< The principal container of labels and buttons

                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox * vboxOptions; ///< The vbox container

                        Smartmatic::GUI::Widgets::SmartmaticButton * buttonBuzzer; ///< Button buzzer test
                        Smartmatic::GUI::Widgets::SmartmaticButton * buttonRedLed; ///< Button red led test
                        Smartmatic::GUI::Widgets::SmartmaticButton * buttonGreenLed; ///< Button green led test
                        Smartmatic::GUI::Widgets::SmartmaticBasicFrame * colorFrame; ///< The color frame
                        Smartmatic::GUI::Widgets::SmartmaticBasicEventBox * colorBox; ////< Color box

                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * instructionLabel; ///< Press button instruction

                        Gdk::Color oneColor;
                        Gdk::Color twoColor;

                        bool showBuzzerButton; ///< flag show buzzer button test
                        bool showRedLedButton; ///< flag show red led button test
                        bool showGreenLedButton; ///< flag show red led button test

                        Smartmatic::SAES::GUI::Widgets::AlarmBoxDiagnoseStepWidget * buzzerOption; ///< buzzer test
                        Smartmatic::SAES::GUI::Widgets::AlarmBoxDiagnoseStepWidget * redLedOption; ///< red led test
                        Smartmatic::SAES::GUI::Widgets::AlarmBoxDiagnoseStepWidget * greenLedOption; ///< green led test
                        Smartmatic::SAES::GUI::Widgets::AlarmBoxDiagnoseStepWidget * buttonOption; ///< button test

                        Smartmatic::SAES::GUI::Widgets::AlarmBoxEndDiagnoseWidget * endWidget; ///< End widget

                        ButtonStateTest buzzerState; ///< The buzzer state
                        ButtonStateTest redLedState; ///< The red led state
                        ButtonStateTest greenLedState; ///< The green led state
                        ButtonStateTest buttonState; ///< The button state

                        unsigned int periodBuzzer; ///< Period buzzer configuration
                        unsigned int periodRedLed; ///< Period red led configuration
                        unsigned int periodGreenLed; ///< Period green led configuration

                        sigc::connection connAlarm; /// The alarm connection signal
                        sigc::connection connOk; ///< The connection signal dispatcher ok
                        sigc::connection connError; ///< The connection signal dispatcher error

                        Smartmatic::System::SafeDispatcher signalEnableButtons; ///< The signal to enabled buttons
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger

                        /**
                         * @fn	void AlarmBoxActionsWidget::onButtonPressed ( Smartmatic::SAES::Operation::Devices::AlarmPolling::AlarmButtonStatus status );
                         * @brief	Box button pressed.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         * @param status
                         */
                        void onButtonPressed ( Smartmatic::SAES::Operation::Devices::AlarmPolling::AlarmButtonStatus status );

                        /**
                         * @fn	void onRedLedAction ();
                         * @brief	Action ON or OFF Red Led.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        void onRedLedAction ();

                        /**
                         * @fn	void onGreenLedAction ();
                         * @brief	Action ON or OFF Green Led.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        void onGreenLedAction ();

                        /**
                         * @fn	void onBuzzerAction ();
                         * @brief	Action ON or OFF Buzzer.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        void onBuzzerAction ();

                        /**
                         * @fn	void validate();
                         * @brief	Validate if running all test in true.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        void validate();

                        /**
                         * @fn	void end();
                         * @brief	End test diagnostic.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        void end();

                        /**
                         * @fn	void error();
                         * @brief	End test diagnostic fail.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        void error();

                        /**
                         * @fn	void viewSuccess();
                         * @brief	View diagnose successfully
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        void viewSuccess();

                        /**
                         * @fn	void viewCancel();
                         * @brief	View diagnose failed
                         * @author	Yadickson Soto
                         * @date	12/09/2013
                         */
                        void viewCancel();

                        /**
                         * @fn	    virtual bool process ();
                         * @brief	Callback from thread only one time. Send command in background
                         * @author	Yadickson Soto
                         * @date	07/06/2015
                         * @return always false
                         */
                        virtual bool process ();

                        /**
                         * @fn	    void onRawObject ( void * object );
                         * @brief	Callback when emit sync signal.
                         * @author	Yadickson Soto
                         * @date	03/08/2015
                         * @param 	object The object to process
                         */
                        void onRawObject ( void * object );

                        /**
                         * @fn	    void setStatus();
                         * @brief	End diagnoses to set status result.
                         * @author	Yadickson Soto
                         * @date	03/08/2015
                         */
                        void setStatus();
                };
            }
        }
    }
}

#endif // _ALARM_BOX_ACTIONS_WIDGET_H_
