/**
 * @file	AlarmBoxDetectedWidget.hxx
 * @brief	Declares the alarm box detected device widget class.
 * @author	Yadickson Soto
 * @date	06/09/2013
 */


#ifndef _ALARM_BOX_DETECTED_WIDGET_H_
#define _ALARM_BOX_DETECTED_WIDGET_H_

#include <Widgets/wizard-widget-base.h>
#include <Gui/Widgets/ProgressWidget.hxx>
#include <System/SafeThread.hxx>
#include <System/SafeDispatcher.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	AlarmBoxDetectedWidget
                 * @brief	Alarm box detected widget.
                 * @author	Yadickson Soto
                 * @date	06/09/2013
                 */

                class AlarmBoxDetectedWidget: public Smartmatic::GUI::Widgets::WizardWidgetBase, private Smartmatic::System::SafeThread
                {
                    public:

                        /**
                         * @fn	AlarmBoxDetectedWidget::AlarmBoxDetectedWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * widget );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         * @param 	widget the visual container
                         */
                        explicit AlarmBoxDetectedWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * widget );

                        /**
                         * @fn	AlarmBoxDetectedWidget::~AlarmBoxDetectedWidget();
                         * @brief	Destroy.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        virtual ~AlarmBoxDetectedWidget();

                        /**
                         * @fn	void AlarmBoxDetectedWidget::initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        void initialize();

                    private:

                        int timeOK; ///< Timeout end alarmbox detected successfully
                        int timeFail; ///< Timeout end alarmbox detected fail

                        Smartmatic::System::SafeDispatcher signalEndDetected; ///< The signal end detected alarm box

                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * widget; ///< The visual container

                    protected:

                        /**
                         * @fn	    virtual bool process ();
                         * @brief	Callback from thread one time. Start detection Alarmbox
                         * @author	Yadickson Soto
                         * @date	07/06/2015
                         * @return false always
                         */
                        virtual bool process ();

                        /**
                         * @fn	    void onRawObject ( void * object );
                         * @brief	Callback when emit sync signal.
                         * @author	Yadickson Soto
                         * @date	23/07/2015
                         * @param 	object The object to process
                         */
                        void onRawObject ( void * object );

                        /**
                         * @fn	void AlarmBoxDetectedWidget::error();
                         * @brief	End test diagnostic fail.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        void error();
                };
            }
        }
    }
}

#endif // _ALARM_BOX_DETECTED_WIDGET_H_
