/*
 * AlarmBoxDiagnoseStepWidget.cxx
 *
 *  Created on: 16/10/2013
 *      Author: soto
 */

#include "AlarmBoxDiagnoseStepWidget.hxx"
#include <Environment/Configurations/resource-path-provider.h>
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define STRING_OK "OK"
#define STRING_NOK "NOK"

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::Environment;
using namespace Smartmatic::Log;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;

ISMTTLog * AlarmBoxDiagnoseStepWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.AlarmBoxDiagnoseStepWidget", GETTEXT_PACKAGE );

AlarmBoxDiagnoseStepWidget::AlarmBoxDiagnoseStepWidget ( Gtk::Widget * container )
    : StepWidget ()
{
    Glib::RefPtr<Gtk::Builder> builder;
    std::string gladeFile = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/AlarmBoxDiagnoseStepWidget.glade" );

    try
    {
        builder = Gtk::Builder::create_from_file ( gladeFile );
    }
    catch ( const Glib::FileError & ex )
    {
        logger->Debug ( "FATAL - AlarmBoxDiagnoseStepWidget Initialize" );
    }

    builder->get_widget_derived ( "main-frame", mainFrame );
    builder->get_widget_derived ( "vbox", vbox );
    builder->get_widget_derived ( "hbox", hbox );
    builder->get_widget_derived ( "image", image );
    builder->get_widget_derived ( "label-container", textContainer );
    builder->get_widget_derived ( "label-options", textOptions );
    builder->get_widget_derived ( "frame-container", frameContainer );
    builder->get_widget_derived ( "hbox-options", buttonGroup );


    if ( container )
    {
        frameContainer->add ( *container );
        frameContainer->show_all_children();
    }

    Smartmatic::SAES::Configuration::AlarmBoxDiagnosisConfiguration & config ( SAESGUIConfigurationManager::getInstance()->getAlarmBoxDiagnosisConfiguration() );

    textContainer->set_size_request ( config.getWidthFirstColumn(), -1 );

    nokOption = new SmartmaticRadioButton ( STRING_NOK, STRING_NOK );
    okOption = new SmartmaticRadioButton ( STRING_OK, STRING_OK );
    dummyOption = new SmartmaticRadioButton ( "", "" );

    buttonGroup->addRadioButton ( nokOption );
    buttonGroup->addRadioButton ( okOption );
    buttonGroup->addRadioButton ( dummyOption );

    dummyOption->set_child_visible ( false );

    buttonGroup->getSignalChange().connect ( sigc::mem_fun ( *this, &AlarmBoxDiagnoseStepWidget::onSignalChange ) );

    clearOption();

    setWidget ( mainFrame );
}

AlarmBoxDiagnoseStepWidget::~AlarmBoxDiagnoseStepWidget()
{
    remove();

    if ( mainFrame )
    {
        delete mainFrame;
        mainFrame = NULL;
    }

    if ( hbox )
    {
        delete hbox;
        hbox = NULL;
    }

    if ( vbox )
    {
        delete vbox;
        vbox = NULL;
    }

    if ( image )
    {
        delete image;
        image = NULL;
    }

    if ( textContainer )
    {
        delete textContainer;
        textContainer = NULL;
    }

    if ( textOptions )
    {
        delete textOptions;
        textOptions = NULL;
    }

    if ( frameContainer )
    {
        delete frameContainer;
        frameContainer = NULL;
    }

    if ( buttonGroup )
    {
        // buttonGroup, inside delete all radio button

        delete buttonGroup;
        buttonGroup = NULL;
    }
}

void AlarmBoxDiagnoseStepWidget::setLabelConfiguration ( LabelConfiguration & labelConf )
{
    LabelConfiguration::SetLabelConfiguration ( textContainer, labelConf );
    LabelConfiguration::SetLabelConfiguration ( textOptions, labelConf );

    okOption->setFontSize ( labelConf.GetSize() );
    nokOption->setFontSize ( labelConf.GetSize() );
}

void AlarmBoxDiagnoseStepWidget::setTextConteiner ( const std::string & textContainer )
{
    this->textContainer->set_text ( textContainer );
}

void AlarmBoxDiagnoseStepWidget::setTextOptions ( const std::string & textOptions, const std::string & textOk, const std::string & textNOk )
{
    this->textOptions->set_text ( textOptions );
    this->okOption->setName ( textOk );
    this->nokOption->setName ( textNOk );
}

void AlarmBoxDiagnoseStepWidget::setSensitive ( bool sensitiveOk, bool sensitiveNOk )
{
    this->okOption->set_sensitive ( sensitiveOk );
    this->nokOption->set_sensitive ( sensitiveNOk );
}

void AlarmBoxDiagnoseStepWidget::clearOption()
{
    image->set_child_visible ( false );
    image->set ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, ( "ui/result-error.png" ) ) );

    buttonGroup->clearAll();

    dummyOption->set_active ( true );

    buttonGroup->start();
}

bool AlarmBoxDiagnoseStepWidget::getOption()
{
    return okOption->get_active();
}

bool AlarmBoxDiagnoseStepWidget::isCheck()
{
    return okOption->get_active() || nokOption->get_active();
}

void AlarmBoxDiagnoseStepWidget::viewOptions ( bool view )
{
    hbox->set_no_show_all();
    hbox->set_visible ( view );
}

void AlarmBoxDiagnoseStepWidget::onSignalChange ( Smartmatic::GUI::Widgets::SmartmaticRadioButton * radioButton )
{
    if ( radioButton->getCode() == STRING_OK )
    {
        image->set_child_visible ( true );
        image->set ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, ( "ui/result-ok.png" ) ) );
    }
    else
    {
        image->set_child_visible ( true );
        image->set ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, ( "ui/result-error.png" ) ) );
    }

    signalChange.emit();
}

sigc::signal<void> AlarmBoxDiagnoseStepWidget::getSignalChange()
{
    return signalChange;
}
