/**
 * @file	AppCalibrationWidget.hxx
 * @brief	Declares the call and wait from application for calibration.
 * @author	Yadickson Soto
 * @date	28/05/2015
 */

#ifndef _APP_CALIBRATION_WIDGET_H_
#define _APP_CALIBRATION_WIDGET_H_

#include <Widgets/StepWidget.hxx>
#include <Log/ISMTTLog.h>
#include <Operation/Diagnosis/CalibrationDiagnosis.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	AppCalibrationWidget
                 * @brief	Calibration diagnosis widget.
                 * @author	Yadickson Soto
                 * @date	28/05/2015
                 */

                class AppCalibrationWidget: public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:

                        /**
                         * @fn	AppCalibrationWidget::AppCalibrationWidget ( ProgressWidget * progress, bool skipConditional = false );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	28/05/2015
                         * @param	progress widget to show messages and progress image animation
                         * @param	skipConditional Skip calibration if file "skip-calibration-tool" if present
                         */
                        AppCalibrationWidget ( ProgressWidget * progress, bool skipConditional = false );

                        /**
                         * @fn	virtual AppCalibrationWidget::~AppCalibrationWidget();
                         * @brief	Class destroyer.
                         * @author	Yadickson Soto
                         * @date	28/05/2015
                         */
                        virtual ~AppCalibrationWidget();

                        /**
                         * @fn	bool calibrate();
                         * @brief	Call gCal calibration.
                         * @author	Yadickson Soto
                         * @date	28/05/2015
                         * @return always false, execute one time
                         */
                        bool calibrate();

                    protected:

                        /**
                         * @fn	void onEndCalibration();
                         * @brief	Callback to end gCal calibration.
                         * @author	Yadickson Soto
                         * @date	28/05/2015
                         */
                        void onEndCalibration();

                    private:

                        ProgressWidget * progress; ///< The frame to show wait save calibration
                        Smartmatic::SAES::Operation::Diagnosis::CalibrationDiagnosis * diagnostic; ///< The calibration tool
                        unsigned int timeOut; ///< The Timeout to wait save calibration
                        static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                };
            }
        }
    }
}

#endif // _APP_CALIBRATION_WIDGET_H_
