/**
 * @file	AutoDiagnosisBaseWidget.hxx
 * @brief	automatic diagnostic widget class.
 * @author	Yadickson Soto
 * @date	20/06/2013
 */

#ifndef AUTODIAGNOSTICWIDGET_HXX_
#define AUTODIAGNOSTICWIDGET_HXX_

#include <Gui/Widgets/ProgressWidget.hxx>
#include <Operation/Diagnosis/IDiagnosis.hxx>
#include <Widgets/wizard-widget-base.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	AutoDiagnosisBaseWidget
                 * @brief	Automatic diagnostic widget.
                 * @author	Yadickson Soto
                 * @date	20/06/2013
                 */
                class AutoDiagnosisBaseWidget : public Smartmatic::GUI::Widgets::WizardWidgetBase
                {
                    public:
                        /**
                         * @fn	AutoDiagnosisBaseWidget::AutoDiagnosisBaseWidget ( ProgressWidget * progress );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	20/06/2013
                         * @param [in,out]	progress	If non-null, the progress.
                         */
                        explicit AutoDiagnosisBaseWidget ( ProgressWidget * progress );
                        /**
                         * @fn	virtual AutoDiagnosisBaseWidget::~AutoDiagnosisBaseWidget();
                         * @brief	Destructor.
                         * @author	Yadickson Soto
                         * @date	20/06/2013
                         */
                        virtual ~AutoDiagnosisBaseWidget();
                        /**
                         * @fn	virtual std::string AutoDiagnosisBaseWidget::getTitleText();
                         * @brief	virtual method getter title.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @return	title.
                         */
                        virtual std::string getTitleText();

                        /**
                         * @fn	virtual void AutoDiagnosisBaseWidget::initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	20/06/2013
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void AutoDiagnosisBaseWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void dispose();

                    protected:

                        /**
                         * @fn	void AutoDiagnosisBaseWidget::end();
                         * @brief	End diagnostic.
                         * @author	Yadickson Soto
                         * @date	20/06/2013
                         */
                        void end();

                        /**
                         * @fn	virtual void firstMessage();
                         * @brief	Show initialize diagnosis message.
                         * @author	Yadickson Soto
                         * @date	20/06/2013
                         */
                        virtual void firstMessage();

                        /**
                         * @fn	virtual void runningMessage();
                         * @brief	Show running diagnosis message.
                         * @author	Yadickson Soto
                         * @date	20/06/2013
                         */
                        virtual void runningMessage();

                        /**
                         * @fn	virtual void test();
                         * @brief	Show running diagnosis.
                         * @author	Yadickson Soto
                         * @date	20/06/2013
                         */
                        virtual void test();

                        /**
                         * @fn	virtual void showResult();
                         * @brief	Show result diagnosis.
                         * @author	Yadickson Soto
                         * @date	20/06/2013
                         */
                        virtual void showResult();

                        Smartmatic::SAES::Operation::Diagnosis::IDiagnosis * diagnostic; ///< diagnostic interface
                        ProgressWidget * progress;	///< The progress

                    private:

                        sigc::connection conn; ///< signal end diagnosis
                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/
                };
            }
        }
    }
}

#endif /* AUTODIAGNOSTICWIDGET_HXX_ */
