/**
 * @file	AutomaticDiagnosticWidget.hxx
 * @brief	automatic diagnostic widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef AUTOMATICDIAGNOSTICWIDGET_HXX_
#define AUTOMATICDIAGNOSTICWIDGET_HXX_

#include <Gui/Widgets/ProgressWidget.hxx>
#include "DiagnosticResultWidget.hxx"
#include "DiagnosisBlockedWidget.hxx"
#include <vector>
#include <Operation/Diagnosis/IDiagnosis.hxx>
#include <Widgets/StepWidget.hxx>
#include <Configuration/SaesGUIConfiguration-schema.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	AutomaticDiagnosticWidget
                 * @brief	Automatic diagnostic widget.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class AutomaticDiagnosticWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:
                        /**
                         * @fn	AutomaticDiagnosticWidget::AutomaticDiagnosticWidget ( ProgressWidget * progress );
                         * @brief	Constructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param [in,out]	progress	If non-null, the progress.
                         */
                        explicit AutomaticDiagnosticWidget ( ProgressWidget * progress );
                        /**
                         * @fn	virtual AutomaticDiagnosticWidget::~AutomaticDiagnosticWidget();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        virtual ~AutomaticDiagnosticWidget();

                        /**
                         * @fn	void AutomaticDiagnosticWidget::start();
                         * @brief	Starts this object.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void start();
                        /**
                         * @fn	virtual std::string AutomaticDiagnosticWidget::getTitleText();
                         * @brief	virtual method getter title.
                         * @author	Yadickson Soto
                         * @date	30/03/2012
                         * @return	title.
                         */
                        virtual std::string getTitleText();

                    protected:

                        /**
                         * @fn	void AutomaticDiagnosticWidget::block();
                         * @brief	Blocks this object.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void block();

                        /**
                         * @fn	void AutomaticDiagnosticWidget::unblock();
                         * @brief	Unblocks this object.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void unblock();

                        /**
                         * @fn	void AutomaticDiagnosticWidget::end();
                         * @brief	Ends this object.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void end();

                        /**
                         * @fn  virtual void AutomaticDiagnosticWidget::initialize();
                         * @brief Initializer method.
                         * @author  Yadickson Soto
                         * @date  08/03/2012
                        */
                        virtual void initialize();
                        /**
                         * @fn	virtual void AutomaticDiagnosticWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void dispose();

                        /**
                         * @fn	void AutomaticDiagnosticWidget::diagnostic();
                         * @brief	Diagnostics this object.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void diagnostic();
                        /**
                         * @fn	void AutomaticDiagnosticWidget::nextPage();
                         * @brief	Next page.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void nextPage();
                        /**
                         * @fn	void AutomaticDiagnosticWidget::checkEndDiagnosis();
                         * @brief	Check end diagnosis.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void checkEndDiagnosis();
                        /**
                         * @fn	void AutomaticDiagnosticWidget::showMessage();
                         * @brief	Shows the message.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void showMessage();
                        /**
                         * @fn	void AutomaticDiagnosticWidget::showResult();
                         * @brief	Shows the result.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void showResult();

                    private:

                        /**
                         * @fn	void firstMessage();
                         * @brief	Show initialize diagnosis message.
                         * @author	Yadickson Soto
                         * @date	17/06/2013
                         */
                        void firstMessage();

                        /**
                         * @fn	void runningMessage();
                         * @brief	Show running diagnosis message.
                         * @author	Yadickson Soto
                         * @date	17/06/2013
                         */
                        void runningMessage();

                        /**
                         * @fn	void test();
                         * @brief	Show running diagnosis.
                         * @author	Yadickson Soto
                         * @date	17/06/2013
                         */
                        void test();

                        /**
                         * @fn  void AutomaticDiagnosticWidget::onSignalBlock();
                         * @brief Signal block handler.
                         * @author  eduardo.fernandez
                         * @date  09/08/2017
                         */
                        void onSignalBlock();

                         /**
                          * @fn  void AutomaticDiagnosticWidget::onSignalResume();
                          * @brief Signal resume handler.
                          * @author  eduardo.fernandez
                          * @date  07/08/2017
                          */
                         void onSignalResume();

                         /**
                          * @fn  void AutomaticDiagnosticWidget::connectMemorySignals();
                          * @brief Connects the memory signals.
                          * @author  eduardo.fernandez
                          * @date  10/08/2017
                          */
                         void connectMemorySignals();

                         /**
                          * @fn  void AutomaticDiagnosticWidget::disconnectMemorySignals();
                          * @brief Disconnects the memory signals.
                          * @author  eduardo.fernandez
                          * @date  10/08/2017
                          */
                         void disconnectMemorySignals();

                        /**
                         * @property	unsigned int current
                         * @brief	Gets the current.
                         * @return	The current.
                         */
                        unsigned int current;
                        ProgressWidget * progress;	///< The progress
                        DiagnosticResultWidget * resultWidget;	///< The result widget
                        DiagnosisBlockedWidget * diagnosisBlockedWidget; ///< diagnosis blocked widget

                        /**
                         * @property	std::vector <Smartmatic::SAES::Operation::Diagnosis::IDiagnosis *> diagnosisList
                         * @brief	Gets a list of diagnosis.
                         * @return	A List of diagnosis.
                         */
                        std::vector <Smartmatic::SAES::Operation::Diagnosis::IDiagnosis *> diagnosisList;
                        /**
                         * @property	std::vector <sigc::connection> diagnosisConnectionList
                         * @brief	Gets a list of diagnosis connections.
                         * @return	A List of diagnosis connections.
                         */
                        std::vector <sigc::connection> diagnosisConnectionList;

                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/

                        bool bothMemoriesConnected;
                        sigc::connection signalBlock;
                        sigc::connection signalResume;
                };
            }
        }
    }
}

#endif /* AUTOMATICDIAGNOSTICWIDGET_HXX_ */
