/**
 * @file	BarcodeReaderDetectedWidget.hxx
 * @brief	Declares the barcode detected widget class.
 * @author	Yadickson Soto
 * @date	14/10/2013
 */

#ifndef _BAR_CODE_READER_DETECTED_WIDGET_H_
#define _BAR_CODE_READER_DETECTED_WIDGET_H_

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include <Operation/Monitor/DeviceTypeMonitor.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	BarcodeReaderDetectedWidget
                 * @brief	Barcode reader detected widget.
                 * @author	Yadickson Soto
                 * @date	14/10/2013
                 */

                class BarcodeReaderDetectedWidget: public BasicDiagnosticWidget
                {
                    public:

                        /**
                         * @fn	BarcodeReaderDetectedWidget ( ProgressWidget * widget );
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         * @param	widget	 	The visual widget
                         */
                        explicit BarcodeReaderDetectedWidget ( ProgressWidget * widget );

                        /**
                         * @fn	virtual ~BarcodeReaderDetectedWidget();
                         * @brief	Destroy.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         */
                        virtual ~BarcodeReaderDetectedWidget();
                        /**
                         * @fn	virtual void initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         */
                        virtual void dispose();

                    private:

                        ProgressWidget * widget; ///< the visual widget
                        sigc::connection connDevice; /// The alarm connection signal

                        int timeOK; ///< Timeout end reconfigure successfully
                        int timeFail; ///< Timeout end reconfigure fail

                        /**
                         * @fn	void deviceDetected ();
                         * @brief	Show message barcode reader device detected.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         */
                        void deviceDetected ();

                        /**
                         * @fn	void reconnectDevice ();
                         * @brief	Show message reconnect barcode reader device.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         */
                        void reconnectDevice ();

                        /**
                         * @fn	void onNotDetected ();
                         * @brief	Callback clicked not detected button.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         */
                        void onNotDetected ();

                        /**
                         * @fn	void skipDetection ();
                         * @brief	Callback clicked skip detection button.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         */
                        void skipDetection ();

                        /**
                         * @fn	void end();
                         * @brief	End diagnostic.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         */
                        void end();
                        /**
                         * @fn	void error();
                         * @brief	Error in diagnose.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         */
                        void error();
                        /**
                         * @fn	void cancel();
                         * @brief	cancel diagnose.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         */
                        void cancel();

                        /**
                         * @fn	void deviceChange( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * deviceTypeMonitor );
                         * @brief	Occurs when the observer notify a change of the device.
                         * @author	Yadickson Soto
                         * @date	13/07/2015
                         * @param 	deviceTypeMonitor The pointer reference to device object.
                         */
                        void deviceChange ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * deviceTypeMonitor );

                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger

                };
            }
        }
    }
}

#endif // _BAR_CODE_READER_DETECTED_WIDGET_H_
