/**
 * @file BarcodeReaderDiagnoseWidget.cxx
 * @brief Body Barcode reader diagnose widget class
 * @date 05/09/2013
 * @author Yadickson Soto
 */

#include "BarcodeReaderDiagnoseWidget.hxx"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Gui/Widgets/Diagnose/BarcodeReaderDetectedWidget.hxx>
#include <Gui/Widgets/Diagnose/BarcodeReaderPrintingWidget.hxx>
#include <Gui/Widgets/Diagnose/BarcodeReaderReconfigureWidget.hxx>
#include <Gui/Widgets/Diagnose/BarcodeReaderScanWidget.hxx>
#include <Gui/Widgets/Diagnose/BarcodeReaderSerialNumberWidget.hxx>

using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;

BarcodeReaderDiagnoseWidget::BarcodeReaderDiagnoseWidget()
    : WizardDiagnoseWidget ( Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_BARCODE )
{
    WizardWidgetBase * detected = AbstractFactoryWidget::createBarcodeReaderDetectedWidget();
    WizardWidgetBase * reconfigure = AbstractFactoryWidget::createBarcodeReaderReconfigureWidget();
    WizardWidgetBase * scan = AbstractFactoryWidget::createBarcodeReaderScanWidget();

    wizardVector.push_back ( detected );

    if ( SAESGUIConfigurationManager::getInstance()->getBarcodeDiagnosisConfiguration().getSetSerialNumber() )
    {
        WizardWidgetBase * serialNumber = AbstractFactoryWidget::createBarcodeReaderSerialNumberWidget();
        wizardVector.push_back ( serialNumber );
    }

    wizardVector.push_back ( reconfigure );

    if ( SAESGUIConfigurationManager::getInstance()->getStartConfiguration().getInfoMachine() ==
         InfoMachineConfiguration::CONFIGURATION_VM )
    {
        WizardWidgetBase * printing = AbstractFactoryWidget::createBarcodeReaderPrintingWidget();

        wizardVector.push_back ( printing );
    }

    wizardVector.push_back ( scan );
}

BarcodeReaderDiagnoseWidget::~BarcodeReaderDiagnoseWidget()
{

}
