/**
 * @file	BarcodeReaderReconfigureWidget.cxx
 * @brief	bar code diagnosis widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "BarcodeReaderReconfigureWidget.hxx"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/BCRController.hxx>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Common::Configuration;

Smartmatic::Log::ISMTTLog * BarcodeReaderReconfigureWidget::logger = Smartmatic::Log::SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.BarcodeReaderReconfigureWidget", GETTEXT_PACKAGE );

BarcodeReaderReconfigureWidget::BarcodeReaderReconfigureWidget ( ProgressWidget * widget )
    : WizardWidgetBase()
    , widget(widget)
    , commandsReconfigure(SAESGUIConfigurationManager::getInstance()->getBarcodeDiagnosisConfiguration().getBarcodeCommandsName())
    , timeOK(SAESGUIConfigurationManager::getInstance()->getBarcodeDiagnosisConfiguration().getReconfigureTimeOk())
    , timeFail(SAESGUIConfigurationManager::getInstance()->getBarcodeDiagnosisConfiguration().getReconfigureTimeFail())
{
    widget->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Widgets.BarcodeDetectionWidget.InfoMessage" ) );
    widget->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::RECONFIGURE_BARCODE );

    signalDispatcher.getSyncSignal().connect ( sigc::mem_fun ( *this, &BarcodeReaderReconfigureWidget::onRawObject ) );

    setWidget ( widget );
}

BarcodeReaderReconfigureWidget::~BarcodeReaderReconfigureWidget()
{
    remove();
    dispose();

    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void BarcodeReaderReconfigureWidget::initialize()
{
    on_disable_close_signal_emit().emit ();
    start ( 0 );
}

void BarcodeReaderReconfigureWidget::dispose()
{

}

bool BarcodeReaderReconfigureWidget::process ()
{
    bool result = BCRController::getInstance()->sendReconfigureCommand ( commandsReconfigure );

    signalDispatcher.emit ( new bool ( result ) );

    return false;
}

void BarcodeReaderReconfigureWidget::onRawObject ( void * object )
{
    bool * status = static_cast < bool * > ( object );

    if ( *status )
    {
        logger->Debug ( "Reconfigure Device Successfully" );
        widget->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Widgets.BarcodeDetectionWidget.BarcodeConnected" ) );
        widget->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::RECONFIGURE_BARCODE_SUCCESS );
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &BarcodeReaderReconfigureWidget::emit ), timeOK );
    }
    else
    {
        logger->Debug ( "Reconfigure Device Fail" );
        widget->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Widgets.BarcodeDetectionWidget.BarcodeConfigurationFail" ) );
        widget->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::RECONFIGURE_BARCODE_FAIL );

        MachineOperationManager::getInstance()->getOperationStatus()->getVotingMachineStatusWrapper()->setBarcodeReaderFullStatus ( true, false );

        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &BarcodeReaderReconfigureWidget::error ), timeFail );
    }

    delete status;
}

void BarcodeReaderReconfigureWidget::error()
{
    on_stop_signal_emit().emit();
}
