/**
 * @file	BarcodeReaderSerialNumberWidget.cxx
 * @brief	(Body of) widget Class which sets the barcode reader's serial number
 * @author	Yadickson Soto
 * @date	28/01/2014
 */

#include "BarcodeReaderSerialNumberWidget.hxx"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/BCRController.hxx>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Voting::Status;

Smartmatic::Log::ISMTTLog * BarcodeReaderSerialNumberWidget::logger = Smartmatic::Log::SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.BarcodeReaderSerialNumberWidget", GETTEXT_PACKAGE );

BarcodeReaderSerialNumberWidget::BarcodeReaderSerialNumberWidget ( ProgressWidget * widget )
    : BasicDiagnosticWidget ( false, false, false ),  widget ( widget )
{
    timeFail = SAESGUIConfigurationManager::getInstance()->getBarcodeDiagnosisConfiguration().getReconfigureTimeFail();

    widget->setInfoText ( N_ ( "Reconfigure Barcode Reader Serial Device." ) );
    widget->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::RECONFIGURE_BARCODE );

    signalDispatcher.getSyncSignal().connect ( sigc::mem_fun ( *this, &BarcodeReaderSerialNumberWidget::onRawObject ) );

    setWidget ( widget );
}

BarcodeReaderSerialNumberWidget::~BarcodeReaderSerialNumberWidget()
{
    dispose();
    remove();

    if ( widget )
    {
        delete widget;
        widget = NULL;
    }
}

void BarcodeReaderSerialNumberWidget::initialize()
{
    serial = MachineOperationManager::getInstance()->getOperationStatus()->getVotingMachineStatusWrapper()->getSerial();
    std::string bcrSerial = BCRController::getInstance()->getDeviceSerial ();

    if ( !bcrSerial.empty() )
    {
        MachineOperationManager::getInstance()->getOperationStatus()->getVotingMachineStatusWrapper()->addStatusCode ( DeviceType::CONFIGURATION_BARCODE, "SN" + bcrSerial ) ;
    }

    if ( serial.empty() || !bcrSerial.empty() )
    {
        logger->Debug ( "Skip Set Serial Device" );
        emit();
    }
    else
    {
        start ( 0 );
    }
}

void BarcodeReaderSerialNumberWidget::dispose()
{

}

bool BarcodeReaderSerialNumberWidget::process()
{
    bool result = BCRController::getInstance()->setDeviceSerial ( serial );

    signalDispatcher.emit ( new bool ( result ) );

    return false;
}

void BarcodeReaderSerialNumberWidget::onRawObject ( void * object )
{
    bool * result = static_cast < bool * > ( object );

    if ( *result )
    {
        logger->Debug ( "Set Serial Device Successfully" );
        MachineOperationManager::getInstance()->getOperationStatus()->getVotingMachineStatusWrapper()->addStatusCode ( DeviceType::CONFIGURATION_BARCODE, "SN" + serial ) ;
        emit();
    }
    else
    {
        logger->Debug ( "Set Serial Device Fail" );
        MachineOperationManager::getInstance()->getOperationStatus()->getVotingMachineStatusWrapper()->addStatusCode ( DeviceType::CONFIGURATION_BARCODE, "SN", VMStatus::VOTING_MACHINE_STATUS_ERROR ) ;
        showErrorReconfigureSerial();
    }

    delete result;
}

void BarcodeReaderSerialNumberWidget::showErrorReconfigureSerial()
{

    widget->setInfoText ( N_ ( "Barcode Reader Reconfigure Device Serial Fail." ) );
    widget->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::RECONFIGURE_BARCODE_FAIL );

    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &BarcodeReaderSerialNumberWidget::error ), timeFail );
}

void BarcodeReaderSerialNumberWidget::error()
{
    on_stop_signal_emit().emit();
}
