/**
 * @file DeviceDiagnosticPrintWidget.hxx
 * @brief Header device diagnostic print widget
 * @date 19/09/2012
 * @author Yadickson Soto
 */

#ifndef DEVICEDIAGNOSTICPRINTWIDGET_HXX_
#define DEVICEDIAGNOSTICPRINTWIDGET_HXX_

#include <Widgets/StepWidget.hxx>
#include <Printing/DiagnosticPrintDocument.hxx>
#include <Gui/Widgets/GenericPrintingWidget.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	DeviceDiagnosticPrintWidget
                 * @brief	device diagnostic print widget.
                 * @author	Yadickson Soto
                 * @date	19/09/2012
                 */
                class DeviceDiagnosticPrintWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:
                        /**
                         * @fn	DeviceDiagnosticPrintWidget::DeviceDiagnosticPrintWidget( GenericPrintingWidget * widget );
                         * @brief	class constructor.
                         * @param 	widget widget
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        explicit DeviceDiagnosticPrintWidget ( GenericPrintingWidget * widget );
                        /**
                         * @fn	virtual DeviceDiagnosticPrintWidget::~DeviceDiagnosticPrintWidget();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        virtual ~DeviceDiagnosticPrintWidget();
                        /**
                         * @fn	void DeviceDiagnosticPrintWidget::start();
                         * @brief	method start print.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        void start();

                    protected:
                        /**
                         * @fn	virtual void initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	07/11/2012
                         */
                        virtual void initialize();
                        /**
                         * @fn	void DeviceDiagnosticPrintWidget::endPrint();
                         * @brief	method end print.
                         * @author	Yadickson Soto
                         * @date	19/09/2012
                         */
                        void endPrint();

                    private:

                        Smartmatic::SAES::GUI::Widgets::GenericPrintingWidget * widget; ///< The widget
                        Smartmatic::SAES::Printing::DiagnosticPrintDocument * print; ///< print document
                };
            }
        }
    }
}
#endif /* DEVICEDIAGNOSTICPRINTWIDGET_HXX_ */
