/**
 * @file DiagnosticButtonWidget.cxx
 * @brief Body diagnostic button widget class
 * @date 06/09/2013
 * @author Yadickson Soto
 */

#include "DiagnosticButtonWidget.hxx"
#include <Configuration/MachineModelEnum.hxx>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Configuration/s-m-t-t-g-u-i-conf-manager.h>
#include <Operation/Voting/VotingOperation.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Operation::Voting;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Voting::Vote;

DiagnosticButtonWidget::DiagnosticButtonWidget ()
    : ButtonsWidget ( false )
{
    int width = SAESGUIConfigurationManager::getInstance()->getGeneralDiagnosisConfiguration().getButtonConfiguration().getButtonWidth();
    int height = SAESGUIConfigurationManager::getInstance()->getGeneralDiagnosisConfiguration().getButtonConfiguration().getButtonHeight();
    int size = SAESGUIConfigurationManager::getInstance()->getGeneralDiagnosisConfiguration().getButtonConfiguration().getFontSize();

    if ( SMTTGUIConfigurationManager::getInstance()->getSmartmaticGUIMachineModelConfiguration().getId() == EnumToString( PM_VIU805 ) )
    {
        double guiReconfigurationFactor = SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSmartmaticGUIMachineModelConfiguration().getGuiReconfigurationFactor();

        width *= guiReconfigurationFactor;
        height *= guiReconfigurationFactor;
    }

    backButton->set_size_request ( width, height );
    acceptButton->set_size_request ( width, height );
    clearButton->set_size_request ( width, height );

    std::string sound = SAESGUIConfigurationManager::getInstance()->getDiagnosisSound();

    clearButton->WidgetsPosition ( 5, 0, 0 );
    clearButton->SetSound ( sound );

    acceptButton->SetButtonType ( SmartmaticButton::Ok );
    acceptButton->WidgetsPosition ( 5, 6, 0 );
    acceptButton->SetSound ( sound );

    backButton->WidgetsPosition ( 5, 0, 0 );
    backButton->SetSound ( sound );

    modifyFontSize ( size );

    setAccessibleName ( "DiagnosticButtonWidget" );
    acceptButton->setAccessibleName ( "ConfirmDiagnose" );
    clearButton->setAccessibleName ( "CancelDiagnose" );
    backButton->setAccessibleName ( "RetryDiagnose" );

    update();
}

DiagnosticButtonWidget::~DiagnosticButtonWidget()
{

}

void DiagnosticButtonWidget::update()
{
    backButton->SetLabel ( _ ( "Smartmatic.SAES.GUI.Widgets.BasicDiagnosticWidget.Retry" ) );
    acceptButton->SetLabel ( _ ( "Smartmatic.SAES.GUI.Widgets.BasicDiagnosticWidget.Ok" ) );
    clearButton->SetLabel ( _ ( "Smartmatic.SAES.GUI.Widgets.BasicDiagnosticWidget.Cancel" ) );

    clearSignals();
}

void DiagnosticButtonWidget::setOkButtonSensitive ( bool sensitive )
{
    acceptButton->set_sensitive ( sensitive );
}

void DiagnosticButtonWidget::setCancelButtonSensitive ( bool sensitive )
{
    clearButton->set_sensitive ( sensitive );
}

void DiagnosticButtonWidget::setRetryButtonSensitive ( bool sensitive )
{
    backButton->set_sensitive ( sensitive );
}
