/*
 * EurnActionsWidget.cxx
 *
 *  Created on: Nov 7, 2017
 *      Author: juanvalera
 */


#include "EurnActionsWidget.hxx"
#include "Configuration/label-configuration.h"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Environment/Configurations/resource-path-provider.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/Devices/EurnController.hxx>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Operation/MachineOperationManager.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::HW::Devices;
using namespace Smartmatic::Log;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Operation::Devices;
using namespace Smartmatic::SAES::Voting::Status;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::GUI::Widgets;

ISMTTLog * EurnActionsWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.EurnActionsWidget", GETTEXT_PACKAGE );

EurnActionsWidget::EurnActionsWidget ()
    : BasicDiagnosticWidget ( true, true )
    , alignment(0.5, 0.5, 0.9, 0.6)
    , openDoorOption(&buttonOpenDoor)
    , redLedOption(&buttonRedLed)
    , greenLedOption(&buttonGreenLed)
    , closeDoorOption(&buttonCloseDoor)
{
    setOkButtonSensitive ( false );

    openDoorState = OFF;
    redLedState = OFF;
    greenLedState = OFF;
    closeDoorState = OFF;

    Smartmatic::SAES::Configuration::EurnDiagnosisConfiguration & config ( SAESGUIConfigurationManager::getInstance()->getEurnDiagnosisConfiguration() );

    timeOk = config.getActionsTimeOk();
    timeFail = config.getActionsTimeFail();

    endWidget = AbstractFactoryWidget::createEurnEndDiagnoseWidget();

    frame.set_shadow_type(Gtk::SHADOW_NONE);
    frame.set_label_align(0.0,0.5);

    vboxOptions.set_spacing(5);
    vboxOptions.set_homogeneous(false);

    alignment.add(vboxOptions);
    frame.add(alignment);

    ButtonConfiguration buttonConf = config.getButtonConfiguration();
    LabelConfiguration labelText = SAESGUIConfigurationManager::ConvertToLabelConfiguration ( SAESGUIConfigurationManager::getInstance()->getGeneralDiagnosisConfiguration().getDiagnosisLabelConfiguration() );

    buttonOpenDoor.ModifyFontSize ( buttonConf.getFontSize() );
    buttonCloseDoor.ModifyFontSize ( buttonConf.getFontSize() );
    buttonRedLed.ModifyFontSize ( buttonConf.getFontSize() );
    buttonGreenLed.ModifyFontSize ( buttonConf.getFontSize() );

    buttonOpenDoor.set_size_request ( buttonConf.getButtonWidth(), buttonConf.getButtonHeight() );
    buttonCloseDoor.set_size_request ( buttonConf.getButtonWidth(), buttonConf.getButtonHeight() );
    buttonRedLed.set_size_request ( buttonConf.getButtonWidth(), buttonConf.getButtonHeight() );
    buttonGreenLed.set_size_request ( buttonConf.getButtonWidth(), buttonConf.getButtonHeight() );

    buttonOpenDoor.signal_clicked().connect ( sigc::mem_fun ( *this, &EurnActionsWidget::onOpenDoorAction ) );
    buttonCloseDoor.signal_clicked().connect ( sigc::mem_fun ( *this, &EurnActionsWidget::onCloseDoorAction ) );
    buttonRedLed.signal_clicked().connect ( sigc::mem_fun ( *this, &EurnActionsWidget::onRedLedAction ) );
    buttonGreenLed.signal_clicked().connect ( sigc::mem_fun ( *this, &EurnActionsWidget::onGreenLedAction ) );

    buttonOpenDoor.set_no_show_all();
    buttonCloseDoor.set_no_show_all();
    buttonRedLed.set_no_show_all();
    buttonGreenLed.set_no_show_all();

    buttonOpenDoor.set_visible ( true );
    buttonCloseDoor.set_visible ( true );
    buttonRedLed.set_visible ( true );
    buttonGreenLed.set_visible ( true );

    openDoorOption.setLabelConfiguration ( labelText );
    redLedOption.setLabelConfiguration ( labelText );
    greenLedOption.setLabelConfiguration ( labelText );
    closeDoorOption.setLabelConfiguration ( labelText );

    vboxOptions.pack_start ( openDoorOption );
    vboxOptions.pack_start ( closeDoorOption );
    vboxOptions.pack_start ( redLedOption );
    vboxOptions.pack_start ( greenLedOption );

    openDoorOption.getSignalChange().connect ( sigc::mem_fun ( *this, &EurnActionsWidget::validate ) );
    redLedOption.getSignalChange().connect ( sigc::mem_fun ( *this, &EurnActionsWidget::validate ) );
    greenLedOption.getSignalChange().connect ( sigc::mem_fun ( *this, &EurnActionsWidget::validate ) );
    closeDoorOption.getSignalChange().connect ( sigc::mem_fun ( *this, &EurnActionsWidget::validate ) );

    setWidget ( &frame );
    signalEnableButtons.getSyncSignal().connect ( sigc::mem_fun ( *this, &EurnActionsWidget::onRawObject ) );
    setAccessibleName ( "EurnActionsWidget" );
}

EurnActionsWidget::~EurnActionsWidget()
{
    remove();

    dispose();

    if ( endWidget )
    {
        delete endWidget;
        endWidget = NULL;
    }
}

void EurnActionsWidget::initialize()
{
    connOk.disconnect();
    connError.disconnect();
    conn_updateEurnStatus.disconnect();

    setOkButtonSensitive ( true );
    setCancelButtonSensitive ( true );

    openDoorState = OFF;
    redLedState = OFF;
    greenLedState = OFF;
    closeDoorState = OFF;

    conn_updateEurnStatus = EurnController::getInstance()->getSignalEurnSatusChanged().connect ( sigc::mem_fun ( *this, &EurnActionsWidget::onSignalEurnStatus ) );
    connOk = signalOkDetected.connect ( sigc::mem_fun ( *this, &EurnActionsWidget::viewSuccess ) );
    connError = signalCancelDetected.connect ( sigc::mem_fun ( *this, &EurnActionsWidget::viewCancel ) );

    openDoorOption.setTextConteiner ( _ ( "Open door test" ) );
    redLedOption.setTextConteiner ( _ ( "Red led test" ) );
    greenLedOption.setTextConteiner ( _ ( "Green led test" ) );
    closeDoorOption.setTextConteiner ( _ ( "Close door test" ) );

    openDoorOption.setTextOptions ( _ ( "Does the door open correctly?" ), _ ( "yes" ), _ ( "no" ) );
    redLedOption.setTextOptions ( _ ( "Does the red led work correctly?" ), _ ( "yes" ), _ ( "no" ) );
    greenLedOption.setTextOptions ( _ ( "Does the green led work correctly?" ), _ ( "yes" ), _ ( "no" ) );
    closeDoorOption.setTextOptions ( _ ( "Does the door close correctly?" ), _ ( "yes" ), _ ( "no" ) );

    buttonCloseDoor.set_sensitive ( false );

    buttonOpenDoor.set_label ( _ ( "Open door" ) );
    buttonRedLed.set_label ( _ ( "Red led ON" ) );
    buttonGreenLed.set_label ( _ ( "Green led ON" ) );
    buttonCloseDoor.set_label  ( _ ( "Close door" ) );

    openDoorOption.clearOption();
    redLedOption.clearOption();
    greenLedOption.clearOption();
    closeDoorOption.clearOption();

    showOpenDoorButton = true;
    showCloseDoorButton = true;
    showGreenLedButton = true;
    showRedLedButton = true;

    restoreEurnState();

    validate();
    start ( 100 );
}

void EurnActionsWidget::onSignalEurnStatus ( EurnController::DeviceStatus status )
{
    Glib::signal_timeout().connect_once (sigc::bind<EurnController::DeviceStatus> (sigc::mem_fun ( *this, &EurnActionsWidget::updateEurnStatus ), status), 10 );
}

void EurnActionsWidget::updateEurnStatus(EurnController::DeviceStatus status)
{
    switch(status)
    {
        case EurnController::CONNECTED_WORKING:
           restoreEurnState();
           signalEnableButtons.emit ( NULL );
        break;
        default:
        case EurnController::CONNECTED_NOT_RESPONDING:
        case EurnController::NOT_CONNECTED:
        break;
    }
}

bool EurnActionsWidget::process ()
{
    bool enableButton = !showOpenDoorButton|| !showCloseDoorButton || !showRedLedButton || !showGreenLedButton;

    if ( !showOpenDoorButton )
    {
        showOpenDoorButton = true;

        if ( openDoorState == OFF )
        {
            openDoorState = ON;
            closeDoorState = OFF;
            EurnController::getInstance()->runDiagnoseOpenDoor();
        }
    }

    if ( !showCloseDoorButton )
    {
        showCloseDoorButton = true;

        if ( closeDoorState == OFF )
        {
            closeDoorState = ON;
            openDoorState = OFF;
            EurnController::getInstance()->runDiagnoseCloseDoor();
        }
    }

    if ( !showRedLedButton )
    {
        showRedLedButton = true;
        redLedState = ON;
        EurnController::getInstance()->runDiagnoseTurnOnRedLed();
    }

    if ( !showGreenLedButton )
    {
        showGreenLedButton = true;
        greenLedState = ON;
        EurnController::getInstance()->runDiagnoseTurnOnGreenLed();
    }

    if ( enableButton )
    {
        signalEnableButtons.emit ( NULL );
    }

    return true;
}

void EurnActionsWidget::dispose()
{
    buttonOpenDoor.set_sensitive ( false );
    buttonCloseDoor.set_sensitive ( false );
    buttonRedLed.set_sensitive ( false );
    buttonGreenLed.set_sensitive ( false );

    showButtons ( false, false, false );

    connOk.disconnect();
    connError.disconnect();
    conn_updateEurnStatus.disconnect();

    stop();
}

void EurnActionsWidget::onRawObject ( void * object )
{
    buttonRedLed.set_sensitive ( true );
    buttonGreenLed.set_sensitive ( true );
    buttonOpenDoor.set_sensitive ( openDoorState == OFF );
    buttonCloseDoor.set_sensitive ( openDoorState == ON );
}

void EurnActionsWidget::onRedLedAction ()
{
    buttonRedLed.set_label ( _ ( "Red led ON" ) );
    buttonRedLed.set_sensitive ( false );
    showRedLedButton = false;
}

void EurnActionsWidget::onGreenLedAction ()
{
    buttonGreenLed.set_label ( _ ( "Green led ON" ) );
    buttonGreenLed.set_sensitive ( false );
    showGreenLedButton = false;
}

void EurnActionsWidget::onOpenDoorAction ()
{
    openDoorOption.viewOptions();
    openDoorOption.setTextOptions ( _ ( "Does the door open correctly?" ), _ ( "yes" ), _ ( "no" ) );
    buttonOpenDoor.set_sensitive ( false );

    showOpenDoorButton = false;
}

void EurnActionsWidget::onCloseDoorAction ()
{
    closeDoorOption.viewOptions();
    closeDoorOption.setTextOptions ( _ ( "Does the door close correctly?" ), _ ( "yes" ), _ ( "no" ) );
    buttonCloseDoor.set_sensitive ( false );

    showCloseDoorButton = false;
}

void EurnActionsWidget::validate()
{
    bool result = openDoorOption.getOption() &&
                  redLedOption.getOption() &&
                  greenLedOption.getOption() &&
                  closeDoorOption.getOption();

    bool check = openDoorOption.isCheck() &&
                 redLedOption.isCheck() &&
                 greenLedOption.isCheck() &&
                 closeDoorOption.isCheck();

    showButtons ( result, !result, false );

    setCancelButtonSensitive ( check );
}

void EurnActionsWidget::restoreEurnState()
{
    EurnController::getInstance()->runDiagnoseTurnOffGreenLed();
    EurnController::getInstance()->runDiagnoseTurnOffRedLed();
    EurnController::getInstance()->runDiagnoseCloseDoor();
    closeDoorState = ON;
    openDoorState = OFF;
}

void EurnActionsWidget::end ()
{
    emit();
}

void EurnActionsWidget::error ()
{
    on_stop_signal_emit().emit();
}

void EurnActionsWidget::viewSuccess ()
{
    showButtons ( false, false, false );
    restoreEurnState();
    setWidget ( endWidget );
    endWidget->showSuccess();
    setStatus();

    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &EurnActionsWidget::end ), timeOk );
}

void EurnActionsWidget::viewCancel ()
{
    showButtons ( false, false, false );
    restoreEurnState();
    setWidget ( endWidget );
    endWidget->showError();
    setStatus();

    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &EurnActionsWidget::error ), timeFail );
}

void EurnActionsWidget::setStatus()
{
    bool openDoor = openDoorOption.getOption();
    bool redLed = redLedOption.getOption();
    bool greenLed = greenLedOption.getOption();
    bool closeDoor = closeDoorOption.getOption();

    MachineOperationManager::getInstance()->getOperationStatus()->getVotingMachineStatusWrapper()->setEurnFullStatus (
        true,
        openDoor,
        closeDoor,
        greenLed,
        redLed);
}
