/**
 * @file	FlashDiagnosisWidget.cxx
 * @brief	flash diagnosis widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "FlashDiagnosisWidget.hxx"
#include "Configuration/label-configuration.h"
#include <Configuration/SaesGUIConfiguration-schema.hxx>
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Configuration/s-a-e-s-functionality-conf-manager.h>
#include <Runtime/Environment/MemoryPathController.h>
#include <Gui/Widgets/FactoryMethodWidget.hxx>
#include <stdexcept>
#include <stdlib.h>
#include <stdio.h>
#include <queue>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Voting;
using namespace Smartmatic::SAES::Operation::Diagnosis;
using namespace Smartmatic::SAES::Functionality::Configuration;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::SAES::Voting::Status;

FlashDiagnosisWidget::FlashDiagnosisWidget ()
    : BasicDiagnosticWidget ()
{
    bool checkBoth = MemoryPathController::getInstance()->getRule() == RulesBasePathType::CONFIGURATION_PM_RULE;
    diagnosis = new FlashDiagnosis ( checkBoth );
    diagnosis->getSignalEnd().connect ( sigc::mem_fun ( *this, &FlashDiagnosisWidget::showResult ) );

    progressWidget = FactoryMethodWidget::createProgressWidget();
    progressWidget->setImage ( "ui/Flash.png" );

    setWidget ( progressWidget );
}

FlashDiagnosisWidget::~FlashDiagnosisWidget()
{
    if ( progressWidget )
    {
        delete progressWidget;
        progressWidget = NULL;
    }

    if ( diagnosis )
    {
        delete diagnosis;
        diagnosis = NULL;
    }
}

void FlashDiagnosisWidget::initialize()
{
    diagnosis->setStatus ( VMStatus::VOTING_MACHINE_STATUS_NOTDIAGNOSED );
    progressWidget->setInfoText ( diagnosis->getMessage() );
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &FlashDiagnosisWidget::SendTest ), 1000 );
}

void FlashDiagnosisWidget::SendTest()
{
    diagnosis->setStatus ( VMStatus::VOTING_MACHINE_STATUS_RUN );
    progressWidget->setInfoText ( diagnosis->getMessage() );
    diagnosis->test();
}

void FlashDiagnosisWidget::showResult()
{
    progressWidget->setInfoText ( diagnosis->getMessage() );
    emit();
}

void FlashDiagnosisWidget::Dispose()
{
}
