/**
 * @file	FlashDiagnosisWidget.hxx
 * @brief	Declares the flash diagnosis widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _FLASH_DIAGNOSIS_WIDGET_H_
#define _FLASH_DIAGNOSIS_WIDGET_H_

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include <Operation/Diagnosis/FlashDiagnosis.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	FlashDiagnosisWidget
                 * @brief	Flash diagnosis widget.
                 * @author	Cesar.bonilla
                 * @date	4/29/2011
                 */

                class FlashDiagnosisWidget: public BasicDiagnosticWidget
                {
                    public:

                        /**
                         * @fn	FlashDiagnosisWidget::FlashDiagnosisWidget ();
                         * @brief	Constructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */
                        FlashDiagnosisWidget ();

                        /**
                         * @fn	FlashDiagnosisWidget::~FlashDiagnosisWidget();
                         * @brief	Finaliser.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        virtual ~FlashDiagnosisWidget();

                        /**
                         * @fn	void FlashDiagnosisWidget::Dispose();
                         * @brief	Dispose of this object, cleaning up any resources it uses.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void Dispose();

                        /**
                         * @fn	void FlashDiagnosisWidget::initialize();
                         * @brief	Initializes this object.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void initialize();

                    private:

                        Smartmatic::SAES::Operation::Diagnosis::FlashDiagnosis * diagnosis; ///< The diagnosis
                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget; ///< The visual container
                        /**
                         * @fn	void FlashDiagnosisWidget::SendTest();
                         * @brief	Sends a test.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        void SendTest();

                        /**
                         * @fn	void FlashDiagnosisWidget::showResult();
                         * @brief	Shows the result.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void showResult();
                };
            }
        }
    }
}

#endif // _FLASH_DIAGNOSIS_WIDGET_H_
