/*
 * LedStripActionsWidget.hxx
 *
 *  Created on: Nov 7, 2017
 *      Author: juanvalera
 */

#ifndef LEDSTRIPACTIONSWIDGET_HXX_
#define LEDSTRIPACTIONSWIDGET_HXX_

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include <Gui/Widgets/Diagnose/LedStripEndDiagnoseWidget.hxx>
#include <Gui/Widgets/Diagnose/AlarmBoxDiagnoseStepWidget.hxx>
#include <Operation/Devices/PDBController.hxx>
#include <Widgets/SmartmaticBasicFrame.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <Widgets/smartmatic-button.h>
#include <set>
#include <System/SafeThread.hxx>
#include <System/SafeDispatcher.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	LedStripActionsWidget
                 * @brief	led strip actions diagnosis widget.
                 * @author	Juan Valera
                 * @date	07/11/2017
                 */

                class LedStripActionsWidget: public BasicDiagnosticWidget, private Smartmatic::System::SafeThread
                {
                    public:

                        /**
                         * @fn	LedStripActionsWidget::LedStripActionsWidget ();
                         * @brief	Constructor.
                         * @author	Juan Valera
                         * @date	07/11/2017
                         */
                        explicit LedStripActionsWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget);

                        /**
                         * @fn	virtual ~LedStripActionsWidget();
                         * @brief	Destroy.
                         * @author	Juan Valera
                         * @date	07/11/2017
                         */
                        virtual ~LedStripActionsWidget();

                        /**
                         * @fn	void LedStripActionsWidget::initialize();
                         * @brief	Initializes this object.
                         * @author	Juan Valera
                         * @date	07/11/2017
                         */
                        void initialize();
                        /**
                         * @fn	virtual void dispose();
                         * @brief	virtual method stop.
                         * @author	Juan Valera
                         * @date	07/11/2017
                         */
                        virtual void dispose();


                    private:

                        /**
                         * @fn  enum ButtonStateTest
                         * @brief   Button action ON or OFF
                         * @author  Juan Valera
                         * @date    07/11/2017
                         */
                        enum ButtonStateTest
                        {
                            ON,
                            OFF
                        };

                        int timeOk;   ///< The time diagnose successfully
                        int timeFail;   ///< The time diagnose fail

                        Smartmatic::GUI::Widgets::SmartmaticBasicFrame  frame; ///< The principal frame
                        Gtk::Alignment  alignment; ///< The principal container of labels and buttons

                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox  vboxOptions; ///< The vbox container

                        Smartmatic::GUI::Widgets::SmartmaticButton  buttonTurnOn; ///< Button turn on test
                        Smartmatic::GUI::Widgets::SmartmaticButton  buttonTurnOff; ///< Button turn off test

                        Smartmatic::SAES::GUI::Widgets::AlarmBoxDiagnoseStepWidget  turnOnOption; ///< turn on test
                        Smartmatic::SAES::GUI::Widgets::AlarmBoxDiagnoseStepWidget  turnOffOption; ///< turn off test

                        Smartmatic::SAES::GUI::Widgets::LedStripEndDiagnoseWidget * endWidget; ///< End widget

                        ButtonStateTest turnOnState; ///< The turn on state
                        ButtonStateTest turnOffState; ///< The turn off state

                        sigc::connection connOk; ///< The connection signal dispatcher ok
                        sigc::connection connError; ///< The connection signal dispatcher error


                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget; ///< The visual container

                        Smartmatic::System::SafeDispatcher signalEnableButtons; ///< The signal to enabled buttons

                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger

                        bool showTurnOnButton; ///< flag show turn on button test
                        bool showTurnOffButton; ///< flag show turn off button test

                        /**
                         * @fn	void end();
                         * @brief	End test diagnostic.
                         * @author	Juan Valera
                         * @date	07/11/2017
                         */
                        void end();

                        /**
                         * @fn	    virtual bool process ();
                         * @brief	Callback from thread only one time. Send command in background
                         * @author	Juan Valera
                         * @date	07/11/2017
                         * @return always false
                         */
                        virtual bool process ();

                        /**
                        * @fn  void onTurnOnAction ();
                        * @brief   Action Turn on.
                        * @author  Juan Valera
                        * @date    07/11/2017
                        */
                       void onTurnOnAction ();

                       /**
                        * @fn  void onTurnOffAction ();
                        * @brief   Action Turn Off.
                        * @author  Juan Valera
                        * @date    07/11/2017
                        */
                       void onTurnOffAction ();

                        /**
                         * @fn  void viewError ();
                         * @brief   View end error in diagnose.
                         * @author  Yadickson Soto
                         * @date    03/02/2014
                         */
                        void viewError ();

                        /**
                         * @fn  void viewOk ();
                         * @brief   View Ok diagnose.
                         * @author  Yadickson Soto
                         * @date    12/09/2013
                         */
                        void viewOk();

                        /**
                         * @fn      void onRawObject ( );
                         * @brief   Callback when emit sync signal.
                         * @author  Yadickson Soto
                         * @date    03/08/2015
                         */
                        void onRawObject ( void * object );
                        /**
                         * @fn  void error ();
                         * @brief   End with error in diagnose.
                         * @author  Yadickson Soto
                         * @date    12/09/2013
                         */
                        void error ();

                        /**
                        * @fn  void validate();
                        * @brief   Validate if running all test in true.
                        * @author  Juan Valera
                        * @date    07/11/2017
                        */
                       void validate();

                       /**
                        * @fn      void setStatus();
                        * @brief   End diagnoses to set status result.
                        * @author  Juan Valera
                        * @date    07/11/2017
                        */
                       void setStatus();
                       /**
                        * @fn      void restoreLedStripState();
                        * @brief   restore Led strip state.
                        * @author  Juan Valera
                        * @date    07/11/2017
                        */
                       void restoreLedStripState();

};
            }
        }
    }
}
#endif /* LEDSTRIPACTIONSWIDGET_HXX_ */
