/**
 * @file MouseWidget.hxx
 * @brief Header class mouse widget
 * @date 22/03/2019
 * @author eduardo.fernandez
 */

#ifndef _MOUSE_WIDGET_HXX_
#define _MOUSE_WIDGET_HXX_

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include <Widgets/smartmatic-entry.h>
#include <Widgets/keypad-widget.h>
#include <Widgets/key-pad-widget-interface.h>
#include <Widgets/smartmatic-button.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	MouseWidget
                 * @brief	Class mouse widget.
                 * @author	eduardo.fernandez
                 * @date	22/03/2019
                 */
                class MouseWidget : public BasicDiagnosticWidget
                {
                    public:
                        /**
                         * @fn	MouseWidget::MouseWidget();
                         * @brief	Class constructor.
                         * @author	eduardo.fernandez
                         * @date	22/03/2019
                         */
                        explicit MouseWidget();
                        /**
                         * @fn	virtual MouseWidget::~MouseWidget();
                         * @brief	Class destructor.
                         * @author  eduardo.fernandez
                         * @date    22/03/2019
                         */
                        virtual ~MouseWidget();

                        /**
                         * @fn	void MouseWidget::initialize();
                         * @brief	Method initialize widget.
                         * @author  eduardo.fernandez
                         * @date    22/03/2019
                         */
                        virtual void initialize();

                    private:

                        /**
                         * @fn  void MouseWidget::setDiagnosticResult();
                         * @brief   Method set diagnostic result.
                         * @author  eduardo.fernandez
                         * @date    26/03/2019
                         * @param   isMousePresent Whether an optical mouse is detected.
                         * @param   isSpecificMousePresent Whether correct optical mouse is detected.
                         * @param   vendorId Detected optical mouse vendor id.
                         * @param   productId Detected optical mouse product id.
                         */
                        void setDiagnosticResult(
                            const bool isMousePresent,
                            const bool isSpecificMousePresent,
                            const std::string& vendorId,
                            const std::string& productId);

                    private:

                        static Smartmatic::Log::ISMTTLog * logger;  ///< logger
                };
            }
        }
    }
}
#endif /* _MOUSE_WIDGET_HXX_ */
