/**
 * @file	PrinterDiagnosisWidget.hxx
 * @brief	Declares the printer diagnosis widget class.
 * @author	Yadickson Soto
 * @date	01/11/2012
 */


#ifndef _PRINTER_DIAGNOSIS_WIDGET_H_
#define _PRINTER_DIAGNOSIS_WIDGET_H_

#include <Gui/Widgets/Diagnose/BasicDiagnosticWidget.hxx>
#include <Operation/Diagnosis/PrinterDiagnosis.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	PrinterDiagnosisWidget
                 * @brief	Printer diagnosis widget.
                 * @author	Yadickson Soto
                 * @date	4/29/2011
                 */

                class PrinterDiagnosisWidget : public BasicDiagnosticWidget
                {
                    public:

                        /**
                         * @fn	PrinterDiagnosisWidget::PrinterDiagnosisWidget ();
                         * @brief	Constructor.
                         * @author	Yadickson Soto
                         * @date	4/29/2011
                         */
                        PrinterDiagnosisWidget ();

                        /**
                         * @fn	PrinterDiagnosisWidget::~PrinterDiagnosisWidget();
                         * @brief	Finaliser.
                         * @author	Yadickson Soto
                         * @date	4/29/2011
                         */

                        virtual ~PrinterDiagnosisWidget();

                        /**
                         * @fn	void PrinterDiagnosisWidget::initialize();
                         * @brief	Initializes this object.
                         * @author	Yadickson Soto
                         * @date	4/29/2011
                         */

                        void initialize();

                    private:

                        int timeOK; ///< Timeout end printing successfully
                        int timeFail; ///< Timeout end printing fail

                        sigc::connection connOk; ///< The connection signal dispatcher ok
                        sigc::connection connError; ///< The connection signal dispatcher error
                        sigc::connection connRetry; ///< The connection signal dispatcher retry
                        sigc::connection connDiag; ///< The connection signal dispatcher diagnose

                        Smartmatic::SAES::Operation::Diagnosis::PrinterDiagnosis * diagnosis; ///< The diagnosis
                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressWidget; ///< The visual container
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger

                        /**
                         * @fn	void PrinterDiagnosisWidget::EmitContinueSignal();
                         * @brief	Emit continue signal.
                         * @author	Yadickson Soto
                         * @date	01/11/2012
                         */
                        void EmitContinueSignal();

                        /**
                         * @fn	void PrinterDiagnosisWidget::on_signalOk();
                         * @brief	Handles signal ok signals.
                         * @author	Yadickson Soto
                         * @date	4/29/2011
                         */

                        void on_signalOk();

                        /**
                         * @fn	void PrinterDiagnosisWidget::on_signalCancel();
                         * @brief	Handles signal cancel signals.
                         * @author	Yadickson Soto
                         * @date	4/29/2011
                         */

                        void on_signalCancel();

                        /**
                         * @fn	virtual void PrinterDiagnosisWidget::on_signalRetry();
                         * @brief	Handles button retry clicked signals.
                         * @author	Daniel Ampuero
                         * @date	25/09/2012
                         */
                        virtual void on_signalRetry();

                        /**
                         * @fn	void PrinterDiagnosisWidget::start();
                         * @brief	Sends a test.
                         * @author	Yadickson Soto
                         * @date	4/29/2011
                         */

                        void start();

                        /**
                         * @fn	void PrinterDiagnosisWidget::checkEndDiagnosis();
                         * @brief	Check end diagnosis.
                         * @author	Yadickson Soto
                         * @date	01/11/2012
                         */
                        void checkEndDiagnosis();
                };
            }
        }
    }
}


#endif // _PRINTER_DIAGNOSIS_WIDGET_H_
