/**
 * @file	SmartcardDiagnosisWidget.cxx
 * @brief	smartcard reader diagnosis widget class.
 * @author	Yadickson Soto
 * @date	11/09/2013
 */

#include "SmartcardDiagnosisWidget.hxx"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Gui/Widgets/AbstractFactoryWidget.hxx>
#include <Gui/Widgets/Diagnose/SmartcardActionsWidget.hxx>
#include <Gui/Widgets/Diagnose/LedStripActionsWidget.hxx>
#include <Gui/Widgets/Diagnose/SmartcardDetectedWidget.hxx>
#include <Gui/Widgets/Diagnose/SmartcardPowerWidget.hxx>
#include <System/OptParser.hxx>
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::System;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;

SmartcardDiagnosisWidget::SmartcardDiagnosisWidget()
    : WizardDiagnoseWidget ( Smartmatic::SAES::Common::Configuration::DeviceType::CONFIGURATION_SMARTCARD )
{
    WizardWidgetBase * detected = AbstractFactoryWidget::createSmartcardDetectedWidget();
    WizardWidgetBase * actions = AbstractFactoryWidget::createSmartcardActionsWidget();


    wizardVector.push_back ( detected );
    wizardVector.push_back ( actions );

    std::string machineModel;

    OptParser::getInstance()->getArg(OptParser::MACHINE_MODEL, machineModel);

    if (StringUtils::toUpper(machineModel) == "VM-A4517")
    {
        WizardWidgetBase * ledStrip = AbstractFactoryWidget::createSmartcardLedStripActionsWidget();
        wizardVector.push_back ( ledStrip );

    }
    if ( StringUtils::toUpper(machineModel) == "VM-A4517" || StringUtils::toUpper(machineModel) == "PM-VIU805"
            || StringUtils::toUpper(machineModel) == "VM-SAES3370")
    {
        WizardWidgetBase * power = AbstractFactoryWidget::createSmartcardPowerWidget();
        wizardVector.push_back ( power );
    }
}

SmartcardDiagnosisWidget::~SmartcardDiagnosisWidget()
{

}
