/**
 * @file WizardDiagnoseWidget.hxx
 * @brief Header wizard diagnose widget
 * @date 09/09/2013
 * @author Yadickson Soto
 */

#ifndef WIZARD_DIAGNOSEWIDGET_HXX_
#define WIZARD_DIAGNOSEWIDGET_HXX_

#include <Widgets/wizard-widget-manager.h>
#include <Voting/Status/voting-machine-status-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class WizardDiagnoseWidget
                 * @brief wizard diagnose widget
                 * @date 09/09/2013
                 * @author Yadickson Soto
                 */
                class WizardDiagnoseWidget : public Smartmatic::GUI::Widgets::WizardWidgetBase
                {
                    protected:

                        /**
                         * @fn WizardDiagnoseWidget( Smartmatic::SAES::Common::Configuration::DeviceType type );
                         * @brief Class constructor
                         * @date 09/09/2013
                         * @author Yadickson Soto
                         * @param type Type diagnose
                         */
                        explicit WizardDiagnoseWidget ( Smartmatic::SAES::Common::Configuration::DeviceType type );

                    public:
                        /**
                         * @fn virtual ~WizardDiagnoseWidget();
                         * @brief Class destructor
                         * @date 09/09/2013
                         * @author Yadickson Soto
                         */
                        virtual ~WizardDiagnoseWidget();
                        /**
                         * @fn void start();
                         * @brief Start running wizard widget
                         * @date 09/09/2013
                         * @author Yadickson Soto
                         */
                        void start();
                        /**
                         * @fn	virtual void dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	09/09/2013
                         */
                        virtual void dispose();

                    protected:

                        /**
                         * @fn	void end();
                         * @brief	End test diagnostic.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        void end();

                        /**
                         * @fn	void error();
                         * @brief	End test diagnostic fail.
                         * @author	Yadickson Soto
                         * @date	06/09/2013
                         */
                        void error();

                        /**
                         * @fn	void cancel();
                         * @brief	Cancel test diagnostic, not fail.
                         * @author	Yadickson Soto
                         * @date	14/10/2013
                         */
                        void cancel();

                        std::vector < Smartmatic::GUI::Widgets::WizardWidgetBase * > wizardVector; ///< The wizard vector

                    private:

                        Smartmatic::SAES::Common::Configuration::DeviceType type; ///< The status type
                        Smartmatic::GUI::Widgets::WizardWidgetManager * manager; ///< The wizard manager

                        sigc::connection managerConnection; ///< The manager connection
                        std::vector < sigc::connection > connections; ///< The pool connections
                };
            }
        }
    }
}
#endif /* WIZARD_DIAGNOSEWIDGET_HXX_ */
