/**
 * @file FactoryMethodWidget.cxx
 * @brief Body class for creating the widget
 * @date 03/11/2011
 * @author Yadickson Soto
 */

#include "FactoryMethodWidget.hxx"
#include "PMInstallMachineWidget.hxx"
#include "VMInstallMachineWidget.hxx"
#include "PMPollingPlaceInfoWidget.hxx"
#include "VMPollingPlaceInfoWidget.hxx"
#include "PMAuthenticationPollingPlaceInfoWidget.hxx"
#include "VMAuthenticationPollingPlaceInfoWidget.hxx"
#include "PMAuthenticationWidget.hxx"
#include "VMAuthenticationWidget.hxx"
#include "VMInitiatorWidget.hxx"
#include "PMInitiatorWidget.hxx"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Configuration/s-a-e-s-hardware-conf-manager.h>
#include <Gui/Widgets/Diagnose/AbleP168AButtonWidget.hxx>
#include <Gui/Widgets/Diagnose/AbleA4517ButtonWidget.hxx>
#include <Operation/Initiator/PMachineInitiator.hxx>
#include <Operation/Initiator/VMachineInitiator.hxx>
#include <Operation/Authenticator/PMachineAuthenticator.hxx>
#include <Operation/Authenticator/VMachineAuthenticator.hxx>
#include <System/OptParser.hxx>
#include <Configuration/MachineModelEnum.hxx>
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::HW::Configuration;
using namespace Smartmatic::SAES::Operation::Initiator;
using namespace Smartmatic::SAES::Operation::Authenticator;
using namespace Smartmatic::System;
using namespace Smartmatic::System::Utils;

InstallMachineWidget * FactoryMethodWidget::createInstallMachineWidget ( ProgressWidget * progress, PollingPlaceInfoWidget * pollingPlaceInfo )
{
    InstallMachineWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->getStartConfiguration().getInfoMachine() )
    {
        case InfoMachineConfiguration::CONFIGURATION_PM:
            {
                widget = new PMInstallMachineWidget ( progress, pollingPlaceInfo );
            }
            break;

        default:
        case InfoMachineConfiguration::CONFIGURATION_VM:
            {
                delete pollingPlaceInfo;
                widget = new VMInstallMachineWidget ( progress );
            }
            break;
    }

    return widget;
}

ProgressWidget * FactoryMethodWidget::createProgressWidget()
{
    return new ProgressWidget ();
}

PollingPlaceInfoWidget * FactoryMethodWidget::createPollingPlaceInfoWidget()
{
    PollingPlaceInfoWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->getStartConfiguration().getInfoMachine() )
    {
        case InfoMachineConfiguration::CONFIGURATION_PM:
            widget = new PMPollingPlaceInfoWidget();
            break;

        default:
        case InfoMachineConfiguration::CONFIGURATION_VM:
            widget = new VMPollingPlaceInfoWidget();
            break;
    }

    return widget;
}

PollingPlaceInfoWidget * FactoryMethodWidget::createAuthenticationPollingPlaceInfoWidget()
{
    PollingPlaceInfoWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->getStartConfiguration().getInfoMachine() )
    {
        case InfoMachineConfiguration::CONFIGURATION_PM:
            widget = new PMAuthenticationPollingPlaceInfoWidget();
            break;

        default:
        case InfoMachineConfiguration::CONFIGURATION_VM:
            widget = new VMAuthenticationPollingPlaceInfoWidget();
            break;
    }

    return widget;
}

BallotOptionButtonWidget * FactoryMethodWidget::createBallotOptionButtonWidget()
{
    BallotOptionButtonWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getBallotOptionButton() )
    {
        case ViewButtonConfiguration::CONFIGURATION_EXPAND_BUTTONS:
            widget = new BallotOptionButtonWidget ( true );
            break;

        default:
        case ViewButtonConfiguration::CONFIGURATION_SEPARATE_BUTTONS:
            widget = new BallotOptionButtonWidget ( false );
            break;
    }

    widget->update();
    return widget;
}

ReferendumButtonWidget * FactoryMethodWidget::createReferendumButtonWidget()
{
    ReferendumButtonWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getBallotOptionButton() )
    {
        case ViewButtonConfiguration::CONFIGURATION_EXPAND_BUTTONS:
            widget = new ReferendumButtonWidget ( true );
            break;

        default:
        case ViewButtonConfiguration::CONFIGURATION_SEPARATE_BUTTONS:
            widget = new ReferendumButtonWidget ( false );
            break;
    }

    widget->update();
    return widget;
}

PartyButtonWidget * FactoryMethodWidget::createPartyButtonWidget()
{
    PartyButtonWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->GetPartySelectionConfiguration().getPartyButton() )
    {
        case ViewButtonConfiguration::CONFIGURATION_EXPAND_BUTTONS:
            widget = new PartyButtonWidget ( true );
            break;

        default:
        case ViewButtonConfiguration::CONFIGURATION_SEPARATE_BUTTONS:
            widget = new PartyButtonWidget ( false );
            break;
    }

    widget->update();
    return widget;
}

TableCenterWidget * FactoryMethodWidget::createTableWidget()
{
    TableCenterWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getBallotOptionTable() )
    {
        case ViewTableConfiguration::CONFIGURATION_COLUMN_FIXED:
            widget = new TableCenterWidget ( true );
            break;

        default:
        case ViewTableConfiguration::CONFIGURATION_COLUMN_CENTER:
            widget = new TableCenterWidget ( false );
            break;
    }

    return widget;
}

TableBoxSelectionWidget * FactoryMethodWidget::createBallotOptionTableBoxSelectionWidget()
{
    TableBoxSelectionWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getBallotOptionTable() )
    {
        case ViewTableConfiguration::CONFIGURATION_COLUMN_FIXED:
            widget = new TableBoxSelectionWidget ( true, true );
            break;

        default:
        case ViewTableConfiguration::CONFIGURATION_COLUMN_CENTER:
            widget = new TableBoxSelectionWidget ( true, false );
            break;
    }

    return widget;
}

FillTableWidget * FactoryMethodWidget::createBallotOptionFillTableWidget ( TableBoxSelectionWidget * tableWidget )
{
    return new FillTableWidget ( tableWidget );
}

AuthenticationWidget * FactoryMethodWidget::createAuthenticationWidget ( PollingPlaceInfoWidget * info )
{
    AuthenticationWidget * widget = NULL;
    IAuthenticator * authenticator = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->getStartConfiguration().getInfoMachine() )
    {
        case InfoMachineConfiguration::CONFIGURATION_PM:
            authenticator = new PMachineAuthenticator();
            widget = new PMAuthenticationWidget ( info, authenticator );
            break;

        default:
        case InfoMachineConfiguration::CONFIGURATION_VM:
            authenticator = new VMachineAuthenticator();
            widget = new VMAuthenticationWidget ( info, authenticator );
            break;
    }

    return widget;
}

IAbleButtonWidget * FactoryMethodWidget::createAble10ButtonWidget()
{
    return new AbleP168AButtonWidget();
}

IAbleButtonWidget * FactoryMethodWidget::createAble20ButtonWidget()
{
    return new AbleA4517ButtonWidget();
}

SerialNumberWidget * FactoryMethodWidget::createSerialNumberWidget()
{
    SerialNumberWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->getStartConfiguration().getInfoMachine() )
    {
        case InfoMachineConfiguration::CONFIGURATION_PM:
            widget = new SerialNumberWidget ( false );
            break;

        default:
        case InfoMachineConfiguration::CONFIGURATION_VM:
            widget = new SerialNumberWidget ( true );
            break;
    }

    return widget;
}

ZipCodeWidget * FactoryMethodWidget::createZipCodeWidget()
{
    ZipCodeWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->getStartConfiguration().getInfoMachine() )
    {
        case InfoMachineConfiguration::CONFIGURATION_PM:
            widget = new ZipCodeWidget ( false );
            break;

        default:
        case InfoMachineConfiguration::CONFIGURATION_VM:
            widget = new ZipCodeWidget ( true );
            break;
    }

    return widget;
}

InitiatorWidget * FactoryMethodWidget::createInitiatorWidget ( ProgressWidget * progress )
{
    InitiatorWidget * widget = NULL;
    IMachineInitiator * initiator = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->getStartConfiguration().getInfoMachine() )
    {
        case InfoMachineConfiguration::CONFIGURATION_PM:
            initiator = new PMachineInitiator();
            widget = new PMInitiatorWidget ( progress, initiator );
            break;

        default:
        case InfoMachineConfiguration::CONFIGURATION_VM:
            initiator = new VMachineInitiator();
            widget = new VMInitiatorWidget ( progress, initiator );
            break;
    }

    return widget;
}

GenericButtonWidget * FactoryMethodWidget::createGenericButtonWidget()
{
    return new GenericButtonWidget();
}

CustomRemarkDiagnoseWidget * FactoryMethodWidget::createCustomRemarkDiagnoseWidget()
{
    CustomRemarkDiagnoseWidget * widget = NULL;

    switch ( SAESGUIConfigurationManager::getInstance()->getStartConfiguration().getInfoMachine() )
    {
        case InfoMachineConfiguration::CONFIGURATION_PM:
            widget = new CustomRemarkDiagnoseWidget ( false );
            break;

        default:
        case InfoMachineConfiguration::CONFIGURATION_VM:
            widget = new CustomRemarkDiagnoseWidget ( true );
            break;
    }

    return widget;
}

ResultsPackageTransmissionWidget * FactoryMethodWidget::createResultsPackageTransmissionWidget()
{
    return new ResultsPackageTransmissionWidget();
}

MouseWidget * FactoryMethodWidget::createMouseWidget()
{
    return new MouseWidget();
}
