/**
 * @file GenericButtonWidget.cxx
 * @brief Body class generic button widget
 * @date 29/11/2012
 * @author Yadickson Soto
 */

#include "GenericButtonWidget.hxx"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Operation/Voting/VotingOperation.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Voting::Vote;
using namespace Smartmatic::SAES::GUI::Operation::Voting;

GenericButtonWidget::GenericButtonWidget ( )
    : ButtonsWidget ( false )
{
    int width = SAESGUIConfigurationManager::getInstance()->getGenericWidgetConfiguration().getButtonConfiguration().getButtonWidth();
    int height = SAESGUIConfigurationManager::getInstance()->getGenericWidgetConfiguration().getButtonConfiguration().getButtonHeight();
    int size = SAESGUIConfigurationManager::getInstance()->getGenericWidgetConfiguration().getButtonConfiguration().getFontSize();

    acceptButton->set_size_request ( width, height );
    clearButton->set_size_request ( width, height );

    acceptButton->SetButtonType ( Smartmatic::GUI::Widgets::SmartmaticButton::Ok );
    clearButton->SetButtonType ( Smartmatic::GUI::Widgets::SmartmaticButton::Delete );

    acceptButton->WidgetsPosition ( 5, 6, 0 );
    clearButton->WidgetsPosition ( 5, 6, 0 );

    modifyFontSize ( size );

    update ();
}

GenericButtonWidget::~GenericButtonWidget()
{
}

void GenericButtonWidget::update()
{
    acceptButton->SetLabel ( _ ( "Smartmatic.SAES.GUI.Widgets.GenericButtonWidget.Accept" ) );
    clearButton->SetLabel ( _ ( "Smartmatic.SAES.GUI.Widgets.GenericButtonWidget.Cancel" ) );

    clearSignals();
}
