/**
 * @file GenericWidget.cxx
 * @brief Body class generic widget
 * @date 29/11/2012
 * @author Yadickson Soto
 */

#include "GenericWidget.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Log;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::GUI::Widgets;

ISMTTLog * GenericWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.GenericWidget", GETTEXT_PACKAGE );

GenericWidget::GenericWidget ( ProgressWidget * progress, GenericButtonWidget * buttons )
    : StepWidget(), progress ( progress ), buttons ( buttons )
{
    this->mainVBox = new SmartmaticBasicVBox ( false, 10 );
    progress->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::NONE );

    mainVBox->pack_start ( *progress, true, true, 0 );
    mainVBox->pack_end ( *buttons, false, true, 10 );

    this->setWidget ( mainVBox );

    mainVBox->setAccessibleName ( "GenericContainer" );
    buttons->setAccessibleName ( "GenericButtonsContainer" );
    setAccessibleName ( "GenericWidget" );
}

GenericWidget::~GenericWidget()
{
    remove();

    if ( mainVBox )
    {
        delete mainVBox;
        mainVBox = NULL;
    }

    if ( buttons )
    {
        delete buttons;
        buttons = NULL;
    }

    if ( progress )
    {
        delete progress;
        progress = NULL;
    }
}

void GenericWidget::setImage ( std::string image )
{
    progress->setImage ( image );
}

void GenericWidget::setImage ( Glib::RefPtr<Gdk::Pixbuf> pixbuff )
{
    progress->setImage ( pixbuff );
}

void GenericWidget::setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::Resource image )
{
    progress->setImage ( image );
}

void GenericWidget::setInfoTitle ( std::string text )
{
    progress->setInfoTitle ( text );
}

void GenericWidget::setInfoText ( std::string text )
{
    progress->setInfoText ( text );
}

void GenericWidget::setInfoFooter ( std::string text )
{
    progress->showInfoFooter ( ! ( text.empty() || text == " " ) );
    progress->setInfoFooter ( text );
}

void GenericWidget::setTextButtons ( std::string ok, std::string cancel )
{
    buttons->setTextAcceptButton ( ok );
    buttons->setTextClearButton ( cancel );
}

void GenericWidget::showButtons ( bool ok , bool cancel )
{
    buttons->showButton ( cancel, ok, false, false );

    if ( cancel || ok )
    {
        buttons->clearSignals();
    }
}

void GenericWidget::showInfoTitle ( bool visible )
{
    progress->showInfoTitle ( visible );
}

void GenericWidget::showImage ( bool visible )
{
    progress->showImage ( visible );
}

void GenericWidget::showInfoText ( bool visible )
{
    progress->showInfoText ( visible );
}

void GenericWidget::showInfoFooter ( bool visible )
{
    progress->showInfoFooter ( visible );
}

sigc::signal<void> GenericWidget::getSignalCancelButtonClicked()
{
    return buttons->getSignalClearButtonClicked();
}

sigc::signal<void> GenericWidget::getSignalAcceptButtonClicked()
{
    return buttons->getSignalAcceptButtonClicked();
}
