/**
 * @file GenericWidget.hxx
 * @brief Header class generic widget
 * @date 29/11/2012
 * @author Yadickson Soto
 */

#ifndef GENERICWIDGET_HXX_
#define GENERICWIDGET_HXX_

#include <Widgets/StepWidget.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include "GenericButtonWidget.hxx"
#include "ProgressWidget.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	GenericWidget
                 * @brief	Class generic widget.
                 * @author	Yadickson Soto
                 * @see StepWidget
                 * @date	29/11/2012
                 */
                class GenericWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:

                        /**
                         * @fn	GenericWidget::GenericWidget( ProgressWidget * progress, GenericButtonWidget * buttons );
                         * @brief	Class constructor.
                         * @param 	progress center widget
                         * @param	buttons generic buttons
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         */
                        GenericWidget ( ProgressWidget * progress, GenericButtonWidget * buttons );
                        /**
                         * @fn	virtual GenericWidget::~GenericWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         */
                        virtual ~GenericWidget();

                        /**
                         * @fn	virtual void GenericWidget::setImage ( std::string image );
                         * @brief	Virtual method setter image relative path to project.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @param	image	image relative path to project.
                         */
                        virtual void setImage ( std::string image );
                        /**
                         * @fn	virtual void GenericWidget::setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::Resource image );
                         * @brief	Virtual method setter image type.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @param	image	image type.
                         */
                        virtual void setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::Resource image );
                        /**
                         * @fn	virtual void GenericWidget::setImage ( Glib::RefPtr<Gdk::Pixbuf> pixbuff );
                         * @brief	Virtual method setter image pixbuff.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @param	pixbuff	The pixbuff.
                         */
                        virtual void setImage ( Glib::RefPtr<Gdk::Pixbuf> pixbuff );
                        /**
                         * @fn	void GenericWidget::setInfoTitle ( std::string text );
                         * @brief	Method setter title text.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @param	text	new title text.
                         */
                        void setInfoTitle ( std::string text );
                        /**
                         * @fn	void GenericWidget::setInfoText ( std::string text );
                         * @brief	Method setter bottom text.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @param	text	new bottom text.
                         */
                        void setInfoText ( std::string text );
                        /**
                         * @fn	void GenericWidget::setInfoFooter ( std::string text );
                         * @brief	Method setter footer text.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @param	text	new footer text.
                         */
                        void setInfoFooter ( std::string text );
                        /**
                         * @fn	void GenericWidget::setTextButtons( std::string ok, std::string cancel );
                         * @brief	Method setter text buttons.
                         * @param 	ok text ok buttons
                         * @param 	cancel text cancel buttons
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         */
                        void setTextButtons ( std::string ok, std::string cancel );
                        /**
                         * @fn	void GenericWidget::showInfoTitle( bool visible = true );
                         * @brief	Method show title.
                         * @param 	visible flag visible
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         */
                        void showInfoTitle ( bool visible = true );
                        /**
                         * @fn	void GenericWidget::showImage( bool visible = true );
                         * @brief	Method show image.
                         * @param 	visible flag visible
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         */
                        void showImage ( bool visible = true );
                        /**
                         * @fn	void GenericWidget::showInfoText( bool visible = true );
                         * @brief	Method show bottom text.
                         * @param 	visible flag visible
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         */
                        void showInfoText ( bool visible = true );
                        /**
                         * @fn	void GenericWidget::showInfoFooter( bool visible = true );
                         * @brief	Method show footer text.
                         * @param 	visible flag visible
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         */
                        void showInfoFooter ( bool visible = true );
                        /**
                         * @fn	void GenericWidget::showButtons( bool ok = true , bool cancel = true );
                         * @brief	Method show buttons.
                         * @param 	ok flag visible ok buttons
                         * @param 	cancel flag visible cancel buttons
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         */
                        void showButtons ( bool ok = true , bool cancel = true );
                        /**
                         * @fn	sigc::signal<void> GenericWidget::getSignalCancelButtonClicked();
                         * @brief	method getter signal cancel button clicked.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @return	signal clicked.
                         */
                        sigc::signal<void> getSignalCancelButtonClicked();
                        /**
                         * @fn	sigc::signal<void> GenericWidget::getSignalAcceptButtonClicked();
                         * @brief	method getter signal accept button clicked.
                         * @author	Yadickson Soto
                         * @date	29/11/2012
                         * @return	signal clicked.
                         */
                        sigc::signal<void> getSignalAcceptButtonClicked();

                    private:

                        Smartmatic::GUI::Widgets::SmartmaticBasicVBox * mainVBox; ///< principal container
                        ProgressWidget * progress; ///< center progress
                        Smartmatic::GUI::Widgets::ButtonsWidget * buttons; ///< buttons widgets
                        static Smartmatic::Log::ISMTTLog * logger;  ///< logger
                };
            }
        }
    }
}

#endif /* GENERICWIDGET_HXX_ */
