/**
 * @file IFillTableWidget.cxx
 * @brief Body Fill Table Widget
 * @date 22/04/2013
 * @author Yadickson Soto
 */

#include "IFillTableWidget.hxx"
#include <Widgets/ISizeWidget.hxx>

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;

IFillTableWidget::IFillTableWidget ( Smartmatic::GUI::Widgets::ITableWidget * tableWidget )
    : tableWidget ( tableWidget )
{
    this->flagSwing = false;
    this->flagPartialSwing = false;
    this->nRow = 0;
    this->nCol = 0;
    this->widgetW = 0.0;
    this->widgetH = 0.0;
    this->currentRow = 0;
    this->currentCol = 0;
}

IFillTableWidget::~IFillTableWidget()
{
    clear();

    if ( tableWidget )
    {
        delete tableWidget;
        tableWidget = NULL;
    }
}

void IFillTableWidget::addPrincipal ( Smartmatic::GUI::Widgets::ISizeWidget * widget )
{
    principalList.push_back ( widget );
}

void IFillTableWidget::addStandIn ( Smartmatic::GUI::Widgets::ISizeWidget * widget )
{
    standInList.push_back ( widget );
}

void IFillTableWidget::clear()
{
    std::list <Smartmatic::GUI::Widgets::ISizeWidget*>::iterator it;

    for (it = principalList.begin(); it != principalList.end(); ++it)
    {
        delete *it;
    }
    principalList.clear();

    for (it = standInList.begin(); it != standInList.end(); ++it)
    {
        delete *it;
    }
    standInList.clear();
}

void IFillTableWidget::fill ( Smartmatic::SAES::GUI::Widgets::Voting::IContestLayout * contestLayout, int totalW, int totalH )
{
    nCol = contestLayout->getColumns();
    nRow = contestLayout->getPivot();
    flagSwing = contestLayout->isSwing();
    flagPartialSwing = contestLayout->isPartialSwing();

    float rowSpacing = contestLayout->getSpacing();
    float colSpacing = contestLayout->getSpacing();

    //calculate rows of table
    widgetW = ( totalW - colSpacing * ( nCol - 1 ) ) / ( float ) nCol;
    widgetH = ( totalH - rowSpacing * ( nRow - 1 ) ) / ( float ) nRow;

    tableWidget->setSpacings ( colSpacing, colSpacing );

    currentRow = 0;
    currentCol = 0;

    putPrincipal();
    putStandIn();
}

void IFillTableWidget::putPrincipal()
{
    unsigned int size = principalList.size();
    unsigned int maxRow = nRow;

    unsigned int pRow;
    int aPivot;
    int standin = ( !standInList.empty() ? 1 : 0 );

    unsigned int principalColumns = ( size / this->nRow ) + ( size % this->nRow == 0 ? 0 : 1 ) + standin;
    bool maxCandidates = ( size > ( nCol - standin ) * nRow );

    if ( size <= nRow || maxCandidates || !flagSwing )
    {
        if (flagPartialSwing)
        {
            pRow = nRow - 1;
            aPivot = 1;
        }
        else
        {
            pRow = nRow;
            aPivot = 0;
        }
    }
    else
    {
        unsigned int value = ( principalColumns - standin );
        value = ( value == 0 ? 1 : value );

        pRow = ( size / value );
        aPivot = ( size % value );
    }

    tableWidget->resize ( nRow, nCol );
    std::list <Smartmatic::GUI::Widgets::ISizeWidget * >::iterator it;

    for ( it = principalList.begin();
            it != principalList.end();
            ++it )
    {
        ISizeWidget * ballot = static_cast < ISizeWidget * > ( *it );
        ballot->setSize ( widgetW, widgetH );

        tableWidget->put ( *it, currentRow, currentCol );

        currentRow++;
        unsigned int add = ( aPivot > 0 ? 1 : 0 );

        if ( currentRow == pRow + add )
        {
            currentRow = 0;
            currentCol++;
            aPivot--;
        }
        else if ( currentRow == maxRow )
        {
            currentRow = 0;
            currentCol++;
        }
    }
}

void IFillTableWidget::putStandIn()
{
    std::list <Smartmatic::GUI::Widgets::ISizeWidget * >::iterator it;

    //calculate first position of the substitute label, then position of stand-in widgets
    if ( ! ( currentRow > 0 && currentCol == nCol - 1 ) )
    {
        currentRow = 0;
    }

    currentCol = nCol - 1;

    //ballot_option substitute
    if ( !standInList.empty() )
    {
        putStandInTitle ();
        currentRow++;

        for ( it = standInList.begin(); it != standInList.end(); ++it )
        {
            ISizeWidget * ballot = static_cast < ISizeWidget * > ( *it );
            ballot->setSize ( widgetW, widgetH );

            tableWidget->put ( *it, currentRow, currentCol );

            currentRow++;

            if ( currentRow == nRow )
            {
                break;
            }
        }
    }
}

void IFillTableWidget::putStandInTitle ()
{

}
