/**
 * @file IFillTableWidget.hxx
 * @brief Header Fill Table Widget
 * @date 22/04/2013
 * @author Yadickson Soto
 */

#ifndef IFILLTABLEWIDGET_HXX_
#define IFILLTABLEWIDGET_HXX_

#include <Widgets/ITableWidget.hxx>
#include <Widgets/ISizeWidget.hxx>
#include <Gui/Widgets/Voting/IContestLayout.hxx>
#include <list>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class IFillTableWidget
                 * @brief Class Fill Table Widget, contains the logic to fill candidates and substitutes in the visual table of selections.
                 * @date 22/04/2013
                 * @author Yadickson Soto
                 */
                class IFillTableWidget
                {
                    public:
                        /**
                         * @fn IFillTableWidget ( Smartmatic::GUI::Widgets::ITableWidget * tableWidget );
                         * @brief Class constructor
                         * @date 22/04/2013
                         * @author Yadickson Soto
                         * @param tableWidget table
                         */
                        explicit IFillTableWidget ( Smartmatic::GUI::Widgets::ITableWidget * tableWidget );
                        /**
                         * @fn virtual ~IFillTableWidget();
                         * @brief Class destructor
                         * @date 22/04/2013
                         * @author Yadickson Soto
                         */
                        virtual ~IFillTableWidget();
                        /**
                         * @fn	void addPrincipal ( Smartmatic::GUI::Widgets::ISizeWidget * ballotOptionWidget );
                         * @brief	method to add a principal (candidate) widget to principalList
                         * @author	Yadickson Soto
                         * @date	23/04/2013
                         * @param 	ballotOptionWidget new widget.
                         */
                        void addPrincipal ( Smartmatic::GUI::Widgets::ISizeWidget * ballotOptionWidget );
                        /**
                         * @fn	void addStandIn ( Smartmatic::GUI::Widgets::ISizeWidget * ballotOptionWidget );
                         * @brief	method to add a stand-in widget to standInList
                         * @author	Yadickson Soto
                         * @date	23/04/2013
                         * @param	ballotOptionWidget new widget.
                         */
                        void addStandIn ( Smartmatic::GUI::Widgets::ISizeWidget * ballotOptionWidget );
                        /**
                         * @fn	void fill ( Smartmatic::SAES::Voting::Election::IContestLayout * contestLayout,
                         * 			int totalW, int totalH );
                         * @brief	method to fill table, contains the logic to fill candidates and substitutes in the visual table of selections.
                         * 			Uses principalList and standInList. Calls putPrincipal and putStandIn methods.
                         * @author	Yadickson Soto
                         * @date	23/04/2013
                         * @param	contestLayout	contest layout info.
                         * @param	totalW 	total width.
                         * @param	totalH 	total height.
                         */
                        void fill ( Smartmatic::SAES::GUI::Widgets::Voting::IContestLayout * contestLayout, int totalW, int totalH );
                        /**
                         * @fn	virtual void putPrincipal( );
                         * @brief	method to paint principal, is responsible for implementing filling behavior only for candidates.
                         * @author	Yadickson Soto
                         * @date	16/03/2012
                         */
                        virtual void putPrincipal( );
                        /**
                         * @fn	virtual void putStandIn();
                         * @brief	method to paint stand in, is responsible for implementing filling behavior only for substitutes.
                         * @author	Yadickson Soto
                         * @date	16/03/2012
                         */
                        virtual void putStandIn ( );
                        /**
                         * @fn	virtual void putStandInTitle ();
                         * @brief	method to paint the stand in title, only if there are substitutes. Calls putStandInTitle method if there are substitutes.
                         * @author	Yadickson Soto
                         * @date	23/04/2013
                         */
                        virtual void putStandInTitle ();
                        /**
                         * @fn	void clear();
                         * @brief	method to clear principalList and standInList, removes all objects of tableWidget.
                         * @author	Yadickson Soto
                         * @date	15/03/2012
                         */
                        void clear();

                    protected:

                        Smartmatic::GUI::Widgets::ITableWidget * tableWidget; ///< table widget
                        std::list <Smartmatic::GUI::Widgets::ISizeWidget * > principalList; ///< principal list
                        std::list <Smartmatic::GUI::Widgets::ISizeWidget * > standInList; ///< stand in list

                        unsigned int nRow; ///< number of rows
                        unsigned int nCol; ///< number of columns
                        bool flagSwing; ///< swing flag for row elements
                        bool flagPartialSwing; ///< partial swing flag for row elements

                        float widgetW; ///< widget width
                        float widgetH;	///< widget height

                        unsigned int currentRow; ///< current row
                        unsigned int currentCol; ///< current column
                };

            } /* namespace Widgets */
        } /* namespace GUI */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* IFILLTABLEWIDGET_HXX_ */
