/**
 * @file IconShutdownWidget.cxx
 * @brief Body class screen info voting widget
 * @date 30/04/2012
 * @author Yadickson Soto
 */

#include "IconShutdownWidget.hxx"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Environment/Configurations/resource-path-provider.h>
#include <System/Runtime/PowerDown.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::Environment;
using namespace Smartmatic::System::Runtime;
using namespace Smartmatic::SAES::Configuration;

IconShutdownWidget::IconShutdownWidget ( ProgressWidget * progress )
    : StepWidget(), progress ( progress )
{
    progress->setInfoTitleConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );
    progress->setInfoTextConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );
    progress->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::NONE );
    progress->setInfoTitle ( "  " );
    progress->setInfoText ( "  " );

    button = new SmartmaticButton();
    button->WidgetsPosition ( 0, 5, 0 );
    button->set_no_show_all();
    button->set_visible ( false );
    button->SetImage ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/screen-shut-down.png" ) );
    button->signal_clicked().connect ( sigc::mem_fun ( *this, &IconShutdownWidget::shutdown ) );

    ButtonConfiguration conf = SAESGUIConfigurationManager::getInstance()->getProcessStatusResultsShutdownFunctionalityConfiguration().getShutDownButtonConf();
    button->ModifyFontSize ( conf.getFontSize() );
    button->set_size_request ( conf.getButtonWidth(), conf.getButtonHeight() );

    hbutton = new Gtk::HButtonBox();
    hbutton->pack_start ( *button, false, false, 10 );

    box = new Gtk::VBox();
    box->pack_start ( *progress );
    box->pack_end ( *hbutton, false, false );

    setTitle ( false );
    setShowBorder ( true );
    setWidget ( box );
}

IconShutdownWidget::~IconShutdownWidget()
{
    this->remove();

    if ( progress )
    {
        delete progress;
        progress = NULL;
    }

    if ( box )
    {
        delete box;
        box = NULL;
    }

    if ( button )
    {
        delete button;
        button = NULL;
    }

    if ( hbutton )
    {
        delete hbutton;
        hbutton = NULL;
    }
}

void IconShutdownWidget::setImageError()
{
    progress->setImage ( "ui/screen-error.png" );
    button->set_visible ( true );
}

void IconShutdownWidget::setImageOk()
{
    progress->setImage ( "ui/screen-ok.png" );
    button->set_visible ( true );
}

void IconShutdownWidget::shutdown()
{
    PowerDown::shutdown();
}
