/**
 * @file	LanguageInstallWidget.hxx
 * @brief	language install widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef LANGUAGEINSTALLWIDGET_HXX_
#define LANGUAGEINSTALLWIDGET_HXX_

#include <gtkmm.h>
#include "change-language-widget.h"
#include <Widgets/StepWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	LanguageInstallWidget
                 * @brief	Language install widget.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class LanguageInstallWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:
                        /**
                         * @fn	LanguageInstallWidget::LanguageInstallWidget();
                         * @brief	Default constructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        LanguageInstallWidget();
                        /**
                         * @fn	virtual LanguageInstallWidget::~LanguageInstallWidget();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        virtual ~LanguageInstallWidget();

                        /**
                         * @fn	void LanguageInstallWidget::setSaveFile ( bool save );
                         * @brief	Sets save file.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	save	true to save.
                         */
                        void setSaveFile ( bool save );
                        /**
                         * @fn	void LanguageInstallWidget::start ( bool force );
                         * @brief	Starts.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	force	true to force.
                         */
                        void start ( bool force );

                        /**
                         * @brief  Get the signal on failed to find a language.
                         * @author manuel.arguelles
                         * @date   Mar 26, 2018
                         * @return The language not found signal.
                         */
                        sigc::signal<void> getSignalLanguageNotFound();

                    private:

                        Smartmatic::SAES::GUI::Widgets::ChangeLanguageWidget * languageWidget;	///< The language widget
                        static Smartmatic::Log::ISMTTLog * logger;	///< The logger

                        sigc::signal<void> signalLanguageNotFound;

                    protected:

                        /**
                         * @fn	void LanguageInstallWidget::initialize();
                         * @brief	Initializes this object.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void initialize();
                        /**
                         * @fn	void LanguageInstallWidget::dispose();
                         * @brief	Performs application-defined tasks associated with freeing, releasing, or resetting
                         * 				unmanaged resources.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void dispose();
                        /**
                         * @fn	void LanguageInstallWidget::end();
                         * @brief	Ends this object.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void end();
                };
            }
        }
    }
}

#endif /* LANGUAGEINSTALLWIDGET_HXX_ */
