/**
 * @file	LogTreeViewWidget.cc
 * @brief	log tree view widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#include "LogTreeViewWidget.h"

#include <Configuration/MachineModelEnum.hxx>
#include <Configuration/s-m-t-t-g-u-i-conf-manager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

#define DATE_COLUMN_MIN_WIDTH 200
#define DATE_COLUMN_MAX_WIDTH 200
#define LIBRARY_COLUMN_MIN_WIDTH 100
#define LIBRARY_COLUMN_MAX_WIDTH 100
#define MESSAGE_COLUMN_MIN_WIDTH 500
#define MESSAGE_COLUMN_MAX_WIDTH 500
#define LEVEL_COLUMN_MIN_WIDTH 100
#define LEVEL_COLUMN_MAX_WIDTH 100
#define SINCE_START_COLUMN_MIN_WIDTH 100
#define SINCE_START_COLUMN_MAX_WIDTH 100
#define TREE_VIEW_ROW_MAX_HEIGHT 30

using namespace Gtk;
using namespace Glib;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::Log;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::Configuration;

LogTreeViewWidget::LogTreeViewWidget()
{
    std::string sDate = _ ( "Smartmatic.SAES.GUI.Widgets.LogTreeViewWidget.Date" );
    std::string sLibrary = _ ( "Smartmatic.SAES.GUI.Widgets.LogTreeViewWidget.Library" );
    std::string sMessage = _ ( "Smartmatic.SAES.GUI.Widgets.LogTreeViewWidget.Message" );
    std::string sLevel = _ ( "Smartmatic.SAES.GUI.Widgets.LogTreeViewWidget.Level" );
    std::string sSinceStart = _ ( "Smartmatic.SAES.GUI.Widgets.LogTreeViewWidget.SinceStart" );

    int dateColumnMinWidth = DATE_COLUMN_MIN_WIDTH;
    int dateColumnMaxWidth = DATE_COLUMN_MAX_WIDTH;
    int libraryColumnMinWidth = LIBRARY_COLUMN_MIN_WIDTH;
    int libraryColumnMaxWidth = LIBRARY_COLUMN_MAX_WIDTH;
    int messageColumnMinWidth = MESSAGE_COLUMN_MIN_WIDTH;
    int messageColumnMaxWidth = MESSAGE_COLUMN_MAX_WIDTH;
    int levelColumnMinWidth = LEVEL_COLUMN_MIN_WIDTH;
    int levelColumnMaxWidth = LEVEL_COLUMN_MAX_WIDTH;
    int sinceStartColumnMinWidth = SINCE_START_COLUMN_MIN_WIDTH;
    int sinceStartColumnMaxWidth = SINCE_START_COLUMN_MAX_WIDTH;
    int treeViewRowHeight = -1;

    if ( SMTTGUIConfigurationManager::getInstance()->getSmartmaticGUIMachineModelConfiguration().getId() == EnumToString( PM_VIU805 ) )
    {
        double guiReconfigurationFactor = SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSmartmaticGUIMachineModelConfiguration().getGuiReconfigurationFactor();

        dateColumnMinWidth *= guiReconfigurationFactor;
        dateColumnMaxWidth *= guiReconfigurationFactor;
        libraryColumnMinWidth *= guiReconfigurationFactor;
        libraryColumnMaxWidth *= guiReconfigurationFactor;
        messageColumnMinWidth *= guiReconfigurationFactor;
        messageColumnMaxWidth *= guiReconfigurationFactor;
        levelColumnMinWidth *= guiReconfigurationFactor;
        levelColumnMaxWidth *= guiReconfigurationFactor;
        sinceStartColumnMinWidth *= guiReconfigurationFactor;
        sinceStartColumnMaxWidth *= guiReconfigurationFactor;
        treeViewRowHeight = TREE_VIEW_ROW_MAX_HEIGHT;
    }

    refListStore = ListStore::create ( logLineTreeModel );
    set_model ( refListStore );

    Gtk::CellRendererText *cellRendererText = new Gtk::CellRendererText();
    cellRendererText->set_fixed_size( -1, treeViewRowHeight );
    TreeViewColumn * column = manage ( new TreeViewColumn ( sDate, logLineTreeModel.date ) );
    column->set_resizable ( false );
    column->set_min_width ( dateColumnMinWidth );
    column->set_max_width ( dateColumnMaxWidth );
    column->set_alignment ( 0.5 );
    column->set_visible ( true );
    column->pack_start( *cellRendererText, false );
    append_column ( *column );
    column = manage ( new TreeViewColumn ( sLibrary, logLineTreeModel.library ) );
    column->set_resizable ( false );
    column->set_min_width ( libraryColumnMinWidth );
    column->set_max_width ( libraryColumnMaxWidth );
    column->set_alignment ( 0.5 );
    column->set_visible ( false );
    column->pack_start( *cellRendererText, false );
    append_column ( *column );
    column = manage ( new TreeViewColumn ( sMessage, logLineTreeModel.message ) );
    column->set_resizable ( false );
    column->set_min_width ( messageColumnMinWidth );
    column->set_max_width ( messageColumnMaxWidth );
    column->set_alignment ( 0.5 );
    column->set_visible ( true );
    column->pack_start( *cellRendererText, false );
    append_column ( *column );
    column = manage ( new TreeViewColumn ( sLevel, logLineTreeModel.level ) );
    column->set_resizable ( false );
    column->set_min_width ( levelColumnMinWidth );
    column->set_max_width ( levelColumnMaxWidth );
    column->set_alignment ( 0.5 );
    column->set_visible ( false );
    column->pack_start( *cellRendererText, false );
    append_column ( *column );
    column = manage ( new TreeViewColumn ( sSinceStart, logLineTreeModel.sinceStart ) );
    column->set_resizable ( false );
    column->set_min_width ( sinceStartColumnMinWidth );
    column->set_max_width ( sinceStartColumnMaxWidth );
    column->set_alignment ( 0.5 );
    column->set_visible ( false );
    column->pack_start( *cellRendererText, false );
    append_column ( *column );
    //set_size_request (800,380);
}

LogTreeViewWidget::~LogTreeViewWidget()
{
}

void LogTreeViewWidget::AddRow ( LogLine logLine )
{
    TreeModel::Row row;
    row = * ( refListStore->append() );
    row[logLineTreeModel.date] = logLine.getDate();
    row[logLineTreeModel.library] = logLine.getLibrary();
    row[logLineTreeModel.message] = logLine.getMessage();
    row[logLineTreeModel.level] = "Level";
    row[logLineTreeModel.sinceStart] = "1234";
}


bool LogTreeViewWidget::IsRowSelected()
{
    return currentCustomCode == "" ? false : true;
}

void LogTreeViewWidget::GetRow ( std::string customCode, LogLine & logLine )
{
}

void LogTreeViewWidget::SelectionChanged()
{
}

std::string LogTreeViewWidget::GetCodeSelected()
{
    return currentCustomCode;
}
