/**
 * @file	menu-option.h
 * @brief	Declares the menu option class.
 */

/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * saesguibase
 * Copyright (C)  2010 <>
 *
 * saesguibase is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * saesguibase is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _MENU_OPTION_H_
#define _MENU_OPTION_H_

#include <string>
#include <vector>
#include <Configuration/menu-option-type-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {

                /**
                 * @class	MenuOption
                 * @brief	Menu option.
                 * @author	Youssef.tourkmani
                 * @date	25/10/2012
                 */
                class MenuOption
                {
                    public:

                        /**
                         * @fn	MenuOption::MenuOption();
                         * @brief	Default constructor.
                         * @author	Luiggi.mendez
                         * @date	27/04/2011
                         */
                        MenuOption();

                        /**
                         * @fn	MenuOption::MenuOption( const std::string & nameKey, const std::string & accessibleName );
                         * @brief	Constructor.
                         * @author	Luiggi.mendez
                         * @date	27/04/2011
                         * @param	nameKey	The name key.
                         * @param	accessibleName accessible name code
                         */
                        MenuOption ( const std::string & nameKey, const std::string & accessibleName );

                        std::string nameKey;	///< The name key
                        std::string imageKey;   ///< The image key
                        std::string accessibleName; ///< accessible name code

                        int width; /// width menu
                        int height; ///< height menu
                        int code;   ///< The code
                        int mappingKey; ///< The mapping key
                        std::string mappingKeyName; ///< Name of the mapping key
                        Smartmatic::SAES::Functionality::Configuration::MenuOptionType optionDescriptor;   ///< The option descriptor
                        std::vector<MenuOption> v_MenuOption;   ///< The v menu option

                        /**
                         * @fn	void MenuOption::SetOptionType(Smartmatic::Functionality::MenuOptionDescriptor& option)
                         * @brief	Sets an option type.
                         * @author	Luiggi.mendez
                         * @date	27/04/2011
                         * @param	option	The option.
                         */
                        void SetOptionType ( const Smartmatic::SAES::Functionality::Configuration::MenuOptionType & option )
                        {
                            optionDescriptor = option;
                        };

                        /**
                         * @fn	static std::vector<MenuOption> MenuOption::GetDefaultConfiguration();
                         * @brief	Gets the default configuration.
                         * @author	Luiggi.mendez
                         * @date	27/04/2011
                         * @return	The default configuration.
                         */
                        static std::vector<MenuOption> GetDefaultConfiguration();

                    private:

                        /**
                         * @fn	static void MenuOption::LoadMenuLabels(std::vector<MenuOption> &v_Option);
                         * @brief	Loads a menu labels.
                         * @author	Luiggi.mendez
                         * @date	27/04/2011
                         * @param	v_Option	The v option.
                         */
                        static void LoadMenuLabels ( std::vector<MenuOption> & v_Option );
                };
            }
        }
    }
}

#endif // _MENU_OPTION_H_
