/**
 * @file	OpenElectionStatusWidget.hxx
 * @brief	open election status widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _OPEN_ELECTION_STATUS_WIDGET_H_
#define _OPEN_ELECTION_STATUS_WIDGET_H_

#include <Widgets/wizard-widget-base.h>
#include "ProgressWidget.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	OpenElectionStatusWidget
                 * @brief	Close election status widget.
                 * @author	Cesar.bonilla
                 * @date	4/29/2011
                 */

                class OpenElectionStatusWidget: public Smartmatic::GUI::Widgets::WizardWidgetBase
                {
                    public:

                        /**
                         * @fn	OpenElectionStatusWidget::OpenElectionStatusWidget ( ProgressWidget * progress );
                         * @brief	Default constructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	progress	widget with label and image.
                         */

                        explicit OpenElectionStatusWidget ( ProgressWidget * progress );

                        /**
                         * @fn	OpenElectionStatusWidget::~OpenElectionStatusWidget();
                         * @brief	Finaliser.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        ~OpenElectionStatusWidget();
                        /**
                         * @fn	virtual void OpenElectionStatusWidget::initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void OpenElectionStatusWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void dispose();

                        /**
                         * @fn	virtual bool OpenElectionStatusWidget::isEnabledButtonExitWizard();
                         * @brief	Method getter is enabled button exit wizard.
                         * @author	Yadickson Soto
                         * @date	22/02/2012
                         * @return	true is enabled button exit wizard.
                         */
                        virtual bool isEnabledButtonExitWizard();

                    private:
                        ProgressWidget * progress; ///< widget with label and image
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger

                        /**
                         * @fn	void OpenElectionStatusWidget::end();
                         * @brief	Method end persist codi files.
                         * @author	Yadickson Soto
                         * @date	16/02/2012
                         */
                        void end();

                        /**
                         * @fn	void OpenElectionStatusWidget::updateLabel ( std::string text );
                         * @brief	Method start persist codi files.
                         * @author	Yadickson Soto
                         * @date	16/02/2012
                         * @param	text	new text for widget.
                         */
                        void updateLabel ( std::string text );
                };
            }
        }
    }
}

#endif // _OPEN_ELECTION_STATUS_WIDGET_H_
