#include "RecountInfoVoteWidget.h"
#include "ConfigBridge.h"
#include <Environment/Configurations/resource-path-provider.h>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/smartmatic-entry.h>
#include <Widgets/SmartmaticBasicTable.hxx>
#include <Voting/VotingCenters/VotingCentersWrapper.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Environment;
using namespace Smartmatic::Log;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::GUI::Operation;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Operation;


namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Recount
                {

                    RecountInfoVoteWidget::RecountInfoVoteWidget()
                    {
                        logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.ProgressWidget", GETTEXT_PACKAGE );

                        std::string gladeFile = ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/RecountInfoVoteWidget.glade" );

                        try
                        {
                            builder = Gtk::Builder::create_from_file ( gladeFile );
                        }
                        catch ( const Glib::FileError & ex )
                        {
                            logger->Debug ( "FATAL - RecountInfoVoteWidget Initialize" );
                        }

                        mainFrame = NULL;
                        builder->get_widget ( "recount-frame", mainFrame );

                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel
                        *labelFrameName, *labelSession, *labelBallot, *labelVoter, *labelKey, *labelValid, *labelMaxMax;
                        builder->get_widget_derived ( "label-frame-name", labelFrameName );
                        builder->get_widget_derived ( "label-session", labelSession );
                        builder->get_widget_derived ( "label-ballot", labelBallot );
                        builder->get_widget_derived ( "label-voter", labelVoter );
                        builder->get_widget_derived ( "label-key", labelKey );
                        builder->get_widget_derived ( "label-valid", labelValid );

                        if ( labelFrameName )
                        {
                            LabelConfiguration::SetLabelConfiguration ( labelFrameName, ConfigBridge::recountScanInfoHeader );
                            Smartmatic::SAES::Voting::VotingCenters::VotingCenter votingCenter;
                            Smartmatic::SAES::Voting::VotingCenters::VotingCentersWrapper::getInstance()->getInstallationVotingCenter ( votingCenter );
                            labelFrameName->set_text ( votingCenter.getCode() );
                        }

                        if ( labelSession )
                        {
                            LabelConfiguration::SetLabelConfiguration ( labelSession, ConfigBridge::recountScanInfoLabel );
                            labelSession->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Scan.Session" ) );
                        }

                        if ( labelBallot )
                        {
                            LabelConfiguration::SetLabelConfiguration ( labelBallot, ConfigBridge::recountScanInfoLabel );
                            labelBallot->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Scan.Ballot" ) );
                        }

                        if ( labelVoter )
                        {
                            LabelConfiguration::SetLabelConfiguration ( labelVoter, ConfigBridge::recountScanInfoLabel );
                            labelVoter->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Scan.Voter" ) );
                        }

                        if ( labelKey )
                        {
                            LabelConfiguration::SetLabelConfiguration ( labelKey, ConfigBridge::recountScanInfoLabel );
                            labelKey->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Scan.Key" ) );
                        }

                        if ( labelValid )
                        {
                            LabelConfiguration::SetLabelConfiguration ( labelValid, ConfigBridge::recountScanInfoLabel );
                            labelValid->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Scan.Valid" ) );
                        }


                        builder->get_widget_derived ( "entry-session-num", m_eSessionNum );
                        builder->get_widget_derived ( "entry-session-id", m_eSessionID );
                        builder->get_widget_derived ( "entry-ballot", m_eBallotID );
                        builder->get_widget_derived ( "entry-voter", m_eVoter );
                        builder->get_widget_derived ( "entry-key", m_eKey );
                        builder->get_widget_derived ( "eventbox-valid", m_ebValid );

                        bool extendedView = SAESGUIConfigurationManager::getInstance()->getRecountFunctionalityConfiguration().getExtendedView();

                        if ( !extendedView )
                        {
                            Smartmatic::GUI::Widgets::SmartmaticBasicTable * tableHolder;
                            builder->get_widget_derived ( "table-holder", tableHolder );

                            if ( tableHolder && m_eKey && labelKey && labelValid && m_ebValid )
                            {
                                tableHolder->remove ( *labelKey );
                                tableHolder->remove ( *m_eKey );
                                tableHolder->remove ( *labelValid );
                                tableHolder->remove ( *m_ebValid );
                                tableHolder->attach ( *labelValid, 	0, 1, 3, 4, 	Gtk::SHRINK | Gtk::FILL, Gtk::SHRINK | Gtk::FILL );
                                tableHolder->attach ( *m_ebValid, 	1, 2, 3, 4, 	Gtk::SHRINK | Gtk::FILL, Gtk::SHRINK | Gtk::FILL );
                            }
                        }

                        builder->get_widget_derived ( "label-maxmax", labelMaxMax );

                        if ( labelMaxMax )
                        {
                            LabelConfiguration::SetLabelConfiguration ( labelMaxMax, ConfigBridge::recountScanInfoLabel );
                            labelMaxMax->set_text ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Scan.LabelTotal" ) );
                        }

                        builder->get_widget_derived ( "label-total", m_lMaxMax );

                        if ( m_lMaxMax )
                        {
                            LabelConfiguration::SetLabelConfiguration ( m_lMaxMax, ConfigBridge::recountScanPageTotalLabelConfig );
                        }

                        SetMaxMax ( 0 );

                        this->setWidget ( mainFrame );
                    }

                    void RecountInfoVoteWidget::SetValid ( bool state )
                    {
                        if ( m_ebValid )
                        {
                            const char * s = state ? "RecountScanVoteValid-Valid" : "RecountScanVoteValid-Invalid";
                            m_ebValid->set_name ( s );
                        }
                    }

                    RecountInfoVoteWidget::~RecountInfoVoteWidget()
                    {
                        // gladeFile and internal elements are auto-manageable

                        delete mainFrame; // deleting NULL is valid
                    }

                    void RecountInfoVoteWidget::initialize()
                    {
                    }

                    void RecountInfoVoteWidget::SetVote ( const int sessionNum, const std::string & code, const std::string & sessionID,
                                                          const std::string & ballotID, const std::string & votingGroup )
                    {
                        if ( m_eSessionNum )
                        {
                            std::ostringstream oss;
                            oss << sessionNum;
                            m_eSessionNum->set_text ( oss.str().c_str() );
                        }

                        if ( m_eSessionID )
                        {
                            m_eSessionID->set_text ( sessionID );
                        }

                        if ( m_eBallotID )
                        {
                            m_eBallotID->set_text ( ballotID );
                        }

                        if ( m_eVoter )
                        {
                            m_eVoter->set_text ( votingGroup );
                        }

                        SetValid ( true );
                    }

                    void RecountInfoVoteWidget::SetVoteFailed()
                    {
                        if ( m_eSessionNum )
                        {
                            m_eSessionNum->set_text ( "" );
                        }

                        if ( m_eSessionID )
                        {
                            m_eSessionID->set_text ( "" );
                        }

                        if ( m_eBallotID )
                        {
                            m_eBallotID->set_text ( "" );
                        }

                        if ( m_eVoter )
                        {
                            m_eVoter->set_text ( "" );
                        }

                        SetValid ( false );
                    }

                    void RecountInfoVoteWidget::SetVoteSuccess()
                    {
                        SetValid ( true );
                    }

                    void RecountInfoVoteWidget::SetMaxMax ( int maxMax )
                    {
                        if ( m_lMaxMax )
                        {
                            std::stringstream ss;
                            ss << maxMax;
                            m_lMaxMax->set_markup ( ss.str() );
                        }
                    }

                } /* Recount */
            } /* namespace Widgets */
        } /* namespace GUI */
    } /* namespace SAES */
} /* namespace Smartmatic */
