#ifndef RECOUNTINFOVOTEWIDGET_H_
#define RECOUNTINFOVOTEWIDGET_H_

#include <Widgets/StepWidget.hxx>
#include <Configuration/label-configuration.h>
#include <Operation/ImageResourcePath.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/smartmatic-entry.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Recount
                {

                    class RecountInfoVoteWidget : public Smartmatic::GUI::Widgets::StepWidget
                    {

                        private:
                            Smartmatic::Log::ISMTTLog * logger;
                            Glib::RefPtr<Gtk::Builder> builder;
                            Gtk::Frame * mainFrame; ///< main widget
                            Smartmatic::GUI::Widgets::SmartmaticEntry * m_eSessionNum, ///< display for session number
                                       * m_eSessionID, ///< display for session id
                                       * m_eBallotID, ///< display for ballot id
                                       * m_eVoter, ///< display for voter type
                                       * m_eKey; ///< display for key id (if enabled)
                            SmartmaticBasicEventBox * m_ebValid; ///< color box with scanned vote status
                            Smartmatic::GUI::Widgets::SmartmaticBasicLabel * m_lMaxMax; ///< the "big" counter label

                            /**
                             * Mainly, changes the color of the box
                             */
                            void SetValid ( bool );

                        public:
                            /**
                             * Constructor
                             */
                            RecountInfoVoteWidget();

                            /**
                             * Destructor
                             */
                            virtual ~RecountInfoVoteWidget();

                            /**
                             * Applies votes data
                             */
                            void SetVote ( const int sessionNum, ///< number of session
                                           const std::string & code, ///< code
                                           const std::string & sessionID, ///< session id
                                           const std::string & ballotID, ///< ballot id
                                           const std::string & votingGroup ///< voting group
                                         );

                            /**
                             * Redraws the widget on failure
                             */
                            void SetVoteFailed();

                            /**
                             * Redraws the widget on success
                             */
                            void SetVoteSuccess();

                            /**
                             * Updates the big counter
                             */
                            void SetMaxMax ( int maxMax );

                        private:

                            /**
                             * initialization hepler
                             */
                            virtual void initialize();
                    };


                } /* Recount */
            } /* namespace Widgets */
        } /* namespace GUI */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* RECOUNTINFOVOTEWIDGET_H_ */
