#ifndef	SMARTMATIC_SAES_GUI_WIDGETS_RECOUNT_RECOUNTSESSION
#define	SMARTMATIC_SAES_GUI_WIDGETS_RECOUNT_RECOUNTSESSION

#include "ClickAbsorber.h"
#include "RecountResultFieldButton.h"
#include "RecountStatPage.h"
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Log/SMTTLogManager.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Recount
                {

                    /**
                     * Represents a single voting session (table in a row)
                     */
                    class RecountSession : public ClickAbsorber
                    {
                        private:
                            Smartmatic::GUI::Widgets::SmartmaticBasicLabel m_sessionName; ///< header for each row (session)
                            std::vector<RecountResultFieldButton *> m_fields; ///< the active elements in each session
                            bool m_isTotals; ///< is this the last row with counters
                            class RecountStatPage * m_thePage; ///< the parent page that holds the table itself
                            int m_row; ///< own row position in te table
                            static int m_startRow; ///< first table-based row number for sessions, after headers
                            bool m_isVisible; ///< current visibility of the session
                            bool m_toRedraw; /// does the current state implies redraw of the elements
                            Smartmatic::Log::ISMTTLog * m_logger; ///< logger
                            int m_maxMax; ///< total-total votes

                        public:

                            /**
                             * Constructor
                             */
                            RecountSession ( RecountStatPage * t, ///< the "parent" page
                                             const char * name, ///< name of session
                                             const char * tooltip, ///< relevant tooltip with session id
                                             int row, ///< our row
                                             bool isLast /// are we the last row with totals
                                           );

                            /**
                             * Destructor
                             */
                            virtual ~RecountSession ( );

                            /**
                             * Relevant for last Total rows only
                             * This function implements a specialized Refresh for the last session. In this regard one better
                             * architecture could be to mockup a new class that inherits RecountSession and just reimplement
                             * Refresh method, but I have no time for this under my mission.
                             */
                            void PopulateTotals ( const std::vector<int> & accumV, ///< pass-over variable from previous to the next
                                                  std::vector<int> & activeV, ///< pass-over variable from previous to the next
                                                  std::vector<int> & maxV, ///< pass-over variable from previous to the next
                                                  std::vector<ClickAbsorber::STATE> & statusV ///< pass-over variable from previous to the next
                                                );

                            /**
                             * Recalculates and sets state, unless last row
                             */
                            void Refresh ( std::vector<int> & accumV, ///< pass-over variable from previous to the next
                                           std::vector<int> & activeV, ///< pass-over variable from previous to the next
                                           std::vector<int> & maxV, ///< pass-over variable from previous to the next
                                           std::vector<ClickAbsorber::STATE> & statusV ///< pass-over variable from previous to the next
                                         );

                            /**
                             * Consumes click or parent click events
                             */
                            void OnStatusChanged ( int x, ///< column
                                                   int y, ///< row
                                                   ClickAbsorber::STATE state ///< current state
                                                 );

                            /**
                             * Sets the tooltip
                             */
                            void SetTooltip ( const char * ///< the new text
                                            );

                            /**
                             * sets/unsets active state
                             */
                            void SetActive ( bool active ///< the new active state
                                           );

                            /**
                             * Sets the start row static member
                             */
                            static void SetStartRow ( int row ///< row
                                                    );

                            /**
                             * Sets our row
                             */
                            void SetRow ( int row ///< row
                                        );

                            /**
                             * Draws - attaches/detaches relevant active elements
                             */
                            void Draw();

                            /**
                             * Increase a vote for specific field
                             */
                            inline void IncField ( int fieldNum ///< field index, 0-based
                                                 )
                            {
                                m_fields[fieldNum]->Inc(); // some marginal speed improvements via inline call
                            }

                            /**
                             * Discloses elements (corresponding to votes) prepared for erasure
                             */
                            void GetForPersistence ( std::list< std::pair<int, int> > & deleteQueue ///< [out] list of coordinates
                                                   );

                            /**
                             * Get votes remaining, not selected for erasure
                             * Must be called on Totals session
                             *
                             * @return number of votes
                             */
                            int GetTotal();

                            /**
                             * Returns All votes counted
                             * Must be called on Totals session
                             * Non-synchronized access
                             *
                             * @return number of votes
                             */
                            int GetMaxMax();
                    };

                }
            }
        }
    }
}

#endif
