/*
 * RecountWidget.cpp
 *
 *  Created on: Apr 29, 2013
 *      Author: Georgi Demirchev
 */

#include "RecountWidget.h"
#include "Recount/ConfigBridge.h"
#include <Configuration/MachineModelEnum.hxx>
#include <Configuration/s-m-t-t-g-u-i-conf-manager.h>
#include <Widgets/SmartmaticBasicScrollContainer.hxx>
#include <iostream>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Widgets;

RecountWidget::RecountWidget ( const std::list<std::string> & voterTypes )
{
    m_configBridge = new Recount::ConfigBridge(); // must be instantiated only here

    m_scanPage = manage ( new Recount::RecountInfoVoteWidget() );
    SmartmaticBasicScrollContainer * sw = Gtk::manage ( new SmartmaticBasicScrollContainer() );
    m_statPage = Gtk::manage ( new Recount::RecountStatPage ( voterTypes ) );
    sw->set_policy ( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC );
    sw->add ( *m_statPage );
    m_statPage->show_all_children ( true );
    m_statPage->show_all();
    m_statPage->show();

    notebookContainer = manage ( new NotebookContainer() );
    notebookContainer->ShowTabs ( true );

    notebookContainer->AppendPage ( m_scanPage, _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.ScanPage" ) );
    notebookContainer->AppendPage ( sw, _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.StatPage" ) );
    sw->show_all_children ( true );
    sw->show_all();
    sw->show();

    int exitButtonWidth = Recount::ConfigBridge::recountExitButtonXSize;

    if ( SMTTGUIConfigurationManager::getInstance()->getSmartmaticGUIMachineModelConfiguration().getId() == EnumToString( PM_VIU805 ) )
    {
        double guiReconfigurationFactor = SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSmartmaticGUIMachineModelConfiguration().getGuiReconfigurationFactor();

        exitButtonWidth *= guiReconfigurationFactor;
    }

    Smartmatic::GUI::Widgets::SmartmaticButton * button = Gtk::manage ( new Smartmatic::GUI::Widgets::SmartmaticButton() );
    button->signal_clicked().connect ( sigc::mem_fun ( *this, &RecountWidget::showConfirmation ) );
    button->SetLabel ( _ ( "Smartmatic.SAES.GUI.Widgets.RecountWidget.Exit" ) );
    button->set_size_request ( exitButtonWidth, -1 );
    notebookContainer->AddBottomWidget ( button );
    setWidget ( notebookContainer );

    refresh();
}

RecountWidget::~RecountWidget()
{
    delete m_configBridge;
}

void RecountWidget::refresh()
{
}

void RecountWidget::SetVote ( int num, const std::string & code, const std::string & sessionID,
                              const std::string & ballotID, const std::string & votingGroup )
{
    m_scanPage->SetVote ( num, code, sessionID, ballotID, votingGroup );
}

void RecountWidget::SetVoteFailed()
{
    m_scanPage->SetVoteFailed();
}

void RecountWidget::SetVoteSuccess()
{
    m_scanPage->SetVoteSuccess();
}

void RecountWidget::Update ( const std::list< std::pair<int, int> > & updates, const std::list<std::string> & updateSessionNames )
{
    m_statPage->Update ( updates, updateSessionNames );

    m_scanPage->SetMaxMax ( m_statPage->GetMaxMax() ); // updates the scan page with total from stat
}

void RecountWidget::exit()
{
    emit();
}

void RecountWidget::before()
{
    m_resumeSignal.emit();
    setWidget ( notebookContainer );
}

void RecountWidget::GetForPersistence ( std::list< std::pair<int, int> > & deleteQueue )
{
    return m_statPage->GetForPersistence ( deleteQueue );
}

void RecountWidget::showConfirmation()
{
    int maxMax = m_statPage->GetMaxMax();
    Recount::RecountPersistConfirm * persistConfirm = new Recount::RecountPersistConfirm ( maxMax, m_statPage->GetTotal() );

    persistConfirm->getSignalCancel().connect ( sigc::mem_fun ( *this, &RecountWidget::before ) );
    persistConfirm->getSignalOK().connect ( sigc::mem_fun ( *this, &RecountWidget::exit ) );
    m_pauseSignal.emit();
    setWidget ( persistConfirm );
}

RecountWidget::PauseSignal RecountWidget::pauseSignal()
{
    return m_pauseSignal;
}

RecountWidget::ResumeSignal RecountWidget::resumeSignal()
{
    return m_resumeSignal;
}
