/**
 * @file ReferendumTableWidget.hxx
 * @brief Header class referendum table widget
 * @date 16/10/2012
 * @author Yadickson Soto
 */

#ifndef REFERENDUMTABLEWIDGET_HXX_
#define REFERENDUMTABLEWIDGET_HXX_

#include <gtkmm.h>
#include <Voting/Election/election-schema.hxx>
#include <Widgets/SmartmaticBasicEventBox.hxx>
#include <Widgets/TableBoxSelectionWidget.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	ReferendumTableWidget
                 * @brief	Class ReferendumTableWidget.
                 * @author	Yadickson Soto
                 * @date	16/10/2012
                 */
                class ReferendumTableWidget : public Smartmatic::GUI::Widgets::SmartmaticBasicEventBox
                {
                    public:
                        /**
                         * @fn	ReferendumTableWidget::ReferendumTableWidget ( Smartmatic::GUI::Widgets::TableBoxSelectionWidget * tableWidget );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	16/10/2012
                         * @param	tableWidget	table widget.
                         */
                        explicit ReferendumTableWidget ( Smartmatic::GUI::Widgets::TableBoxSelectionWidget * tableWidget );
                        /**
                         * @fn	virtual ReferendumTableWidget::~ReferendumTableWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	16/10/2012
                         */
                        virtual ~ReferendumTableWidget();
                        /**
                         * @fn	void ReferendumTableWidget::addWidget ( Smartmatic::GUI::Widgets::BoxSelectionWidget * referendumWidget );
                         * @brief	method add widget.
                         * @author	Yadickson Soto
                         * @date	16/10/2012
                         * @param [in,out]	referendumWidget	If non-null, the referendum widget.
                         */
                        void addWidget ( Smartmatic::GUI::Widgets::BoxSelectionWidget * referendumWidget );
                        /**
                         * @fn	void ReferendumTableWidget::clear();
                         * @brief	method clear.
                         * @author	Yadickson Soto
                         * @date	16/10/2012
                         */
                        void clear();
                        /**
                         * @fn Smartmatic::GUI::Widgets::TableBoxSelectionWidget * getTableWidget();
                         * @brief Gets table box selection widget
                         * @date 29/07/2014
                         * @author Yadickson Soto
                         * @return table box selection widget
                         */
                        Smartmatic::GUI::Widgets::TableBoxSelectionWidget * getTableWidget();

                    protected:

                        Smartmatic::GUI::Widgets::TableBoxSelectionWidget * tableWidget; ///< fill table widget
                        int row; ///< row count
                        int column; ///< column count
                };
            }
        }
    }
}

#endif /* REFERENDUMTABLEWIDGET_HXX_ */
