/**
 * @file SystemFilesIntegrityCheckWidget.hxx
 * @brief Header class system files integrity check widget
 * @date 15/01/2019
 * @author eduardo.fernandez
 */

#ifndef SYSTEM_FILES_INTEGRITY_CHECK_WIDGET_HXX_
#define SYSTEM_FILES_INTEGRITY_CHECK_WIDGET_HXX_

#include <Gui/Widgets/ProgressWidget.hxx>
#include <Voting/Election/ElectionWrapper.hxx>
#include <Widgets/StepWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	SystemFilesIntegrityCheckWidget
                 * @brief	Class system files integrity check widget.
                 * @author	eduardo.fernandez
                 * @date	15/01/2019
                 */
                class SystemFilesIntegrityCheckWidget : public Smartmatic::GUI::Widgets::StepWidget
                {
                    public:

                        /**
                         * @fn	SystemFilesIntegrityCheckWidget::SystemFilesIntegrityCheckWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress );
                         * @brief	Class constructor.
                         * @author  eduardo.fernandez
                         * @date    15/01/2019
                         * @param	progress	progress widget.
                         */
                        explicit SystemFilesIntegrityCheckWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress );

                        /**
                         * @fn	virtual SystemFilesIntegrityCheckWidget::~SystemFilesIntegrityCheckWidget();
                         * @brief	Class destructor.
                         * @author  eduardo.fernandez
                         * @date    15/01/2019
                         */
                        virtual ~SystemFilesIntegrityCheckWidget();

                        /**
                         * @fn  virtual SystemFilesIntegrityCheckWidget::~SystemFilesIntegrityCheckWidget();
                         * @brief   initialize method.
                         * @author  eduardo.fernandez
                         * @date    15/01/2019
                         */
                        virtual void initialize();

                        /**
                         * @brief virtual method getter title
                         * @return title
                         * @date 30/03/2012
                         * @author Yadickson Soto
                         */
                        virtual std::string getTitleText();

                    private:

                        /**
                         * @fn void SystemFilesIntegrityCheckWidget::verifyChecksums();
                         * @brief   verify checksums method.
                         * @author  eduardo.fernandez
                         * @date    15/01/2019
                         * @return  Whether the verification was successful.
                         */
                        bool verifyChecksums();

                        /**
                         * @fn  void SystemFilesIntegrityCheckWidget::showError();
                         * @brief   show error method.
                         * @author  eduardo.fernandez
                         * @date    15/01/2019
                         */
                        void showError();

                        /**
                         * @fn      virtual bool process ();
                         * @brief   Callback from thread to search and mount device monitor pool.
                         * @author  eduardo.fernandez
                         * @date    15/01/2019
                         */
                        void process();

                        /**
                         * @fn void endChecking();
                         * @brief Ends verifying checksums.
                         * @author  eduardo.fernandez
                         * @date    15/01/2019
                         */
                        void endVerifyingChecksums();

                    private:

                        static Smartmatic::Log::ISMTTLog *m_logger;
                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * m_progress; ///< principal frame

                        Smartmatic::SAES::Voting::Election::ElectionWrapper *m_election;
                        Smartmatic::SAES::Runtime::Environment::SaesDirectories *m_directories;
                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * m_errorWidget;   ///< The error widget
                        Glib::Thread * m_thread; ///< The thread pointer
                        bool m_successfulVerification;

                        Glib::Dispatcher m_signalDispatcher; ///< Signal dispatcher
                };
            }
        }
    }
}

#endif /* SYSTEM_FILES_INTEGRITY_CHECK_WIDGET_HXX_ */
