/**
 * @file	BasicTransmissionWidget.cxx
 * @brief	basic diagnostic widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "BasicTransmissionWidget.hxx"

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;

BasicTransmissionWidget::BasicTransmissionWidget ( GenericWidget * widget, bool showCancel, bool showRetry )
    : WizardWidgetBase(), widget ( widget )
{
    m_thread = NULL;

    signalEndProcess.connect ( sigc::mem_fun ( *this, &BasicTransmissionWidget::endProcess ) );
    signalErrorProcess.connect ( sigc::mem_fun ( *this, &BasicTransmissionWidget::errorProcess ) );

    widget->getSignalAcceptButtonClicked().connect ( sigc::mem_fun ( *this, &BasicTransmissionWidget::initialize ) );
    widget->getSignalCancelButtonClicked().connect ( sigc::mem_fun ( *this, &BasicTransmissionWidget::errorMessage ) );

    showButtons ( showCancel, showRetry );
    setWidget ( widget );
}

BasicTransmissionWidget::~BasicTransmissionWidget ()
{
    remove();

    if ( widget )
    {
        delete widget;
        widget = NULL;
    }

    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }
}

void BasicTransmissionWidget::showButtons ( bool showCancel, bool showRetry )
{
    widget->showButtons ( showRetry, showCancel );
}

void BasicTransmissionWidget::initialize()
{
    showButtons ( false, false );

    if ( !Glib::thread_supported() )
    {
        Glib::thread_init();
    }

    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }

    m_thread = Glib::Thread::create ( sigc::mem_fun ( *this, &BasicTransmissionWidget::runThreadProcess ), true );
}


void BasicTransmissionWidget::runThreadProcess()
{
    bool validate = runProcess ();

    if ( validate )
    {
        signalEndProcess.emit();
    }
    else
    {
        signalErrorProcess.emit();
    }
}

void BasicTransmissionWidget::end()
{
    emit();
}

void BasicTransmissionWidget::endProcess()
{
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &BasicTransmissionWidget::showSuccessMessage ), 100 );
}

void BasicTransmissionWidget::errorProcess ()
{
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &BasicTransmissionWidget::showErrorMessage ), 100 );
}

void BasicTransmissionWidget::errorMessage()
{
    showButtons ( false, false );
    m_cancel_signal.emit();
}
