/**
 * @file CheckNetworkWidget.hxx
 * @brief Header of the widget which checks the network device.
 * @date 08/04/2014
 * @author Yadickson Soto
 */

#ifndef CHECK_NETWORK_WIDGET_HXX_
#define CHECK_NETWORK_WIDGET_HXX_

#include <Gui/Widgets/Transmission/BasicTransmissionWidget.hxx>
#include <Operation/Monitor/DeviceTypeMonitor.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	CheckNetworkWidget
                 * @brief	Widget which checks the network device.
                 * @author	Yadickson Soto
                 * @see 	BasicTransmissionWidget
                 * @date	08/04/2014
                 */
                class CheckNetworkWidget: public BasicTransmissionWidget
                {
                    public:
                        /**
                         * @fn	CheckNetworkWidget ( GenericWidget * widget );
                         * @brief	Class constructor.
                         * @author	Yadickson Soto
                         * @date	08/04/2014
                         * @param	widget	widget with label and image.
                         */
                        CheckNetworkWidget ( GenericWidget * widget );

                        /**
                         * @fn	virtual ~CheckNetworkWidget();
                         * @brief	Class destructor.
                         * @author	Yadickson Soto
                         * @date	08/04/2014
                         */
                        virtual ~CheckNetworkWidget();

                        /**
                         * @fn	virtual void initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	08/04/2014
                         */
                        virtual void initialize();

                        /**
                         * @fn	virtual bool runProcess();
                         * @brief	Method which checks the network device.
                         * @author	Yadickson Soto
                         * @date	08/04/2014
                         * @return true if success
                         */
                        virtual bool runProcess();

                        /**
                         * @fn	virtual void showSuccessMessage();
                         * @brief	Show success message.
                         * @author	Yadickson Soto
                         * @date	02/05/2014
                         */
                        virtual void showSuccessMessage();

                        /**
                         * @fn	virtual void showErrorMessage();
                         * @brief	Updates the label because of an error in the processing.
                         * @author	Yadickson Soto
                         * @date	08/04/2014
                         */
                        virtual void showErrorMessage();

                    protected:

                        /**
                         * @fn	void deviceChange( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * deviceTypeMonitor );
                         * @brief	Callback when the device monitor detects a change.
                         * @author	Yadickson Soto
                         * @date	10/04/2014
                         * @param 	deviceTypeMonitor device change
                         */
                        void deviceChange ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * deviceTypeMonitor );

                    private:

                        sigc::connection connNetworkInterface;	///< connection to up network interface
                };
            }
        }
    }
}

#endif /* CHECK_NETWORK_WIDGET_HXX_ */
