/**
 * @file	VMInstallMachineWidget.cxx
 * @brief	voting machine install machine widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#include "VMInstallMachineWidget.hxx"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Gui/Widgets/VMPollingPlaceInfoWidget.hxx>
#include <Voting/VotingCenters/VotingCentersWrapper.hxx>
#include <Voting/Election/ElectionInstalationLanguages.h>
#include <Operation/MachineOperationManager.hxx>
#include <Log/SMTTLogManager.h>
#include <Log/ISMTTLog.h>
#include <Operation/LoginManager.hxx>
#include <Gui/Widgets/FactoryMethodWidget.hxx>
#include <Gui/Windows/USBMonitorWindow.hxx>
#include <Functionalities/saes-functionality-manager.h>
#include <System/Utils/StringUtils.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Voting::VotingCenters;
using namespace Smartmatic::SAES::Voting::Election;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::GUI::Windows;
using namespace Smartmatic::SAES::Functionality;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::Environment;

ISMTTLog * VMInstallMachineWidget::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Windows.VMInstallMachineWidget", GETTEXT_PACKAGE );

VMInstallMachineWidget::VMInstallMachineWidget ( ProgressWidget * progressWidget )
    : InstallMachineWidget(), progressWidget ( progressWidget )
{
    this->loginOk = false;
    m_thread = NULL;

    initialize();

    signalDispatcher.connect ( sigc::mem_fun ( *this, &VMInstallMachineWidget::onShowInfo ) );

    std::string password;

    LoginManager loginManager;

    if ( loginManager.getPassword ( password ) )
    {
        authentication ( password );
    }
    else
    {
        showInfo();
    }
}

VMInstallMachineWidget::~VMInstallMachineWidget()
{
    dispose();
}

void VMInstallMachineWidget::dispose()
{
    this->remove();

    if ( progressWidget )
    {
        delete progressWidget;
        progressWidget = NULL;
    }

    if ( errorWidget )
    {
        delete errorWidget;
        errorWidget = NULL;
    }

    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }
}

void VMInstallMachineWidget::initialize()
{
    progressWidget->setImage ( Smartmatic::SAES::GUI::Operation::ImageResourcePath::PROGRESS );
    progressWidget->setInfoTitle ( "  " );
    progressWidget->setInfoText ( _ ( "Smartmatic.SAES.GUI.Windows.VMInstallationWindow.ProgressMessage" ) );

    progressWidget->setInfoTitleConfig ( SAESGUIConfigurationManager::getInstance()->GetWelcomeContestCenterLabelConfiguration() );
    progressWidget->setInfoTextConfig ( SAESGUIConfigurationManager::getInstance()->GetWelcomeContestCenterLabelConfiguration() );

    errorWidget = FactoryMethodWidget::createProgressWidget();
    errorWidget->setImage ( "ui/authentication-error.gif" );
    errorWidget->setInfoTitle ( "  " );
    errorWidget->setInfoText ( _ ( "Smartmatic.SAES.GUI.Windows.VMInstallationWindow.AuthenticationFailedAutomatic" ) );

    if ( VotingCentersWrapper::getInstance()->getVotingCenters().size() == 1 )
    {
        VotingCenter votingCenter;
        VotingCentersWrapper::getInstance()->getInstallationVotingCenter ( votingCenter );
        center = StringUtils::toLowerUtf8(votingCenter.getCode());
    }
}

void VMInstallMachineWidget::authentication ( const std::string& password )
{
    this->password = password;
    showProgressLogin();
}

void VMInstallMachineWidget::showProgressLogin()
{
    setWidget ( progressWidget );

    if ( !Glib::thread_supported() )
    {
        Glib::thread_init();
    }

    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }

    m_thread = Glib::Thread::create ( sigc::mem_fun ( *this, &VMInstallMachineWidget::checkData ), true );
}

void VMInstallMachineWidget::checkData()
{
    loginOk = false;

    if ( MachineOperationManager::getInstance()->authentication ( center, password, true ) )
    {
        MachineOperationManager::getInstance()->refreshOperationStatus();

        if ( !ElectionInstalationLanguages::getInstance()->getStringLanguages().empty() )
        {
            loginOk = true;
        }
    }

    signalDispatcher.emit();
}

void VMInstallMachineWidget::onShowInfo()
{
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &VMInstallMachineWidget::showInfo ), 0 );
}

void VMInstallMachineWidget::showInfo()
{
    if ( !loginOk )
    {
        logger->Debug ( "Error authentication" );
        setWidget ( errorWidget );
    }
    else
    {
        logger->Debug ( "authentication ok" );
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &VMInstallMachineWidget::end ), 0 );
    }
}

void VMInstallMachineWidget::end()
{
    SaesFunctionalityManager::getInstance()->AddRunningSelectedModeForVM();
    MachineOperationManager::getInstance()->getElectoralConfiguration()->notReload();
    stop();
    emit();
}

void VMInstallMachineWidget::stop()
{
    conn.disconnect();
}

std::string VMInstallMachineWidget::getTitleText()
{
    return N_ ( "Smartmatic.SAES.GUI.Windows.VMInstallationWindow.Title" );
}
