/**
 * @file	VMInstallationConfirmation.cxx
 * @brief	voting machine installation confirmation class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "VMInstallationConfirmation.hxx"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <Environment/Configurations/resource-path-provider.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::Environment;
using namespace Smartmatic::Log;

ISMTTLog * VMInstallationConfirmation::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.VMInstallationConfirmation", GETTEXT_PACKAGE );

VMInstallationConfirmation::VMInstallationConfirmation ( PollingPlaceInfoWidget * pollingPlaceInfoWidget )
    : StepWidget(), pollingPlaceInfoWidget ( pollingPlaceInfoWidget )
{
    this->mainFrame = NULL;
    this->infoFrame = NULL;
    this->buttonOk = NULL;
    this->initialize();

    infoFrame->add ( *pollingPlaceInfoWidget );

    setWidget ( mainFrame );
}

VMInstallationConfirmation::~VMInstallationConfirmation()
{
    dispose();
}

void VMInstallationConfirmation::initialize()
{
    Glib::RefPtr<Gtk::Builder> builder;

    try
    {
        builder = Gtk::Builder::create_from_file ( ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, "ui/vm_installation_confirmation.glade" ) );
    }
    catch ( const Glib::FileError & ex )
    {
        logger->Debug ( "FATAL - VMInstallationConfirmation initialize" );
    }

    int buttonWidth = SAESGUIConfigurationManager::getInstance()->GetVMInstallationConfiguration().getButtonsWidth();
    int buttonHeight = SAESGUIConfigurationManager::getInstance()->GetVMInstallationConfiguration().getButtonsHeight();
    std::string sound = SAESGUIConfigurationManager::getInstance()->getVMInstalationSound();

    builder->get_widget_derived ( "main-frame", mainFrame );
    builder->get_widget_derived ( "info-frame", infoFrame );
    builder->get_widget_derived ( "buttonOk", buttonOk );

    buttonOk->set_label ( _ ( "Smartmatic.SAES.GUI.Windows.VMInstallationWindow.ButtonOk" ) );
    buttonOk->SetSound ( sound );
    buttonOk->set_size_request ( buttonWidth, buttonHeight );
    buttonOk->ModifyFontSize ( 18 );
    buttonOk->set_no_show_all ( true );

    int timeout = SAESGUIConfigurationManager::getInstance()->GetVMInstallationConfiguration().getTimeOutShowMessage();

    if ( timeout < 0 )
    {
        buttonOk->set_visible ( true );
        buttonOk->signal_clicked().connect ( sigc::mem_fun ( *this, &VMInstallationConfirmation::end ) );
    }
    else
    {
        buttonOk->set_visible ( false );
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &VMInstallationConfirmation::end ), timeout );
    }
}

void VMInstallationConfirmation::dispose()
{
    this->remove();

    if ( mainFrame )
    {
        delete mainFrame;
        mainFrame = NULL;
    }

    if ( infoFrame )
    {
        delete infoFrame;
        infoFrame = NULL;
    }

    if ( buttonOk )
    {
        delete buttonOk;
        buttonOk = NULL;
    }

    if ( pollingPlaceInfoWidget )
    {
        delete pollingPlaceInfoWidget;
        pollingPlaceInfoWidget = NULL;
    }
}

void VMInstallationConfirmation::end()
{
    buttonOk->set_sensitive ( false );
    emit();
}

void VMInstallationConfirmation::refresh()
{
    pollingPlaceInfoWidget->fillInfoWidget();
}
