/**
 * @file DualWaitingForCardWidget.hxx
 * @brief Header of the widget class with voting information and waiting for card.
 * The start of the voter experience is divided into two parts,
 * election information and voting instructions.
 * @date 13/03/2014
 * @author Yadickson Soto
 */

#ifndef DUAL_WAITING_FOR_CARD_WIDGET_HXX_
#define DUAL_WAITING_FOR_CARD_WIDGET_HXX_

#include <Widgets/StepWidget.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>
#include <Gui/Widgets/Voting/WaitingForCardWidget.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	DualWaitingForCardWidget
                     * @brief	Widget class with voting information and waiting for card.
                     * The start of the voter experience is divided into two parts,
                     * election information and voting instructions.
                     * @author	Yadickson Soto
                     * @date	13/03/2014
                     */
                    class DualWaitingForCardWidget : public Smartmatic::GUI::Widgets::StepWidget
                    {
                        public:

                            /**
                             * @fn	DualWaitingForCardWidget (
                             *   Smartmatic::SAES::GUI::Widgets::ProgressWidget * votingInfoWidget,
                             *   Smartmatic::SAES::GUI::Widgets::Voting::WaitingForCardWidget * waitingCardWidget );
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             * @param votingInfoWidget progress info election widget
                             * @param progressWaitingCardWidget progress waiting for card widget
                             */
                            DualWaitingForCardWidget (
                                Smartmatic::SAES::GUI::Widgets::ProgressWidget * votingInfoWidget,
                                Smartmatic::SAES::GUI::Widgets::Voting::WaitingForCardWidget * waitingCardWidget );
                            /**
                             * @fn	virtual DualWaitingForCardWidget::~DualWaitingForCardWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             */
                            virtual ~DualWaitingForCardWidget();
                            /**
                             * @fn	virtual void DualWaitingForCardWidget::refresh();
                             * @brief	refresh widget method.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             */
                            virtual void refresh();
                            /**
                             * @fn	void showInfo ( bool show = true );
                             * @brief	Show electoral information widget.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             * @param show show electoral information
                             */
                            void showInfo ( bool show = true );

                            /**
                             * @fn	Smartmatic::SAES::GUI::Widgets::Voting::WaitingForCardWidget * getWaitingForCardWidget();
                             * @brief	Gets waiting for card widget class.
                             * @author	Yadickson Soto
                             * @date	13/03/2014
                             * @return 	waiting for card widget class
                             */
                            Smartmatic::SAES::GUI::Widgets::Voting::WaitingForCardWidget * getWaitingForCardWidget();

                        private:

                            Smartmatic::GUI::Widgets::SmartmaticBasicVBox * vbox; ///< vertical box
                            Smartmatic::SAES::GUI::Widgets::ProgressWidget * votingInfoWidget; ///< info widget, is used to present the Electoral Information frame
                            Smartmatic::SAES::GUI::Widgets::Voting::WaitingForCardWidget * waitingCardWidget; ///< waiting for card widget
                    };
                }
            }
        }
    }
}

#endif /* DUAL_WAITING_FOR_CARD_WIDGET_HXX_ */
