/**
 * @file	ElectoralTypeSelectionBoxWidget.cxx
 * @brief	Body electoral type selection widget.
 * @author	Yadickson Soto
 * @date	13/11/2012
 */

#include "ElectoralTypeSelectionBoxWidget.hxx"
#include <Operation/MachineOperationManager.hxx>
#include <Resources/election-string-resources-manager.h>
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include <System/Utils/StringUtils.hxx>
#include <Operation/Voting/VotingOperation.hxx>
#include <Voting/CardData/card-data-wrapper.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::Voting::VotingDevice;
using namespace Smartmatic::SAES::Voting::CardData;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::SAES::GUI::Operation::Voting;

ElectoralTypeSelectionBoxWidget::ElectoralTypeSelectionBoxWidget ( )
    : StepWidget ( )
{
    currentBox = NULL;
    externalBox = NULL;
    tableWidget = NULL;

    setTitle ( false );
    setShowBorder ( true );
    setName ( VotingOperation::getWindowName() );

    initialize();

    setWidget ( externalBox );
    setAccessibleName ( "ElectoralTypeSelectionBox" );
}

ElectoralTypeSelectionBoxWidget::~ElectoralTypeSelectionBoxWidget()
{
    remove ();
    dispose();
}

void ElectoralTypeSelectionBoxWidget::initialize()
{
    tableWidget = new TableBoxSelectionWidget ( false, false, true );
    tableWidget->setSpacings ( 20, 0 );
    tableWidget->getSignalClick().connect ( sigc::mem_fun ( this, &ElectoralTypeSelectionBoxWidget::onBoxClicked ) );

    int boxWidth = SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getBoxWidth();
    int boxHeight = SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getBoxHeight();

    externalBox = new SmartmaticBasicVBox ( false , 0 );
    externalBox->pack_start ( *tableWidget );

    Gdk::Color selected = SAESGUIConfigurationManager::ConvertToGdkColor ( SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getSelectedColor() );
    Gdk::Color unselected = SAESGUIConfigurationManager::ConvertToGdkColor ( SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getUnSelectedColor() );
    Smartmatic::GUI::Configuration::LabelConfiguration boxLabelConf = SAESGUIConfigurationManager::ConvertToLabelConfiguration ( SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getBoxLabelConfiguration() );

    std::list < Custom_attribute_definition > listCAD;
    std::list < Custom_attribute_definition >::iterator it;
    Voting_device vd = MachineOperationManager::getInstance()->getElectoralConfiguration()->getVotingDevice()->getFirstVotingDevice();
    listCAD = MachineOperationManager::getInstance()->getElectoralConfiguration()->getVotingDevice()->getCustomAttributeDefinitionList ( vd, Machine_type::VOTING_DEVICES_PM );

    int pos = 0;

    for ( it = listCAD.begin();
            it != listCAD.end();
            ++it )
    {
        for ( Custom_attribute_definition_values::Custom_attribute_definition_valueIterator c ( ( *it ).getCustom_attribute_definition_values().getCustom_attribute_definition_value().begin() );
                c != ( *it ).getCustom_attribute_definition_values().getCustom_attribute_definition_value().end(); ++c, pos++ )
        {
            std::string value = ( *c ).getValue();
            std::string name = ElectionStringResourcesManager::getInstance()->getResource ( value );
            std::string code = ( *it ).getCode();

            BoxSelectionWidget * box = manage ( new BoxSelectionWidget ( code, value, true, true ) );
            box->setSelectedColor ( selected );
            box->setUnselectedColor ( unselected );
            box->set_size_request ( boxWidth, boxHeight );

            SmartmaticBasicLabel * label = manage ( new SmartmaticBasicLabel ( name ) );
            Smartmatic::GUI::Configuration::LabelConfiguration::SetLabelConfiguration ( label, boxLabelConf );
            label->set_size_request ( boxWidth, boxHeight );

            box->addWidget ( label );
            box->set_name ( "voting_experience_language_widget" );
            box->setName ( "language_widget_event_box" );

            std::string electoralCode = StringUtils::intToString ( pos );

            box->setAccessibleName ( "ElectoralTypeBox" + electoralCode );
            label->setAccessibleName ( "ElectoralTypeBox" + electoralCode );

            tableWidget->put ( box, pos, 0 );
        }
    }

    tableWidget->clear();

    tableWidget->setAccessibleName ( "ElectoralTypeSelectionMainTable" );
    externalBox->setAccessibleName ( "ElectoralTypeSelectionContainer" );
}

void ElectoralTypeSelectionBoxWidget::dispose()
{
    if ( externalBox )
    {
        delete externalBox;
        externalBox = NULL;
    }

    if ( tableWidget )
    {
        delete tableWidget;
        tableWidget = NULL;
    }
}

void ElectoralTypeSelectionBoxWidget::refresh()
{
    tableWidget->clear();
}

void ElectoralTypeSelectionBoxWidget::onBoxClicked ( std::list < Smartmatic::GUI::Widgets::BoxSelectionWidget * > & list )
{
    bool selected = !list.empty();

    if ( selected )
    {
        currentBox = ( * ( list.begin() ) );
    }
    else
    {
        currentBox = NULL;
    }

    emit();
}

void ElectoralTypeSelectionBoxWidget::getCardData ( Smartmatic::SAES::Voting::CardData::Card_data & cardData )
{
    std::vector<Custom_attribute> attributes;

    Custom_attribute  attribute;
    attribute.setCode ( currentBox->getCode() );
    attribute.setValue ( currentBox->getOptionalValue() );
    attributes.push_back ( attribute );

    CardDataWrapper::GenerateCardData ( MachineOperationManager::getInstance()->getElectoralConfiguration(), MachineOperationManager::getInstance()->getOperationStatus(), attributes, cardData, true, Smartmatic::SAES::Voting::CardData::Card_type::CARD_DATA_OFFICIAL_VOTE_CARD, false );
}
