/**
 * @file FactoryVotingWidget.hxx
 * @brief Header class for create widget
 * @date 29/02/2012
 * @author Yadickson Soto
 */

#ifndef FACTORYVOTINGWIDGET_HXX_
#define FACTORYVOTINGWIDGET_HXX_

#include "ILanguageSelectionWidget.hxx"
#include "ElectoralTypeSelectionBoxWidget.hxx"
#include "PreviewWidget.hxx"
#include "VotePreviewWidget.hxx"
#include "TimeOutPreviewWidget.hxx"
#include "WaitingForCardWidget.hxx"
#include "PrintTimeOutWidget.hxx"
#include "PrintVoteErrorWidget.hxx"
#include "RemoveCardWidget.hxx"
#include "FoldPrintVoteWidget.hxx"
#include "CardRemovedWidget.hxx"
#include "PrintVoteWidget.hxx"
#include "InterruptVotingWidget.hxx"
#include "KeypadVotingPasswordWidget.hxx"
#include "NullVotingWidget.hxx"
#include "InterruptWidget.hxx"
#include "VotingExperienceValidationWidget.hxx"
#include "ICustomAttributeSelectionWidget.hxx"
#include "ScreenVotingWidget.hxx"
#include "VotingExperienceWidget.hxx"
#include "SimulatorVotesWidget.hxx"
#include "CustomAttributeSelectionButtonWidget.hxx"
#include "LanguageSelectionButtonWidget.hxx"
#include "PrintAndFoldVoteWidget.hxx"
#include "PrintAudioVoteWidget.hxx"
#include "EndVotingSequenceWidget.hxx"
#include "DualWaitingForCardWidget.hxx"
#include "WaitingVotingWidget.hxx"
#include "ScanVoteWidget.hxx"
#include "../AudioVoting/AudioVotingExperienceWidget.hxx"
#include "../AudioVoting/EndAudioVotingSequenceWidget.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	FactoryVotingWidget
                     * @brief	Class for create widget.
                     * @author	Yadickson Soto
                     * @date	29/02/2012
                     */
                    class FactoryVotingWidget
                    {
                        public:
                            /**
                             * @fn	static ILanguageSelectionWidget * FactoryVotingWidget::createLanguageSelectionWidgetConfig( bool showConfirmation );
                             * @brief	Method for create language selection widget config.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             * @param	showConfirmation		true to show confirmation.
                             * @return	new widget.
                             */
                            static ILanguageSelectionWidget * createLanguageSelectionWidgetConfig ( bool showConfirmation );
                            /**
                             * @fn	static LanguageSelectionWidget * FactoryVotingWidget::createVotingLanguageSelectionWidget();
                             * @brief	Method for create voting language selection widget.
                             * @author	Yadickson Soto
                             * @date	08/03/2012
                             * @return	new widget.
                             */
                            static ILanguageSelectionWidget * createVotingLanguageSelectionWidget();
                            /**
                             * @fn	static ElectoralTypeSelectionBoxWidget * FactoryVotingWidget::createSimulationWidget();
                             * @brief	Method for create simulation custom attributes widget.
                             * @author	Yadickson Soto
                             * @date	08/03/2012
                             * @return	new widget.
                             */
                            static ElectoralTypeSelectionBoxWidget * createSimulationWidget();
                            /**
                             * @fn	static PreviewWidget * FactoryVotingWidget::createPreviewWidget();
                             * @brief	Method for create vote preview widget.
                             * @author	Yadickson Soto
                             * @date	16/04/2012
                             * @return	new widget.
                             */
                            static PreviewWidget * createPreviewWidget();
                            /**
                             * @fn	static VotePreviewWidget * FactoryVotingWidget::createVotePreviewWidget();
                             * @brief	Method for create vote preview widget.
                             * @author	Yadickson Soto
                             * @date	16/04/2012
                             * @return	new widget.
                             */
                            static VotePreviewWidget * createVotePreviewWidget();
                            /**
                             * @fn	static TimeOutPreviewWidget * FactoryVotingWidget::createTimeOutPreviewWidget();
                             * @brief	Method for create timeout preview widget.
                             * @author	Yadickson Soto
                             * @date	16/04/2012
                             * @return	new widget.
                             */
                            static TimeOutPreviewWidget * createTimeOutPreviewWidget();
                            /**
                             * @fn	static WaitingForCardWidget * FactoryVotingWidget::createWaitingForCardWidget();
                             * @brief	Method for create waiting card widget.
                             * @author	Yadickson Soto
                             * @date	16/04/2012
                             * @return	new widget.
                             */
                            static WaitingForCardWidget * createWaitingForCardWidget();
                            /**
                             * @fn	static PrintTimeOutWidget * FactoryVotingWidget::createPrintTimeOutWidget();
                             * @brief	Method for create print timeout widget.
                             * @author	Yadickson Soto
                             * @date	16/04/2012
                             * @return	new widget.
                             */
                            static PrintTimeOutWidget * createPrintTimeOutWidget();
                            /**
                             * @fn	static PrintVoteErrorWidget * FactoryVotingWidget::createPrintVoteErrorWidget();
                             * @brief	Method for create print vote error widget.
                             * @author	Yadickson Soto
                             * @date	16/04/2012
                             * @return	new widget.
                             */
                            static PrintVoteErrorWidget * createPrintVoteErrorWidget();
                            /**
                             * @fn  static VoteComplianceFailureWidget * FactoryVotingWidget::createVoteComplianceFailureWidget();
                             * @brief   Method for create vote compliance failure widget.
                             * @author  eduardo.fernandez
                             * @date    12/02/2018
                             * @return  new widget.
                             */
                            static VoteComplianceFailureWidget * createVoteComplianceFailureWidget();
                            /**
                             * @fn	static RemoveCardWidget * FactoryVotingWidget::createRemoveCardWidget();
                             * @brief	Method for create remove card widget.
                             * @author	Yadickson Soto
                             * @date	16/04/2012
                             * @return	new widget.
                             */
                            static RemoveCardWidget * createRemoveCardWidget();
                            /**
                             * @fn	static FoldPrintVoteWidget * FactoryVotingWidget::createFoldPrintVoteWidget();
                             * @brief	Method for create end print vote widget.
                             * @author	Yadickson Soto
                             * @date	16/04/2012
                             * @return	new widget.
                             */
                            static FoldPrintVoteWidget * createFoldPrintVoteWidget();
                            /**
                             * @fn	static CardRemovedWidget * FactoryVotingWidget::createCardRemovedWidget();
                             * @brief	Method for create card removed widget.
                             * @author	Yadickson Soto
                             * @date	16/04/2012
                             * @return	new widget.
                             */
                            static CardRemovedWidget * createCardRemovedWidget();
                            /**
                             * @fn	static PrintVoteWidget * FactoryVotingWidget::createPrintVoteWidget();
                             * @brief	Method for create print vote widget.
                             * @author	Yadickson Soto
                             * @date	16/04/2012
                             * @return	new widget.
                             */
                            static PrintVoteWidget * createPrintVoteWidget();
                            /**
                             * @fn	static InterruptVotingWidget * FactoryVotingWidget::createInterruptVotingWidget();
                             * @brief	Method for create interrupt voting widget.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             * @return	new widget.
                             */
                            static InterruptVotingWidget * createInterruptVotingWidget();
                            /**
                             * @fn	static KeypadVotingPasswordWidget * FactoryVotingWidget::createKeypadVotingPasswordWidget();
                             * @brief	Method for create keypad voting password widget.
                             * @author	Yadickson Soto
                             * @date	17/04/2012
                             * @return	new widget.
                             */
                            static KeypadVotingPasswordWidget * createKeypadVotingPasswordWidget();
                            /**
                             * @fn	static NullVotingWidget * FactoryVotingWidget::createNullVotingWidget();
                             * @brief	Method for create end voting widget.
                             * @author	Yadickson Soto
                             * @date	24/04/2012
                             * @return	new widget.
                             */
                            static NullVotingWidget * createNullVotingWidget();
                            /**
                             * @fn	static InterruptWidget * FactoryVotingWidget::createInterruptWidget();
                             * @brief	Method for create interrupt widget.
                             * @author	Yadickson Soto
                             * @date	24/04/2012
                             * @return	new widget.
                             */
                            static InterruptWidget * createInterruptWidget();
                            /**
                             * @fn	static VotingExperienceValidationWidget * FactoryVotingWidget::createVotingExperineceValidationWidget();
                             * @brief	Method for create voting experience validation widget.
                             * @author	Yadickson Soto
                             * @date	25/04/2012
                             * @return	new widget.
                             */
                            static VotingExperienceValidationWidget * createVotingExperineceValidationWidget();
                            /**
                             * @fn	static ICustomAttributeSelectionWidget * FactoryVotingWidget::createCustomAttributeWidget ( Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition & customAttribute );
                             * @brief	Method for create custom attribute widget.
                             * @author	Yadickson Soto
                             * @date	25/04/2012
                             * @param	customAttribute	custom attribute definition.
                             * @return	new widget.
                             */
                            static ICustomAttributeSelectionWidget * createCustomAttributeWidget ( Smartmatic::SAES::Voting::VotingDevice::Custom_attribute_definition & customAttribute );
                            /**
                             * @fn	static ScreenVotingWidget * FactoryVotingWidget::createScreenVotingWidget();
                             * @brief	Method for create screen voting widget.
                             * @author	Yadickson Soto
                             * @date	30/04/2012
                             * @return	new widget.
                             */
                            static ScreenVotingWidget * createScreenVotingWidget();
                            /**
                             * @fn	static VotingExperienceWidget * FactoryVotingWidget::createVotingExperienceWidget();
                             * @brief	Method for create voting experience widget.
                             * @author	Yadickson Soto
                             * @date	15/05/2012
                             * @return	new widget.
                             */
                            static VotingExperienceWidget * createVotingExperienceWidget();
                            /**
                             * @fn  static AudioVotingExperienceWidget * FactoryVotingWidget::createAudioVotingExperienceWidget();
                             * @brief   Method for create audio voting experience widget.
                             * @author  Eduardo Fernández
                             * @date    09/11/2017
                             * @return  new widget.
                             */
                            static Smartmatic::SAES::GUI::Widgets::AudioVoting::AudioVotingExperienceWidget * createAudioVotingExperienceWidget();
                            /**
                             * @fn	static SimulatorVotesWidget * FactoryVotingWidget::createSimulatorVotesWidget();
                             * @brief	Method for create simulator votes widget.
                             * @author	Yadickson Soto
                             * @date	05/10/2012
                             * @return	new widget.
                             */
                            static SimulatorVotesWidget * createSimulatorVotesWidget();
                            /**
                             * @fn	static CustomAttributeSelectionButtonWidget * FactoryVotingWidget::createCustomAttributeSelectionButtonWidget();
                             * @brief	Method for create custom attribute selection button widget.
                             * @author	Yadickson Soto
                             * @date	14/11/2012
                             * @return	new widget.
                             */
                            static CustomAttributeSelectionButtonWidget * createCustomAttributeSelectionButtonWidget();
                            /**
                             * @fn	static LanguageSelectionButtonWidget * FactoryVotingWidget::createLanguageSelectionButtonWidget();
                             * @brief	Method for create language selection button widget.
                             * @author	Yadickson Soto
                             * @date	14/11/2012
                             * @return	new widget.
                             */
                            static LanguageSelectionButtonWidget * createLanguageSelectionButtonWidget();
                            /**
                             * @fn	static PrintAndFoldVoteWidget * createPrintAndFoldVoteWidget();
                             * @brief	Method for create print and fold widget.
                             * @author	Yadickson Soto
                             * @date	20/03/2013
                             * @return	new widget.
                             */
                            static PrintAndFoldVoteWidget * createPrintAndFoldVoteWidget();
                            /**
                             * @fn	static EndVotingSequenceWidget * createEndVotingSequenceWidget();
                             * @brief	Method for create end voting sequence widget.
                             * @author	Yadickson Soto
                             * @date	20/03/2013
                             * @return	new widget.
                             */
                            static EndVotingSequenceWidget * createEndVotingSequenceWidget();
                            /**
                             * @fn  static EndAudioVotingSequenceWidget * createEndAudioVotingSequenceWidget();
                             * @brief   Method for create end audio voting sequence widget.
                             * @author  Eduardo Fernández
                             * @date    17/11/2017
                             * @return  new widget.
                             */
                            static EndAudioVotingSequenceWidget * createEndAudioVotingSequenceWidget();
                            /**
                             * @fn	static WaitingVotingWidget * createWaitingVotingWidget();
                             * @brief	Method for create main container for waiting voting experience widget.
                             * @author	Yadickson Soto
                             * @date	20/03/2013
                             * @return	new widget.
                             */
                            static WaitingVotingWidget * createWaitingVotingWidget();
                            /**
                             * @fn	static DualWaitingForCardWidget * createDualWaitingForCardWidget();
                             * @brief	Method for create dual information for waiting for card widget.
                             * @author	Yadickson Soto
                             * @date	20/03/2014
                             * @return	new widget.
                             */
                            static DualWaitingForCardWidget * createDualWaitingForCardWidget();
                            /**
                             * @fn	static ScanVoteWidget * createScanVoteWidget();
                             * @brief	Method for create scan vote widget.
                             * @author	Yadickson Soto
                             * @date	27/03/2014
                             * @return	new widget.
                             */
                            static ScanVoteWidget * createScanVoteWidget();

                            static PrintAudioVoteWidget * createPrintAudioVoteWidget();
                    };
                }
            }
        }
    }
}

#endif /* FACTORYVOTINGWIDGET_HXX_ */
