/**
 * @file FoldPrintVoteWidget.cxx
 * @brief Body class end print vote widget
 * @date 29/02/2012
 * @author Yadickson Soto
 */

#include "FoldPrintVoteWidget.hxx"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;

FoldPrintVoteWidget::FoldPrintVoteWidget ( ProgressWidget * progress )
    : WizardWidgetBase(), progress ( progress )
{
    progress->setInfoTextConfig ( SAESGUIConfigurationManager::getInstance()->GetVotingWindowEndMessagelabelConfig() );
    progress->setImage ( "ui/voting-experience-finalization-image.gif" );
    setAccessibleName ( "FoldVote" );

    refresh();
    setTitle ( false );
    setShowBorder ( true );
    setWidget ( progress );
}

FoldPrintVoteWidget::~FoldPrintVoteWidget()
{
    this->remove();

    if ( progress )
    {
        delete progress;
        progress = NULL;
    }
}

void FoldPrintVoteWidget::refresh()
{
    progress->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Windows.VotingWindow.BendPrintedTicket" ) );
}

void FoldPrintVoteWidget::setText ( std::string text )
{
    progress->setInfoText ( text );
}

void FoldPrintVoteWidget::initialize()
{
    unsigned int time = SAESGUIConfigurationManager::getInstance()->getWaitTimeByBasicImageType ( Smartmatic::SAES::Voting::Screen::BasicImageType::GENERATED_IMAGES_FOLD_VOTE );
    Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &FoldPrintVoteWidget::end ), time );
}

void FoldPrintVoteWidget::end()
{
    emit();
}
