/**
 * @file	ILanguageSelectionWidget.cxx
 * @brief	Body interface language selection widget.
 * @author	Yadickson Soto
 * @date	13/11/2012
 */

#include "ILanguageSelectionWidget.hxx"
#include "Voting/set-language-functionality.h"
#include "Resources/election-string-resources-manager.h"
#include <Operation/MachineOperationManager.hxx>
#include <Operation/Voting/VotingOperation.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::SAES::GUI::Operation::Voting;
using namespace Smartmatic::SAES::Operation;

/**
 * @brief method sort languages
 * @param l1 language one
 * @param l2 language two
 * @return true is l1 < l2
 * @date 13/11/2012
 * @author Yadickson Soto
 */
static bool sortLanguages ( Smartmatic::SAES::Voting::Election::Language l1, Smartmatic::SAES::Voting::Election::Language l2 )
{
    std::string t1 = ElectionStringResourcesManager::getInstance()->getResource ( l1.getName_key() );
    std::string t2 = ElectionStringResourcesManager::getInstance()->getResource ( l2.getName_key() );
    return ( t1.compare ( t2 ) < 0 );
}

ILanguageSelectionWidget::ILanguageSelectionWidget ( bool showConfirmation, bool sortAlphabetically )
    : StepWidget()
{
    this->flagForce = false;
    this->showConfirmation = showConfirmation;
    this->sortAlphabetically = sortAlphabetically;

    Smartmatic::SAES::Voting::Election::Languages::LanguageSequence langSequence = MachineOperationManager::getInstance()->getElectoralConfiguration()->getLanguages().getLanguage();
    Smartmatic::SAES::Voting::Election::Languages::LanguageIterator it;

    for ( it = langSequence.begin(); it != langSequence.end(); ++it )
    {
        languagesList.push_back ( *it );
    }

    if ( sortAlphabetically )
    {
        languagesList.sort ( sortLanguages );
    }

    Smartmatic::SAES::Voting::SetLanguageFunctionality::getCurrentLanguageCountry ( currentLanguage, currentCountry );

    setTitle ( false );
    setShowBorder ( true );
    setName ( VotingOperation::getWindowName() );
}

ILanguageSelectionWidget::~ILanguageSelectionWidget()
{

}

void ILanguageSelectionWidget::SetBackLanguage()
{
    Smartmatic::SAES::Voting::SetLanguageFunctionality::setNewVotingLanguageByLanguageCountry ( currentLanguage, currentCountry );
}

void ILanguageSelectionWidget::start()
{

}

bool ILanguageSelectionWidget::ShowWidget()
{
    return languagesList.size() > 1;
}
