/**
 * @file	ILanguageSelectionWidget.hxx
 * @brief	Header interface the language selection widget.
 * @author	Yadickson Soto
 * @date	13/11/2012
 */

#ifndef _ILANGUAGE_SELECTION_WIDGET_H_
#define _ILANGUAGE_SELECTION_WIDGET_H_

#include <Widgets/StepWidget.hxx>
#include <Voting/Election/election-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	ILanguageSelectionWidget
                     * @brief	Language selection widget.
                     * @author	Yadickson Soto
                     * @date	13/11/2012
                     */
                    class ILanguageSelectionWidget: public virtual Smartmatic::GUI::Widgets::StepWidget
                    {
                        public:

                            /**
                             * @fn	ILanguageSelectionWidget::ILanguageSelectionWidget ( );
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             * @param	showConfirmation	true to show confirmation.
                             * @param	sortAlphabetically	true to sort alphabetically.
                             */
                            ILanguageSelectionWidget ( bool showConfirmation, bool sortAlphabetically );
                            /**
                             * @fn	virtual ILanguageSelectionWidget::~ILanguageSelectionWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             */
                            virtual ~ILanguageSelectionWidget();
                            /**
                             * @fn	virtual void ILanguageSelectionWidget::start();
                             * @brief	virtual method start.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             */
                            virtual void start();
                            /**
                             * @fn	virtual void ILanguageSelectionWidget::SimulateButtonNPressed ( unsigned int index ) = 0;
                             * @brief	Simulate the press of the button indexed in N.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             * @param	index	code of the language.
                             */
                            virtual void SimulateButtonNPressed ( unsigned int index ) = 0;
                            /**
                             * @fn	void ILanguageSelectionWidget::SetBackLanguage();
                             * @brief	Sets the back language.
                             * @author	Juan Delgado
                             * @date	28/04/2011
                             */
                            void SetBackLanguage();
                            /**
                             * @fn	bool ILanguageSelectionWidget::ShowWidget();
                             * @brief	Shows the widget.
                             * @author	Juan Delgado, Yadickson Soto
                             * @date	28/04/2011
                             * @return	true if it succeeds, false if it fails.
                             */
                            bool ShowWidget();

                        protected:

                            std::list < Smartmatic::SAES::Voting::Election::Language > languagesList; ///< language list
                            std::string currentLanguage;   ///< The current language
                            std::string currentCountry;	///< The current country
                            bool showConfirmation; ///< flag to show confirmation.
                            bool sortAlphabetically; ///< flag to sort alphabetically.
                            bool flagForce; ///< flagForce
                    };
                }
            }
        }
    }
}

#endif // _ILANGUAGE_SELECTION_WIDGET_H_
