/**
 * @file IPrintVoteWidget.hxx
 * @brief Header interface print vote widget
 * @date 03/04/2013
 * @author Yadickson Soto
 */

#ifndef IPRINTVOTEWIDGET_HXX_
#define IPRINTVOTEWIDGET_HXX_

#include <Widgets/wizard-widget-base.h>
#include <Operation/Devices/PrinterController.hxx>
#include <Printing/VotePrintDocument.h>
#include <Gui/Widgets/Voting/PrintVoteErrorWidget.hxx>
#include <Gui/Widgets/Voting/VoteComplianceFailureWidget.hxx>
#include <System/SafeTime.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	IPrintVoteWidget
                     * @brief	Class print vote widget.
                     * @author	Yadickson Soto
                     * @date	03/04/2013
                     */
                    class IPrintVoteWidget : public Smartmatic::GUI::Widgets::WizardWidgetBase
                    {
                        public:

                            /**
                             * @fn	IPrintVoteWidget::IPrintVoteWidget ( Smartmatic::SAES::GUI::Widgets::Voting::PrintVoteErrorWidget * printVoteErrorWidget );
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	03/04/2013
                             * @param printVoteErrorWidget print vote error widget
                             * @param voteComplianceFailureWidget vote compliance failure widget
                             */
                            explicit IPrintVoteWidget (
                                Smartmatic::SAES::GUI::Widgets::Voting::PrintVoteErrorWidget * printVoteErrorWidget,
                                Smartmatic::SAES::GUI::Widgets::Voting::VoteComplianceFailureWidget * voteComplianceFailureWidget);
                            /**
                             * @fn	virtual IPrintVoteWidget::~IPrintVoteWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	03/04/2013
                             */
                            virtual ~IPrintVoteWidget();

                        protected:
                            /**
                             * @fn	virtual void initialize();
                             * @brief	Initializer method.
                             * @author	Yadickson Soto
                             * @date	03/04/2013
                             */
                            virtual void initialize();

                            /**
                             * @fn	void onOK();
                             * @brief	Method callback printer ok
                             * @author	Yadickson Soto
                             * @date	03/04/2013
                             */
                            void onOK();
                            /**
                             * @fn	void onError( const std::string& message );
                             * @brief	Method callback printer error
                             * @author	Yadickson Soto
                             * @date	03/04/2013
                             * @param message message
                             */
                            void onError ( const std::string& message );
                            /**
                             * @fn	void endOK();
                             * @brief	Method callback printer ok
                             * @author	Yadickson Soto
                             * @date	03/04/2013
                             */
                            void endOK();
                            /**
                             * @fn	void endError();
                             * @brief	Method callback printer error
                             * @author	Yadickson Soto
                             * @date	03/04/2013
                             */
                            void endError();

                        private:

                            Smartmatic::SAES::GUI::Widgets::Voting::PrintVoteErrorWidget * printVoteErrorWidget; ///< print vote error widget
                            Smartmatic::SAES::GUI::Widgets::Voting::VoteComplianceFailureWidget * voteComplianceFailureWidget; ///< vote compliance failure widget
                            Smartmatic::SAES::Operation::Devices::PrinterController * printer; ///< printer process
                            Smartmatic::SAES::Printing::VotePrintDocument * votePrintDocument;  ///< vote print document
                            Smartmatic::System::SafeTime safeTime; ///< safe time
                            Smartmatic::SAES::Voting::Vote::Vote * m_vote;
                            static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
                    };
                }
            }
        }
    }
}

#endif /* PRINTVOTEWIDGET_HXX_ */
