/**
 * @file	LanguageSelectionBoxWidget.hxx
 * @brief	Header interface the language selection widget.
 * @author	Yadickson Soto
 * @date	13/11/2012
 */

#ifndef _LANGUAGE_SELECTION_BOX_WIDGET_H_
#define _LANGUAGE_SELECTION_BOX_WIDGET_H_

#include "ILanguageSelectionWidget.hxx"
#include "LanguageSelectionButtonWidget.hxx"
#include <Widgets/TableBoxSelectionWidget.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <Widgets/SmartmaticBasicFrame.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	LanguageSelectionBoxWidget
                     * @brief	Language selection widget.
                     * @author	Yadickson Soto
                     * @date	13/11/2012
                     */
                    class LanguageSelectionBoxWidget: public ILanguageSelectionWidget
                    {
                        public:

                            /**
                             * @fn	LanguageSelectionBoxWidget::LanguageSelectionBoxWidget ( );
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             * @param	showConfirmation	true to show confirmation.
                             * @param	sortAlphabetically	true to sort alphabetically.
                             */
                            LanguageSelectionBoxWidget ( bool showConfirmation, bool sortAlphabetically );
                            /**
                             * @fn	virtual LanguageSelectionBoxWidget::~LanguageSelectionBoxWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             */
                            virtual ~LanguageSelectionBoxWidget();
                            /**
                             * @fn	virtual void LanguageSelectionBoxWidget::SimulateButtonNPressed ( unsigned int index ) = 0;
                             * @brief	Simulate the press of the button indexed in N.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             * @param	index	code of the language.
                             * @return	code of language simulated.
                             */
                            virtual void SimulateButtonNPressed ( unsigned int index );
                            /**
                             * @fn	virtual void LanguageSelectionBoxWidget::refresh();
                             * @brief	refresh widget method.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             */
                            virtual void refresh();

                        private:

                            /**
                             * @fn	virtual void LanguageSelectionBoxWidget::initialize();
                             * @brief	Initializer method.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             */
                            virtual void initialize();
                            /**
                             * @fn	virtual void LanguageSelectionBoxWidget::dispose();
                             * @brief	virtual method stop.
                             * @author	Yadickson Soto
                             * @date	13/11/2012
                             */
                            virtual void dispose();
                            /**
                             * @fn	void LanguageSelectionBoxWidget::onAcceptClicked();
                             * @brief	method accept click button.
                             * @author	Yadickson Soto
                             * @date	14/11/2012
                             */
                            void onAcceptClicked();
                            /**
                             * @fn	void LanguageSelectionBoxWidget::onClearClicked();
                             * @brief	method cancel click button.
                             * @author	Yadickson Soto
                             * @date	14/11/2012
                             */
                            void onClearClicked();
                            /**
                             * @fn	void LanguageSelectionBoxWidget::onBoxClicked( std::list < Smartmatic::GUI::Widgets::BoxSelectionWidget * > & list);
                             * @brief	method box click.
                             * @author	Yadickson Soto
                             * @date	14/11/2012
                             * @param list box selected
                             */
                            void onBoxClicked ( std::list < Smartmatic::GUI::Widgets::BoxSelectionWidget * > & list );
                            /**
                             * @fn	void LanguageSelectionBoxWidget::setLanguage(std::string code);
                             * @brief	method set language.
                             * @author	Yadickson Soto
                             * @date	14/11/2012
                             * @param code set selection language code
                             */
                            void setLanguage ( std::string code );

                            Smartmatic::GUI::Widgets::SmartmaticBasicLabel * headerLabel; ///< header label
                            Smartmatic::GUI::Widgets::SmartmaticBasicFrame * bottomFrame; ///< bottom frame
                            Smartmatic::GUI::Widgets::SmartmaticBasicVBox * externalBox; ///< external vbox
                            LanguageSelectionButtonWidget * buttonWidget; ///< button widget
                            Smartmatic::GUI::Widgets::BoxSelectionWidget * currentBox; ///< current box
                            Smartmatic::GUI::Widgets::TableBoxSelectionWidget * tableWidget; ///< table widgets
                    };
                }
            }
        }
    }
}

#endif // _LANGUAGE_SELECTION_BOX_WIDGET_H_
