/**
 * @file LanguageSelectionButtonWidget.cxx
 * @brief Body language selection button widget
 * @date 14/11/2012
 * @author Yadickson Soto
 */

#include "LanguageSelectionButtonWidget.hxx"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Operation/FormatLabel.hxx>
#include <Operation/Voting/VotingOperation.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets::Voting;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Voting::Vote;
using namespace Smartmatic::SAES::GUI::Operation;
using namespace Smartmatic::SAES::GUI::Operation::Voting;

LanguageSelectionButtonWidget::LanguageSelectionButtonWidget ( bool expand )
    : ButtonsWidget ( expand )
{
    int size;

    if ( expand )
    {
        int spacing = SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getExpandButton().getSpacing();
        size = SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getExpandButton().getFontSize();
        setSpacing ( spacing );
    }
    else
    {
        int acceptWidth = SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getSeparateButton().getAcceptButtonWidth();
        int clearWidth = SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getSeparateButton().getClearButtonWidth();
        size = SAESGUIConfigurationManager::getInstance()->getLanguageSelectionWidgetConfiguration().getSeparateButton().getFontSize();
        acceptButton->set_size_request ( acceptWidth, -1 );
        clearButton->set_size_request ( clearWidth, -1 );
    }

    std::string soundPartyS = SAESGUIConfigurationManager::getInstance()->getPartySelectSound();

    acceptButton->WidgetsPosition ( 5, 0, 0 );
    acceptButton->SetSound ( soundPartyS );
    clearButton->WidgetsPosition ( 5, 0, 0 );
    clearButton->SetSound ( soundPartyS );

    modifyFontSize ( size );

    setAccessibleName ( "LanguageSelectionButtonsContainer" );
    acceptButton->setAccessibleName ( "ConfirmLanguageSelected" );
    clearButton->setAccessibleName ( "CancelLanguageSelected" );
}

LanguageSelectionButtonWidget::~LanguageSelectionButtonWidget()
{
}

void LanguageSelectionButtonWidget::update()
{
    acceptButton->SetLabel ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.Voting.LanguageSelectionButtonWidget.AcceptSelection" ) ) );
    clearButton->SetLabel ( FormatLabel::format ( N_ ( "Smartmatic.SAES.GUI.Widgets.Voting.LanguageSelectionButtonWidget.ClearSelection" ) ) );

    acceptButton->SetCustomName ( VotingOperation::getButtonName() );
    clearButton->SetCustomName ( VotingOperation::getButtonName() );

    clearSignals();
}
