/**
 * @file PreviewWidget.hxx
 * @brief Body class preview
 * @date 13/04/2012
 * @author Yadickson Soto
 */

#ifndef PREVIEWWIDGET_HXX_
#define PREVIEWWIDGET_HXX_

#include <Widgets/StepWidget.hxx>
#include <Voting/Vote/vote-schema.hxx>
#include "VotePreviewWidget.hxx"
#include "TimeOutPreviewWidget.hxx"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	PreviewWidget
                     * @brief	Class preview widget.
                     * @author	Yadickson Soto
                     * @date	13/04/2012
                     */
                    class PreviewWidget : public Smartmatic::GUI::Widgets::StepWidget
                    {
                        public:
                            /**
                             * @fn	PreviewWidget::PreviewWidget();
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	13/04/2012
                             */
                            PreviewWidget();
                            /**
                             * @fn	virtual PreviewWidget::~PreviewWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	13/04/2012
                             */
                            virtual ~PreviewWidget();
                            /**
                             * @fn	void PreviewWidget::preview ( Smartmatic::SAES::Voting::Vote::Vote & vote );
                             * @brief	Method preview.
                             * @author	Yadickson Soto
                             * @date	13/04/2012
                             * @param	vote	to preview.
                             */
                            void preview ( Smartmatic::SAES::Voting::Vote::Vote & vote );
                            /**
                             * @fn	void PreviewWidget::error();
                             * @brief	Method preview error.
                             * @author	Yadickson Soto
                             * @date	13/04/2012
                             */
                            void error();

                        protected:
                            /**
                             * @fn	void PreviewWidget::back();
                             * @brief	Method back widget.
                             * @author	Yadickson Soto
                             * @date	05/10/2011
                             */
                            void back();
                            /**
                             * @fn	void PreviewWidget::resetTimeOut();
                             * @brief	Method reset time out widget.
                             * @author	Yadickson Soto
                             * @date	03/06/2013
                             */
                            void resetTimeOut();
                            /**
                             * @fn	void PreviewWidget::viewVote();
                             * @brief	Method view vote.
                             * @author	Yadickson Soto
                             * @date	05/10/2011
                             */
                            void viewVote();
                            /**
                             * @fn	bool release();
                             * @brief	Stop vote preview. Emit signal dispatcherRelease
                             * @author	Yadickson Soto
                             * @date	05/10/2011
                             * @return 	always return false
                             */
                            bool release();

                            /**
                             * @fn	void PreviewWidget::setTimeout();
                             * @brief	Method set timeout.
                             * @author	Yadickson Soto
                             * @date	05/10/2011
                             */
                            void setTimeout();
                            /**
                             * @fn	bool PreviewWidget::releaseTimeout ();
                             * @brief	Method release timeout.
                             * @author	Yadickson Soto
                             * @date	05/10/2011
                             */
                            void releaseTimeout ();
                            /**
                             * @fn	bool PreviewWidget::releaseTimeoutClose ();
                             * @brief	Method release timeout close.
                             * @author	Yadickson Soto
                             * @date	24/05/2012
                             */
                            bool releaseTimeoutClose ();
                            /**
                             * @fn	void previewBack();
                             * @brief	Callback method: preview back from VotePreviewWidget class.
                             * @author	Yadickson Soto
                             * @date	03/06/2013
                             */
                            void previewBack();
                            /**
                             * @fn	void deleteVotePreview ();
                             * @brief	Delete VotePreviewWidget class.
                             * @author	Yadickson Soto
                             * @date	03/06/2013
                             */
                            void deleteVotePreview ();

                        private:

                            bool view; ///< flag view vote

                            sigc::connection connTimeout; ///< The connection timeout
                            sigc::connection connTimeoutClose;	///< The connection timeout close

                            Glib::Dispatcher dispatcherRelease; ///< dispatcher timeout release
                            Glib::Dispatcher dispatcherBack; ///< dispatcher back

                            Smartmatic::SAES::Voting::Vote::Vote vote; ///< vote to preview
                            VotePreviewWidget * votePreviewWidget; ///< vote preview widget
                            TimeOutPreviewWidget * timeOutPreviewWidget; ///< timeout preview widget
                            static Smartmatic::Log::ISMTTLog * logger;	///< The logger
                    };
                }
            }
        }
    }
}

#endif /* PREVIEWWIDGET_HXX_ */
