/**
 * @file PrintAndFoldVoteWidget.hxx
 * @brief Header class print vote widget
 * @date 20/03/2013
 * @author Yadickson Soto
 */

#ifndef PRINTANDFOLDVOTEWIDGET_HXX_
#define PRINTANDFOLDVOTEWIDGET_HXX_

#include <Gui/Widgets/ProgressWidget.hxx>
#include <Gui/Widgets/Voting/IPrintVoteWidget.hxx>
#include <Widgets/SmartmaticBasicVBox.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	PrintAndFoldVoteWidget
                     * @brief	Class end print vote widget.
                     * @author	Yadickson Soto
                     * @date	20/03/2013
                     */
                    class PrintAndFoldVoteWidget : public IPrintVoteWidget
                    {
                        public:

                            /**
                             * @fn	PrintAndFoldVoteWidget (
                             *   Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressPrint,
                             *   Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressFold,
                             *   Smartmatic::SAES::GUI::Widgets::Voting::PrintVoteErrorWidget * printVoteErrorWidget );
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	20/03/2013
                             * @param progressPrint progress print
                             * @param progressFold progress fold
                             * @param printVoteErrorWidget print vote error widget.
                             * @param voteComplianceFailureWidget vote compliance failure widget.
                             */
                            PrintAndFoldVoteWidget (
                                Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressPrint,
                                Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressFold,
                                Smartmatic::SAES::GUI::Widgets::Voting::PrintVoteErrorWidget * printVoteErrorWidget,
                                Smartmatic::SAES::GUI::Widgets::Voting::VoteComplianceFailureWidget * voteComplianceFailureWidget);
                            /**
                             * @fn	virtual PrintAndFoldVoteWidget::~PrintAndFoldVoteWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	20/03/2013
                             */
                            virtual ~PrintAndFoldVoteWidget();
                            /**
                             * @fn	virtual void PrintAndFoldVoteWidget::refresh();
                             * @brief	refresh widget method.
                             * @author	Yadickson Soto
                             * @date	20/03/2013
                             */
                            virtual void refresh();

                        private:

                            Smartmatic::GUI::Widgets::SmartmaticBasicVBox * vbox; ///< vertical box
                            Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressPrint; ///< print widget
                            Smartmatic::SAES::GUI::Widgets::ProgressWidget * progressFold; ///< fold widget
                    };
                }
            }
        }
    }
}

#endif /* PRINTANDFOLDVOTEWIDGET_HXX_ */
