/**
 * @file ScanVoteWidget.hxx
 * @brief Header of the scan vote widget class, which asks the user to go scan his vote to complete the voting process.
 * @date 27/03/2014
 * @author Yadickson Soto
 */

#ifndef SCAN_VOTE_WIDGET_HXX_
#define SCAN_VOTE_WIDGET_HXX_

#include <Gui/Widgets/ProgressWidget.hxx>
#include <Widgets/wizard-widget-base.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	ScanVoteWidget
                     * @brief	The scan vote widget class, which asks the user to go scan his vote to complete the voting process.
                     * @author	Yadickson Soto
                     * @date	27/03/2014
                     */
                    class ScanVoteWidget : public Smartmatic::GUI::Widgets::WizardWidgetBase
                    {
                        public:

                            /**
                             * @fn	ScanVoteWidget::ScanVoteWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress );
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	27/03/2014
                             * @param	progress	progress widget.
                             */
                            explicit ScanVoteWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress );
                            /**
                             * @fn	virtual ScanVoteWidget::~ScanVoteWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	27/03/2014
                             */
                            virtual ~ScanVoteWidget();
                            /**
                             * @fn	virtual void ScanVoteWidget::refresh();
                             * @brief	refresh widget method.
                             * @author	Yadickson Soto
                             * @date	27/03/2014
                             */
                            virtual void refresh();

                        protected:
                            /**
                             * @fn	virtual void initialize();
                             * @brief	Initializer method.
                             * @author	Yadickson Soto
                             * @date	27/03/2014
                             */
                            virtual void initialize();
                            /**
                             * @fn	void end();
                             * @brief	Method end
                             * @author	Yadickson Soto
                             * @date	27/03/2014
                             */
                            void end();

                        private:

                            Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress; ///< principal frame
                    };
                }
            }
        }
    }
}

#endif /* SCAN_VOTE_WIDGET_HXX_ */
