/**
 * @file ScreenVotingWidget.hxx
 * @brief Header class screen info voting widget
 * @date 30/04/2012
 * @author Yadickson Soto
 */

#ifndef SCREENVOTINGWIDGET_HXX_
#define SCREENVOTINGWIDGET_HXX_

#include <Gui/Widgets/ProgressWidget.hxx>
#include <Widgets/StepWidget.hxx>
#include <Widgets/smartmatic-button.h>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	ScreenVotingWidget
                     * @brief	Class card removed widget.
                     * @author	Yadickson Soto
                     * @date	30/04/2012
                     */
                    class ScreenVotingWidget : public Smartmatic::GUI::Widgets::StepWidget
                    {
                        public:

                            /**
                             * @fn	ScreenVotingWidget::ScreenVotingWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress );
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	30/04/2012
                             * @param	progress	progress widget.
                             */
                            explicit ScreenVotingWidget ( Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress );
                            /**
                             * @fn	virtual ScreenVotingWidget::~ScreenVotingWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	30/04/2012
                             */
                            virtual ~ScreenVotingWidget();
                            /**
                             * @fn	void ScreenVotingWidget::setCenterName ( const std::string& centerName );
                             * @brief	refresh widget method.
                             * @author	Yadickson Soto
                             * @date	30/03/2012
                             * @param	centerName	Name of the center.
                             */
                            void setCenterName ( const std::string& centerName );
                            /**
                             * @fn	void ScreenVotingWidget::setCurrentCenter ( int currentCenter );
                             * @brief	method setter current center.
                             * @author	Yadickson Soto
                             * @date	30/03/2012
                             * @param	currentCenter	current center.
                             */
                            void setCurrentCenter ( int currentCenter );
                            /**
                             * @fn	void ScreenVotingWidget::setTotalCenter ( int totalCenters );
                             * @brief	method setter total centers.
                             * @author	Yadickson Soto
                             * @date	30/03/2012
                             * @param	totalCenters	total centers.
                             */
                            void setTotalCenter ( int totalCenters );
                            /**
                             * @fn	virtual void ScreenVotingWidget::refresh();
                             * @brief	refresh widget method.
                             * @author	Yadickson Soto
                             * @date	30/03/2012
                             */
                            virtual void refresh();

                        private:

                            Smartmatic::SAES::GUI::Widgets::ProgressWidget * progress; ///< principal frame
                            int totalCenters; ///< total centers
                            int currentCenter; ///< current center
                            std::string centerName; ///< center name
                    };
                }
            }
        }
    }
}

#endif /* SCREENVOTINGWIDGET_HXX_ */
