/**
 * @file SimulatorVotesWidget.hxx
 * @brief Header simulator votes widget class
 * @date 05/10/2012
 * @author Yadickson Soto
 */

#ifndef SIMULATORVOTESWIDGET_HXX_
#define SIMULATORVOTESWIDGET_HXX_

#include <Widgets/StepWidget.hxx>
#include <Widgets/smartmatic-entry.h>
#include <Widgets/smartmatic-button.h>
#include <Voting/Vote/vote-schema.hxx>
#include <Printing/VotePrintDocument.h>
#include <Operation/Devices/PrinterController.hxx>
#include <Gui/Widgets/Diagnose/CheckListDiagnoseWidget.hxx>
#include <list>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                namespace Voting
                {
                    /**
                     * @class	SimulatorVotesWidget
                     * @brief	simulator votes widget class.
                     * @author	Yadickson Soto
                     * @date	05/10/2012
                     */
                    class SimulatorVotesWidget : public Smartmatic::GUI::Widgets::StepWidget,
                        public Smartmatic::SAES::Printing::PrintDocumentClient
                    {
                        public:
                            /**
                             * @fn	SimulatorVotesWidget::SimulatorVotesWidget();
                             * @brief	Class constructor.
                             * @author	Yadickson Soto
                             * @date	05/10/2012
                             */
                            SimulatorVotesWidget();
                            /**
                             * @fn	virtual SimulatorVotesWidget::~SimulatorVotesWidget();
                             * @brief	Class destructor.
                             * @author	Yadickson Soto
                             * @date	05/10/2012
                             */
                            virtual ~SimulatorVotesWidget();

                            Glib::Dispatcher startPrint; ///< signal start print
                            Glib::Dispatcher stopPrint; ///< signal stop print

                        protected:

                            /**
                             * @fn	void SimulatorVotesWidget::initialize();
                             * @brief	Method initialize widget.
                             * @author	Yadickson Soto
                             * @date	05/10/2012
                             */
                            void initialize();
                            /**
                             * @fn	void SimulatorVotesWidget::dispose();
                             * @brief	Method dispose widget.
                             * @author	Yadickson Soto
                             * @date	05/10/2012
                             */
                            void dispose();

                            /**
                             * @fn	void SimulatorVotesWidget::validate();
                             * @brief	Validates this object.
                             * @author	Youssef.tourkmani
                             * @date	01/11/2012
                             */
                            void validate();

                            /**
                             * @fn	void SimulatorVotesWidget::simulate();
                             * @brief	Simulates this object.
                             * @author	Youssef.tourkmani
                             * @date	01/11/2012
                             */
                            void simulate();

                            /**
                             * @fn	void SimulatorVotesWidget::messageUpdate();
                             * @brief	Message update.
                             * @author	Youssef.tourkmani
                             * @date	01/11/2012
                             */
                            void messageUpdate();

                            /**
                             * @fn	void SimulatorVotesWidget::endSimulate();
                             * @brief	Ends a simulate.
                             * @author	Youssef.tourkmani
                             * @date	01/11/2012
                             */
                            void endSimulate();

                            /**
                             * @fn	void SimulatorVotesWidget::end();
                             * @brief	Ends this object.
                             * @author	Youssef.tourkmani
                             * @date	01/11/2012
                             */
                            void end();

                            /**
                             * @fn	void SimulatorVotesWidget::addVotes();
                             * @brief	Adds votes.
                             * @author	Youssef.tourkmani
                             * @date	01/11/2012
                             */
                            void addVotes();

                            /**
                             * @fn	void SimulatorVotesWidget::nextPrint();
                             * @brief	Next print.
                             * @author	Youssef.tourkmani
                             * @date	01/11/2012
                             */
                            void nextPrint();

                            /**
                             * @fn	void SimulatorVotesWidget::printProcess();
                             * @brief	Print process.
                             * @author	Youssef.tourkmani
                             * @date	01/11/2012
                             */
                            void printProcess();
                            /**
                             * @fn	void PrinterDiagnosis::endPrint();
                             * @brief	Ends a print.
                             * @author	Yadickson Soto
                             * @date	09/08/2013
                             */
                            void endPrint();
                            /**
                             * @fn	void errorPrint( const std::string& message );
                             * @brief	Ends a print with error.
                             * @author	Yadickson Soto
                             * @date	09/08/2013
                             */
                            void errorPrint ( const std::string& message );

                        private:

                            Gtk::EventBox * mainFrame; ///< main frame
                            Gtk::Alignment * mainAlignment; ///< main alignment
                            Gtk::Alignment * tableAlignment; ///< table alignment
                            Gtk::VBox * mainVbox; ///< main vbox
                            Gtk::Label * countText; ///< count text
                            Gtk::Label * fullText; ///< full text
                            Smartmatic::GUI::Widgets::SmartmaticBasicCheckButton * fullCheck; ///< check
                            Gtk::Label * messageText; ///< message text
                            Gtk::Table * table; ///< container
                            Gtk::HButtonBox * buttonBox; ///< button box

                            Smartmatic::GUI::Widgets::SmartmaticEntry * countEntry; ///< count entry
                            Smartmatic::GUI::Widgets::SmartmaticButton * simButton; ///< sim button
                            Smartmatic::GUI::Widgets::SmartmaticButton * exitButton; ///< exit button

                            std::string message; ///< message
                            unsigned int count; ///< current count vote
                            std::vector < Smartmatic::SAES::Voting::Vote::Vote * > voteList; ///< vote list
                            Smartmatic::SAES::Printing::VotePrintDocument * votePrint;	///< The vote print
                            Smartmatic::SAES::Operation::Devices::PrinterController * printer; ///< printer controller
                            static Smartmatic::Log::ISMTTLog * logger;  ///< logger
                    };
                }
            }
        }
    }
}
#endif /* SIMULATORVOTESWIDGET_HXX_ */
