/**
 * @file ToolkitElement.cpp
 * @brief Body class toolkit element
 * @date 28/05/2011
 * @author Gerardo Hernandez
 */

#include "ToolkitElement.h"
#include <Configuration/MachineModelEnum.hxx>
#include <Configuration/s-m-t-t-g-u-i-conf-manager.h>

using namespace Smartmatic::Configuration;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;

ToolkitElement::ToolkitElement ( std::string imagepath, std::string messageA, MenuOption optionA,
                                 WizardConfiguration currentWizardConfiguration,  bool useMessage )
    : SmartmaticBasicFrame ()
{
    option = optionA;

    image = manage ( new SmartmaticBasicImage () );
    vbox = manage ( new SmartmaticBasicVBox() );
    title = manage ( new SmartmaticBasicLabel() );
    clickEventBox = manage ( new SmartmaticBasicEventBox() );
    title->set_label ( messageA );
    vbox->pack_start ( *image, false, false, 3 );

    try
    {
        int width = currentWizardConfiguration.getToolboxElementWidth();
        int height = currentWizardConfiguration.getToolboxElementHeight();

        if ( SMTTGUIConfigurationManager::getInstance()->getSmartmaticGUIMachineModelConfiguration().getId() == EnumToString( PM_VIU805 ) )
        {
            double guiReconfigurationFactor = SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSmartmaticGUIMachineModelConfiguration().getGuiReconfigurationFactor();

            width *= guiReconfigurationFactor;
            height *= guiReconfigurationFactor;
        }

        Glib::RefPtr<Gdk::Pixbuf> im = Gdk::Pixbuf::create_from_file ( imagepath, width, height, false );

        image->set ( im );
    }
    catch ( ... )
    {

    }

    if ( useMessage )
    {
        vbox->pack_end ( *title, false, false, 1 );
    }

    clickEventBox->add ( *vbox );
    clickEventBox->signal_button_press_event().connect ( sigc::mem_fun ( *this, &ToolkitElement::on_eventbox_clicked ) );
    add ( *clickEventBox );
    show_all_children ( true );

    image->setAccessibleName ( optionA.accessibleName );
    vbox->setAccessibleName ( optionA.accessibleName + "VerticalBox" );
    title->setAccessibleName ( optionA.accessibleName );
    clickEventBox->setAccessibleName ( optionA.accessibleName + "Container" );
}

bool ToolkitElement::on_eventbox_clicked ( GdkEventButton * event )
{
    m_toolkit_element_sigc.emit ( option );
    return true;
}

ToolkitElement::~ToolkitElement()
{

}
