/**
 * @file WizardConfiguration.cpp
 * @brief Body wizard widget configuration class
 * @date 30/08/2013
 * @author Yadickson Soto
 */

#include "WizardConfiguration.h"

using namespace Smartmatic::SAES::GUI::Widgets;

WizardConfiguration::WizardConfiguration()
{
    this->enumIntState = 0;
    this->toolboxElementHeight = 0;
    this->toolboxElementWidth = 0;
    this->helpWindow_UseHelp = 0;
    this->enableFilePrinting = true;
}

WizardConfiguration::~WizardConfiguration()
{

}

std::vector<MenuOption> WizardConfiguration::GetCurrentToolbox ( std::vector<WizardConfiguration> configuration,
        std::string currentState )
{
    for ( unsigned int i = 0; i < configuration.size(); i++ )
    {
        if ( configuration[i].isState ( currentState ) )
        {
            return configuration[i].getToolbox();
        }
    }

    std::vector<MenuOption> empty;
    return empty;
}

std::vector<MenuOption> WizardConfiguration::GetCurrentPrincipaButtonBox ( std::vector<WizardConfiguration> configuration,
        std::string currentState )
{
    for ( unsigned int i = 0; i < configuration.size(); i++ )
    {
        if ( configuration[i].isState ( currentState ) )
        {
            return configuration[i].getPrincipalOptions();
        }
    }

    std::vector<MenuOption> empty;
    return empty;
}

WizardConfiguration WizardConfiguration::GetWizardWidgetConfigurationByState ( std::vector<WizardConfiguration> configuration, std::string currentState )
{
    for ( unsigned int i = 0; i < configuration.size(); i++ )
    {
        if ( configuration[i].isState ( currentState ) )
        {
            return configuration[i];
        }
    }

    WizardConfiguration empty;
    return empty;
}


bool WizardConfiguration::isState ( const std::string& value )
{
    if ( value == getStateEnum() )
    {
        return true;
    }

    return false;
}

std::vector<MenuOption> WizardConfiguration::getPrincipalOptions()
{
    return options;
}

std::vector<MenuOption>  WizardConfiguration::getToolbox()
{
    return toolkit;
}

void WizardConfiguration::setToolbox ( const std::vector<MenuOption>& value )
{
    toolkit = value;
}

void WizardConfiguration::setPrincipalOptions ( const std::vector<MenuOption>& value )
{
    options = value;
}

std::string WizardConfiguration::getStateName()
{
    return state_Name;
}
void WizardConfiguration::setStateName ( const std::string& value )
{
    state_Name = value;
}

std::string WizardConfiguration::getStateDescription()
{
    return state_Description;
}
void WizardConfiguration::setStateDescription ( const std::string& value )
{
    state_Description = value;
}

void WizardConfiguration::setAccessibleName ( const std::string & value )
{
    stateAccesibleName = value;
}

std::string WizardConfiguration::getAccessibleName ()
{
    return stateAccesibleName;
}

void WizardConfiguration::setTimelineAccessibleName ( const std::string & value )
{
    timelineAccesibleName = value;
}

std::string WizardConfiguration::getTimelineAccessibleName ()
{
    return timelineAccesibleName;
}

std::string WizardConfiguration::getStateHelpTitleKey()
{
    return stateHelp_TitleKey;
}
void WizardConfiguration::setStateHelpTitleKey ( const std::string& value )
{
    stateHelp_TitleKey = value;
}

std::string WizardConfiguration::getStateHelpContentKey()
{
    return stateHelp_ContentKey;
}
void WizardConfiguration::setStateHelpContentKey ( const std::string& value )
{
    stateHelp_ContentKey = value;
}

std::string WizardConfiguration::getStateHelpRelativeImagePath()
{
    return stateHelp_RelativeImagePath;
}
void WizardConfiguration::setStateHelpRelativeImagePath ( const std::string& value )
{
    stateHelp_RelativeImagePath = value;
}

std::string WizardConfiguration::getTimelineNameKey()
{
    return timeline_NameKey;
}
void WizardConfiguration::setTimelineNameKey ( const std::string& value )
{
    timeline_NameKey = value;
}

std::string WizardConfiguration::getTimelineDescriptionKey()
{
    return timeline_DescriptionKey;
}
void WizardConfiguration::setTimelineDescriptionKey ( const std::string& value )
{
    timeline_DescriptionKey = value;
}

std::vector < std::string > & WizardConfiguration::getTimelineRelativeImagesPath()
{
    return timelineRelativeImagesPath;
}

std::vector < std::string > & WizardConfiguration::getTimelineCodes()
{
    return timelineCodes;
}

void WizardConfiguration::addTimelineRelativeImagePath ( const std::string & value, const std::string & code )
{
    timelineRelativeImagesPath.push_back ( value );
    timelineCodes.push_back ( code );
}

std::string WizardConfiguration::getStateEnum()
{
    return stateEnum;
}
void WizardConfiguration::setStateEnum ( const std::string& value )
{
    stateEnum = value;
}

std::string WizardConfiguration::getHelpTitle()
{
    return getStateHelpTitleKey();
}

std::string WizardConfiguration::getHelpContent()
{
    return getStateHelpContentKey();
}

std::string WizardConfiguration::getHelpTitleAccessibleName()
{
    return getTimelineAccessibleName() + "HelpTitle";
}

std::string WizardConfiguration::getHelpContentAccessibleName()
{
    return getTimelineAccessibleName() + "HelpContent";
}

int WizardConfiguration::getToolboxElementWidth()
{
    return toolboxElementWidth;
}
int WizardConfiguration::getToolboxElementHeight()
{
    return toolboxElementHeight;
}

void WizardConfiguration::setToolboxElementWidth ( int value )
{
    toolboxElementWidth = value;
}
void WizardConfiguration::setToolboxElementHeight ( int value )
{
    toolboxElementHeight = value;
}

int WizardConfiguration::getEnumIntState()
{
    return enumIntState;
}
void WizardConfiguration::setEnumIntState ( int value )
{
    enumIntState = value;
}
bool WizardConfiguration::isEnumIntState ( int value )
{
    if ( value == enumIntState )
    {
        return true;
    }

    return false;
}

void WizardConfiguration::setButtonsLabelConfiguration ( Smartmatic::GUI::Configuration::LabelConfiguration value )
{
    buttonsLabelConfiguration = value;
}
void WizardConfiguration::setTitleHelpLabelConfiguration ( Smartmatic::GUI::Configuration::LabelConfiguration value )
{
    titleHelpLabelConfiguration = value;
}
void WizardConfiguration::setHelpLabelConfiguration ( Smartmatic::GUI::Configuration::LabelConfiguration value )
{
    helpLabelConfiguration = value;
}

Smartmatic::GUI::Configuration::LabelConfiguration WizardConfiguration::getButtonsLabelConfiguration()
{
    return buttonsLabelConfiguration;
}

Smartmatic::GUI::Configuration::LabelConfiguration WizardConfiguration::getTitleHelpLabelConfiguration()
{
    return titleHelpLabelConfiguration;
}

Smartmatic::GUI::Configuration::LabelConfiguration WizardConfiguration::getHelpLabelConfiguration()
{
    return helpLabelConfiguration;
}

std::string WizardConfiguration::getImageHelp()
{
    return helpWindow_ImageHelp;
}
void WizardConfiguration::setImageHelp ( const std::string& value )
{
    helpWindow_ImageHelp = value;
}

std::string WizardConfiguration::getPdfHelp()
{
    return helpWindow_PdfHelp;
}
void WizardConfiguration::setPdfHelp ( const std::string& value )
{
    helpWindow_PdfHelp = value;
}

std::string WizardConfiguration::getTitleKey()
{
    return helpWindow_TitleKey;
}
void WizardConfiguration::setTitleKey ( const std::string& value )
{
    helpWindow_TitleKey = value;
}

bool WizardConfiguration::getUseHelp()
{
    return helpWindow_UseHelp;
}

void WizardConfiguration::setUseHelp ( bool value )
{
    helpWindow_UseHelp = value;
}

void WizardConfiguration::setEnableFilePrinting ( bool enable )
{
    enableFilePrinting = enable;
}

bool WizardConfiguration::getEnableFilePrinting ()
{
    return enableFilePrinting;
}
