/**
 * @file WizardTimeline.cpp
 * @brief Body wizard time line class
 * @date 28/05/2011
 * @author Gerardo Hernandez
 */

#include "WizardTimeline.h"
#include "Environment/Configurations/resource-path-provider.h"
#include <Operation/ImageResourcePath.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Operation;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::Environment;

WizardTimeline::WizardTimeline ( std::vector<std::string> & imagesPath, std::vector<std::string> & codes )
    : SmartmaticBasicHBox()
{
    std::vector<std::string>::iterator iter;
    int i = 0;

    for ( iter = imagesPath.begin(); iter != imagesPath.end(); ++iter, i++ )
    {
        std::string image_path = ImageResourcePath::getPath ( *iter );
        SmartmaticBasicImage *image = new SmartmaticBasicImage ( image_path );
        image->setAccessibleName ( codes[i] );
        pack_start ( *image, false, true, 0 );
        imageVector.push_back ( image );
    }

    show_all_children();
}

WizardTimeline::~WizardTimeline()
{
    std::vector<SmartmaticBasicImage *>::iterator iter;

    for ( iter = imageVector.begin(); iter != imageVector.end(); ++iter )
    {
        if ( *iter )
        {
            delete *iter;
        }
    }

    imageVector.clear();
}
