/**
 * @file	ballot-option-widget.h
 * @brief	Declares the ballot option widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */

#ifndef _BALLOT_OPTION_WIDGET_H_
#define _BALLOT_OPTION_WIDGET_H_

#include <Gui/Widgets/BallotOptionInfoWidget.hxx>
#include <Gui/Widgets/voting-widget-base.h>
#include <Gui/Widgets/Voting/IContestLayout.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	BallotOptionWidget
                 * @brief	Ballot option widget.
                 * @author	Cesar.bonilla
                 * @date	4/29/2011
                 */

                class BallotOptionWidget: public BallotOptionInfoWidget
                {
                    public:

                        /**
                         * @fn	BallotOptionWidget ( const Smartmatic::SAES::Voting::Election::Eligible_option & elegibleOption,
                         *                   Smartmatic::SAES::Runtime::Environment::SaesDirectories & saesDir,
                         *                   bool showNumber, bool enableClick, bool showBorder );
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	26/02/2014
                         * @param	elegibleOption	ballot option to be displayed.
                         * @param	saesDir			The saes directory, used to retrieve image files.
                         * @param	showNumber		true to show, false to hide the number.
                         * @param	enableClick		true to enable click and change selection color.
                         * @param	showBorder		true to show border widget.
                         */
                        BallotOptionWidget ( const Smartmatic::SAES::Voting::Election::Eligible_option & elegibleOption,
                                             Smartmatic::SAES::Runtime::Environment::SaesDirectories & saesDir,
                                             bool showNumber, bool enableClick, bool showBorder,
                                             Smartmatic::SAES::GUI::Widgets::Voting::IContestLayout * layout);

                        /**
                         * @fn	virtual ~BallotOptionWidget();
                         * @brief	class destructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        virtual ~BallotOptionWidget();

                        /**
                         * @fn	virtual void BallotOptionWidget::setSize ( int width, int height );
                         * @brief	set size elements.
                         * @author	Yadickson Soto
                         * @date	16/03/2012
                         * @param	width 	Widget's width.
                         * @param	height	Widget's height.
                         */
                        virtual void setSize ( int width, int height );

                    private:

                        VotingWidgetBase * votingWidget; ///< The voting widget
                };
            }
        }
    }
}

#endif // _BALLOT_OPTION_WIDGET_H_
