/**
 * @file	close-election-confirmation-widget.cc
 * @brief	close election confirmation widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "close-election-confirmation-widget.h"
#include <Log/ISMTTLog.h>
#include <System/Exception/XmlException.hxx>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Operation/MachineOperationManager.hxx>
#include <Widgets/smartmatic-button.h>
#include <Widgets/SmartmaticBasicVBox.hxx>
#include <Operation/AccessibleManager.hxx>
#include <Configuration/MachineModelEnum.hxx>
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include "Configuration/s-m-t-t-g-u-i-conf-manager.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

#define BUTTON_WIDTH  170
#define BUTTON_HEIGHT 70

using namespace Gtk;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Configuration;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::GUI::Operation;
using namespace Smartmatic::Log;

Smartmatic::Log::ISMTTLog * CloseElectionConfirmationWidget::logger = Smartmatic::Log::SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.CloseElectionConfirmationWidget", GETTEXT_PACKAGE );

CloseElectionConfirmationWidget::CloseElectionConfirmationWidget()
{
    int buttonWidth  = BUTTON_WIDTH;
    int buttonHeight = BUTTON_HEIGHT;

    if ( SMTTGUIConfigurationManager::getInstance()->getSmartmaticGUIMachineModelConfiguration().getId() == EnumToString( PM_VIU805 ) )
    {
        double guiReconfigurationFactor = SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSmartmaticGUIMachineModelConfiguration().getGuiReconfigurationFactor();

        buttonWidth *= guiReconfigurationFactor;
        buttonHeight *= guiReconfigurationFactor;
    }

    SmartmaticButton * confirmButton = manage ( new SmartmaticButton ( _ ( "Smartmatic.SAES.GUI.Functionality.CloseElectionFunctionality.ConfirmButton" ) ) );
    confirmButton->signal_clicked().connect ( sigc::mem_fun ( *this, &CloseElectionConfirmationWidget::on_confirmButton_clicked ) );
    confirmButton->set_size_request ( buttonWidth, buttonHeight );
    confirmButton->SetButtonType ( SmartmaticButton::Ok );
    confirmButton->WidgetsPosition ( 5, 6, 0 );
    SmartmaticButton * cancelButton = manage ( new SmartmaticButton ( _ ( "Smartmatic.SAES.GUI.Functionality.CloseElectionFunctionality.CancelButton" ) ) );
    cancelButton->signal_clicked().connect ( sigc::mem_fun ( *this, &CloseElectionConfirmationWidget::on_cancelButton_clicked ) );
    cancelButton->set_size_request ( buttonWidth, buttonHeight );
    cancelButton->SetButtonType ( SmartmaticButton::Cancel );
    cancelButton->WidgetsPosition ( 5, 6, 0 );
    HButtonBox * buttonBox = manage ( new HButtonBox() );
    buttonBox->set_size_request ( 300, 200 );
    buttonBox->set_layout ( BUTTONBOX_SPREAD );
    buttonBox->pack_start ( *cancelButton, false, false );
    buttonBox->pack_start ( *confirmButton, false, false );

    label = manage ( new SmartmaticBasicLabel ( _ ( "Smartmatic.SAES.GUI.Functionality.CloseElectionFunctionality.CloseConfirmation" ) ) );
    label->set_size_request ( 980, 200 );
    Pango::FontDescription fontTitle = label->get_style()->get_font();
    fontTitle.set_size ( 20 * Pango::SCALE );
    fontTitle.set_weight ( Pango::WEIGHT_BOLD );
    label->modify_font ( fontTitle );
    label->set_alignment ( 0.5, 0.5 );
    SmartmaticBasicVBox * vbox = manage ( new SmartmaticBasicVBox() );
    vbox->pack_start ( *label, false, false );
    vbox->pack_start ( *buttonBox, false, false );
    Alignment * questionAlign = manage ( new Alignment() );
    questionAlign->set ( 0.5, 0.5, 0, 0 );
    questionAlign->add ( *vbox );
    setWidget ( questionAlign );

    confirmButton->setAccessibleName ( "CloseElectionConfirm" );
    cancelButton->setAccessibleName ( "CloseElectionCancel" );
    label->setAccessibleName ( "CloseElectionConfirmationInfo" );
    vbox->setAccessibleName ( "CloseElectionConfirmationContainer" );

    AccessibleManager::setName ( questionAlign, "panelCloseElectionConfirmationAlignmentContainer" );
    AccessibleManager::setName ( buttonBox, "panelCloseElectionConfirmationButtonContainer" );

    setAccessibleName ( "CloseElectionConfirmationWidget" );
}

CloseElectionConfirmationWidget::~CloseElectionConfirmationWidget()
{
}

void CloseElectionConfirmationWidget::on_confirmButton_clicked()
{
    emit();
}

void CloseElectionConfirmationWidget::on_cancelButton_clicked()
{
    m_stop_signal.emit();
}

void CloseElectionConfirmationWidget::initialize()
{
    unsigned int totalOfficialScannedVotes = MachineOperationManager::getInstance()->getVoteStatistics()->getOfficialVotes();

    if ( totalOfficialScannedVotes > 0 )
    {
        if ( !SAESGUIConfigurationManager::getInstance()->GetCloseElectionFunctionalityConfiguration().getShowConfirmation() )
        {
            set_no_show_all();
            hide();
            emit();
        }

        label->set_text ( _ ( "Smartmatic.SAES.GUI.Functionality.CloseElectionFunctionality.CloseConfirmationMessage" ) );
    }
}
