/**
 * @file	close-election-status-widget.cc
 * @brief	close election status widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "close-election-status-widget.h"
#include <Operation/MachineOperationManager.hxx>
#include <System/IO/File.h>
#include "Environment/Configurations/resource-path-provider.h"
#include <Log/ISMTTLog.h>
#include <System/Exception/CryptoException.hxx>
#include <System/Exception/SignedException.hxx>
#include <System/Exception/XmlException.hxx>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::Environment;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::Log;

Smartmatic::Log::ISMTTLog * CloseElectionStatusWidget::logger = Smartmatic::Log::SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Widgets.CloseElectionStatusWidget", GETTEXT_PACKAGE );

CloseElectionStatusWidget::CloseElectionStatusWidget ( ProgressWidget * progress )
    : WizardWidgetBase(), progress ( progress )
{
    m_thread = NULL;

    this->progress->setImage ( "ui/close-election.gif" );
    this->progress->setInfoText ( N_ ( "Smartmatic.SAES.GUI.Widgets.CloseElectionStatusWidget.ClosingElection" ) );
    setWidget ( progress );

    setAccessibleName ( "CloseElectionStatusWidget" );
}

CloseElectionStatusWidget::~CloseElectionStatusWidget()
{
    dispose();

    this->remove();

    if ( progress )
    {
        delete progress;
        progress = NULL;
    }
}

void CloseElectionStatusWidget::initialize()
{
    m_disable_close_signal.emit();

    if ( !Glib::thread_supported() )
    {
        Glib::thread_init();
    }

    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }

    m_thread = Glib::Thread::create ( sigc::mem_fun ( *this, &CloseElectionStatusWidget::start ), true );
}

void CloseElectionStatusWidget::dispose()
{
    if ( m_thread != NULL )
    {
        m_thread->join();
        m_thread = NULL;
    }
}

void CloseElectionStatusWidget::start()
{
    bool errorHappen = true;

    try
    {
        MachineOperationManager::getInstance()->closeElection();
        errorHappen = false;
    }
    catch ( CryptoException & ex )
    {
        logger->Debug ( "CloseElectionStatusWidget CryptoException" );
    }
    catch ( SignedException & ex )
    {
        logger->Debug ( "CloseElectionStatusWidget SignedException" );
    }
    catch ( XmlException & ex )
    {
        logger->Debug ( "CloseElectionStatusWidget XmlException" );
    }
    catch ( ... )
    {
        logger->Debug ( "CloseElectionStatusWidget Error" );
    }

    if ( !errorHappen )
        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &CloseElectionStatusWidget::end ), 500 );
    else
        emitError();
}

void CloseElectionStatusWidget::end()
{
    emit();
}

void CloseElectionStatusWidget::updateLabel ( std::string text )
{
    progress->hideInfoTitle();
    progress->hideImage();
    progress->setInfoText ( text );
    m_stop_signal.emit();
}

bool CloseElectionStatusWidget::isEnabledButtonExitWizard()
{
    return false;
}
