/**
 * @file	complex-ballot-option-widget.cc
 * @brief	complex ballot option widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "complex-ballot-option-widget.h"
#include <Configuration/label-configuration.h>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <System/IO/File.h>

using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Voting::Election;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::Runtime::Environment;
using namespace Smartmatic::System::IO;

ComplexBallotOptionWidget::ComplexBallotOptionWidget ( const Eligible_option & eligibleOption, SaesDirectories & saesDir, bool enableClick, bool showBorder )
    : BallotOptionInfoWidget ( eligibleOption, saesDir, enableClick, showBorder )
{
    votingWidget = NULL;
    labelWidget = manage ( new SmartmaticBasicLabel ( labelFullName ) );

    circle = manage ( new CircleWidget() );
    circle->set_size_request ( 30, -1 );

    numberLabel = manage ( new SmartmaticBasicLabel() );
    numberLabel->set_text ( labelNumber );
    numberLabel->set_size_request ( numberWidth, -1 );

    static LabelConfiguration numberChildConfiguration = SAESGUIConfigurationManager::getInstance()->GetVotingWidgetNumberChildLabelConfiguration();
    static LabelConfiguration listConfiguration = SAESGUIConfigurationManager::getInstance()->GetVotingWidgetLabelChildLabelConfiguration();

    Smartmatic::GUI::Configuration::LabelConfiguration::SetLabelConfigurationWithoutAlignment ( numberLabel, numberChildConfiguration );
    Smartmatic::GUI::Configuration::LabelConfiguration::SetLabelConfigurationWithoutAlignment ( labelWidget, listConfiguration );

    hbox = manage ( new SmartmaticBasicHBox ( false, 10 ) );
    hbox->pack_start ( *numberLabel, false, false );
    hbox->pack_start ( *circle, false, false );
    hbox->pack_start ( *labelWidget, false, false );
    hbox->show_all_children();

    getSignalClick().connect ( sigc::mem_fun ( this, &ComplexBallotOptionWidget::onBoxClicked ) );

    addWidget ( hbox );
    show_all_children();
}

ComplexBallotOptionWidget::~ComplexBallotOptionWidget()
{
}

void ComplexBallotOptionWidget::forceShowImage ( int imageHeight, float imageRelation )
{
    if ( File::getInstance()->canOpenFile ( imagePath ) )
    {
        getEventBox()->remove();

        if ( votingWidget )
        {
            hbox->remove ( *votingWidget );
        }

        if ( labelWidget )
        {
            hbox->remove ( *labelWidget );
        }

        int spacing2 = SAESGUIConfigurationManager::getInstance()->GetBallotOptionSelectionConfiguration().getImageInListPadgging();
        float imageWidth = imageHeight * imageRelation;

        Smartmatic::SAES::Configuration::WidgetDisplayType display ( DisplayType::CONFIGURATION_IMAGE_RESIZE, 0, 0.5 );

        votingWidget = manage ( new VotingWidgetBase ( display, imagePath, "0", paddingConfig, numberWidth, imageWidth, ( int ) imageHeight, false ) );
        votingWidget->set_size_request ( imageWidth, imageHeight );

        SmartmaticBasicHBox * newHbox = manage ( new SmartmaticBasicHBox ( false, spacing2 ) );

        newHbox->pack_start ( *hbox, false, false );
        newHbox->pack_start ( *votingWidget, false, false );
        newHbox->show_all_children();

        addWidget ( newHbox );
    }
}

void ComplexBallotOptionWidget::onBoxClicked ( Smartmatic::GUI::Widgets::BoxSelectionWidget * widget )
{
    circle->SetMark ( widget->getStatus() );
}

void ComplexBallotOptionWidget::clear()
{
    BoxSelectionWidget::clear();
    circle->SetMark ( getStatus() );
}

Category ComplexBallotOptionWidget::getCategory()
{
    return Smartmatic::SAES::Voting::Election::Category::ELECTION_LIST;
}

void ComplexBallotOptionWidget::setSize ( int width, int height )
{
    BoxSelectionWidget::setSize ( width, height );

    if ( votingWidget )
    {
        votingWidget->setSize ( width, height );
        votingWidget->show();
    }
}
