/**
 * @file complex-ballot-option-widget.h
 * @brief ballot option widget with a circle
 * @author Juan delgado <juan.delgado@smartmatic.com>
 */

#ifndef _COMPLEX_BALLOT_OPTION_WIDGET_H_
#define _COMPLEX_BALLOT_OPTION_WIDGET_H_

#include <Gui/Widgets/BallotOptionInfoWidget.hxx>
#include <Gui/Widgets/voting-widget-base.h>
#include <Widgets/circle-widget.h>
#include <Widgets/SmartmaticBasicLabel.hxx>
#include <Widgets/SmartmaticBasicHBox.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	ComplexBallotOptionWidget
                 * @brief	This component is a widget used to allow the list vote (list is a selectable option in the candidate list screen).
                 * @author	Cesar.bonilla
                 * @date	4/29/2011
                 */

                class ComplexBallotOptionWidget: public BallotOptionInfoWidget
                {
                    public:

                        /**
                         * @fn	ComplexBallotOptionWidget::ComplexBallotOptionWidget ( const Smartmatic::SAES::Voting::Election::Eligible_option & eligibleOption,
                         *                          Smartmatic::SAES::Runtime::Environment::SaesDirectories & saesDir,
                         *                          bool enableClick, bool showBorder );
                         * @brief	class constructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	eligibleOption	ballot option to be displayed.
                         * @param	saesDir			The saes directory, used to retrieve image files.
                         * @param	enableClick		true to enable click and change selection color.
                         * @param	showBorder		true to show border widget.
                         */

                        ComplexBallotOptionWidget ( const Smartmatic::SAES::Voting::Election::Eligible_option & eligibleOption,
                                                    Smartmatic::SAES::Runtime::Environment::SaesDirectories & saesDir,
                                                    bool enableClick, bool showBorder );

                        /**
                         * @fn	ComplexBallotOptionWidget::~ComplexBallotOptionWidget();
                         * @brief	Finaliser.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        virtual ~ComplexBallotOptionWidget();

                        /**
                         * @fn	void forceShowImage ( int imageHeight, float imageRelation );
                         * @brief	Force show image.
                         * @author	Yadickson Soto
                         * @date	26/02/2014
                         * @param	imageHeight	 	Height of the image.
                         * @param	imageRelation	The image relation.
                         */
                        void forceShowImage ( int imageHeight, float imageRelation );

                        /**
                         * @fn	virtual Smartmatic::SAES::Voting::Election::Category getCategory();
                         * @brief	Gets category type of ballot.
                         * @author	Yadickson Soto
                         * @date	26/02/2014
                         * @return	if ballot is principal.
                         */
                        virtual Smartmatic::SAES::Voting::Election::Category getCategory();

                        /**
                         * @fn	virtual void BallotOptionWidget::setSize ( int width, int height );
                         * @brief	set size elements.
                         * @author	Yadickson Soto
                         * @date	16/03/2012
                         * @param	width 	Widget's width.
                         * @param	height	Widget's height.
                         */
                        virtual void setSize ( int width, int height );

                        /**
                         * @fn virtual void clear();
                         * @brief Method clear
                         * @date 26/02/2014
                         * @author Yadickson Soto
                         */
                        virtual void clear();

                    protected:

                        /**
                         * @fn	void onBoxClicked ( Smartmatic::GUI::Widgets::BoxSelectionWidget * widget );
                         * @brief	callback for when the box is clicked.
                         * @author	Yadickson Soto
                         * @date	24/02/2014
                         * @param	widget box selected
                         */
                        void onBoxClicked ( Smartmatic::GUI::Widgets::BoxSelectionWidget * widget );

                    private:

                        Smartmatic::GUI::Widgets::CircleWidget * circle; ///< The graphical circle, between list number and list image, in the candidate selection screen.
                        VotingWidgetBase * votingWidget; ///< The voting widget
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * labelWidget; ///< The label widget
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel	* numberLabel;	///< Number of labels
                        Smartmatic::GUI::Widgets::SmartmaticBasicHBox * hbox;	///< The hbox

                };
            }
        }
    }
}

#endif // _COMPLEX_BALLOT_OPTION_WIDGET_H_
