/**
 * @file	party-widget.h
 * @brief	Declares the party widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _PARTY_WIDGET_H_
#define _PARTY_WIDGET_H_


#include <gtkmm.h>
#include "voting-widget-base.h"
#include "Voting/Election/election-schema.hxx"
#include "Runtime/Environment/saes-directories.h"
#include <Widgets/SmartmaticBasicFrame.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	PartyWidget
                 * @brief	Header class PartyWidget.
                 * @author	Juan delgado &lt;juan.delgado@smartmatic.com&gt;
                 * @date	4/29/2011
                 */

                class PartyWidget: public Smartmatic::GUI::Widgets::SmartmaticBasicFrame
                {
                    public:

                        /**
                         * @fn	PartyWidget::PartyWidget ( Smartmatic::SAES::Voting::Election::Ballot_option & ballotParty,
                         * 			Smartmatic::SAES::Runtime::Environment::SaesDirectories & saesDir, int width, int height );
                         * @brief	class constructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	ballotParty	ballot option party to be displayed.
                         * @param	saesDir		 	The saes dir.
                         * @param	width			 	widget's width.
                         * @param	height		 	widget's height.
                         */

                        PartyWidget ( Smartmatic::SAES::Voting::Election::Ballot_option & ballotParty,
                                      Smartmatic::SAES::Runtime::Environment::SaesDirectories & saesDir,
                                      int width, int height );

                        /**
                         * @fn	PartyWidget::PartyWidget ( std::string text, int width, int height );
                         * @brief	class constructor for null party.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	text		to be displayed.
                         * @param	width 	widget's width.
                         * @param	height	widget's height.
                         */

                        PartyWidget ( std::string text, int width, int height );

                        /**
                         * @fn	void PartyWidget::RefreshLabel ( std::string text );
                         * @brief	Refresh label.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	text	The text.
                         */

                        void RefreshLabel ( std::string text );

                        /**
                         * @fn	PartyWidget::~PartyWidget();
                         * @brief	class destructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        ~PartyWidget();

                        /**
                         * @fn	Smartmatic::SAES::Voting::Election::Party & PartyWidget::getParty();
                         * @brief	Gets the party.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The party.
                         */
                        Smartmatic::SAES::Voting::Election::Party & getParty();

                        /**
                         * @fn	std::string PartyWidget::getPartyCode();
                         * @brief	Gets party code.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @return	The party code.
                         */
                        std::string getPartyCode();

                        /**
                         * @brief  Gets the smallest font size in the party widget.
                         * @author manuel.arguelles
                         * @date   oct  2, 2018
                         * @return The smallest font size in use or -1 if the font
                         * size is not currently available.
                         */
                        int getSmallestFontSize() const;

                        /**
                         * @brief  Sets the font size of the party widget.
                         * The font size could be reduced if required to fit the
                         * screen/widget.
                         * @author manuel.arguelles
                         * @date   oct  2, 2018
                         * @param  fontSize The size of the font.
                         */
                        void setFontSize(int fontSize);

                    private:
                        /**
                         * Child Widgets
                         */
                        VotingWidgetBase * votingWidget; ///< The voting widget
                        Gtk::Label * labelString;	///< The label string
                        bool m_widgetEnabled; ///< true to enable, false to disable the widget
                        bool isPartyNull; ///< flag is party null

                        /**
                         * SAES voting objects
                         */
                        Smartmatic::SAES::Voting::Election::Party party;	///< The party
                        Smartmatic::SAES::Voting::Election::Ballot_option ballotParty;  ///< The ballot party
                        static Smartmatic::Log::ISMTTLog * logger;	///< The logger
                };
            }
        }
    }
}

#endif // _PARTY_WIDGET_H_
