/**
 * @file	print-pv-report-widget.h
 * @brief	Declares the print pv report widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _PRINT_PV_REPORT_WIDGET_H_
#define _PRINT_PV_REPORT_WIDGET_H_

#include <gtkmm.h>
#include <Widgets/wizard-widget-base.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	PrintPVReportWidget
                 * @brief	Print pv report widget.
                 * @author	Youssef.tourkmani
                 * @date	01/11/2012
                 */
                class PrintPVReportWidget: public Smartmatic::GUI::Widgets::WizardWidgetBase
                {
                    public:
                        /**
                         * @fn	PrintPVReportWidget::PrintPVReportWidget();
                         * @brief	Default constructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        PrintPVReportWidget();

                        /**
                         * @fn	PrintPVReportWidget::~PrintPVReportWidget();
                         * @brief	Destructor.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        ~PrintPVReportWidget();

                        /**
                         * @fn	virtual void PrintPVReportWidget::initialize();
                         * @brief	Initializer method.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void initialize();
                        /**
                         * @fn	virtual void PrintPVReportWidget::dispose();
                         * @brief	virtual method stop.
                         * @author	Yadickson Soto
                         * @date	08/03/2012
                         */
                        virtual void dispose();

                    private:

                        /**
                         * @fn	void PrintPVReportWidget::ThreadStart();
                         * @brief	Thread start.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void ThreadStart();

                        /**
                         * @fn	void PrintPVReportWidget::on_done();
                         * @brief	Handles done signals.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         */
                        void on_done();

                        /**
                         * @fn	void PrintPVReportWidget::UpdateLabel ( Glib::ustring text );
                         * @brief	Updates the label described by text.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	text	The text.
                         */
                        void UpdateLabel ( Glib::ustring text );
                        Gtk::Label * label; ///< The label
                        Gtk::Image * loadImage; ///< The load image
                        Glib::Thread * m_thread; ///< The thread pointer

                        static Smartmatic::Log::ISMTTLog * logger; /**<logger*/ ///< The logger
                };
            }
        }
    }
}

#endif // _PRINT_PV_REPORT_WIDGET_H_
