/**
 * @file	referendum-selection-widget.cc
 * @brief	referendum selection widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "referendum-selection-widget.h"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include "Resources/election-string-resources-manager.h"
#include "Voting/ElectoralConfiguration.hxx"
#include "System/Sounds/smartmatic-sounds-manager.h"
#include <Operation/MachineOperationManager.hxx>
#include <Gui/Widgets/party-widget.h>
#include <Operation/MachineOperationManager.hxx>
#include "Configuration/label-configuration.h"
#include "Resources/election-string-resources-manager.h"
#include "Voting/Election/ElectionWrapper.hxx"
#include <Operation/Voting/VotingOperation.hxx>
#include <Operation/FormatLabel.hxx>
#include "AbstractFactoryWidget.hxx"
#include "FactoryMethodWidget.hxx"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Gtk;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::SAES::Voting::Election;
using namespace Smartmatic::SAES::Operation::Voting;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::Voting::Election;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::SAES::GUI::Operation::Voting;
using namespace Smartmatic::SAES::GUI::Operation;

ReferendumSelectionWidget::ReferendumSelectionWidget ( Contest * contest )
{
    currentBallot = NULL;

    showBackButton = false;
    showClearButton = false;
    m_widgetEnabled = true;

    buttonWidget = FactoryMethodWidget::createReferendumButtonWidget();
    tableWidgets = AbstractFactoryWidget::createReferendumTableWidget();
    config = SAESGUIConfigurationManager::getInstance()->GetReferendumConfiguration();
    this->contest = contest;

    bottomHeigth = config.getFrameBottomHeight();
    bottomFrame = manage ( new SmartmaticBasicFrame() );
    bottomFrame->show();
    bottomFrame->add ( *buttonWidget );
    bottomFrame->set_size_request ( -1, bottomHeigth );
    std::string question = ComposeQuestionText();

    SmartmaticBasicLabel * labelQuestion = manage ( new SmartmaticBasicLabel() );
    labelQuestion->set_size_request ( -1, config.getQuestionHeight() );
    labelQuestion->set_text ( question );
    labelQuestion->set_line_wrap ( config.getWrapQuestion() );
    labelQuestion->set_line_wrap_mode ( Pango::WRAP_WORD );

    static Smartmatic::GUI::Configuration::LabelConfiguration labelConf = SAESGUIConfigurationManager::getInstance()->GetReferendumQuestionLabelConfiguration();
    LabelConfiguration::SetLabelConfiguration ( labelQuestion, labelConf );

    labelEventBox = manage ( new SmartmaticBasicEventBox() );
    labelEventBox->set_name ( "referendumquestioneventbox" );
    labelEventBox->set_size_request ( -1, config.getQuestionHeight() );
    labelEventBox->add ( *labelQuestion );

    Alignment * align = manage ( new Alignment() );
    align->set_padding ( 0, 0, 20, 20 );
    align->set ( 0.5, 0.5, 0, 0 );
    align->add ( *labelEventBox );

    internalBox = manage ( new SmartmaticBasicVBox ( false ) );
    internalBox->pack_start ( *align, false, false );
    clientAreaFrame = manage ( new SmartmaticBasicFrame() );
    clientAreaFrame->add ( *internalBox );
    clientAreaFrame->show();

    headerLabel = manage ( new SmartmaticBasicLabel() );
    headerLabel->show();
    headerLabel->set_size_request ( -1, config.getFrameTopHeight() );

    Smartmatic::GUI::Configuration::LabelConfiguration headerConfig = getTitleLabelConfig();
    Smartmatic::GUI::Configuration::LabelConfiguration::SetLabelConfiguration ( headerLabel, headerConfig );

    externalBox = manage ( new SmartmaticBasicVBox ( false, 0 ) );
    externalBox->show();

    Gtk::HSeparator * separator = manage ( new Gtk::HSeparator() );

    externalBox->pack_start ( *headerLabel, false, false );
    externalBox->pack_start ( *separator, false, false );
    externalBox->pack_start ( *clientAreaFrame, true, true );
    externalBox->pack_start ( *bottomFrame, false, false );

    if ( SAESGUIConfigurationManager::getInstance()->GetReferendumConfiguration().getEnableClick() )
    {
        buttonWidget->getSignalClearButtonClicked().connect ( sigc::mem_fun ( this, &ReferendumSelectionWidget::on_clearButton_clicked ) );
        buttonWidget->getSignalAcceptButtonClicked().connect ( sigc::mem_fun ( this, &ReferendumSelectionWidget::on_acceptButton_clicked ) );
        buttonWidget->getSignalBackButtonClicked().connect ( sigc::mem_fun ( this, &ReferendumSelectionWidget::on_backButton_clicked ) );
    }

    refresh();
    setWidget ( externalBox );
    setTitle ( false );

    setAccessibleName ( "ReferendumSelectionWidget" );

    headerLabel->setAccessibleName ( "ReferendumHeader" );
    labelEventBox->setAccessibleName ( "ReferendumQuestionContainer" );
    labelQuestion->setAccessibleName ( "ReferendumQuestionTitle" );
    externalBox->setAccessibleName ( "ReferendumMainContainer" );
    internalBox->setAccessibleName ( "ReferendumTableContainer" );
    clientAreaFrame->setAccessibleName ( "ReferendumCenterContainer" );
    bottomFrame->setAccessibleName ( "ReferendumButtonContainer" );
}

ReferendumSelectionWidget::~ReferendumSelectionWidget()
{
    this->remove();

    if ( buttonWidget )
    {
        delete buttonWidget;
        buttonWidget = NULL;
    }

    if ( tableWidgets )
    {
        delete tableWidgets;
        tableWidgets = NULL;
    }
}

void ReferendumSelectionWidget::refresh()
{
    showClearButton = config.getShowClearButton();
    RefreshLabels();
}

void ReferendumSelectionWidget::RefreshLabels()
{
    headerLabel->set_text ( getTitleText() );
    buttonWidget->update();
}

std::string ReferendumSelectionWidget::ComposeQuestionText()
{
    Glib::ustring format =  _ ( "Smartmatic.SAES.GUI.Widgets.ReferendumSelectionWidget.QuestionPlaceHolder" );
    return FormatLabel::contestText ( *contest, format );
}

void ReferendumSelectionWidget::Initialize ( std::list<Eligible_option * > & principalBallotList )
{
    Display_info disInfo = contest->getDisplay_info();
    disInfo.getImage_width_height_relation();

    tableWidgets->clear();
    int w = config.getBallotWidth();
    int h = config.getBallotHeight();

    std::list<Smartmatic::SAES::Voting::Election::Eligible_option * >::iterator it;	///< The iterator
    bool enableClick = SAESGUIConfigurationManager::getInstance()->GetReferendumConfiguration().getEnableClick();
    int pos = 0;

    for ( it = principalBallotList.begin(); it != principalBallotList.end(); ++it )
    {
        ReferendumWidget * referendumWidget = manage ( new ReferendumWidget ( * ( *it ), enableClick ) );
        referendumWidget->setSize ( w, h );
        referendumWidget->show();

        std::stringstream ss;
        ss << "ReferendumOptionWidget" << pos++;

        referendumWidget->setAccessibleName ( ss.str() );
        tableWidgets->addWidget ( referendumWidget );
    }

    if ( config.getShowNullOption() )
    {
        ReferendumWidget * nullWidget = manage ( new ReferendumWidget ( N_ ( "Smartmatic.SAES.GUI.Widgets.ReferendumSelectionWidget.NullSelection" ), enableClick ) );
        nullWidget->setSize ( w, h );
        nullWidget->show();

        nullWidget->setAccessibleName ( "ReferendumNullOptionWidget" );
        tableWidgets->addWidget ( nullWidget );
    }

    tableWidgets->getTableWidget()->getBoxSignalClick().connect ( sigc::mem_fun ( this, &ReferendumSelectionWidget::onBallotOptionClicked ) );

    int top = config.getBallotBoxTopPadding();
    int left = config.getBallotBoxLeftPadding();
    Alignment * align = manage ( new Alignment() );
    align->set_padding ( top, 0, left, 0 );
    align->set ( 0.5, 0.5, 0, 0 );
    align->add ( *tableWidgets );
    internalBox->pack_start ( *align, false, false );
    show();
    show_all_children();
}

void ReferendumSelectionWidget::onBallotOptionClicked ( BoxSelectionWidget * ballot )
{
    currentBallot = ballot;

    if ( ballot->getStatus() )
    {
        buttonWidget->showButton ( showClearButton, true, false );
    }
    else
    {
        buttonWidget->showButton ( false, false, showBackButton );
    }
}

ReferendumSelectionWidget::type_back_clicked ReferendumSelectionWidget::back_clicked()
{
    return m_back_clicked;
}

ReferendumSelectionWidget::type_ballotOption_clicked ReferendumSelectionWidget::ballotOption_clicked()
{
    return m_ballotOption_clicked;
}

ReferendumSelectionWidget::type_back_clicked ReferendumSelectionWidget::accept_clicked()
{
    return m_accept_clicked;
}

Smartmatic::SAES::Voting::Election::Contest * ReferendumSelectionWidget::getContest()
{
    return contest;
}

void ReferendumSelectionWidget::on_nullOption_clicked()
{
    on_clearButton_clicked();
    m_null_clicked.emit();
}

void ReferendumSelectionWidget::on_clearButton_clicked()
{
    tableWidgets->clear();
    buttonWidget->clearSignals();
    buttonWidget->showButton ( false, false, showBackButton );
}

void ReferendumSelectionWidget::on_acceptButton_clicked()
{
    if ( currentBallot != NULL )
    {
        if ( currentBallot->getCode() == N_ ( "Smartmatic.SAES.GUI.Widgets.ReferendumSelectionWidget.NullSelection" ) )
        {
            m_null_clicked.emit();
        }
        else
        {
            m_ballotOption_clicked.emit ( currentBallot->getCode(), currentBallot->getStatus() );
        }
    }

    m_accept_clicked.emit();
}

void ReferendumSelectionWidget::on_backButton_clicked()
{
    m_back_clicked.emit();
}

ReferendumSelectionWidget::type_back_clicked ReferendumSelectionWidget::null_clicked()
{
    return m_null_clicked;
}

void ReferendumSelectionWidget::SetBackButton ( bool show )
{
    this->showBackButton = show;
    buttonWidget->showButton ( false, false, showBackButton );
}

Smartmatic::GUI::Configuration::LabelConfiguration ReferendumSelectionWidget::getTitleLabelConfig()
{
    return SAESGUIConfigurationManager::getInstance()->GetReferendumHeaderLabelConfiguration();
}

Smartmatic::GUI::Configuration::LabelConfiguration ReferendumSelectionWidget::getBottomLabelConfig()
{
    return SAESGUIConfigurationManager::getInstance()->GetReferendumBottomLabelConfiguration();
}

std::string ReferendumSelectionWidget::getTitleText()
{
    std::string title;
    Glib::ustring s_referendumHeaderFormat;
    Glib::ustring s_referendumHeaderFormatNoQuestion;

    switch ( VotingOperation::getVoteMode() )
    {
        case Smartmatic::SAES::Voting::Vote::VoteMode::VOTE_S:
        case Smartmatic::SAES::Voting::Vote::VoteMode::VOTE_O:
        default:
            s_referendumHeaderFormat = _ ( "Smartmatic.SAES.GUI.Windows.VotingWindow.ReferendumHeaderFormat" );
            s_referendumHeaderFormatNoQuestion = _ ( "Smartmatic.SAES.GUI.Windows.VotingWindow.ReferendumHeaderFormatNoQuestion" );
            break;

        case Smartmatic::SAES::Voting::Vote::VoteMode::VOTE_D:
            s_referendumHeaderFormat = _ ( "Smartmatic.SAES.GUI.Windows.VotingWindow.ReferendumHeaderFormat.Demo" );
            s_referendumHeaderFormatNoQuestion = _ ( "Smartmatic.SAES.GUI.Windows.VotingWindow.ReferendumHeaderFormatNoQuestion.Demo" );
            break;
    }

    if ( showBackButton )
    {
        title = FormatLabel::contestText ( *contest, s_referendumHeaderFormat );
    }
    else
    {
        title = FormatLabel::contestText ( *contest, s_referendumHeaderFormatNoQuestion );
    }

    FormatLabel::checkComposeString ( title );
    return title;
}

std::string ReferendumSelectionWidget::getBottomText()
{
    std::string bottom;
    Glib::ustring s_referendumFooterFormat;

    switch ( VotingOperation::getVoteMode() )
    {
        case Smartmatic::SAES::Voting::Vote::VoteMode::VOTE_S:
        case Smartmatic::SAES::Voting::Vote::VoteMode::VOTE_O:
        default:
            s_referendumFooterFormat = _ ( "Smartmatic.SAES.GUI.Windows.VotingWindow.ReferendumFooterFormat" );
            break;

        case Smartmatic::SAES::Voting::Vote::VoteMode::VOTE_D:
            s_referendumFooterFormat = _ ( "Smartmatic.SAES.GUI.Windows.VotingWindow.ReferendumFooterFormat.Demo" );
            break;
    }

    bottom = FormatLabel::contestText ( *contest, s_referendumFooterFormat );
    FormatLabel::checkComposeString ( bottom );
    return bottom;
}

void ReferendumSelectionWidget::SetWidgetEnabled ( bool enabled )
{
    m_widgetEnabled = enabled;
}
