/**
 * @file	referendum-widget.cc
 * @brief	referendum widget class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "referendum-widget.h"
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include "Resources/election-string-resources-manager.h"
#include "Configuration/label-configuration.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Voting::Election;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::Resources;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::GUI::Configuration;

ReferendumWidget::ReferendumWidget ( Eligible_option & elegibleOption, bool enableClick )
    : BoxSelectionWidget ( ( * ( elegibleOption.getBallot_options().getBallot_option() ).begin() ).getCode(), enableClick )
{
    std::string sname = elegibleOption.getBallot_name_key();
    std::string labelName = ElectionStringResourcesManager::getInstance()->getResource ( sname );

    config ( labelName );
}

ReferendumWidget::ReferendumWidget ( const std::string & text, bool enableClick )
    : BoxSelectionWidget ( text, enableClick )
{
    std::string labelName = _ ( text.c_str() );

    config ( labelName );
}

ReferendumWidget::~ReferendumWidget()
{

}

void ReferendumWidget::config ( const std::string & labelName )
{
    static ReferendumConfiguration config = SAESGUIConfigurationManager::getInstance()->GetReferendumConfiguration();
    static Gdk::Color selectedColor = SAESGUIConfigurationManager::ConvertToGdkColor ( config.getSelectedColor() );
    static Gdk::Color unSelectedColor = SAESGUIConfigurationManager::ConvertToGdkColor ( config.getUnSelectedColor() );
    static LabelConfiguration referendumConfiguration = SAESGUIConfigurationManager::getInstance()->GetReferendumBallotsLabelConfiguration();

    setSelectedColor ( selectedColor );
    setUnselectedColor ( unSelectedColor );

    label = manage ( new SmartmaticBasicLabel ( labelName ) );
    label->setAccessibleName ( "OptionText" );

    Smartmatic::GUI::Configuration::LabelConfiguration::SetLabelConfiguration ( label, referendumConfiguration );

    addWidget ( label );
}
