/**
 * @file	voting-widget-base.h
 * @brief	Declares the voting widget base class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#ifndef _VOTING_WIDGET_BASE_H_
#define _VOTING_WIDGET_BASE_H_

#include <gtkmm.h>

#include "Configuration/label-configuration.h"
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>
#include <Configuration/SaesGUIConfiguration-schema.hxx>
#include <Widgets/SmartmaticBasicImage.hxx>
#include <Widgets/SmartmaticBasicLabel.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace GUI
        {
            namespace Widgets
            {
                /**
                 * @class	VotingWidgetBase
                 * @brief	Voting widget base.
                 * @author	Cesar.bonilla
                 * @date	4/29/2011
                 */

                class VotingWidgetBase: public Gtk::Container
                {
                    public:

                        /**
                         * @fn	VotingWidgetBase::VotingWidgetBase ( Smartmatic::SAES::Configuration::WidgetDisplayType & display,
                         * 			std::string displayString, std::string number, int padding, int numberWidth, int width,
                         * 			int height, bool showNumberA = true, bool isReferendum = false );
                         * @brief	class constructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	display			 	widget type.
                         * @param	displayString	if widget is Text is label name, if Image is image path.
                         * @param	number			 	number.
                         * @param	padding			 	widget padding.
                         * @param	numberWidth	 	Number of widths.
                         * @param	width				 	Widget's width.
                         * @param	height			 	Widget's height.
                         * @param	showNumberA	 	true to show, false to hide the number a.
                         * @param	isReferendum 	true to set referendum mode.
                         */

                        VotingWidgetBase ( Smartmatic::SAES::Configuration::WidgetDisplayType & display, std::string displayString, std::string number, int padding, int numberWidth, int width, int height, bool showNumberA = true, bool isReferendum = false );

                        /**
                         * @fn	VotingWidgetBase::VotingWidgetBase ( Smartmatic::SAES::Configuration::WidgetDisplayType & display,
                         * 			std::string displayString, std::string number, int padding, int numberWidth,
                         * 			Smartmatic::GUI::Configuration::LabelConfiguration labelChildConfigurationA, int width,
                         * 			int height, bool showNumberA = true );
                         * @brief	Constructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	display										The display.
                         * @param	displayString							The display string.
                         * @param	number										Number of.
                         * @param	padding										The padding.
                         * @param	numberWidth								Number of widths.
                         * @param	labelChildConfigurationA	The label child configuration a.
                         * @param	width											Widget's width.
                         * @param	height										Widget's height.
                         * @param	showNumberA								true to show, false to hide the number a.
                         */

                        VotingWidgetBase ( Smartmatic::SAES::Configuration::WidgetDisplayType & display, std::string displayString, std::string number, int padding, int numberWidth,
                                           Smartmatic::GUI::Configuration::LabelConfiguration labelChildConfigurationA, int width, int height, bool showNumberA = true );

                        /**
                         * @fn	VotingWidgetBase::VotingWidgetBase ( std::string topString, std::string bottomString,
                         * 			std::string number, int padding, int numberWidth, int width, int height,
                         * 			bool showNumberA = true );
                         * @brief	class constructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	topString			top string to be displayed.
                         * @param	bottomString	bottom string to be displayed.
                         * @param	number				number.
                         * @param	padding				widget padding.
                         * @param	numberWidth 	Number of widths.
                         * @param	width					Widget's width.
                         * @param	height				Widget's height.
                         * @param	showNumberA 	true to show, false to hide the number a.
                         */

                        VotingWidgetBase ( std::string topString, std::string bottomString, std::string number, int padding, int numberWidth, int width, int height, bool showNumberA = true );

                        /**
                         * @fn	VotingWidgetBase::VotingWidgetBase ( std::string topString, int topAlignment, std::string bottomString, int bottomAlignment,
                         * 			std::string number, int padding, int numberWidth, int width, int height,
                         * 			bool showNumberA = true );
                         * @brief	class constructor.
                         * @author	Gabriel.jaimes
                         * @date	7/01/2022
                         * @param	topString				top string to be displayed.
                         * @param	topAlignment		top label alignment
                         * @param	bottomString		bottom string to be displayed.
                         * @param	bottomAlignment	bottom label alignment.
                         * @param	number					number.
                         * @param	padding					widget padding.
                         * @param	numberWidth 		Number of widths.
                         * @param	width						Widget's width.
                         * @param	height					Widget's height.
                         * @param	showNumberA 		true to show, false to hide the number a.
                         */

                        VotingWidgetBase ( std::string topString, Smartmatic::GUI::Configuration::LabelAlignmentEnum topAlignment,
                                           std::string bottomString, Smartmatic::GUI::Configuration::LabelAlignmentEnum bottomAlignment,
                                           std::string number, int padding, int numberWidth, int width, int height, bool showNumberA );

                        /**
                         * @fn	VotingWidgetBase::~VotingWidgetBase();
                         * @brief	class destructor.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         */

                        virtual ~VotingWidgetBase();

                        /**
                         * @fn	void VotingWidgetBase::Initialize ( int width, int height );
                         * @brief	create child widgets.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	width 	Widget's width.
                         * @param	height	Widget's height.
                         */

                        void Initialize ( int width, int height );

                        /**
                         * @fn	void VotingWidgetBase::Initialize ( int width, int height, int topAlignment, int bottomAlignment);
                         * @brief	create a widget child for the dual text display option.
                         * @author	Gabiel.jaimes
                         * @date	7/01/2022
                         * @param	width 					Widget's width.
                         * @param	height					Widget's height.
                         * @param	topAlignment 		Widget top text alignment.
                         * @param	bottomAlignment	Widget bottom text alignment..
                         */

                        void Initialize ( int width, int height,
                                          Smartmatic::GUI::Configuration::LabelAlignmentEnum topAlignment,
                                          Smartmatic::GUI::Configuration::LabelAlignmentEnum bottomAlignment);

                        /**
                         * @fn	void VotingWidgetBase::setSize ( int width, int height );
                         * @brief	set size elements.
                         * @author	Yadickson Soto
                         * @date	16/03/2012
                         * @param	width 	Widget's width.
                         * @param	height	Widget's height.
                         */
                        void setSize ( int width, int height );

                        /**
                         * @fn	void VotingWidgetBase::refreshLabel ( std::string text );
                         * @brief	Refresh label.
                         * @author	Youssef.tourkmani
                         * @date	01/11/2012
                         * @param	text	The text.
                         */
                        void refreshLabel ( std::string text );

                        /**
                         * @brief  Gets the smallest font size that guarantees
                         * the text fit on screen/widget.
                         * @author manuel.arguelles
                         * @date   oct  2, 2018
                         * @return The font size or -1 if the font size is not
                         * yet available.
                         */
                        int getSmallestAdjustedFontSize() const;

                        /**
                         * @brief  Sets a new font size to use.
                         * The supplied font size will be evaluated and reduced
                         * to allow the text to fit on screen/widget.
                         * @author manuel.arguelles
                         * @date   oct  2, 2018
                         * @param  fontSize The size of the font to use.
                         */
                        void setFontSize(int fontSize);

                    protected:

                        /**
                         * @fn	virtual void VotingWidgetBase::on_size_allocate ( Gtk::Allocation & allocation );
                         * @brief	Handles size allocate signals.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	allocation	The allocation.
                         */

                        virtual void on_size_allocate ( Gtk::Allocation & allocation );

                        /**
                         * @fn	virtual void VotingWidgetBase::forall_vfunc ( gboolean include_internals,
                         * 			GtkCallback callback, gpointer callback_data );
                         * @brief	Forall vfunc.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	include_internals	The include internals.
                         * @param	callback				 	The callback.
                         * @param	callback_data		 	Information describing the callback.
                         */

                        virtual void forall_vfunc ( gboolean include_internals, GtkCallback callback, gpointer callback_data );

                        /**
                         * @fn	virtual void VotingWidgetBase::on_add ( Gtk::Widget * child );
                         * @brief	Handles add signals.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	child	If non-null, the child.
                         */

                        virtual void on_add ( Gtk::Widget * child );

                        /**
                         * @fn	virtual void VotingWidgetBase::on_remove ( Gtk::Widget * child );
                         * @brief	Handles remove signals.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @param	child	If non-null, the child.
                         */

                        virtual void on_remove ( Gtk::Widget * child );

                        /**
                         * @fn	virtual GType VotingWidgetBase::child_type_vfunc() const;
                         * @brief	Gets the child type vfunc.
                         * @author	Cesar.bonilla
                         * @date	4/29/2011
                         * @return	.
                         */

                        virtual GType child_type_vfunc() const;

                    private:

                        /**
                         * @fn	VotingWidgetBase::getDefaultLabel ( std::string content, std::string accessibleName,
                         * 			Smartmatic::GUI::Configuration::LabelConfiguration& labelConfiguration);
                         * @brief	class constructor.
                         * @author	Gabiel.jaimes
                         * @date	7/01/2022
                         * @param	content							The string to be displayed.
                         * @param	accessibleName			The accessible name for component.
                         * @param	labelConfiguration	The label configuration.
                         * @return A basic label with the default parameters in the creation of the widget.
                         */

                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * getDefaultLabel( std::string content, std::string accessibleName,
                                                                                          Smartmatic::GUI::Configuration::LabelConfiguration& labelConfiguration);

                        /**
                         * @fn	void VotingWidgetBase::showNumberLabel ();
                         * @brief	shows the id number of the widget if it is instantiated.
                         * @author	Gabiel.jaimes
                         * @date	7/01/2022
                         */

                        void showNumberLabel();

                        /**
                         * @brief  Sets the smallest font size that guarantees
                         * the text displays completely on screen.
                         * @author manuel.arguelles
                         * @date   oct  2, 2018
                         * @param  newFontSize The adjusted font size.
                         */
                        void setSmallestAdjustedFontSize(int newFontSize);

                        /**
                         * @fn	void VotingWidgetBase::initializeChilds ();
                         * @brief	Initializes the child widgets of the class to null..
                         * @author	Gabiel.jaimes
                         * @date	7/01/2022
                         */
                        void initializeChilds();

                    private:
                        /**
                         * Child Widgets
                         */
                        Smartmatic::GUI::Widgets::SmartmaticBasicImage * image_child;	///< The image child
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * label_child;	///< The label child
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * top_child; ///< The top child
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * bottom_child;  ///< The bottom child
                        Smartmatic::GUI::Widgets::SmartmaticBasicLabel * number_child;  ///< Number of childs

                        /**
                         * Variables
                         */
                        bool showNumber;	///< true to show, false to hide the number
                        bool isReferendum;	///< true to show, false to hide the number
                        int numberWidth;	///< Number of widths
                        int padding;	///< The padding
                        bool sizeAllocateCallback;  ///< true to size allocate callback
                        Smartmatic::SAES::Configuration::WidgetDisplayType display;   ///< The display
                        std::string number; ///< Number
                        std::string displayString;  ///< The display string
                        std::string topString;  ///< The top string
                        Smartmatic::GUI::Configuration::LabelAlignmentEnum top_alignment; ///< The top alignment
                        std::string bottomString;   ///< The bottom string
                        Smartmatic::GUI::Configuration::LabelAlignmentEnum botton_alignment;///< The bottom alignment
                        int smallestAdjustedFontSize; ///< The smallest font that guarantees the text fit.

                };
            }
        }
    }
}

#endif // _VOTING_WIDGET_BASE_H_
