/**
 * @file DeviceMonitorWindow.cxx
 * @brief Body class device monitor window
 * @date 13/12/2012
 * @author Yadickson Soto
 */

#include "DeviceMonitorWindow.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Configuration/DeviceTypeMonitorWindowConfigurationManager.hxx>
#include <Operation/Monitor/DeviceTypeMonitorPool.hxx>
#include <Gui/Widgets/DeviceMonitorWidget.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Windows;
using namespace Smartmatic::SAES::GUI::Widgets;
using namespace Smartmatic::GUI::Windows;
using namespace Smartmatic::SAES::Configuration;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::Log;
using namespace Smartmatic::SAES::Common::Operation::Monitor;
using namespace Smartmatic::SAES::Common::Configuration;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::SAES::Operation::Monitor;

DeviceMonitorWindow * DeviceMonitorWindow::instance = NULL;
ISMTTLog * DeviceMonitorWindow::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Windows.DeviceMonitorWindow", GETTEXT_PACKAGE );

DeviceMonitorWindow::DeviceMonitorWindow()
    : PopUpMessageWindow()
{
    visible = DeviceTypeMonitorWindowConfigurationManager::getInstance()->isVisible();
    border = DeviceTypeMonitorWindowConfigurationManager::getInstance()->getBorder();

    iconWidth = DeviceTypeMonitorWindowConfigurationManager::getInstance()->getIconWidth();
    iconHeight = DeviceTypeMonitorWindowConfigurationManager::getInstance()->getIconHeight();
    timeOut = DeviceTypeMonitorWindowConfigurationManager::getInstance()->getTimeOut();

    int opacity = DeviceTypeMonitorWindowConfigurationManager::getInstance()->getOpacity();

    widget = Gtk::manage(new Gtk::VBox ( false, 0 ));
    widget->set_border_width ( border );

    if ( visible )
    {
        std::list < DeviceTypeMonitor * > & devices ( DeviceTypeMonitorPool::getInstance()->getDeviceTypeMonitors() );
        std::list < DeviceTypeMonitor * >::iterator it;

        for ( it = devices.begin();
                it != devices.end();
                ++it )
        {
            DeviceMonitorWidget * device = Gtk::manage ( new DeviceMonitorWidget ( *it, iconWidth, iconHeight ) );
            device->set_size_request ( iconWidth, iconHeight );

            this->devices.push_back ( device );
            widget->pack_start ( *device, false, false, 0 );
        }
    }

    setOpacity ( opacity );
    setTimerToClose ( timeOut );

    remove ();
    add ( *widget );
    show_all_children();
}

DeviceMonitorWindow::~DeviceMonitorWindow()
{
    stop();
}

void DeviceMonitorWindow::start()
{
    if ( visible && !signalChange.connected() )
    {
        deviceChange ( NULL );

        signalChange.disconnect();
        signalChange = DeviceTypeMonitorPool::getInstance()->getDeviceChangedSignal().connect ( sigc::mem_fun ( *this, &DeviceMonitorWindow::deviceChange ) );
    }
}

void DeviceMonitorWindow::stop()
{
    signalChange.disconnect();
}

void DeviceMonitorWindow::deviceChange ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * deviceTypeMonitor )
{
    int count = 0;

    std::list < DeviceMonitorWidget * >::iterator it;

    for ( it = devices.begin();
            it != devices.end();
            ++it )
    {
        bool view = ( *it )->isShowWidget() || ( deviceTypeMonitor != NULL && ( *it )->getDeviceTypeMonitor()->getType() == deviceTypeMonitor->getType() && DeviceTypeMonitorWindowConfigurationManager::getInstance()->isDeviceWidgetShowing ( deviceTypeMonitor->getType() ) );

        ( *it )->update();
        ( *it )->showWidget ( view );

        if ( view )
        {
            count++;
        }
    }

    if ( count > 0 )
    {
        int width = ( border * 2 ) + iconWidth;
        int height = ( border * 2 ) + ( iconHeight * count );

        set_default_size ( width, height );
        set_size_request ( width, height );

        Smartmatic::GUI::Configuration::PositionConfiguration & position ( DeviceTypeMonitorWindowConfigurationManager::getInstance()->getPosition() );
        setPosition ( position );

        Glib::signal_timeout().connect_once ( sigc::mem_fun ( *this, &DeviceMonitorWindow::ShowDialog ), 0 );
    }
}

void DeviceMonitorWindow::QuitDialog()
{
    std::list < DeviceMonitorWidget * >::iterator it;

    for ( it = devices.begin();
            it != devices.end();
            ++it )
    {
        ( *it )->showWidget ( false );
    }

    PopUpMessageWindow::QuitDialog();
}

DeviceMonitorWindow * DeviceMonitorWindow::getInstance()
{
    if ( !instance )
    {
        instance = new DeviceMonitorWindow();
    }

    return instance;
}
