/**
 * @file USBMonitorWindow.hxx
 * @brief Header class usb monitor window
 * @date 13/12/2012
 * @author Yadickson Soto
 */

#ifndef USB_MONITOR_WINDOW_HXX_
#define USB_MONITOR_WINDOW_HXX_

#include <Windows/pop-up-message-window.h>
#include <Operation/Monitor/DeviceTypeMonitor.hxx>
#include <Gui/Widgets/ProgressWidget.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace SAES
    {
        namespace GUI
        {
            namespace Windows
            {
                /**
                 * @class	USBMonitorWindow
                 * @brief	class usb monitor window.
                 * @author	Yadickson Soto
                 * @date	13/12/2012
                 */
                class USBMonitorWindow : public Smartmatic::GUI::Windows::PopUpMessageWindow
                {
                    public:
                        /**
                         * @fn	virtual USBMonitorWindow::~USBMonitorWindow();
                         * @brief	class destructor.
                         * @author	Yadickson Soto
                         * @date	13/12/2012
                         */
                        virtual ~USBMonitorWindow();
                        /**
                         * @fn	static USBMonitorWindow * USBMonitorWindow::getInstance();
                         * @brief	method getter instance class.
                         * @author	Yadickson Soto
                         * @date	13/12/2012
                         * @return	instance class.
                         */
                        static USBMonitorWindow * getInstance();
                        /**
                         * @fn	void USBMonitorWindow::start();
                         * @brief	method start.
                         * @author	Yadickson Soto
                         * @date	13/12/2012
                         */
                        void start();
                        /**
                         * @fn	void USBMonitorWindow::stop();
                         * @brief	method stop.
                         * @author	Yadickson Soto
                         * @date	13/12/2012
                         */
                        void stop();

                    protected:
                        /**
                         * @fn	USBMonitorWindow::USBMonitorWindow();
                         * @brief	class constructor.
                         * @author	Yadickson Soto
                         * @date	13/12/2012
                         */
                        USBMonitorWindow();
                        /**
                         * @fn	void deviceChange( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * deviceTypeMonitor );
                         * @brief	getter device monitor change
                         * @author	Yadickson Soto
                         * @date	27/06/2013
                         * @param 	deviceTypeMonitor device change
                         */
                        void deviceChange ( Smartmatic::SAES::Common::Operation::Monitor::DeviceTypeMonitor * deviceTypeMonitor );

                    private:

                        static USBMonitorWindow * instance; ///< instance class
                        sigc::connection signalChange; ///< The signal change usb
                        Smartmatic::SAES::GUI::Widgets::ProgressWidget * widget; ///< list widget
                        static Smartmatic::Log::ISMTTLog * logger; ///< The logger
                };
            }
        }
    }
}

#endif /* USB_MONITOR_WINDOW_HXX_ */
