/**
 * @file FunctionalityWindowManager.cxx
 * @brief Body functionality window signal manager
 * @date 03/10/2012
 * @author Yadickson Soto
 */

#include "FunctionalityWindowManager.hxx"
#include <Operation/WindowsManager.hxx>
#include <Gui/Windows/empty-window.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Operation;
using namespace Smartmatic::SAES::GUI::Windows;
using namespace Smartmatic::GUI::Windows;
using namespace Smartmatic::GUI::Operation;
using namespace Smartmatic::Log;

FunctionalityWindowManager * FunctionalityWindowManager::instance = NULL;

ISMTTLog * FunctionalityWindowManager::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Operation.FunctionalityWindowManager", GETTEXT_PACKAGE );

FunctionalityWindowManager::FunctionalityWindowManager()
{
    connected();
}

FunctionalityWindowManager::~FunctionalityWindowManager()
{
    std::list <Smartmatic::GUI::Windows::ExitWindowListener * >::iterator it;

    disconnected();

    for (it = functionalityList.begin(); it != functionalityList.end(); ++it)
    {
        delete *it;
    }

    functionalityList.clear();
}

void FunctionalityWindowManager::push ( ExitWindowListener * functionality )
{
    functionalityList.push_back ( functionality );
    std::stringstream ss;
    ss << "Push functionality : " << functionalityList.size();
    logger->Debug ( ss.str() );
}

void FunctionalityWindowManager::pop()
{
    functionalityList.pop_back();
    std::stringstream ss;
    ss << "Pop functionality : " << functionalityList.size();
    logger->Debug ( ss.str() );
}

void FunctionalityWindowManager::onExit()
{
    if ( !functionalityList.empty() )
    {
        ExitWindowListener * functionality = functionalityList.back();
        functionality->onExit();
        pop();
    }
}

void FunctionalityWindowManager::onBeforeExit()
{
    if ( !functionalityList.empty() )
    {
        ExitWindowListener * functionality = functionalityList.back();
        functionality->onBeforeExit();
    }
}

void FunctionalityWindowManager::disconnected()
{
    connBeforeExitWindow.disconnect();
    connExitWindow.disconnect();
}

void FunctionalityWindowManager::connected()
{
    EmptyWindow * window = ( EmptyWindow * ) WindowsManager::getInstance()->current();

    if ( window )
    {
        connBeforeExitWindow.disconnect();
        connExitWindow.disconnect();
        connBeforeExitWindow = window->getSignalShowExitMessage().connect ( sigc::mem_fun ( this, &FunctionalityWindowManager::onBeforeExit ) );
        connExitWindow = window->getSignalExitButton().connect ( sigc::mem_fun ( this, &FunctionalityWindowManager::onExit ) );
    }
}

unsigned int FunctionalityWindowManager::getCount()
{
    return functionalityList.size();
}

FunctionalityWindowManager * FunctionalityWindowManager::getInstance()
{
    if ( !instance )
    {
        instance = new FunctionalityWindowManager();
    }

    return instance;
}
