/**
 * @file ImageResourcePath.cxx
 * @brief Body class image resource path
 * @date 14/12/2012
 * @author Yadickson Soto
 */

#include "ImageResourcePath.hxx"
#include <Environment/Configurations/resource-path-provider.h>
#include <Configuration/s-a-e-s-g-u-i-conf-manager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::GUI::Operation;
using namespace Smartmatic::Environment;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Configuration;

ImageResourcePath::ImageResourcePath()
{

}

ImageResourcePath::~ImageResourcePath()
{

}

std::string ImageResourcePath::getPath ( ImageResourcePath::Resource image )
{
    std::string path;

    switch ( SAESGUIConfigurationManager::getInstance()->getStartConfiguration().getInfoMachine() )
    {
        case InfoMachineConfiguration::CONFIGURATION_PM:
            getPMPath ( image, path );
            break;

        default:
        case InfoMachineConfiguration::CONFIGURATION_VM:
            getVMPath ( image, path );
            break;
    }

    return path;
}

std::string ImageResourcePath::getPath ( std::string image )
{
    return ResourcePathProvider::getInstance()->GetResourcePath ( PACKAGE_NAME, image );
}

void ImageResourcePath::getPMPath ( ImageResourcePath::Resource image, std::string & path )
{
    switch ( image )
    {
        case NOT_FOUND:
            path = getPath ( "ui/image-not-found.gif" );
            break;

        case PROGRESS:
            path = getPath ( "ui/loading.gif" );
            break;

        case PREPARE_PRINT:
            path = getPath ( "ui/RPW_inactive.img" );
            break;

        case PRINTING:
            path = getPath ( "ui/printer-mp.gif" );
            break;

        case PRINTING_OK:
            path = getPath ( "ui/printer-ok-mp.img" );
            break;

        case PRINTING_ERROR:
            path = getPath ( "ui/printer-error-mp.img" );
            break;

        case PRINTING_TEST:
            path = getPath ( "ui/printer-test-logo-mp.bmp" );
            break;

        case SMARTCARD:
            path = getPath ( "ui/smartcard-mp.gif" );
            break;

        case SMARTCARD_DETECT:
            path = getPath ( "ui/smartcard-detect.gif" );
            break;

        case SMARTCARD_DISABLED:
            path = getPath ( "ui/smartcard-diagnostic-failed-pm.gif" );
            break;

        case SMARTCARD_INSERT:
            path = getPath ( "ui/smartcard_activation.gif" );
            break;

        case SMARTCARD_REMOVE:
            path = getPath ( "ui/smartcard-remove.gif" );
            break;

        case SMARTCARD_AUTO_DIAGNOSIS:
            path = getPath ( "ui/smartcard-auto-diagnosis-mp.gif" );
            break;

        case AUTO_DIAGNOSIS_DEVICES:
            path = getPath ( "ui/auto-diagnosis-devices-mp.gif" );
            break;

        case RECONFIGURE_BARCODE:
            path = getPath ( "ui/barcode_recoveryConnected.gif" );
            break;

        case RECONFIGURE_BARCODE_SUCCESS:
            path = getPath ( "ui/barcode_connected.gif" );
            break;

        case RECONFIGURE_BARCODE_FAIL:
            path = getPath ( "ui/barcode_noConnected.gif" );
            break;

        case PRINTER_CONNECTED:
            path = getPath ( "ui/printer-connected-mp.img" );
            break;

        case PRINTER_DISCONNECTED:
            path = getPath ( "ui/printer-disconnected-mp.img" );
            break;

        case BARCODE_CONNECTED:
            path = getPath ( "ui/barcode-connected-mp.img" );
            break;

        case BARCODE_DISCONNECTED:
            path = getPath ( "ui/barcode-disconnected-mp.img" );
            break;

        case SMARTCARD_CONNECTED:
            path = getPath ( "ui/scr-connected-mp.img" );
            break;

        case SMARTCARD_DISCONNECTED:
            path = getPath ( "ui/scr-disconnected-mp.img" );
            break;

        case FLASH_CONNECTED:
            path = getPath ( "ui/flash-connected-mp.img" );
            break;

        case FLASH_DISCONNECTED:
            path = getPath ( "ui/flash-disconnected-mp.img" );
            break;

        case MOUSE_CONNECTED:
            path = getPath ( "ui/mouse-connected-mp.img" );
            break;

        case MOUSE_DISCONNECTED:
            path = getPath ( "ui/mouse-disconnected-mp.img" );
            break;

        case ONE_USB_CONNECTED:
            path = getPath ( "ui/one-usb-connected.png" );
            break;

        case TWO_USB_CONNECTED:
            path = getPath ( "ui/two-usb-connected.png" );
            break;

        case TWO_USB_DISCONNECTED:
            path = getPath ( "ui/two-usb-disconnected.png" );
            break;

        case ETHERNET_CONNECTED:
            path = getPath ( "ui/network-cable-connected.png" );
            break;

        case ETHERNET_DISCONNECTED:
            path = getPath ( "ui/network-cable-disconnected.png" );
            break;

        case SCREEN_CALIBRATION_INSTRUCTION:
        case NONE:
        default:
            break;
    }
}

void ImageResourcePath::getVMPath ( ImageResourcePath::Resource image, std::string & path )
{
    switch ( image )
    {
        case NOT_FOUND:
            path = getPath ( "ui/image-not-found.gif" );
            break;

        case PROGRESS:
            path = getPath ( "ui/loading.gif" );
            break;

        case PREPARE_PRINT:
        case PRINTING:
            path = getPath ( "ui/printer.img" );
            break;

        case PRINTING_OK:
            path = getPath ( "ui/printer-ok.img" );
            break;

        case PRINTING_ERROR:
            path = getPath ( "ui/printer-error.img" );
            break;

        case PRINTING_TEST:
            path = getPath ( "ui/printer-test-logo-mv.bmp" );
            break;

        case SMARTCARD:
            path = getPath ( "ui/smartcard.gif" );
            break;

        case SMARTCARD_DETECT:
            path = getPath ( "ui/smartcard-detect-mv.gif" );
            break;

        case SMARTCARD_DISABLED:
            path = getPath ( "ui/smartcard-disabled-mv.gif" );
            break;

        case SMARTCARD_INSERT:
            path = getPath ( "ui/smartcard-insert-mv.gif" );
            break;

        case SMARTCARD_REMOVE:
            path = getPath ( "ui/smartcard-remove-mv.gif" );
            break;

        case SMARTCARD_AUTO_DIAGNOSIS:
            path = getPath ( "ui/smartcard-auto-diagnosis-mv.gif" );
            break;

        case AUTO_DIAGNOSIS_DEVICES:
            path = getPath ( "ui/auto-diagnosis-devices-mv.gif" );
            break;

        case RECONFIGURE_BARCODE:
            path = getPath ( "ui/waitingForVoterReconfigureBarcode.gif" );
            break;

        case RECONFIGURE_BARCODE_SUCCESS:
            path = getPath ( "ui/barcode-connected-mv.img" );
            break;

        case RECONFIGURE_BARCODE_FAIL:
            path = getPath ( "ui/barcode-disconnected-mv.img" );
            break;

        case PRINTER_CONNECTED:
            path = getPath ( "ui/printer-connected-mv.img" );
            break;

        case PRINTER_DISCONNECTED:
            path = getPath ( "ui/printer-disconnected-mv.img" );
            break;

        case BARCODE_CONNECTED:
            path = getPath ( "ui/barcode-connected-mv.img" );
            break;

        case BARCODE_DISCONNECTED:
            path = getPath ( "ui/barcode-disconnected-mv.img" );
            break;

        case SMARTCARD_CONNECTED:
            path = getPath ( "ui/scr-connected-mv.img" );
            break;

        case SMARTCARD_DISCONNECTED:
            path = getPath ( "ui/scr-disconnected-mv.img" );
            break;

        case FLASH_CONNECTED:
            path = getPath ( "ui/flash-connected-mv.img" );
            break;

        case FLASH_DISCONNECTED:
            path = getPath ( "ui/flash-disconnected-mv.img" );
            break;

        case MOUSE_CONNECTED:
            path = getPath ( "ui/mouse-connected-mv.img" );
            break;

        case MOUSE_DISCONNECTED:
            path = getPath ( "ui/mouse-disconnected-mv.img" );
            break;

        case SCREEN_CALIBRATION_INSTRUCTION:
            path = getPath ( "ui/screen-calibration.gif" );
            break;

        case ETHERNET_CONNECTED:
        case ETHERNET_DISCONNECTED:
        case ONE_USB_CONNECTED:
        case TWO_USB_CONNECTED:
        case TWO_USB_DISCONNECTED:
        case NONE:
        default:
            break;
    }
}
