/**
 * @file VotingOperation.cxx
 * @brief Body class operation voting mode
 * @date 23/04/2012
 * @author Yadickson Soto
 */

#include "VotingOperation.hxx"
#include <Operation/MachineOperationManager.hxx>
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"

using namespace Smartmatic::SAES::GUI::Operation::Voting;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Voting::Vote;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::GUI::Widgets;

VotingOperation::VotingOperation()
{
}

VotingOperation::~VotingOperation()
{
}

void VotingOperation::refresh()
{
    getVoteMode();
}

std::string VotingOperation::getWindowName()
{
    std::string name;

    switch ( getVoteMode() )
    {
        case VoteMode::VOTE_S:
        case VoteMode::VOTE_O:
            name = SAESGUIConfigurationManager::getInstance()->GetVotingExperienceWindowName();
            break;

        default:
        case VoteMode::VOTE_D:
            name = SAESGUIConfigurationManager::getInstance()->GetVotingExperienceWindowDemoName();
            break;
    }

    return name;
}

std::string VotingOperation::getButtonName()
{
    std::string name;

    switch ( getVoteMode() )
    {
        case VoteMode::VOTE_S:
        case VoteMode::VOTE_O:
            name = SAESGUIConfigurationManager::getInstance()->GetVotingWindowButtonName();
            break;

        default:
        case VoteMode::VOTE_D:
            name = SAESGUIConfigurationManager::getInstance()->GetVotingWindowButtonDemoName();
            break;
    }

    return name;
}

VoteMode VotingOperation::getVoteMode()
{
    VoteMode mode = VoteMode::VOTE_O;

    if ( MachineOperationManager::getInstance()->getVotingExperienceController() )
    {
        mode = MachineOperationManager::getInstance()->getVotingExperienceController()->getVotingMode();
    }

    return mode;
}
