/**
 * @file	VotingWidgetManager.cxx
 * @brief	voting widget manager class.
 * @author	Youssef.tourkmani
 * @date	01/11/2012
 */


#include "VotingWidgetManager.hxx"
#include <Windows/basic-window.h>
#include "Configuration/s-a-e-s-g-u-i-conf-manager.h"
#include "Configuration/s-m-t-t-g-u-i-conf-manager.h"
#include <list>
#include "Operation/Voting/VotingExperienceController.hxx"
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::GUI::Operation::Voting;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::SAES::GUI::Configuration;
using namespace Smartmatic::SAES::Operation::Voting;
using namespace Smartmatic::SAES::Operation;
using namespace Smartmatic::GUI::Configuration;
using namespace Smartmatic::Log;

ISMTTLog * VotingWidgetManager::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.GUI.Operation.VotingWidgetManager", GETTEXT_PACKAGE );


VotingWidgetManager * VotingWidgetManager::instance = NULL;

VotingWidgetManager::VotingWidgetManager()
    : ICheckCondition ( _ ( "Smartmatic.SAES.GUI.Operation.VotingWidgetManager.CreatingVotingMaps" ) )
{
    electoralConfiguration = NULL;
    saesDir = NULL;
}

VotingWidgetManager::~VotingWidgetManager()
{
    dispose();
}

Smartmatic::SAES::Operation::Initiator::TestStatus::Tests VotingWidgetManager::check ()
{
    Smartmatic::SAES::Operation::Initiator::TestStatus::Tests result;

    try
    {
        init();
        result = Smartmatic::SAES::Operation::Initiator::TestStatus::Passed;
    }
    catch ( ... )
    {
        result = Smartmatic::SAES::Operation::Initiator::TestStatus::Failed;
    }

    return result;
}

void VotingWidgetManager::SetElectoralConfiguration ( Smartmatic::SAES::Voting::ElectoralConfiguration * electoralConfiguration )
{
    this->electoralConfiguration = electoralConfiguration;
}

void VotingWidgetManager::SetSaesDirectories ( Smartmatic::SAES::Runtime::Environment::SaesDirectories * saesDir )
{
    this->saesDir = saesDir;
}

void VotingWidgetManager::init ()
throw ( ElectionException, VotingDeviceException, HashException )
{
    dispose();
    electoralConfiguration->loadAllData();
    std::list < Smartmatic::SAES::Voting::Election::Contest * > allContest = electoralConfiguration->getContestList();
    std::list < Smartmatic::SAES::Voting::Election::Contest * >::iterator itc;

    Smartmatic::SAES::GUI::Widgets::BallotOptionSelectionWidget * ballotOptionSelectionWidget = NULL;

    int widthPanel, heightPanel;

    SMTTGUIConfigurationManager::getInstance()->getCenterSize ( widthPanel, heightPanel );

    for ( itc = allContest.begin();
            itc != allContest.end();
            ++itc )
    {
        std::list < Smartmatic::SAES::Voting::Election::Ballot_option * > & partyListByContest ( electoralConfiguration->getBallotOptionPartyByContest ( ( *itc )->getCode() ) );
        std::list < Smartmatic::SAES::Voting::Election::Ballot_option * >::iterator itp;

        if (mapPartySelectionWidget.find(( *itc )->getCode()) != mapPartySelectionWidget.end())
        {
            throw std::runtime_error("The party selection already exist.");
        }

        Smartmatic::SAES::GUI::Widgets::PartySelectionWidget * partySelectionWidget = new Smartmatic::SAES::GUI::Widgets::PartySelectionWidget ( *itc, false );
        partySelectionWidget->set_size_request ( widthPanel, heightPanel );
        partySelectionWidget->Initialize ( partyListByContest, *saesDir );
        partySelectionWidget->show_all_children();
        partySelectionWidget->show();

        mapPartySelectionWidget.insert(std::pair<std::string, Smartmatic::SAES::GUI::Widgets::PartySelectionWidget*>( ( *itc )->getCode(), partySelectionWidget));

        if (mapBallotOptionSelectionWidget.find(( *itc )->getCode()) == mapBallotOptionSelectionWidget.end())
        {
            BallotOptionWidgetMap empty;
            mapBallotOptionSelectionWidget.insert(std::pair< std::string , BallotOptionWidgetMap >(( *itc )->getCode() , empty));
        }

        BallotOptionWidgetMap& current = mapBallotOptionSelectionWidget.find(( *itc )->getCode())->second;

        for ( itp = partyListByContest.begin(); itp != partyListByContest.end(); ++itp )
        {
            Smartmatic::SAES::Voting::Election::Party & party ( ( *itp )->getParty() );

            if (current.find(party.getCode()) != current.end())
            {
                throw std::runtime_error("The ballot option selection already exists.");
            }

            std::list < Smartmatic::SAES::Voting::Election::Eligible_option * > & ballotList ( electoralConfiguration->getEligibleOptionsListByContestParty ( ( *itc )->getCode() , party.getCode() ) );
            std::list < Smartmatic::SAES::Voting::Election::Eligible_option * > & principalBallotList ( electoralConfiguration->getEligibleOptionsPrincipalByContestParty ( ( *itc )->getCode() , party.getCode() ) );
            std::list < Smartmatic::SAES::Voting::Election::Eligible_option * > & standInBallotList ( electoralConfiguration->getEligibleOptionsStandInByContestParty ( ( *itc )->getCode() , party.getCode() ) );
            ballotOptionSelectionWidget = new Smartmatic::SAES::GUI::Widgets::BallotOptionSelectionWidget ( *itc );
            ballotOptionSelectionWidget->set_size_request ( widthPanel, heightPanel );
            ballotOptionSelectionWidget->Initialize ( ballotList, principalBallotList, standInBallotList, *saesDir );
            ballotOptionSelectionWidget->show_all_children();
            ballotOptionSelectionWidget->show();
            ballotOptionSelectionWidget->hide();
            current [ party.getCode() ] = ballotOptionSelectionWidget;
        }
    }
}

void VotingWidgetManager::dispose ()
{
    PartyWidgetMap::iterator itp;

    for ( itp = mapPartySelectionWidget.begin();
            itp != mapPartySelectionWidget.end();
            ++itp )
    {
        Smartmatic::SAES::GUI::Widgets::PartySelectionWidget *party = ( *itp ).second;

        if ( party )
        {
            delete party;
        }
    }

    mapPartySelectionWidget.clear();
    std::map < std::string , BallotOptionWidgetMap >::iterator itb;
    BallotOptionWidgetMap::iterator itbo;
    Smartmatic::SAES::GUI::Widgets::BallotOptionSelectionWidget * ballotOption;

    for ( itb = mapBallotOptionSelectionWidget.begin(); itb != mapBallotOptionSelectionWidget.end(); ++itb )
    {
        BallotOptionWidgetMap & itmap = ( *itb ).second;

        for ( itbo = itmap.begin();
                itbo != itmap.end();
                ++itbo )
        {
            ballotOption = ( *itbo ).second;

            if ( ballotOption )
            {
                delete ballotOption;
            }
        }
    }

    mapBallotOptionSelectionWidget.clear();
}

Smartmatic::SAES::GUI::Widgets::PartySelectionWidget * VotingWidgetManager::getPartySelectionWidgetByContest ( std::string contestCode )
{
    return mapPartySelectionWidget[ contestCode ];
}

Smartmatic::SAES::GUI::Widgets::BallotOptionSelectionWidget * VotingWidgetManager::getBallotOptionSelectionWidgetByContestParty ( std::string contestCode, std::string partyCode )
{
    return ( mapBallotOptionSelectionWidget [ contestCode ] ) [ partyCode ];
}

unsigned int VotingWidgetManager::getBallotOptionSelectionTotalBallotsWidgetByContestParty ( std::string contestCode, std::string partyCode )
{
    unsigned int response = 0;
    std::map< std::string , BallotOptionWidgetMap >::iterator ballotOptionsIterator = mapBallotOptionSelectionWidget.find(contestCode);

    if (ballotOptionsIterator != mapBallotOptionSelectionWidget.end())
    {
        BallotOptionWidgetMap::iterator ballotOptionIterator = ballotOptionsIterator->second.find(partyCode);

        if (ballotOptionIterator != ballotOptionsIterator->second.end())
        {
            response = ballotOptionIterator->second->GetTotalBallotsDisplayed();
        }
    }

    return response;
}

void VotingWidgetManager::clearBallotOptionSelectionWidget()
{
    std::map < std::string , BallotOptionWidgetMap >::iterator itb;
    BallotOptionWidgetMap::iterator itbo;
    Smartmatic::SAES::GUI::Widgets::BallotOptionSelectionWidget * ballotOption = NULL;

    for ( itb = mapBallotOptionSelectionWidget.begin();
          itb != mapBallotOptionSelectionWidget.end();
          ++itb )
    {
        BallotOptionWidgetMap & itmap = ( *itb ).second;

        for ( itbo = itmap.begin();
                itbo != itmap.end();
                ++itbo )
        {
            ballotOption = ( *itbo ).second;
            ballotOption->ClearVisualSelection();
        }
    }
}

VotingWidgetManager * VotingWidgetManager::getInstance()
{
    if ( instance == NULL )
    {
        instance = new VotingWidgetManager();
    }

    return instance;
}

VotingWidgetManager::PartyWidgetMap & VotingWidgetManager::getMapPartySelectionWidget()
{
    return mapPartySelectionWidget;
}

std::map < std::string , VotingWidgetManager::BallotOptionWidgetMap > & VotingWidgetManager::getMapBallotOptionSelectionWidget()
{
    return mapBallotOptionSelectionWidget;
}

void VotingWidgetManager::update()
{
    std::map < std::string , BallotOptionWidgetMap >::iterator itb;
    BallotOptionWidgetMap::iterator itbo;
    Smartmatic::SAES::GUI::Widgets::BallotOptionSelectionWidget * ballotOption;

    for ( itb = mapBallotOptionSelectionWidget.begin();
            itb != mapBallotOptionSelectionWidget.end();
            ++itb )
    {
        BallotOptionWidgetMap & itmap = ( *itb ).second;

        for ( itbo = itmap.begin();
                itbo != itmap.end();
                ++itbo )
        {
            ballotOption = ( *itbo ).second;
            ballotOption->refresh();
        }
    }

    PartyWidgetMap::iterator itp;

    for ( itp = mapPartySelectionWidget.begin();
            itp != mapPartySelectionWidget.end();
            ++itp )
    {
        Smartmatic::SAES::GUI::Widgets::PartySelectionWidget * party;
        party = ( *itp ).second;
        party->refresh();
    }
}
