#ifndef TEST_DEVICE_TYPE_MONITOR_WINDOW_CONF_MANAGER_TEST
#define TEST_DEVICE_TYPE_MONITOR_WINDOW_CONF_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <tests/MockSaesGuiConfigurationManager.hxx>
#include <tests/MockConfigurationPersistenceManager.hxx>
#include <Configuration/DeviceTypeMonitorWindowConfigurationManager.hxx>

class DeviceTypeMonitorWindowConfigurationManagerTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::Configuration::ConfigurationPersistenceManager ConfigurationPersistenceManager;
        typedef Smartmatic::SAES::GUI::Configuration::SAESGUIConfigurationManager SAESGUIConfigurationManager;
        typedef Smartmatic::SAES::GUI::Configuration::DeviceTypeMonitorWindowConfigurationManager DeviceTypeMonitorWindowConfigurationManager;
        typedef Smartmatic::GUI::Configuration::PositionConfiguration PositionConfiguration;
        typedef Smartmatic::SAES::Configuration::DeviceTypeMonitorWindowConfiguration DeviceTypeMonitorWindowConfiguration;
        typedef Smartmatic::SAES::Configuration::DevicesToShowConfiguration DevicesToShowConfiguration;
        typedef Smartmatic::SAES::Configuration::DeviceConfiguration DeviceConfiguration;

        DeviceTypeMonitorWindowConfigurationManagerTest()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testGetDeviceMonitorWindowConfigurationPresent()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesGuiConfigurationManager configurationManager;
            SAESGUIConfigurationManager::getInstance ( &configurationManager );

            CPPUNIT_ASSERT ( true == SAESGUIConfigurationManager::getInstance()->getConfiguration()->getDeviceTypeMonitorWindowConfiguration().present() );

            persistenceManager.verify();
        }

        void testGetDeviceMonitorWindowConfigurationDefaultValues()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesGuiConfigurationManager configurationManager;
            SAESGUIConfigurationManager::getInstance ( &configurationManager );

            SAESGUIConfigurationManager::getInstance()->getConfiguration()->getDeviceTypeMonitorWindowConfiguration().reset();

            DeviceTypeMonitorWindowConfigurationManager * deviceMonitorManager = DeviceTypeMonitorWindowConfigurationManager::getInstance();

            CPPUNIT_ASSERT ( false == deviceMonitorManager->isVisible() );
            CPPUNIT_ASSERT ( 0 == deviceMonitorManager->getTimeOut() );
            CPPUNIT_ASSERT ( 0 == deviceMonitorManager->getOpacity() );
            CPPUNIT_ASSERT ( 100 == deviceMonitorManager->getIconWidth() );
            CPPUNIT_ASSERT ( 100 == deviceMonitorManager->getIconHeight() );
            CPPUNIT_ASSERT ( PositionConfiguration::CONFIGURATION_BOTTOM_RIGHT == deviceMonitorManager->getPosition() );
            CPPUNIT_ASSERT ( 0 == deviceMonitorManager->getBorder() );

            delete deviceMonitorManager;

            persistenceManager.verify();
        }

        void testGetDeviceMonitorWindowConfigurationWithoutDevices()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesGuiConfigurationManager configurationManager;
            SAESGUIConfigurationManager::getInstance ( &configurationManager );

            SAESGUIConfigurationManager::getInstance()->getConfiguration()->getDeviceTypeMonitorWindowConfiguration().present();

            DevicesToShowConfiguration devicesToShow;

            DeviceTypeMonitorWindowConfiguration deviceMonitorConfig (
                true,
                1,
                2,
                100,
                200,
                PositionConfiguration ( PositionConfiguration::CONFIGURATION_CENTER_CENTER ),
                3,
                devicesToShow );

            SAESGUIConfigurationManager::getInstance()->getConfiguration()->setDeviceTypeMonitorWindowConfiguration ( deviceMonitorConfig );

            DeviceTypeMonitorWindowConfigurationManager * deviceMonitorManager = DeviceTypeMonitorWindowConfigurationManager::getInstance();

            CPPUNIT_ASSERT ( true == deviceMonitorManager->isVisible() );
            CPPUNIT_ASSERT ( 1 == deviceMonitorManager->getTimeOut() );
            CPPUNIT_ASSERT ( 2 == deviceMonitorManager->getOpacity() );
            CPPUNIT_ASSERT ( 100 == deviceMonitorManager->getIconWidth() );
            CPPUNIT_ASSERT ( 200 == deviceMonitorManager->getIconHeight() );
            CPPUNIT_ASSERT ( PositionConfiguration::CONFIGURATION_CENTER_CENTER == deviceMonitorManager->getPosition() );
            CPPUNIT_ASSERT ( 3 == deviceMonitorManager->getBorder() );

            delete deviceMonitorManager;

            persistenceManager.verify();
        }

        void testGetDeviceMonitorWindowConfigurationWithDevices()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSaesGuiConfigurationManager configurationManager;
            SAESGUIConfigurationManager::getInstance ( &configurationManager );

            SAESGUIConfigurationManager::getInstance()->getConfiguration()->getDeviceTypeMonitorWindowConfiguration().present();

            DevicesToShowConfiguration devicesToShow;
            DevicesToShowConfiguration::DeviceTypeMonitorSequence deviceSeq;

            deviceSeq.push_back ( DeviceConfiguration ( DeviceConfiguration::CONFIGURATION_BARCODE ) );
            deviceSeq.push_back ( DeviceConfiguration ( DeviceConfiguration::CONFIGURATION_FLASH ) );

            devicesToShow.setDeviceTypeMonitor ( deviceSeq );

            DeviceTypeMonitorWindowConfiguration deviceMonitorConfig (
                true,
                10,
                20,
                100,
                200,
                PositionConfiguration ( PositionConfiguration::CONFIGURATION_TOP_LEFT ),
                25,
                devicesToShow );

            SAESGUIConfigurationManager::getInstance()->getConfiguration()->setDeviceTypeMonitorWindowConfiguration ( deviceMonitorConfig );

            DeviceTypeMonitorWindowConfigurationManager * deviceMonitorManager = DeviceTypeMonitorWindowConfigurationManager::getInstance();

            CPPUNIT_ASSERT ( true == deviceMonitorManager->isVisible() );
            CPPUNIT_ASSERT ( 10 == deviceMonitorManager->getTimeOut() );
            CPPUNIT_ASSERT ( 20 == deviceMonitorManager->getOpacity() );
            CPPUNIT_ASSERT ( 100 == deviceMonitorManager->getIconWidth() );
            CPPUNIT_ASSERT ( 200 == deviceMonitorManager->getIconHeight() );
            CPPUNIT_ASSERT ( PositionConfiguration::CONFIGURATION_TOP_LEFT == deviceMonitorManager->getPosition() );
            CPPUNIT_ASSERT ( 25 == deviceMonitorManager->getBorder() );
            CPPUNIT_ASSERT ( true == deviceMonitorManager->isDeviceWidgetShowing ( DeviceConfiguration::CONFIGURATION_BARCODE ) );
            CPPUNIT_ASSERT ( true == deviceMonitorManager->isDeviceWidgetShowing ( DeviceConfiguration::CONFIGURATION_FLASH ) );
            CPPUNIT_ASSERT ( false == deviceMonitorManager->isDeviceWidgetShowing ( DeviceConfiguration::CONFIGURATION_MOUSE ) );

            delete deviceMonitorManager;

            persistenceManager.verify();
        }

        CPPUNIT_TEST_SUITE ( DeviceTypeMonitorWindowConfigurationManagerTest );

        CPPUNIT_TEST ( testGetDeviceMonitorWindowConfigurationPresent );
        CPPUNIT_TEST ( testGetDeviceMonitorWindowConfigurationDefaultValues );
        CPPUNIT_TEST ( testGetDeviceMonitorWindowConfigurationWithoutDevices );
        CPPUNIT_TEST ( testGetDeviceMonitorWindowConfigurationWithDevices );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_DEVICE_TYPE_MONITOR_WINDOW_CONF_MANAGER_TEST */
