/**
 * @file   BarcodeGetFactorySerialNumberCommand.cxx
 * @brief  Implementation of BarcodeGetFactorySerialNumberCommand class.
 * Queries the device for its factory serial number.
 * @author manuel.arguelles
 * @date   Apr  5, 2018
 */

#include "BarcodeGetFactorySerialNumberCommand.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/Utils/StringUtils.hxx>
#include <sstream>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::HW::Commands;
using namespace Smartmatic::SAES::HW::Connections;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::Log;

ISMTTLog* BarcodeGetFactorySerialNumberCommand::m_logger = SMTTLogManager::GetLogger(
    "Smartmatic.SAES.HW.Commands.BarcodeGetFactorySErialNumberCommand",
    GETTEXT_PACKAGE);

BarcodeGetFactorySerialNumberCommand::BarcodeGetFactorySerialNumberCommand(IConnection* connection)
    : CommandBaseBarcode(connection)
{
    hasResponse_ = true;
}

BarcodeGetFactorySerialNumberCommand::~BarcodeGetFactorySerialNumberCommand()
{
}

void BarcodeGetFactorySerialNumberCommand::initialize()
{
    data.push_back(0x33);
    data.push_back(0x48);
    data.push_back(0x30);
    data.push_back(0x33);
    data.push_back(0x30);
}

bool BarcodeGetFactorySerialNumberCommand::processResponse(const std::vector<unsigned char>& response)
{
    std::string serial;
    std::stringstream ss;

    for (unsigned int i = 9; !response.empty() && i < response.size() - 1; ++i)
    {
        ss << response[i];
    }

    serial = ss.str();

    if (!serial.empty())
    {
        this->response.clear();
        this->response.assign(serial.begin(), serial.end());

        m_logger->Debug("Found factory serial number (" + serial + ").");
    }
    else
    {
        m_logger->Debug("Device factory serial number not found.");
    }

    return !serial.empty();
}
