/**
 * @file	BarcodeGetSerialNumberCommand.cxx
 * @brief	Body the barcode get serial number from device command class.
 * @date	23/06/2015
 * @author	Yadickson Soto
 */

#include "BarcodeGetSerialNumberCommand.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/Utils/StringUtils.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::HW::Commands;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::Log;

ISMTTLog * BarcodeGetSerialNumberCommand::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.HW.Commands.BarcodeGetSerialNumberCommand", GETTEXT_PACKAGE );

BarcodeGetSerialNumberCommand::BarcodeGetSerialNumberCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection )
    : CommandBaseBarcode ( connection )
{
    hasResponse_ = true;
}

BarcodeGetSerialNumberCommand::~BarcodeGetSerialNumberCommand()
{
}

void BarcodeGetSerialNumberCommand::initialize()
{
    data.push_back ( 0x33 );
    data.push_back ( 0x48 );
    data.push_back ( 0x30 );
    data.push_back ( 0x32 );
    data.push_back ( 0x30 );
}

bool BarcodeGetSerialNumberCommand::processResponse ( const std::vector<unsigned char> & response )
{
    std::string serial;
    std::stringstream ss;

    for ( unsigned int i = 9; !response.empty() && i < response.size() - 1; i++ )
    {
        ss << response[i];
    }

    serial = ss.str();

    if ( !serial.empty() )
    {
        this->response.clear();
        this->response.assign ( serial.begin(), serial.end() );

        logger->Debug ( "Found serial number (" + serial + ")." );
    }
    else
    {
        logger->Debug ( "Device serial number not found." );
    }

    return !serial.empty();
}
