/**
 * @file	BarcodeModelCommand.cxx
 * @brief	Body the barcode model command class.
 * @date	23/06/2015
 * @author	Yadickson Soto
 */

#include "BarcodeModelCommand.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/Utils/StringUtils.hxx>
#include <System/Utils/SafeBufferUtils.hxx>
#include <System/SafeBuffer.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::HW::Commands;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::System;
using namespace Smartmatic::Log;

ISMTTLog * BarcodeModelCommand::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.HW.Commands.BarcodeModelCommand", GETTEXT_PACKAGE );

BarcodeModelCommand::BarcodeModelCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection )
    : CommandBaseBarcode ( connection )
{
    hasResponse_ = true;
}

BarcodeModelCommand::~BarcodeModelCommand()
{
}

void BarcodeModelCommand::initialize()
{
    data.push_back ( 0x33 );
    data.push_back ( 0x47 );
}

bool BarcodeModelCommand::processResponse ( const std::vector<unsigned char> & response )
{
    std::string model;

    if ( response.size() >= 4 )
    {
        SafeBuffer full ( ( unsigned char * ) &response[4], response.size() - 4 );
        SafeBufferUtils buffUtil ( full );

        std::vector < SafeBuffer > result = buffUtil.splitByEndLine();
        std::vector < SafeBuffer >::iterator it;

        for ( it = result.begin();
                it != result.end();
                ++it )
        {
            SafeBuffer item ( *it );
            std::string temp;

            temp.assign ( ( const char * ) item.GetData(), item.GetSize() );
            temp = StringUtils::trim ( temp );

            if ( StringUtils::regex ( "Device ID:", temp ) )
            {
                temp = StringUtils::replace ( temp, "Device ID:", "" );
                temp = StringUtils::trim ( temp );
                temp = StringUtils::removeAll(temp, " ");

                model = StringUtils::toLower ( temp );

                this->response.clear();
                this->response.assign ( model.begin(), model.end() );

                break;
            }
        }
    }

    if ( !model.empty() )
    {
        logger->Debug ( "Found device model ( " + model + " )." );
    }
    else
    {
        logger->Debug ( "Device model not found." );
    }

    return !model.empty();
}
