/**
 * @file	BarcodeSendConfigCommand.cxx
 * @brief	Body to send barcode reconfiguration command.
 * @date	26/06/2015
 * @author	Yadickson Soto
 */

#include "BarcodeSendConfigCommand.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/Utils/StringUtils.hxx>
#include <Commands/DataCommandElement.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::HW::Commands;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::Log;

ISMTTLog * BarcodeSendConfigCommand::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.HW.Commands.BarcodeSendConfigCommand", GETTEXT_PACKAGE );

BarcodeSendConfigCommand::BarcodeSendConfigCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection,
        const std::string & command, unsigned int timeout, unsigned int retries, bool mandatory )
    : CommandStructure ( connection ), command ( command ), mandatory ( mandatory )
{
    this->timeoutBeforeReceive = timeout * 1000;
    this->retriesToReceive = retries;
    hasResponse_ = true;
}

BarcodeSendConfigCommand::~BarcodeSendConfigCommand()
{

}

void BarcodeSendConfigCommand::initialize()
{
    data.insert ( data.end(), command.begin(), command.end() );
}

bool BarcodeSendConfigCommand::processResponse ( const std::vector<unsigned char> & response )
{
    return !mandatory || response[0] == 0x06;
}

CommandStructure::CommandList BarcodeSendConfigCommand::getCommandList ()
{
    CommandList commands;

    commands.push_back ( new DataCommandElement ( data ) );

    return commands;
}
