/**
 * @file ChecksumCommandElement.hxx
 * @brief	Defines the checksum calculation command element.
 * @author	Yadickson Soto
 * @date	17/02/2014
 */

#ifndef CHECKSUM_COMMAND_ELEMENT_HXX_
#define CHECKSUM_COMMAND_ELEMENT_HXX_

#include <Commands/CommandElement.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Commands
            {
                /**
                 * @class	ChecksumCommandElement
                 * @brief	Defines the checksum calculation command element.
                 * @author	Yadickson Soto
                 * @date	17/02/2014
                 */
                class ChecksumCommandElement : public CommandElement
                {
                    public:

                        /**
                         * @fn	ChecksumCommandElement ( const std::vector<unsigned char> & data );
                         * @brief	Default constructor.
                         * @author	Yadickson Soto
                         * @date	17/02/2014
                         * @param	data The input data on which to calculate the checksum value.
                         */
                        explicit ChecksumCommandElement ( const std::vector<unsigned char> & data );

                        /**
                         * @fn	virtual ~ChecksumCommandElement();
                         * @brief	Default destructor.
                         * @author	Yadickson Soto
                         * @date	17/02/2014
                         */
                        virtual ~ChecksumCommandElement();

                        /**
                         * @fn virtual void addToCommand( std::vector < unsigned char > & command );
                         * @brief Adds the checksum value of the data to the being-constructed command.
                         * @date 17/02/2014
                         * @author Yadickson Soto
                         * @param	command The being-constructed command, to which we want to add the data checksum command element.
                         */
                        virtual void addToCommand ( std::vector < unsigned char > & command );

                    private:

                        const std::vector<unsigned char> & data; ///< The input data to calculate checksum value.
                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */
#endif /* CHECKSUM_COMMAND_ELEMENT_HXX_ */
