/**
 * @file   CommandBaseAbled.hxx
 * @brief  Declaration of CommandBaseAbled class.
 * @author eduardo.fernandez
 * @date   Jan 11, 2018
 */

#ifndef COMMAND_BASE_ABLED_HXX
#define COMMAND_BASE_ABLED_HXX

#include "command-structure.h"

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Connections
            {
                class IConnection;
            }

            namespace Commands
            {

                /**
                 * @class  CommandBaseAbled.
                 * @brief  Base class for the abled commands.
                 * @author eduardo.fernandez
                 * @date   Jan 11, 2018
                 */
                class CommandBaseAbled : public CommandStructure
                {
                    public:

                        /**
                         * @brief  Creates an instance of the class.
                         * @author eduardo.fernandez
                         * @date   Jan 11, 2018
                         */
                        explicit CommandBaseAbled(HW::Connections::IConnection* connection);

                        /**
                         * @brief  Destroys an instance of the class.
                         * @author eduardo.fernandez
                         * @date   Jan 11, 2018
                         */
                        virtual ~CommandBaseAbled();

                    protected:

                        /**
                         * @brief  Gets the list of commands.
                         * @author eduardo.fernandez
                         * @date   Jan 11, 2018
                         */
                        virtual CommandList getCommandList();

                        /**
                         * @brief  Process the response
                         * @author eduardo.fernandez
                         * @date   Jan 11, 2018
                         * @param  response The vector with the response bytes.
                         * @return True if the response was valid, false if not.
                         */
                        virtual bool processResponse(const std::vector<unsigned char>& response);

                    private:

                        /**
                         * @brief  Adds the sender id to the command.
                         * @author eduardo.fernandez
                         * @date   Jan 11, 2018
                         */
                        void addSenderId();

                        /**
                         * @brief  Adds the MAC to the command.
                         * @author eduardo.fernandez
                         * @date   Nov  1, 2017
                         */
                        void addMAC();

                        /**
                         * @brief  Adds noise bytes to the data.
                         * @author eduardo.fernandez
                         * @date   Jan 11, 2018
                         */
                        void addNoise();

                        /**
                         * @brief  Adds the size of the data to the command.
                         * @author eduardo.fernandez
                         * @date   Jan 11, 2018
                         */
                        void addCommandLength();
                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */


#endif /* COMMAND_BASE_ABLED_HXX */
