/**
 * @file   CommandBasePDB.hxx
 * @brief  Declaration of CommandBasePDB class.
 * @author manuel.arguelles
 * @date   Oct 31, 2017
 */

#ifndef COMMAND_BASE_PDB_HXX
#define COMMAND_BASE_PDB_HXX

#include "command-structure.h"

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Connections
            {
                class IConnection;
            }

            namespace Commands
            {

                /**
                 * @class  CommandBasePDB.
                 * @brief  Base class for the PDB commands.
                 * @author manuel.arguelles
                 * @date   Oct 31, 2017
                 */
                class CommandBasePDB : public CommandStructure
                {
                    public:

                        /**
                         * @brief  Creates an instance of the class.
                         * @author manuel.arguelles
                         * @date   Oct 31, 2017
                         */
                        explicit CommandBasePDB(HW::Connections::IConnection* connection);

                        /**
                         * @brief  Destroys an instance of the class.
                         * @author manuel.arguelles
                         * @date   Oct 31, 2017
                         */
                        virtual ~CommandBasePDB();

                    protected:

                        /**
                         * @brief  Gets the list of commands.
                         * @author manuel.arguelles
                         * @date   Oct 31, 2017
                         */
                        virtual CommandList getCommandList();

                        /**
                         * @brief  Process the response
                         * @author manuel.arguelles
                         * @date   Oct 31, 2017
                         * @param  response The vector with the response bytes.
                         * @return True if the response was valid, false if not.
                         */
                        virtual bool processResponse(const std::vector<unsigned char>& response);

                    private:

                        /**
                         * @brief  Adds the sender id to the command.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        void addSenderId();

                        /**
                         * @brief  Adds the MAC to the command.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        void addMAC();

                        /**
                         * @brief  Adds noise bytes to the data.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        void addNoise();

                        /**
                         * @brief  Adds the size of the data to the command.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        void addCommandLength();
                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */


#endif /* COMMAND_BASE_PDB_HXX */
