/**
 * @file   EurnError.hxx
 * @brief  Enumeration of Eurn's errors.
 * @author manuel.arguelles
 * @date   Aug 29, 2017
 */

#ifndef EURN_ERROR_HXX
#define EURN_ERROR_HXX

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Commands
            {

                /**
                 * @brief  Eurn error enumeration.
                 * @author manuel.arguelles
                 * @date   Aug 29, 2017
                 */
                enum EurnError
                {
                    /**
                     * @brief  No error
                     * @author manuel.arguelles
                     * @date   Aug 29, 2017
                     */
                    EURN_ERROR_NO_ERROR = 0,

                    /**
                     * @brief  Unknown command error.
                     * @author manuel.arguelles
                     * @date   Aug 29, 2017
                     */
                    EURN_ERROR_UNKNOWN_COMMAND,

                    /**
                     * @brief  Checksum error.
                     * @author manuel.arguelles
                     * @date   Aug 29, 2017
                     */
                    EURN_ERROR_CHECKSUM,

                    /**
                     * @brief  Invalid header error.
                     * @author manuel.arguelles
                     * @date   Aug 29, 2017
                     */
                    EURN_ERROR_HEADER,

                    /**
                     * @brief  Invalid response format.
                     * @author manuel.arguelles
                     * @date   Aug 29, 2017
                     */
                    EURN_ERROR_FORMAT
                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* EURN_ERROR_HXX */
