/**
 * @file   EurnPingCommand.hxx
 * @brief  Declaration of EurnPingCommand class.
 * @author manuel.arguelles
 * @date   Aug 25, 2017
 */

#ifndef EURN_PING_COMMAND_HXX
#define EURN_PING_COMMAND_HXX

#include "CommandBaseEurn.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Connections
            {
                class IConnection;
            }

            namespace Commands
            {

                /**
                 * @class  EurnPingCommand
                 * @brief  Command to ping the eurn.
                 * @author manuel.arguelles
                 * @date   Aug 25, 2017
                 */
                class EurnPingCommand : public CommandBaseEurn
                {
                    public:

                        /**
                         * @brief  Instantiate an Impingement object.
                         * @author manuel.arguelles
                         * @date   Aug 25, 2017
                         */
                        explicit EurnPingCommand(HW::Connections::IConnection* connection);

                        /**
                         * @brief  Destroys an EurnPingCommand object.
                         * @author manuel.arguelles
                         * @date   Aug 25, 2017
                         */
                        virtual ~EurnPingCommand();

                    public:

                        /**
                         * @brief  Checks if the door is open
                         * @author manuel.arguelles
                         * @date   Aug 29, 2017
                         * @return True if the door is open, false if it is closed.
                         */
                        bool isDoorOpen();

                        /**
                         * @brief  Checks if the red led is on.
                         * @author manuel.arguelles
                         * @date   Aug 29, 2017
                         * @return True if the red led is on, false if not.
                         */
                        bool isRedLedOn();

                        /**
                         * @brief  Checks if the green led is on.
                         * @author manuel.arguelles
                         * @date   Aug 29, 2017
                         * @return True if the green led is on, false if not.
                         */
                        bool isGreenLedOn();

                        /**
                         * @brief  Checks if the red led is blinking.
                         * @author manuel.arguelles
                         * @date   Aug 29, 2017
                         * @return True if the red led is blinking, false if not.
                         */
                        bool isRedLedBlinking();

                        /**
                         * @brief  Checks if the green led is blinking.
                         * @author manuel.arguelles
                         * @date   Aug 29, 2017
                         * @return True if the green led is blinking, false if not.
                         */
                        bool isGreenLedBlinking();

                        /**
                         * @brief  Gets the byte with the version.
                         * @author manuel.arguelles
                         * @date   Aug 29, 2017
                         * @return Char if successful, 0x00 if not.
                         */
                        unsigned char getVersion();

                    protected:

                        /**
                         * @brief  Gets the complete command list to ping the eurn.
                         * @author manuel.arguelles
                         * @date   Aug 25, 2017
                         */
                        virtual CommandStructure::CommandList getCommandList();

                    private:

                        /**
                         * @brief  Initialize the data of the ping command.
                         * @author manuel.arguelles
                         * @date   Aug 25, 2017
                         */
                        void initialize();

                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */

#endif /* EURN_PING_COMMAND_HXX */
