/**
 * @file	P168AProductVersionInfoCommand.cxx
 * @brief	Body the P168A read product version info command class.
 * @date	13/09/2012
 * @author	Yadickson Soto
 */

#include "P168AProductVersionInfoCommand.hxx"
#include "Log/ISMTTLog.h"
#include <Log/SMTTLogManager.h>
#include <System/Utils/StringUtils.hxx>
#include <Commands/P168AHeaderCommandElement.hxx>
#include <Commands/DataCommandElement.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate
#define COMMAND 0x01 ///< command value

using namespace Smartmatic::SAES::HW::Commands;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::Log;

ISMTTLog * P168AProductVersionInfoCommand::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.HW.Commands.P168AProductVersionInfoCommand", GETTEXT_PACKAGE );

P168AProductVersionInfoCommand::P168AProductVersionInfoCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection )
    : CommandBaseP168A ( connection )
{
    hasResponse_ = true;
}

P168AProductVersionInfoCommand::~P168AProductVersionInfoCommand()
{
}

void P168AProductVersionInfoCommand::initialize()
{
    commandByte.push_back ( COMMAND );
}

CommandStructure::CommandList P168AProductVersionInfoCommand::getCommandList ()
{
    CommandList commands;

    commands.push_back ( new P168AHeaderCommandElement() );
    commands.push_back ( new DataCommandElement ( commandByte ) );

    return commands;
}

bool P168AProductVersionInfoCommand::processResponse ( const std::vector<unsigned char> & response )
{
    std::string info;

    if ( response.size() > 3 && response[0] == 0x1B && response[1] == COMMAND )
    {
        std::vector<unsigned char> rawResponse;
        rawResponse.insert ( rawResponse.end(), &response[3], &response[3] + response[2] );

        this->response = rawResponse;
        info = StringUtils::arrayHexToAsciiString ( rawResponse );
    }

    if ( !info.empty() )
    {
        logger->Debug ( "Found product version info ( " + info + " )." );
    }
    else
    {
        logger->Debug ( "Product version info not found." );
    }

    return !info.empty();
}
