/**
 * @file	P168AWriteMemoryCommand.cxx
 * @brief	Body the P168A reset memory command class.
 * @date	12/09/2012
 * @author	Yadickson Soto
 */

#include "P168AWriteMemoryCommand.hxx"
#include "Log/ISMTTLog.h"
#include <Log/SMTTLogManager.h>
#include <System/Utils/StringUtils.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate
#define COMMAND 0x1D ///< command value

using namespace Smartmatic::SAES::HW::Commands;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::Log;

ISMTTLog * P168AWriteMemoryCommand::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.HW.Commands.P168AWriteMemoryCommand", GETTEXT_PACKAGE );

P168AWriteMemoryCommand::P168AWriteMemoryCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection, unsigned char address1, unsigned char address2, std::vector <unsigned char> & data )
    : CommandBaseP168A ( connection ), dataToWrite ( data )
{
    hasResponse_ = true;
    this->address1 = address1;
    this->address2 = address2;
}

P168AWriteMemoryCommand::~P168AWriteMemoryCommand()
{
}

void P168AWriteMemoryCommand::initialize()
{
    commandByte.push_back ( COMMAND );
    commandByte.push_back ( address1 );
    commandByte.push_back ( address2 );
    data.insert ( data.end(), dataToWrite.begin(), dataToWrite.end() );
}
