/*
 * PDBSetSerialNumberCommand.hxx
 *
 *  Created on: Nov 18, 2017
 *      Author: marcelmancini
 */

#ifndef PDBSETSERIALNUMBERCOMMAND_HXX
#define PDBSETSERIALNUMBERCOMMAND_HXX

#include "CommandBasePDB.hxx"

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Connections
            {
                class IConnection;
            }

            namespace Commands
            {
                /**
                 * @class  PDBSetSerialNumberCommand
                 * @brief  Command to set the serial number of the machine in the PDB's EEPROM.
                 * @author manuel.arguelles
                 * @date   Nov  1, 2017
                 */
                class PDBSetSerialNumberCommand : public CommandBasePDB
                {
                    public:

                        /**
                         * @brief  Creates an instance of the class.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        PDBSetSerialNumberCommand(HW::Connections::IConnection* connection, const  std::vector<unsigned char> & serialChars);

                        /**
                         * @brief  Destroys an instance of the class.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        virtual ~PDBSetSerialNumberCommand();

                    private:

                        /**
                         * @brief  Initialize the command.
                         * @author manuel.arguelles
                         * @date   Nov  1, 2017
                         */
                        virtual void initialize();

                    private:

                        std::vector<unsigned char> m_serialChars;
                };

            } /* namespace Commands */
        } /* namespace HW */
    } /* namespace SAES */
} /* namespace Smartmatic */



#endif /* PDBSETSERIALNUMBERCOMMAND_HXX */
