/**
 * @file	alarm-buzzer-command.h
 * @brief	Declares the alarm buzzer command class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */


#ifndef _ALARM_BUZZER_COMMAND_H_
#define _ALARM_BUZZER_COMMAND_H_

#include "command-base-alarm.h"

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Commands
            {
                /**
                 * @class AlarmBuzzerCommand
                 * @brief alarm buzzer command class
                 * @date 01/11/2012
                   * @author Yadickson Soto
                   */
                class AlarmBuzzerCommand: public CommandBaseAlarm
                {

                    public:

                        /**
                         * @fn	AlarmBuzzerCommand::AlarmBuzzerCommand(Smartmatic::SAES::HW::Connections::IConnection * connection, unsigned char period, unsigned char repeat);
                         * @brief	Default constructor.
                         * @author	Yadickson Soto
                         * @date	18/02/2014
                         * @param 	connection The connection provider
                         * @param	period	The period.
                         * @param	repeat	The repeat.
                         */
                        AlarmBuzzerCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection, unsigned char period, unsigned char repeat );

                    private:

                        /**
                         * @fn	void AlarmBuzzerCommand::initialize();
                         * @brief	Initializes this object.
                         * @author	Fsilva
                         * @date	27/04/2011
                         */

                        void initialize();

                        unsigned char period;   ///< The period
                        unsigned char repeat;   ///< The repeat
                };
            }
        }
    }
}

#endif // _ALARM_BUZZER_COMMAND_H_
