/**
 * @file	A4517AbledConfigurationManager.hxx
 * @brief	Declares the A4517 able-d configuration manager class.
 * @author	eduardo.fernandez
 * @date	Jan 17, 2018
 */

#ifndef A4517_ABLED_CONFIGURATION_MANAGER_H
#define A4517_ABLED_CONFIGURATION_MANAGER_H

#include <string>
#include <Configuration/a4517-abled-device-schema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Configuration
            {
                /**
                 * @class	A4517AbledConfigurationManager
                 * @brief	Manager for A4517 able-d configurations class.
                 * @author	eduardo.fernandez
                 * @date	Jan 17, 2018
                 */
                class A4517AbledConfigurationManager
                {
                    public:

                        /**
                         * @fn	static A4517AbledConfigurationManager *getInstance(A4517AbledConfigurationManager * externManager = NULL);
                         * @brief	Gets the current A4517 able-d Configuration Manager.
                         * @author	eduardo.fernandez
                         * @date	Jan 17, 2018
                         * @param 	externManager external manager to unit test
                         * @return	instance of the class
                         */
                        static A4517AbledConfigurationManager * getInstance ( A4517AbledConfigurationManager * externManager = NULL );

                        /**
                         * @fn	const AbledDeviceConfiguration::ButtonTypeSequence & getButtons ();
                         * @brief	Gets the button list configuration.
                         * @author	eduardo.fernandez
                         * @date	Jan 17, 2018
                         * @return 	The button list configuration.
                         */
                        const A4517AbledDeviceConfiguration::ButtonTypeSequence & getButtons ();

                        /**
                         * @fn	virtual ~A4517AbledConfigurationManager();
                         * @brief	Class destructor
                         * @author	eduardo.fernandez
                         * @date	Jan 17, 2018
                         */
                        virtual ~A4517AbledConfigurationManager();

                    protected:

                        /**
                         * @fn	virtual AbledDeviceConfiguration & getA4517AbledDeviceConfiguration();
                         * @brief	Gets A4517 able-d configuration.
                         * @author	eduardo.fernandez
                         * @date	Jan 17, 2018
                         * @return	The able-d configuration.
                         */
                        virtual A4517AbledDeviceConfiguration & getA4517AbledDeviceConfiguration();

                        /**
                         * @fn	A4517AbledConfigurationManager();
                         * @brief	Default constructor.
                         * @author	eduardo.fernandez
                         * @date	Jan 17, 2018
                         */
                        A4517AbledConfigurationManager();

                        static A4517AbledConfigurationManager * instance; ///< The singleton instance
                };
            }
        }
    }
}

#endif // A4517_ABLED_CONFIGURATION_MANAGER_H
