/**
 * @file	BarcodeDeviceConfigurationManager.cxx
 *
 * @brief	barcode configuration manager class.
 */

#include "BarcodeDeviceConfigurationManager.hxx"
#include "s-a-e-s-hardware-conf-manager.h"

using namespace Smartmatic::SAES::HW::Configuration;

BarcodeDeviceConfigurationManager * BarcodeDeviceConfigurationManager::instance = NULL; ///< The singleton instance

BarcodeDeviceConfigurationManager::BarcodeDeviceConfigurationManager()
{

}

BarcodeDeviceConfigurationManager::~BarcodeDeviceConfigurationManager()
{
    instance = NULL;
}

BarcodeCommands::CommandSequence BarcodeDeviceConfigurationManager::getBarcodeConfigurationCommands ( const std::string & commandBlock, const std::string & barcodeModel )
{
    BarcodeCommands::CommandSequence list;
    BarcodeDeviceConfiguration::ConfigurationCommandsSequence & configSeq ( getBarcodeDeviceConfiguration().getConfigurationCommands() );
    BarcodeDeviceConfiguration::ConfigurationCommandsIterator iter;

    std::string primarySearch = commandBlock + "-" + barcodeModel;

    bool commandsFound = false;

    for ( iter = configSeq.begin();
            iter != configSeq.end() && !commandsFound;
            iter++ )
    {
        if ( ( * iter ).getCommandBlockName() == primarySearch )
        {
            list.insert ( list.begin(), ( * iter ).getCommand().begin(), ( * iter ).getCommand().end() );
            commandsFound = true;
        }
    }

    if ( !commandsFound )
    {
        for ( iter = configSeq.begin();
                iter != configSeq.end() && !commandsFound;
                iter++ )
        {
            if ( ( * iter ).getCommandBlockName() == commandBlock )
            {
                list.insert ( list.begin(), ( * iter ).getCommand().begin(), ( * iter ).getCommand().end() );
                commandsFound = true;
                break;
            }
        }
    }

    return list;
}

std::string BarcodeDeviceConfigurationManager::getModelFile ()
{
    return getBarcodeDeviceConfiguration().getModelFile().present() ? getBarcodeDeviceConfiguration().getModelFile().get() : "";
}

std::string BarcodeDeviceConfigurationManager::getSerialFile ()
{
    return getBarcodeDeviceConfiguration().getSerialFile().present() ? getBarcodeDeviceConfiguration().getSerialFile().get() : "";
}

std::string BarcodeDeviceConfigurationManager::getCommandsFile ()
{
    return getBarcodeDeviceConfiguration().getCommandsFile().present() ? getBarcodeDeviceConfiguration().getCommandsFile().get() : "";
}

std::string BarcodeDeviceConfigurationManager::getBufferFile ()
{
    return getBarcodeDeviceConfiguration().getBufferFile().present() ? getBarcodeDeviceConfiguration().getBufferFile().get() : "";
}

bool BarcodeDeviceConfigurationManager::simulationEnabled ()
{
    return !getModelFile().empty() && !getSerialFile().empty() && !getCommandsFile().empty() && !getBufferFile().empty();
}

BarcodeDeviceConfiguration & BarcodeDeviceConfigurationManager::getBarcodeDeviceConfiguration()
{
    if ( !SAESHardwareConfigurationManager::getInstance()->getConfiguration()->getBarcodeDeviceConfiguration().present() )
    {
        BarcodeDeviceConfiguration config;
        BarcodeDeviceConfiguration::ConfigurationCommandsSequence commands;

        config.setConfigurationCommands ( commands );

        SAESHardwareConfigurationManager::getInstance()->getConfiguration()->setBarcodeDeviceConfiguration ( config );
    }

    return SAESHardwareConfigurationManager::getInstance()->getConfiguration()->getBarcodeDeviceConfiguration().get();
}

BarcodeDeviceConfigurationManager * BarcodeDeviceConfigurationManager::getInstance ( BarcodeDeviceConfigurationManager * externManager )
{
    if ( ! instance )
    {
        instance = ( externManager == NULL ? new BarcodeDeviceConfigurationManager() : externManager );
    }

    return instance;
}
