/**
 * @file	P168AConfigurationManager.cxx
 * @brief	abler-d configuration manager class.
 * @author	Yadickson Soto
 * @date	01/07/2015
 */

#include "P168AConfigurationManager.hxx"
#include "s-a-e-s-hardware-conf-manager.h"

using namespace Smartmatic::SAES::HW::Configuration;

P168AConfigurationManager * P168AConfigurationManager::instance = NULL; ///< The singleton instance

P168AConfigurationManager::P168AConfigurationManager()
{

}

P168AConfigurationManager::~P168AConfigurationManager()
{
    instance = NULL;
}

const P168ADeviceConfiguration::ButtonTypeSequence & P168AConfigurationManager::getButtons ()
{
    return getP168ADeviceConfiguration().getButtonType();
}

std::string P168AConfigurationManager::getSerialMachineFile ()
{
    return getP168ADeviceConfiguration().getSerialMachineFile().present() ? getP168ADeviceConfiguration().getSerialMachineFile().get() : "";
}

std::string P168AConfigurationManager::getAbleDButtonsFile ()
{
    return getP168ADeviceConfiguration().getAbleDButtonsFile().present() ? getP168ADeviceConfiguration().getAbleDButtonsFile().get() : "";
}

bool P168AConfigurationManager::simulationEnabled ()
{
    return !getSerialMachineFile().empty() && !getAbleDButtonsFile().empty();
}

P168ADeviceConfiguration & P168AConfigurationManager::getP168ADeviceConfiguration()
{
    if ( ! SAESHardwareConfigurationManager::getInstance()->getConfiguration()->getP168ADeviceConfiguration().present() )
    {
        P168ADeviceConfiguration config;
        P168ADeviceConfiguration::ButtonTypeSequence seq;

        config.setButtonType ( seq );
        config.setSerialMachineFile ( "" );
        config.setAbleDButtonsFile ( "" );

        SAESHardwareConfigurationManager::getInstance()->getConfiguration()->setP168ADeviceConfiguration ( config );
    }

    return SAESHardwareConfigurationManager::getInstance()->getConfiguration()->getP168ADeviceConfiguration().get();
}

P168AConfigurationManager * P168AConfigurationManager::getInstance ( P168AConfigurationManager * externManager )
{
    if ( ! instance )
    {
        instance = ( externManager == NULL ? new P168AConfigurationManager() : externManager );
    }

    return instance;
}
