/*
 * PDBDeviceConfigurationManager.hxx
 *
 *  Created on: Oct 31, 2017
 *      Author: juanvalera
 */

#ifndef PDBDEVICECONFIGURATIONMANAGER_HXX_
#define PDBDEVICECONFIGURATIONMANAGER_HXX_

#include <string>
#include <Configuration/PDBDeviceSchema.hxx>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Configuration
            {
                /**
                 * @class	PDBDeviceConfigurationManager
                 * @brief	Manager for PDB configurations class.
                 * @author	Juan Valera
                 * @date	31/10/2017
                 */
                class PDBDeviceConfigurationManager
                {
                    public:

                        /**
                         * @fn	static PDBDeviceConfigurationManager *getInstance(PDBDeviceConfigurationManager * externManager = NULL);
                         * @brief	Gets the current PDB Configuration Manager.
                         * @author	Juan Valera
                         * @date	31/10/2017
                         * @param 	externManager external manager to unit test
                         * @return	instance of the class
                         */
                        static PDBDeviceConfigurationManager * getInstance ( PDBDeviceConfigurationManager * externManager = NULL );

                        /**
                         * @fn	PDBPortType getPDBPortForA4517SCRPowerCycle ();
                         * @brief	Gets USB port to perform fower cycle in the SCR.
                         * @author	Juan Valera
                         * @date	08/07/2015
                         * @return 	The pdb usb port
                         */
                        PDBPortType getPDBPortForA4517SCRPowerCycle ();

                        /**
                         * @fn	PDBPortType getPDBPortForVIUSCRPowerCycle ();
                         * @brief	Gets USB port to perform fower cycle in the SCR.
                         * @author	Juan Valera
                         * @date	08/07/2015
                         * @return 	The pdb usb port
                         */
                        PDBPortType getPDBPortForVIUSCRPowerCycle ();

                        /**
                         * @fn	virtual ~PDBDeviceConfigurationManager();
                         * @brief	Class destructor
                         * @author	Juan Valera
                         * @date	31/10/2017
                         */
                        virtual ~PDBDeviceConfigurationManager();

                        /**
                         * @fn	virtual PDBDeviceConfiguration & getConfiguration();
                         * @brief	Gets PDB device configuration.
                         * @author	Juan Valera
                         * @date	01/11/2017
                         * @return	The PDB device configuration.
                         */
                        virtual PDBDeviceConfiguration & getConfiguration();

                    protected:
                        /**
                         * @fn	PDBDeviceConfigurationManager();
                         * @brief	Default constructor.
                         * @author	Juan Valera
                         * @date	31/10/2017
                         */
                        PDBDeviceConfigurationManager();

                        /**
                         * @fn	virtual PDBDeviceConfiguration & getPDBDeviceConfiguration();
                         * @brief	Gets PDB device configuration.
                         * @author	Juan Valera
                         * @date	31/10/2017
                         * @return	The PDB device configuration.
                         */
                        virtual PDBDeviceConfiguration & getPDBDeviceConfiguration();

                        static PDBDeviceConfigurationManager * instance; ///< The singleton instance
                };
            }
        }
    }
}
#endif /* PDBDEVICECONFIGURATIONMANAGER_HXX_ */
