/**
 * @file FactoryConnection.cxx
 * @brief Declares the factory connection class.
 * @author Yadickson Soto
 * @date 20/02/2014
 */

#include "FactoryConnection.hxx"
#include "RS232Connection.hxx"
#include "UsbConnection.hxx"
#include <System/OptParser.hxx>
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::System;
using namespace Smartmatic::System::Utils;
using namespace Smartmatic::SAES::HW::Connections;

IConnection * FactoryConnection::createAlarmBoxDeviceConnection ()
{
    IConnection * connection = new RS232Connection ( 57600, 8, false, false );
    return connection;
}

IConnection * FactoryConnection::createBarcodeDeviceConnection ()
{
    IConnection * connection = new RS232Connection ( 9600, 8, false, false );
    return connection;
}

IConnection * FactoryConnection::createP168ADeviceConnection ()
{
    IConnection * connection = new RS232Connection ( 9600, 8, false, true );
    return connection;
}

IConnection * FactoryConnection::createEurnDeviceConnection ()
{
    IConnection * connection = new RS232Connection ( 115200, 8, false, false );
    return connection;
}

IConnection * FactoryConnection::createPDBDeviceConnection ()
{
    IConnection *connection = new UsbConnection("0x28cd", "0x40cc", 0);

    return connection;
}

IConnection * FactoryConnection::createIOBDeviceConnection ()
{
    IConnection * connection = new UsbConnection("0x28cd", "0x40ce", 0);

    return connection;
}

IConnection * FactoryConnection::createAbledDeviceConnection ()
{
    IConnection* connection = new UsbConnection("0x28cd", "0x4042", 0);

    return connection;
}
