/**
 * @file	SerialPortConnection.cxx
 * @brief	serial port connection class.
 * @author	Youssef.tourkmani
 * @date	31/10/2012
 */


#include "SerialPortConnection.hxx"
#include <Connections/RS232Connection.hxx>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/Utils/StringUtils.hxx>
#include <unistd.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Smartmatic::SAES::HW::Connections;
using namespace Smartmatic::Log;
using namespace Smartmatic::System::Utils;

ISMTTLog * SerialPortConnection::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.HW.Connections.SerialPortConnection", GETTEXT_PACKAGE );

SerialPortConnection::SerialPortConnection ( IConnection * connection )
    : connection ( connection ), clientListener ( NULL )
{

}

SerialPortConnection::~SerialPortConnection()
{
    if ( connection )
    {
        delete connection;
        connection = NULL;
    }
}

bool SerialPortConnection::openConnection ( const std::string & device )
{
    return connection->openConnection ( device );
}

bool SerialPortConnection::sendCommand ( const std::vector<unsigned char> & data )
{
    logger->Debug ( "Send " + StringUtils::arrayHexToString ( data ) );

    if ( !connection->sendCommand ( data ) )
    {
        logger->Debug ( "ERROR - Serial port connection, write failed" );
        return false;
    }

    return true;
}

Smartmatic::System::SafeVector <unsigned char> SerialPortConnection::readBuffer ()
{
    Smartmatic::System::SafeVector <unsigned char> buffer;
    bool retry = true;

    while ( true )
    {
        std::vector<unsigned char> commandAnswer;

        commandAnswer = connection->readBuffer ();

        if ( !commandAnswer.empty() )
        {
            buffer.insert ( buffer.end(), commandAnswer.begin(), commandAnswer.end() );
            retry = true;
        }
        else if ( retry )
        {
            usleep ( getTimeOut() );
            retry = false;
        }
        else
        {
            if ( !buffer.empty() && clientListener )
            {
                clientListener->peekEvent ( buffer );
            }

            break;
        }
    }

    return buffer;
}

bool SerialPortConnection::closeConnection()
{
    return connection->closeConnection();
}

void SerialPortConnection::setListener ( IPeekListener * clientListener )
{
    this->clientListener = clientListener;
}

unsigned int SerialPortConnection::getTimeOut()
{
    return connection->getTimeOut();
}
