/**
 * @file	AlarmBoxDevice.cxx
 * @brief	alarm device class.
 * @author	Yadickson Soto
 * @date	30/06/2015
 */

#include "AlarmBoxDevice.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <Commands/alarm-buzzer-command.h>
#include <Commands/alarm-green-led-command.h>
#include <Commands/alarm-red-led-command.h>
#include <Commands/alarm-ping-command.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::SAES::HW::Commands;
using namespace Smartmatic::SAES::HW::Devices;
using namespace Smartmatic::SAES::HW::Connections;
using namespace Smartmatic::Log;

ISMTTLog * AlarmBoxDevice::logger = SMTTLogManager::GetLogger ( "Smartmatic.SAES.HW.Devices.AlarmBoxDevice", GETTEXT_PACKAGE );

AlarmBoxDevice::AlarmBoxDevice ( IConnection * connection )
    : connection ( connection )
{

}

AlarmBoxDevice::~AlarmBoxDevice()
{
    if ( connection )
    {
        delete connection;
        connection = NULL;
    }
}

bool AlarmBoxDevice::open ( const std::string & device )
{
    logger->Debug ( "Open alarm box device" );
    return connection->openConnection ( device );
}

bool AlarmBoxDevice::close()
{
    logger->Debug ( "Close alarm box device" );
    return connection->closeConnection();
}

bool AlarmBoxDevice::sendPing()
{
    AlarmPingCommand pingCommand ( connection );
    return pingCommand.execute ();
}

bool AlarmBoxDevice::turnOnRedLed ( unsigned char period )
{
    AlarmRedLedCommand redLed ( connection, period, 0x01 );
    return redLed.execute ();
}

bool AlarmBoxDevice::turnOffRedLed()
{
    AlarmRedLedCommand redLed ( connection, 0x00, 0x00 );
    return redLed.execute ();
}

bool AlarmBoxDevice::turnOnGreenLed ( unsigned char period )
{
    AlarmGreenLedCommand greenLed ( connection, period, 0x01 );
    return greenLed.execute ();
}

bool AlarmBoxDevice::turnOffGreenLed()
{
    AlarmGreenLedCommand greenLed ( connection, 0x00, 0x00 );
    return greenLed.execute ();
}

bool AlarmBoxDevice::turnOnBuzzer ( unsigned char period )
{
    AlarmBuzzerCommand buzzer ( connection, period, 0x01 );
    return buzzer.execute ();
}

bool AlarmBoxDevice::turnOffBuzzer()
{
    AlarmBuzzerCommand buzzer ( connection, 0x00, 0x00 );
    return buzzer.execute ();
}

bool AlarmBoxDevice::isButtonPressed ()
{
    bool buttonPresed = false;

    std::vector<unsigned char> buffer = connection->readBuffer();

    if ( buffer.size() > 4 )
    {
        if ( buffer[0] == 0x55 && buffer[1] == 0xA1 && buffer[2] == 0x00 && buffer[3] == 0x00 && buffer[4] == 0xAA )
        {
            logger->Debug ( "buttonPress" );
            buttonPresed = true;
        }
    }

    return buttonPresed;
}
