/**
 * @file	AlarmBoxInterface.hxx
 * @brief	Declares the alarm box device interface.
 * @author	Yadickson Soto
 * @date	30/06/2015
 */

#ifndef _ALARM_BOX_INTERFACE_H_
#define _ALARM_BOX_INTERFACE_H_

#include <string>

namespace Smartmatic
{
    namespace SAES
    {
        namespace HW
        {
            namespace Devices
            {
                /**
                 * @class	AlarmBoxInterface
                 * @brief	The alarm box interface
                 * @author	Yadickson Soto
                 * @date	30/06/2015
                 */
                class AlarmBoxInterface
                {

                    public:

                        /**
                         * @fn	virtual ~AlarmBoxInterface();
                         * @brief	Class destroyer.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         */
                        virtual ~AlarmBoxInterface() {};

                        /**
                         * @fn	virtual bool open( const std::string & device ) = 0;
                         * @brief	Opens the connections.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @param 	device device path
                         * @return	true if successful.
                         */
                        virtual bool open ( const std::string & device ) = 0;

                        /**
                         * @fn	virtual bool close() = 0;
                         * @brief	Closes the connections.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @return	true if successful.
                         */
                        virtual bool close() = 0;

                        /**
                         * @fn	virtual bool sendPing() = 0;
                         * @brief	Sends a ping.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @return	true if it succeeds, false if it fails.
                         */
                        virtual bool sendPing() = 0;

                        /**
                         * @fn	virtual bool turnOnRedLed ( unsigned char period ) = 0;
                         * @brief	Turn on the red led.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @param	period	The period.
                         */
                        virtual bool turnOnRedLed ( unsigned char period ) = 0;

                        /**
                         * @fn	virtual bool turnOffRedLed() = 0;
                         * @brief	Turn off the red led.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         */
                        virtual bool turnOffRedLed() = 0;

                        /**
                         * @fn	virtual bool turnOnGreenLed ( unsigned char period ) = 0;
                         * @brief	Turn on the green led.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @param	period	The period.
                         */
                        virtual bool turnOnGreenLed ( unsigned char period ) = 0;

                        /**
                         * @fn	virtual bool turnOffGreenLed() = 0;
                         * @brief	Turn off the green led.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         */
                        virtual bool turnOffGreenLed() = 0;

                        /**
                         * @fn	virtual bool turnOnBuzzer ( unsigned char period ) = 0;
                         * @brief	Turn on the buzzer.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @param	period	The period.
                         */
                        virtual bool turnOnBuzzer ( unsigned char period ) = 0;

                        /**
                         * @fn	virtual bool turnOffBuzzer() = 0;
                         * @brief	Turn off the buzzer.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         */
                        virtual bool turnOffBuzzer() = 0;

                        /**
                         * @fn	virtual bool isButtonPressed () = 0;
                         * @brief	Check if button is pressed.
                         * @author	Yadickson Soto
                         * @date	30/06/2015
                         * @return	true if button is pressed.
                         */
                        virtual bool isButtonPressed () = 0;
                };
            }
        }
    }
}

#endif // _ALARM_BOX_INTERFACE_H_

