/**
 * @file AbleDButtonState.cxx
 * @brief Body manager for all able-d button status
 * @date 30/06/2015
 * @author Yadickson Soto
 */

#include "AbleDButtonState.hxx"
#include <System/Utils/StringUtils.hxx>

using namespace Smartmatic::SAES::HW::Operation;
using namespace Smartmatic::System::Utils;

AbleDButtonState::AbleDButtonState()
{
    resetAllButtonStates();
    changed = false;
}

AbleDButtonState::~AbleDButtonState()
{

}

void AbleDButtonState::updateStatus ( ButtonType type, ButtonState state )
{
    if (buttonMap[type] != state)
    {
        resetAllButtonStates();
        buttonMap[type] = state;
        changed = true;
    }
}

AbleDButtonState::ButtonState AbleDButtonState::getStatus ( ButtonType type )
{
    return buttonMap [ type ];
}

bool AbleDButtonState::isChanged ()
{
    bool result = changed;

    changed = false;

    return result;
}

AbleDButtonState::ButtonType AbleDButtonState::stringToButtonType ( const std::string & strType )
{
    AbleDButtonState::ButtonType type = UNKNOW;
    std::string temp = StringUtils::toUpper ( StringUtils::trim ( strType ) );

    if ( temp == "HELP" )
    {
        type = HELP;
    }
    else if ( temp == "SELECT" )
    {
        type = SELECT;
    }
    else if ( temp == "UP" )
    {
        type = UP;
    }
    else if ( temp == "DOWN" )
    {
        type = DOWN;
    }
    else if ( temp == "RIGHT" )
    {
        type = RIGHT;
    }
    else if ( strType == "LEFT" )
    {
        type = LEFT;
    }
    else if ( temp == "PAUSE" )
    {
        type = PAUSE;
    }
    else if ( temp == "SPEED_UP" )
    {
        type = SPEED_UP;
    }
    else if ( temp == "SPEED_DOWN" )
    {
        type = SPEED_DOWN;
    }
    else if ( temp == "VOLUME_UP" )
    {
        type = VOLUME_UP;
    }
    else if ( temp == "VOLUME_DOWN" )
    {
        type = VOLUME_DOWN;
    }
    else if ( temp == "ACTIVATE" )
    {
        type = ACTIVATE;
    }

    return type;
}

AbleDButtonState::ButtonState AbleDButtonState::stringToButtonState ( const std::string & strStatus )
{
    AbleDButtonState::ButtonState status = NONE;
    std::string temp = StringUtils::toUpper ( StringUtils::trim ( strStatus ) );

    if ( temp == "PRESS" )
    {
        status = PRESS;
    }
    else if ( temp == "HOLD" )
    {
        status = HOLD;
    }
    else if ( temp == "RELEASE" )
    {
        status = RELEASE;
    }

    return status;
}

void AbleDButtonState::resetAllButtonStates()
{
    buttonMap[ HELP ] = NONE;
    buttonMap[ SELECT ] = NONE;
    buttonMap[ UP ] = NONE;
    buttonMap[ DOWN ] = NONE;
    buttonMap[ RIGHT ] = NONE;
    buttonMap[ LEFT ] = NONE;
    buttonMap[ PAUSE ] = NONE;
    buttonMap[ SPEED_UP ] = NONE;
    buttonMap[ SPEED_DOWN ] = NONE;
    buttonMap[ VOLUME_UP ] = NONE;
    buttonMap[ VOLUME_DOWN ] = NONE;
    buttonMap[ ACTIVATE ] = NONE;
}
