#ifndef TEST_BARCODE_CRC_COMMAND_ELEMENT_TEST
#define TEST_BARCODE_CRC_COMMAND_ELEMENT_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Commands/BarcodeCRCCommandElement.hxx>
#include <System/Utils/StringUtils.hxx>

class BarcodeCRCCommandElementTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::SAES::HW::Commands::BarcodeCRCCommandElement BarcodeCRCCommandElement;

    public:

        BarcodeCRCCommandElementTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testCRCDataEmpty()
        {
            std::vector<unsigned char> command;

            BarcodeCRCCommandElement length;

            std::string expected = "ff";
            std::string result;

            length.addToCommand ( command );

            result = StringUtils::arrayHexToString ( command );

            CPPUNIT_ASSERT ( 1 == command.size() );
            CPPUNIT_ASSERT ( expected == result );
        }

        void testCRCDataOneElement()
        {
            std::vector<unsigned char> command;

            command.push_back ( 0x33 );

            BarcodeCRCCommandElement length;

            std::string expected = "33ff";
            std::string result;

            length.addToCommand ( command );

            result = StringUtils::arrayHexToString ( command );

            CPPUNIT_ASSERT ( 2 == command.size() );
            CPPUNIT_ASSERT ( expected == result );
        }

        void testCRCDataTwoElements()
        {
            std::vector<unsigned char> command;

            command.push_back ( 0x7E );
            command.push_back ( 0x33 );

            BarcodeCRCCommandElement length;

            std::string expected = "7e33ff";
            std::string result;

            length.addToCommand ( command );

            result = StringUtils::arrayHexToString ( command );

            CPPUNIT_ASSERT ( 3 == command.size() );
            CPPUNIT_ASSERT ( expected == result );
        }

        void testCRCDataThreeElements()
        {
            std::vector<unsigned char> command;

            command.push_back ( 0x7E );
            command.push_back ( 0x00 );
            command.push_back ( 0x01 );

            BarcodeCRCCommandElement length;

            std::string expected = "7e0001fe";
            std::string result;

            length.addToCommand ( command );

            result = StringUtils::arrayHexToString ( command );

            CPPUNIT_ASSERT ( 4 == command.size() );
            CPPUNIT_ASSERT ( expected == result );
        }

        void testCRCModelCommandElements()
        {
            std::vector<unsigned char> command;

            command.push_back ( 0x7E );
            command.push_back ( 0x00 );
            command.push_back ( 0x00 );
            command.push_back ( 0x02 );
            command.push_back ( 0x33 );
            command.push_back ( 0x47 );

            BarcodeCRCCommandElement length;

            std::string expected = "7e000002334789";
            std::string result;

            length.addToCommand ( command );

            result = StringUtils::arrayHexToString ( command );

            CPPUNIT_ASSERT ( 7 == command.size() );
            CPPUNIT_ASSERT ( expected == result );
        }

        void testCRCGetSerialNumberElements()
        {
            std::vector<unsigned char> command;

            command.push_back ( 0x7E );
            command.push_back ( 0x00 );
            command.push_back ( 0x00 );
            command.push_back ( 0x05 );
            command.push_back ( 0x33 );
            command.push_back ( 0x48 );
            command.push_back ( 0x30 );
            command.push_back ( 0x32 );
            command.push_back ( 0x30 );

            BarcodeCRCCommandElement length;

            std::string expected = "7e0000053348303230b3";
            std::string result;

            length.addToCommand ( command );

            result = StringUtils::arrayHexToString ( command );

            CPPUNIT_ASSERT ( 10 == command.size() );
            CPPUNIT_ASSERT ( expected == result );
        }

        CPPUNIT_TEST_SUITE ( BarcodeCRCCommandElementTest );

        CPPUNIT_TEST ( testCRCDataEmpty );
        CPPUNIT_TEST ( testCRCDataOneElement );
        CPPUNIT_TEST ( testCRCDataTwoElements );
        CPPUNIT_TEST ( testCRCDataThreeElements );
        CPPUNIT_TEST ( testCRCModelCommandElements );
        CPPUNIT_TEST ( testCRCGetSerialNumberElements );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_BARCODE_CRC_COMMAND_ELEMENT_TEST */
