#ifndef TEST_BARCODE_MODEL_COMMAND_TEST
#define TEST_BARCODE_MODEL_COMMAND_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Commands/BarcodeModelCommand.hxx>
#include <System/Utils/StringUtils.hxx>
#include <tests/StoreMockConnection.hxx>

class BarcodeModelCommandTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::System::SafeVector<unsigned char> ResponseVector;
        typedef Smartmatic::SAES::HW::Commands::BarcodeModelCommand BarcodeModelCommand;

    public:

        BarcodeModelCommandTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testGetModelEmptyResponse()
        {
            StoreMockConnection connection;

            BarcodeModelCommand modelCommand ( &connection );
            ResponseVector response;

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == modelCommand.execute() );
            CPPUNIT_ASSERT ( "7e000002334789" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testGetModelWithResponseFail_Device_ID_Not_Found()
        {
            StoreMockConnection connection;

            BarcodeModelCommand modelCommand ( &connection );
            ResponseVector response;

            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == modelCommand.execute() );
            CPPUNIT_ASSERT ( true == modelCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "7e000002334789" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testGetModelWithResponseFail_Device_ID_Empty()
        {
            StoreMockConnection connection;

            BarcodeModelCommand modelCommand ( &connection );
            ResponseVector response;

            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 'D' );
            response.push_back ( 'e' );
            response.push_back ( 'v' );
            response.push_back ( 'i' );
            response.push_back ( 'c' );
            response.push_back ( 'e' );
            response.push_back ( ' ' );
            response.push_back ( 'I' );
            response.push_back ( 'D' );
            response.push_back ( ':' );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == modelCommand.execute() );
            CPPUNIT_ASSERT ( true == modelCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "7e000002334789" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testGetModelWithResponseSuccess()
        {
            StoreMockConnection connection;

            BarcodeModelCommand modelCommand ( &connection );
            ResponseVector response;

            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 'D' );
            response.push_back ( 'e' );
            response.push_back ( 'v' );
            response.push_back ( 'i' );
            response.push_back ( 'c' );
            response.push_back ( 'e' );
            response.push_back ( ' ' );
            response.push_back ( 'I' );
            response.push_back ( 'D' );
            response.push_back ( ':' );
            response.push_back ( ' ' );
            response.push_back ( 'h' );
            response.push_back ( 'r' );
            response.push_back ( 's' );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == modelCommand.execute() );
            CPPUNIT_ASSERT ( "hrs" == StringUtils::arrayHexToAsciiString ( modelCommand.getResponse() ) );
            CPPUNIT_ASSERT ( "7e000002334789" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        CPPUNIT_TEST_SUITE ( BarcodeModelCommandTest );

        CPPUNIT_TEST ( testGetModelEmptyResponse );
        CPPUNIT_TEST ( testGetModelWithResponseFail_Device_ID_Not_Found );
        CPPUNIT_TEST ( testGetModelWithResponseFail_Device_ID_Empty );
        CPPUNIT_TEST ( testGetModelWithResponseSuccess );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_BARCODE_MODEL_COMMAND_TEST */
