#ifndef TEST_BARCODE_SEND_CONFIG_COMMAND_TEST
#define TEST_BARCODE_SEND_CONFIG_COMMAND_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Commands/BarcodeSendConfigCommand.hxx>
#include <System/Utils/StringUtils.hxx>
#include <tests/StoreMockConnection.hxx>

class BarcodeSendConfigCommand : public Smartmatic::SAES::HW::Commands::BarcodeSendConfigCommand
{
    public:

        BarcodeSendConfigCommand ( Smartmatic::SAES::HW::Connections::IConnection * connection,
                                   const std::string & command, unsigned int retries, bool mandatory )
            : Smartmatic::SAES::HW::Commands::BarcodeSendConfigCommand ( connection, command, 0, retries, mandatory )
        {

        }
};

class BarcodeSendConfigCommandTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::System::SafeVector<unsigned char> ResponseVector;

    public:

        BarcodeSendConfigCommandTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testSendCommandFail_Mandatory_True()
        {
            StoreMockConnection connection;

            BarcodeSendConfigCommand sendConfigCommand ( &connection, "NLS0203000", 1, true );
            ResponseVector response;

            response.push_back ( 0x15 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == sendConfigCommand.execute() );
            CPPUNIT_ASSERT ( "4e4c5330323033303030" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testSendCommandFail_Mandatory_False()
        {
            StoreMockConnection connection;

            BarcodeSendConfigCommand sendConfigCommand ( &connection, "NLS0203000", 1, false );
            ResponseVector response;

            response.push_back ( 0x15 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == sendConfigCommand.execute() );
            CPPUNIT_ASSERT ( "4e4c5330323033303030" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testSendCommandSuccess_Mandatory_True()
        {
            StoreMockConnection connection;

            BarcodeSendConfigCommand sendConfigCommand ( &connection, "NLS0203000", 1, true );
            ResponseVector response;

            response.push_back ( 0x06 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == sendConfigCommand.execute() );
            CPPUNIT_ASSERT ( "4e4c5330323033303030" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        CPPUNIT_TEST_SUITE ( BarcodeSendConfigCommandTest );

        CPPUNIT_TEST ( testSendCommandFail_Mandatory_True );
        CPPUNIT_TEST ( testSendCommandFail_Mandatory_False );
        CPPUNIT_TEST ( testSendCommandSuccess_Mandatory_True );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_BARCODE_SEND_CONFIG_COMMAND_TEST */
