#ifndef TEST_COMMAND_STRUCTURE_TEST
#define TEST_COMMAND_STRUCTURE_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Commands/command-structure.h>
#include <Commands/ByteCommandElement.hxx>
#include <System/Utils/StringUtils.hxx>
#include <tests/MockConnection.hxx>
#include <tests/StoreMockConnection.hxx>
#include "MockCommandStructureBase.hxx"
#include "MockCommandStructureCore.hxx"

class CommandStructureTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::SAES::HW::Commands::CommandStructure CommandStructure;
        typedef Smartmatic::SAES::HW::Commands::ByteCommandElement ByteCommandElement;
        typedef Smartmatic::System::SafeVector<unsigned char> ResponseVector;

    public:

        CommandStructureTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testExecuteIfConnectionIsNull()
        {
            MockCommandStructureBase mock ( NULL );

            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, initialize ) initialize_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, hasResponse ) hasResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, clearCommandList, ext ) clearCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, getCommandList ) getCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, analyzeResponse ) analyzeResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, processResponse, ext ) processResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, sendCommand, ext ) sendCommand_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, getCommand, ext ) getCommand_mock ( &mock );

            initialize_mock.expects ( MOCKPP_NS::never() );
            hasResponse_mock.expects ( MOCKPP_NS::never() );
            clearCommandList_mock.expects ( MOCKPP_NS::never() );
            getCommandList_mock.expects ( MOCKPP_NS::never() );
            analyzeResponse_mock.expects ( MOCKPP_NS::never() );
            processResponse_mock.expects ( MOCKPP_NS::never() );
            sendCommand_mock.expects ( MOCKPP_NS::never() );
            getCommand_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == mock.execute() );
            CPPUNIT_ASSERT ( true == mock.getResponse().empty() );

            mock.verify();
        }

        void testExecuteWithoutHasResponse()
        {
            MockConnection connection;
            MockCommandStructureBase mock ( &connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, initialize ) initialize_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, hasResponse ) hasResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, clearCommandList, ext ) clearCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, getCommandList ) getCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, analyzeResponse ) analyzeResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, processResponse, ext ) processResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, sendCommand, ext ) sendCommand_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, getCommand, ext ) getCommand_mock ( &mock );

            initialize_mock
            .expects ( MOCKPP_NS::once() )
            .before ( "getCommandList" )
            .id ( "initialize" );

            getCommandList_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "initialize" )
            .before ( "getCommand" )
            .id ( "getCommandList" );

            getCommand_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "getCommandList" )
            .before ( "clearCommandList" )
            .id ( "getCommand" );

            clearCommandList_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "getCommand" )
            .before ( "sendCommand" )
            .id ( "clearCommandList" );

            sendCommand_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "clearCommandList" )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) )
            .id ( "sendCommand" );

            analyzeResponse_mock.expects ( MOCKPP_NS::never() );
            processResponse_mock.expects ( MOCKPP_NS::never() );

            hasResponse_mock
            .expects ( MOCKPP_NS::once () )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            CPPUNIT_ASSERT ( true == mock.execute() );
            CPPUNIT_ASSERT ( true == mock.getResponse().empty() );

            connection.verify();
            mock.verify();
        }

        void testExecuteWithoutHasResponse_ErrorSendCommand()
        {
            MockConnection connection;
            MockCommandStructureBase mock ( &connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, initialize ) initialize_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, hasResponse ) hasResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, clearCommandList, ext ) clearCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, getCommandList ) getCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, analyzeResponse ) analyzeResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, processResponse, ext ) processResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, sendCommand, ext ) sendCommand_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, getCommand, ext ) getCommand_mock ( &mock );

            initialize_mock
            .expects ( MOCKPP_NS::once() )
            .before ( "getCommandList" )
            .id ( "initialize" );

            getCommandList_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "initialize" )
            .before ( "getCommand" )
            .id ( "getCommandList" );

            getCommand_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "getCommandList" )
            .before ( "clearCommandList" )
            .id ( "getCommand" );

            clearCommandList_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "getCommand" )
            .before ( "sendCommand" )
            .id ( "clearCommandList" );

            sendCommand_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "clearCommandList" )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) )
            .id ( "sendCommand" );

            analyzeResponse_mock.expects ( MOCKPP_NS::never() );
            processResponse_mock.expects ( MOCKPP_NS::never() );

            hasResponse_mock
            .expects ( MOCKPP_NS::never () );

            CPPUNIT_ASSERT ( false == mock.execute() );
            CPPUNIT_ASSERT ( true == mock.getResponse().empty() );

            connection.verify();
            mock.verify();
        }

        void testExecuteWithHasResponse()
        {
            MockConnection connection;
            MockCommandStructureBase mock ( &connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, initialize ) initialize_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, hasResponse ) hasResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, clearCommandList, ext ) clearCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, getCommandList ) getCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, analyzeResponse ) analyzeResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, processResponse, ext ) processResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, sendCommand, ext ) sendCommand_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, getCommand, ext ) getCommand_mock ( &mock );

            initialize_mock
            .expects ( MOCKPP_NS::once() )
            .before ( "getCommandList" )
            .id ( "initialize" );

            getCommandList_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "initialize" )
            .before ( "getCommand" )
            .id ( "getCommandList" );

            getCommand_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "getCommandList" )
            .before ( "clearCommandList" )
            .id ( "getCommand" );

            clearCommandList_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "getCommand" )
            .before ( "sendCommand" )
            .id ( "clearCommandList" );

            sendCommand_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "clearCommandList" )
            .before ( "analyzeResponse" )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) )
            .id ( "sendCommand" );

            analyzeResponse_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "sendCommand" )
            .before ( "processResponse" )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) )
            .id ( "analyzeResponse" );

            processResponse_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "analyzeResponse" )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) )
            .id ( "processResponse" );

            hasResponse_mock
            .expects ( MOCKPP_NS::once () )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            CPPUNIT_ASSERT ( true == mock.execute() );
            CPPUNIT_ASSERT ( true == mock.getResponse().empty() );

            connection.verify();
            mock.verify();
        }

        void testExecuteWithHasResponse_If_analizeResponseFail()
        {
            MockConnection connection;
            MockCommandStructureBase mock ( &connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, initialize ) initialize_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, hasResponse ) hasResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, clearCommandList, ext ) clearCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, getCommandList ) getCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, analyzeResponse ) analyzeResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, processResponse, ext ) processResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, sendCommand, ext ) sendCommand_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, getCommand, ext ) getCommand_mock ( &mock );

            initialize_mock
            .expects ( MOCKPP_NS::once() )
            .before ( "getCommandList" )
            .id ( "initialize" );

            getCommandList_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "initialize" )
            .before ( "getCommand" )
            .id ( "getCommandList" );

            getCommand_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "getCommandList" )
            .before ( "clearCommandList" )
            .id ( "getCommand" );

            clearCommandList_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "getCommand" )
            .before ( "sendCommand" )
            .id ( "clearCommandList" );

            sendCommand_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "clearCommandList" )
            .before ( "analyzeResponse" )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) )
            .id ( "sendCommand" );

            analyzeResponse_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "sendCommand" )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) )
            .id ( "analyzeResponse" );

            processResponse_mock.expects ( MOCKPP_NS::never() );

            hasResponse_mock
            .expects ( MOCKPP_NS::once () )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            CPPUNIT_ASSERT ( false == mock.execute() );
            CPPUNIT_ASSERT ( true == mock.getResponse().empty() );

            connection.verify();
            mock.verify();
        }

        void testExecuteWithHasResponse_If_processResponseFail()
        {
            MockConnection connection;
            MockCommandStructureBase mock ( &connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );

            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, initialize ) initialize_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, hasResponse ) hasResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, clearCommandList, ext ) clearCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, getCommandList ) getCommandList_mock ( &mock );
            MOCKPP_CHAINER_FOR ( MockCommandStructureBase, analyzeResponse ) analyzeResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, processResponse, ext ) processResponse_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, sendCommand, ext ) sendCommand_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandStructureBase, getCommand, ext ) getCommand_mock ( &mock );

            initialize_mock
            .expects ( MOCKPP_NS::once() )
            .before ( "getCommandList" )
            .id ( "initialize" );

            getCommandList_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "initialize" )
            .before ( "getCommand" )
            .id ( "getCommandList" );

            getCommand_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "getCommandList" )
            .before ( "clearCommandList" )
            .id ( "getCommand" );

            clearCommandList_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "getCommand" )
            .before ( "sendCommand" )
            .id ( "clearCommandList" );

            sendCommand_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "clearCommandList" )
            .before ( "analyzeResponse" )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) )
            .id ( "sendCommand" );

            analyzeResponse_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "sendCommand" )
            .before ( "processResponse" )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) )
            .id ( "analyzeResponse" );

            processResponse_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "analyzeResponse" )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) )
            .id ( "processResponse" );

            hasResponse_mock
            .expects ( MOCKPP_NS::once () )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            CPPUNIT_ASSERT ( false == mock.execute() );
            CPPUNIT_ASSERT ( true == mock.getResponse().empty() );

            connection.verify();
            mock.verify();
        }

        void testExecuteWithoutHasResponse_SendError()
        {
            MockConnection connection;
            MockCommandStructureCore mock ( &connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );

            Send_mock
            .expects ( MOCKPP_NS::once () )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            MOCKPP_CHAINER_FOR ( MockCommandStructureCore, initialize ) initialize_mock ( &mock );

            initialize_mock
            .expects ( MOCKPP_NS::once() );

            CPPUNIT_ASSERT ( false == mock.execute() );
            CPPUNIT_ASSERT ( true == mock.getResponse().empty() );

            connection.verify();
            mock.verify();
        }

        void testExecuteWithHasResponse_SendOk_ReadError()
        {
            MockConnection connection;
            MockCommandStructureCore mock ( &connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( &connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            Read_mock
            .expects ( MOCKPP_NS::once() );

            Send_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            MOCKPP_CHAINER_FOR ( MockCommandStructureCore, initialize ) initialize_mock ( &mock );

            initialize_mock
            .expects ( MOCKPP_NS::once() );

            CPPUNIT_ASSERT ( false == mock.execute() );
            CPPUNIT_ASSERT ( true == mock.getResponse().empty() );

            connection.verify();
            mock.verify();
        }

        void testExecuteWithHasResponse_SendOk_ReadOk()
        {
            StoreMockConnection connection;
            MockCommandStructureCore mock ( &connection );
            ResponseVector response;

            response.push_back ( 0x00 );
            response.push_back ( 0x02 );
            response.push_back ( 0x03 );
            response.push_back ( 0x04 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            mock.commands.push_back ( new ByteCommandElement ( 0xAA ) );
            mock.commands.push_back ( new ByteCommandElement ( 0xBC ) );
            mock.commands.push_back ( new ByteCommandElement ( 0x0f ) );

            MOCKPP_CHAINER_FOR ( MockCommandStructureCore, initialize ) initialize_mock ( &mock );

            initialize_mock
            .expects ( MOCKPP_NS::once() );

            CPPUNIT_ASSERT ( true == mock.execute() );

            CPPUNIT_ASSERT ( false == mock.getResponse().empty() );
            CPPUNIT_ASSERT ( 4 == mock.getResponse().size() );
            CPPUNIT_ASSERT ( "aabc0f" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
            mock.verify();
        }

        CPPUNIT_TEST_SUITE ( CommandStructureTest );

        CPPUNIT_TEST ( testExecuteIfConnectionIsNull );
        CPPUNIT_TEST ( testExecuteWithoutHasResponse );
        CPPUNIT_TEST ( testExecuteWithoutHasResponse_ErrorSendCommand );

        CPPUNIT_TEST ( testExecuteWithHasResponse );
        CPPUNIT_TEST ( testExecuteWithHasResponse_If_analizeResponseFail );
        CPPUNIT_TEST ( testExecuteWithHasResponse_If_processResponseFail );

        CPPUNIT_TEST ( testExecuteWithoutHasResponse_SendError );
        CPPUNIT_TEST ( testExecuteWithHasResponse_SendOk_ReadError );
        CPPUNIT_TEST ( testExecuteWithHasResponse_SendOk_ReadOk );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_COMMAND_STRUCTURE_TEST */
