#ifndef TEST_DATA_COMMAND_ELEMENT_TEST
#define TEST_DATA_COMMAND_ELEMENT_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Commands/DataCommandElement.hxx>
#include <System/Utils/StringUtils.hxx>

class DataCommandElementTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::SAES::HW::Commands::DataCommandElement DataCommandElement;

    public:

        DataCommandElementTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testInputDataEmpty()
        {
            std::vector<unsigned char> input;
            std::vector<unsigned char> command;

            DataCommandElement dataElement ( input );

            dataElement.addToCommand ( command );

            CPPUNIT_ASSERT ( true == command.empty() );
        }

        void testInputData_OneByte()
        {
            std::vector<unsigned char> input;
            std::vector<unsigned char> command;

            input.push_back ( 0xFF );

            DataCommandElement dataElement ( input );

            std::string expected = "ff";
            std::string result;

            dataElement.addToCommand ( command );

            result = StringUtils::arrayHexToString ( command );

            CPPUNIT_ASSERT ( false == command.empty() );
            CPPUNIT_ASSERT ( expected == result );
        }

        void testInputData_TwoByte()
        {
            std::vector<unsigned char> input;
            std::vector<unsigned char> command;

            input.push_back ( 0xFF );
            input.push_back ( 0xA0 );

            DataCommandElement dataElement ( input );

            std::string expected = "ffa0";
            std::string result;

            dataElement.addToCommand ( command );

            result = StringUtils::arrayHexToString ( command );

            CPPUNIT_ASSERT ( false == command.empty() );
            CPPUNIT_ASSERT ( expected == result );
        }

        void testInputData_TwoByte_TwoCalls()
        {
            std::vector<unsigned char> input;
            std::vector<unsigned char> command;

            input.push_back ( 0xFF );
            input.push_back ( 0xA0 );

            DataCommandElement dataElement ( input );

            std::string expected = "ffa0ffa0";
            std::string result;

            dataElement.addToCommand ( command );
            dataElement.addToCommand ( command );

            result = StringUtils::arrayHexToString ( command );

            CPPUNIT_ASSERT ( false == command.empty() );
            CPPUNIT_ASSERT ( expected == result );
        }

        CPPUNIT_TEST_SUITE ( DataCommandElementTest );

        CPPUNIT_TEST ( testInputDataEmpty );
        CPPUNIT_TEST ( testInputData_OneByte );
        CPPUNIT_TEST ( testInputData_TwoByte );
        CPPUNIT_TEST ( testInputData_TwoByte_TwoCalls );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_DATA_COMMAND_ELEMENT_TEST */
