#ifndef TEST_P168A_BOARD_MODEL_NAME_TEST
#define TEST_P168A_BOARD_MODEL_NAME_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Commands/P168ABoardModelNameCommand.hxx>
#include <System/Utils/StringUtils.hxx>
#include <tests/StoreMockConnection.hxx>

class P168ABoardModelNameCommandTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::System::SafeVector<unsigned char> ResponseVector;
        typedef Smartmatic::SAES::HW::Commands::P168ABoardModelNameCommand P168ABoardModelNameCommand;

    public:

        P168ABoardModelNameCommandTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testGetBoardModelFail()
        {
            StoreMockConnection connection;
            P168ABoardModelNameCommand boardModelCommand ( &connection );
            ResponseVector response;

            response.push_back ( 0x00 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == boardModelCommand.execute() );
            CPPUNIT_ASSERT ( true == boardModelCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b00" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testGetBoardModelFail_Header_Fail()
        {
            StoreMockConnection connection;
            P168ABoardModelNameCommand boardModelCommand ( &connection );
            ResponseVector response;

            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x01 );
            response.push_back ( 0xff );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == boardModelCommand.execute() );
            CPPUNIT_ASSERT ( true == boardModelCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b00" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testGetBoardModelFail_Command_Fail()
        {
            StoreMockConnection connection;
            P168ABoardModelNameCommand boardModelCommand ( &connection );
            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x01 );
            response.push_back ( 0x01 );
            response.push_back ( 0xff );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == boardModelCommand.execute() );
            CPPUNIT_ASSERT ( true == boardModelCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b00" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testGetBoardModelFail_Length_Zero()
        {
            StoreMockConnection connection;
            P168ABoardModelNameCommand boardModelCommand ( &connection );
            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0xff );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( false == boardModelCommand.execute() );
            CPPUNIT_ASSERT ( true == boardModelCommand.getResponse().empty() );
            CPPUNIT_ASSERT ( "1b00" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testGetBoardModelSuccess()
        {
            StoreMockConnection connection;
            P168ABoardModelNameCommand boardModelCommand ( &connection );
            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x00 );
            response.push_back ( 0x05 );
            response.push_back ( 'P' );
            response.push_back ( '1' );
            response.push_back ( '6' );
            response.push_back ( '8' );
            response.push_back ( 'A' );
            response.push_back ( 0x00 );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == boardModelCommand.execute() );
            CPPUNIT_ASSERT ( "P168A" == StringUtils::arrayHexToAsciiString ( boardModelCommand.getResponse() ) );
            CPPUNIT_ASSERT ( "1b00" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        CPPUNIT_TEST_SUITE ( P168ABoardModelNameCommandTest );

        CPPUNIT_TEST ( testGetBoardModelFail );
        CPPUNIT_TEST ( testGetBoardModelFail_Header_Fail );
        CPPUNIT_TEST ( testGetBoardModelFail_Command_Fail );
        CPPUNIT_TEST ( testGetBoardModelFail_Length_Zero );
        CPPUNIT_TEST ( testGetBoardModelSuccess );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_P168A_BOARD_MODEL_NAME_TEST */
