#ifndef TEST_P168A_WRITE_MEMORY_TEST
#define TEST_P168A_WRITE_MEMORY_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Commands/P168AWriteMemoryCommand.hxx>
#include <System/Utils/StringUtils.hxx>
#include <tests/StoreMockConnection.hxx>

class P168AWriteMemoryCommandTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::SAES::HW::Commands::P168AWriteMemoryCommand P168AWriteMemoryCommand;
        typedef Smartmatic::System::SafeVector<unsigned char> ResponseVector;

    public:

        P168AWriteMemoryCommandTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testWriteMemoryTo_0x80_0x00_empty_success()
        {
            StoreMockConnection connection;
            std::vector <unsigned char> data;
            ResponseVector response;
            P168AWriteMemoryCommand writeCommand ( &connection, 0x80, 0x00, data );

            response.push_back ( 0x1B );
            response.push_back ( 0x1D );
            response.push_back ( 0x80 );
            response.push_back ( 0x00 );
            response.push_back ( 0x01 );
            response.push_back ( 0xAA );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<unsigned int> ( 100 ) );

            CPPUNIT_ASSERT ( true == writeCommand.execute() );
            CPPUNIT_ASSERT ( "1b1d800000" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        void testWriteMemoryTo_0x80_0x00_four_elements_success()
        {
            StoreMockConnection connection;
            std::vector <unsigned char> data;
            ResponseVector response;

            data.push_back ( 0xA1 );
            data.push_back ( 0xB2 );
            data.push_back ( 0xC3 );
            data.push_back ( 0xD4 );

            P168AWriteMemoryCommand writeCommand ( &connection, 0x80, 0x00, data );

            response.push_back ( 0x1B );
            response.push_back ( 0x1D );
            response.push_back ( 0x80 );
            response.push_back ( 0x00 );
            response.push_back ( 0x01 );
            response.push_back ( 0xAA );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( &connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, getTimeOut ) TimeOut_mock ( &connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<unsigned int> ( 100 ) );

            CPPUNIT_ASSERT ( true == writeCommand.execute() );
            CPPUNIT_ASSERT ( "1b1d800004a1b2c3d4" == StringUtils::arrayHexToString ( connection.sendBuffer ) );

            connection.verify();
        }

        CPPUNIT_TEST_SUITE ( P168AWriteMemoryCommandTest );

        CPPUNIT_TEST ( testWriteMemoryTo_0x80_0x00_empty_success );
        CPPUNIT_TEST ( testWriteMemoryTo_0x80_0x00_four_elements_success );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_P168A_WRITE_MEMORY_TEST */
