#ifndef TEST_ALARM_BOX_CONF_MANAGER_TEST
#define TEST_ALARM_BOX_CONF_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Configuration/configuration-persistence-manager.h>
#include <Configuration/AlarmBoxConfigurationManager.hxx>
#include <tests/MockSAESHWConfigurationManager.hxx>
#include <tests/MockConfigurationPersistenceManager.hxx>
#include <tests/StoreMockAlarmBoxConfManager.hxx>
#include <tests/MockProcessLauncher.hxx>
#include <tests/MockExitProcess.hxx>

class AlarmBoxConfManagerTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::SAES::HW::Configuration::AlarmBoxConfigurationManager AlarmBoxConfigurationManager;
        typedef Smartmatic::SAES::HW::Configuration::SAESHardwareConfigurationManager SAESHardwareConfigurationManager;
        typedef Smartmatic::Configuration::ConfigurationPersistenceManager ConfigurationPersistenceManager;
        typedef Smartmatic::System::Runtime::ProcessLauncher ProcessLauncher;
        typedef Smartmatic::System::Runtime::ExitProcess ExitProcess;

        AlarmBoxConfManagerTest()
        {
        }

        void setUp()
        {
        }

        void tearDown()
        {
        }

        void testGetDefaultConfiguration_ConfigurationIsEmpty()
        {
            MockConfigurationPersistenceManager manager;
            MockProcessLauncher launcher;
            MockExitProcess exitProcess;
            MockSAESHWConfigurationManager saeshwManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &manager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            ExitProcess::getInstance ( &exitProcess );
            ProcessLauncher::getInstance ( &launcher );
            ConfigurationPersistenceManager::getInstance ( &manager );
            SAESHardwareConfigurationManager::getInstance ( &saeshwManager );

            SAESHardwareConfigurationManager::getInstance()->getConfiguration()->getAlarmBoxConfiguration().reset();

            AlarmBoxConfigurationManager * alarmBoxManager = AlarmBoxConfigurationManager::getInstance();

            CPPUNIT_ASSERT ( false == alarmBoxManager->simulationEnabled() );
            CPPUNIT_ASSERT ( true == alarmBoxManager->getAlarmBoxPingFile().empty() );
            CPPUNIT_ASSERT ( true == alarmBoxManager->getAlarmBoxButtonFile().empty() );
            CPPUNIT_ASSERT ( true == alarmBoxManager->getAlarmBoxBehaviorFile().empty() );

            manager.verify();
            launcher.verify();
            exitProcess.verify();

            delete alarmBoxManager;
        }

        void testGetDefaultConfiguration_MockConfigurationIsEmpty()
        {
            StoreMockAlarmBoxConfManager mock;
            AlarmBoxConfigurationManager * alarmBoxManager = AlarmBoxConfigurationManager::getInstance ( &mock );

            CPPUNIT_ASSERT ( false == alarmBoxManager->simulationEnabled() );
            CPPUNIT_ASSERT ( true == alarmBoxManager->getAlarmBoxPingFile().empty() );
            CPPUNIT_ASSERT ( true == alarmBoxManager->getAlarmBoxButtonFile().empty() );
            CPPUNIT_ASSERT ( true == alarmBoxManager->getAlarmBoxBehaviorFile().empty() );
        }

        void testGetConfigurationValues()
        {
            StoreMockAlarmBoxConfManager mock;
            AlarmBoxConfigurationManager * alarmBoxManager = AlarmBoxConfigurationManager::getInstance ( &mock );

            mock.config.setAlarmBoxPingFile ( "ping" );
            mock.config.setAlarmBoxButtonFile ( "" );
            mock.config.setAlarmBoxBehaviorFile ( "" );

            CPPUNIT_ASSERT ( false == alarmBoxManager->simulationEnabled() );
            CPPUNIT_ASSERT ( "ping" == alarmBoxManager->getAlarmBoxPingFile() );
            CPPUNIT_ASSERT ( true == alarmBoxManager->getAlarmBoxButtonFile().empty() );
            CPPUNIT_ASSERT ( true == alarmBoxManager->getAlarmBoxBehaviorFile().empty() );

            mock.config.setAlarmBoxPingFile ( "ping" );
            mock.config.setAlarmBoxButtonFile ( "button" );
            mock.config.setAlarmBoxBehaviorFile ( "" );

            CPPUNIT_ASSERT ( false == alarmBoxManager->simulationEnabled() );
            CPPUNIT_ASSERT ( "ping" == alarmBoxManager->getAlarmBoxPingFile() );
            CPPUNIT_ASSERT ( "button" == alarmBoxManager->getAlarmBoxButtonFile() );
            CPPUNIT_ASSERT ( true == alarmBoxManager->getAlarmBoxBehaviorFile().empty() );

            mock.config.setAlarmBoxPingFile ( "ping" );
            mock.config.setAlarmBoxButtonFile ( "button" );
            mock.config.setAlarmBoxBehaviorFile ( "behavior" );

            CPPUNIT_ASSERT ( true == alarmBoxManager->simulationEnabled() );
            CPPUNIT_ASSERT ( "ping" == alarmBoxManager->getAlarmBoxPingFile() );
            CPPUNIT_ASSERT ( "button" == alarmBoxManager->getAlarmBoxButtonFile() );
            CPPUNIT_ASSERT ( "behavior" == alarmBoxManager->getAlarmBoxBehaviorFile() );
        }

        CPPUNIT_TEST_SUITE ( AlarmBoxConfManagerTest );

        CPPUNIT_TEST ( testGetDefaultConfiguration_ConfigurationIsEmpty );
        CPPUNIT_TEST ( testGetDefaultConfiguration_MockConfigurationIsEmpty );
        CPPUNIT_TEST ( testGetConfigurationValues );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_ALARM_BOX_CONF_MANAGER_TEST */
