#ifndef TEST_SERIAL_PORT_CONNECTION_TEST
#define TEST_SERIAL_PORT_CONNECTION_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Connections/SerialPortConnection.hxx>
#include <tests/StoreMockConnection.hxx>
#include <tests/MockConnection.hxx>
#include <tests/MockPeekListener.hxx>
#include <System/Utils/StringUtils.hxx>

class SerialPortConnectionTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::SAES::HW::Connections::SerialPortConnection SerialPortConnection;
        typedef Smartmatic::System::SafeVector<unsigned char> ResponseVector;

    public:

        SerialPortConnectionTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testOpenConnectionFail ()
        {
            MockConnection * connection = new MockConnection();
            SerialPortConnection serialPort ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == serialPort.openConnection ( "" ) );

            connection->verify();
        }

        void testOpenConnectionSuccess ()
        {
            MockConnection * connection = new MockConnection();
            SerialPortConnection serialPort ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == serialPort.openConnection ( "" ) );

            connection->verify();
        }

        void testSendCommandFail ()
        {
            MockConnection * connection = new MockConnection();
            SerialPortConnection serialPort ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );

            ResponseVector data;

            data.push_back ( 0xAA );
            data.push_back ( 0xBB );

            CPPUNIT_ASSERT ( false == serialPort.sendCommand ( data ) );

            connection->verify();
        }

        void testSendCommandSuccess ()
        {
            MockConnection * connection = new MockConnection();
            SerialPortConnection serialPort ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );

            ResponseVector data;

            data.push_back ( 0xAA );
            data.push_back ( 0xBB );

            CPPUNIT_ASSERT ( true == serialPort.sendCommand ( data ) );

            connection->verify();
        }

        void testSendCommandCheckSendData ()
        {
            StoreMockConnection * connection = new StoreMockConnection();
            SerialPortConnection serialPort ( connection );

            ResponseVector response;

            response.push_back ( 0xAA );
            response.push_back ( 0xBB );

            MOCKPP_CHAINER_FOR_EXT ( StoreMockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( StoreMockConnection, closeConnection ) Close_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );

            ResponseVector data;

            data.push_back ( 0xAA );
            data.push_back ( 0xBB );

            CPPUNIT_ASSERT ( true == serialPort.sendCommand ( data ) );
            CPPUNIT_ASSERT ( "aabb" == StringUtils::arrayHexToString ( connection->sendBuffer ) );
            connection->verify();
        }

        void testReadEmptyBuffer ()
        {
            MockConnection * connection = new MockConnection();
            SerialPortConnection serialPort ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) getTimeOut_mock ( connection );

            ResponseVector response;

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            getTimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<unsigned int> ( 0 ) );

            CPPUNIT_ASSERT ( true == serialPort.readBuffer().empty() );

            connection->verify();
        }

        void testReadOneBuffer ()
        {
            MockConnection * connection = new MockConnection();
            SerialPortConnection serialPort ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) getTimeOut_mock ( connection );

            ResponseVector emptyBuffer;
            ResponseVector dataBuffer;

            dataBuffer.push_back ( 0xAB );
            dataBuffer.push_back ( 0xCD );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::atLeastOnce() )
            .will (
                MOCKPP_NS::onConsecutiveCalls (
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( emptyBuffer ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( dataBuffer ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( emptyBuffer ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( emptyBuffer ) )
            );

            Close_mock.expects ( MOCKPP_NS::never() );
            getTimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<unsigned int> ( 0 ) );

            ResponseVector response = serialPort.readBuffer();

            CPPUNIT_ASSERT ( false == response.empty() );
            CPPUNIT_ASSERT ( "abcd" == StringUtils::arrayHexToString ( response ) );

            connection->verify();
        }

        void testReadTwoBuffer ()
        {
            MockConnection * connection = new MockConnection();
            SerialPortConnection serialPort ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) getTimeOut_mock ( connection );

            ResponseVector emptyBuffer;
            ResponseVector dataBuffer1;
            ResponseVector dataBuffer2;

            dataBuffer1.push_back ( 0xAB );
            dataBuffer1.push_back ( 0xCD );

            dataBuffer2.push_back ( 0x00 );
            dataBuffer2.push_back ( 0x11 );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::atLeastOnce() )
            .will (
                MOCKPP_NS::onConsecutiveCalls (
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( emptyBuffer ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( dataBuffer1 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( emptyBuffer ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( dataBuffer2 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( emptyBuffer ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( emptyBuffer ) )
            );

            Close_mock.expects ( MOCKPP_NS::never() );
            getTimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<unsigned int> ( 0 ) );

            ResponseVector response = serialPort.readBuffer();

            CPPUNIT_ASSERT ( false == response.empty() );
            CPPUNIT_ASSERT ( "abcd0011" == StringUtils::arrayHexToString ( response ) );

            connection->verify();
        }

        void testReadOneBufferWithListener ()
        {
            MockConnection * connection = new MockConnection();
            MockPeekListener listener;
            SerialPortConnection serialPort ( connection );
            serialPort.setListener ( &listener );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) getTimeOut_mock ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockPeekListener, peekEvent, ext ) peekEvent_mock ( &listener );

            ResponseVector emptyBuffer;
            ResponseVector dataBuffer;

            dataBuffer.push_back ( 0xAB );
            dataBuffer.push_back ( 0xCD );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::atLeastOnce() )
            .will (
                MOCKPP_NS::onConsecutiveCalls (
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( emptyBuffer ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( dataBuffer ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( emptyBuffer ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( emptyBuffer ) )
            );

            Close_mock.expects ( MOCKPP_NS::never() );
            getTimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<unsigned int> ( 0 ) );

            peekEvent_mock.expects ( MOCKPP_NS::once() );

            ResponseVector response = serialPort.readBuffer();

            CPPUNIT_ASSERT ( false == response.empty() );
            CPPUNIT_ASSERT ( "abcd" == StringUtils::arrayHexToString ( response ) );

            connection->verify();
            peekEvent_mock.verify();
        }

        void testCloseConnectionFail ()
        {
            MockConnection * connection = new MockConnection();
            SerialPortConnection serialPort ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );

            CPPUNIT_ASSERT ( false == serialPort.closeConnection() );

            connection->verify();
        }

        void testCloseConnectionSuccess ()
        {
            MockConnection * connection = new MockConnection();
            SerialPortConnection serialPort ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );

            CPPUNIT_ASSERT ( true == serialPort.closeConnection() );

            connection->verify();
        }

        CPPUNIT_TEST_SUITE ( SerialPortConnectionTest );

        CPPUNIT_TEST ( testOpenConnectionFail );
        CPPUNIT_TEST ( testOpenConnectionSuccess );

        CPPUNIT_TEST ( testSendCommandFail );
        CPPUNIT_TEST ( testSendCommandSuccess );
        CPPUNIT_TEST ( testSendCommandCheckSendData );

        CPPUNIT_TEST ( testReadEmptyBuffer );
        CPPUNIT_TEST ( testReadOneBuffer );
        CPPUNIT_TEST ( testReadTwoBuffer );
        CPPUNIT_TEST ( testReadOneBufferWithListener );

        CPPUNIT_TEST ( testCloseConnectionFail );
        CPPUNIT_TEST ( testCloseConnectionSuccess );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_SERIAL_PORT_CONNECTION_TEST */
