#ifndef TEST_ALARM_BOX_DEVICE_TEST
#define TEST_ALARM_BOX_DEVICE_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Devices/AlarmBoxDevice.hxx>
#include <tests/MockConnection.hxx>
#include <tests/MockSerialPortConnection.hxx>
#include <System/Utils/StringUtils.hxx>

class AlarmBoxDeviceTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::SAES::HW::Devices::AlarmBoxDevice AlarmBoxDevice;
        typedef Smartmatic::System::SafeVector<unsigned char> ResponseVector;

    public:

        AlarmBoxDeviceTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testOpenConnectionFail ()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.open ( "" ) );

            connection->verify();
        }

        void testOpenConnectionSuccess ()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == device.open ( "" ) );

            connection->verify();
        }

        void testCloseConnectionFail ()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.close() );

            connection->verify();
        }

        void testCloseConnectionSuccess ()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == device.close() );

            connection->verify();
        }

        void testSendPingFail()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.sendPing() );

            connection->verify();
        }

        void testSendPingSuccess()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response;
            response.push_back ( 0x55 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0xAA );

            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == device.sendPing() );

            connection->verify();
        }

        void testOnRedLedFail()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.turnOnRedLed ( 0x20 ) );

            connection->verify();
        }

        void testOnRedLedSuccess()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response;
            response.push_back ( 0x00 );

            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == device.turnOnRedLed ( 0x20 ) );

            connection->verify();
        }

        void testOffRedLedFail()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.turnOffRedLed() );

            connection->verify();
        }

        void testOffRedLedSuccess()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response;
            response.push_back ( 0x00 );

            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == device.turnOffRedLed() );

            connection->verify();
        }

        void testOnGreenLedFail()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.turnOnGreenLed ( 0x20 ) );

            connection->verify();
        }

        void testOnGreenLedSuccess()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response;
            response.push_back ( 0x00 );

            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == device.turnOnGreenLed ( 0x20 ) );

            connection->verify();
        }

        void testOffGreenLedFail()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.turnOffGreenLed() );

            connection->verify();
        }

        void testOffGreenLedSuccess()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response;
            response.push_back ( 0x00 );

            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == device.turnOffGreenLed() );

            connection->verify();
        }

        void testOnBuzzerFail()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.turnOnBuzzer ( 0x20 ) );

            connection->verify();
        }

        void testOnBuzzerSuccess()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response;
            response.push_back ( 0x00 );

            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == device.turnOnBuzzer ( 0x20 ) );

            connection->verify();
        }

        void testOffBuzzerFail()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.turnOffBuzzer() );

            connection->verify();
        }

        void testOffBuzzerSuccess()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response;
            response.push_back ( 0x00 );

            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( true == device.turnOffBuzzer() );

            connection->verify();
        }

        void testButtonPressedEmptyResponseFalse()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response;

            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Send_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.isButtonPressed() );

            connection->verify();
        }

        void testButtonPressedMultiResponse()
        {
            MockConnection * connection = new MockConnection();
            AlarmBoxDevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector responseFail1;
            ResponseVector responseFail2;
            ResponseVector responseFail3;
            ResponseVector responseFail4;
            ResponseVector responseFail5;
            ResponseVector responseFail6;

            responseFail1.push_back ( 0x00 );
            responseFail1.push_back ( 0x00 );
            responseFail1.push_back ( 0x00 );
            responseFail1.push_back ( 0x00 );
            responseFail1.push_back ( 0x00 );

            responseFail2.push_back ( 0x55 );
            responseFail2.push_back ( 0xA1 );
            responseFail2.push_back ( 0x00 );
            responseFail2.push_back ( 0x00 );
            responseFail2.push_back ( 0xAB );

            responseFail3.push_back ( 0x55 );
            responseFail3.push_back ( 0xA1 );
            responseFail3.push_back ( 0x00 );
            responseFail3.push_back ( 0x01 );
            responseFail3.push_back ( 0xAA );

            responseFail4.push_back ( 0x55 );
            responseFail4.push_back ( 0xA1 );
            responseFail4.push_back ( 0x01 );
            responseFail4.push_back ( 0x00 );
            responseFail4.push_back ( 0xAA );

            responseFail5.push_back ( 0x55 );
            responseFail5.push_back ( 0xA2 );
            responseFail5.push_back ( 0x00 );
            responseFail5.push_back ( 0x00 );
            responseFail5.push_back ( 0xAA );

            responseFail6.push_back ( 0x55 );
            responseFail6.push_back ( 0xA1 );
            responseFail6.push_back ( 0x00 );
            responseFail6.push_back ( 0x00 );
            responseFail6.push_back ( 0xAA );

            Read_mock
            .expects ( MOCKPP_NS::exactly ( 6 ) )
            .will (
                MOCKPP_NS::onConsecutiveCalls (
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( responseFail1 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( responseFail2 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( responseFail3 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( responseFail4 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( responseFail5 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( responseFail6 ) )
            );

            Send_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.isButtonPressed() );
            CPPUNIT_ASSERT ( false == device.isButtonPressed() );
            CPPUNIT_ASSERT ( false == device.isButtonPressed() );
            CPPUNIT_ASSERT ( false == device.isButtonPressed() );
            CPPUNIT_ASSERT ( false == device.isButtonPressed() );
            CPPUNIT_ASSERT ( true == device.isButtonPressed() );

            connection->verify();
        }

        CPPUNIT_TEST_SUITE ( AlarmBoxDeviceTest );

        CPPUNIT_TEST ( testOpenConnectionFail );
        CPPUNIT_TEST ( testOpenConnectionSuccess );

        CPPUNIT_TEST ( testCloseConnectionFail );
        CPPUNIT_TEST ( testCloseConnectionSuccess );

        CPPUNIT_TEST ( testSendPingFail );
        CPPUNIT_TEST ( testSendPingSuccess );

        CPPUNIT_TEST ( testOnRedLedFail );
        CPPUNIT_TEST ( testOnRedLedSuccess );

        CPPUNIT_TEST ( testOffRedLedFail );
        CPPUNIT_TEST ( testOffRedLedSuccess );

        CPPUNIT_TEST ( testOnGreenLedFail );
        CPPUNIT_TEST ( testOnGreenLedSuccess );

        CPPUNIT_TEST ( testOffGreenLedFail );
        CPPUNIT_TEST ( testOffGreenLedSuccess );

        CPPUNIT_TEST ( testOnBuzzerFail );
        CPPUNIT_TEST ( testOnBuzzerSuccess );

        CPPUNIT_TEST ( testOffBuzzerFail );
        CPPUNIT_TEST ( testOffBuzzerSuccess );

        CPPUNIT_TEST ( testButtonPressedEmptyResponseFalse );
        CPPUNIT_TEST ( testButtonPressedMultiResponse );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_ALARM_BOX_DEVICE_TEST */
