#ifndef TEST_P168A_DEVICE_TEST
#define TEST_P168A_DEVICE_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Devices/P168ADevice.hxx>
#include <tests/MockConnection.hxx>
#include <tests/MockSerialPortConnection.hxx>
#include <tests/MockBarcodeReaderDevice.hxx>
#include <System/Utils/StringUtils.hxx>

class P168ADeviceTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Utils::StringUtils StringUtils;
        typedef Smartmatic::SAES::HW::Devices::P168ADevice P168ADevice;
        typedef Smartmatic::System::SafeVector<unsigned char> ResponseVector;
        typedef Smartmatic::System::SafeBuffer SafeBuffer;
        typedef Smartmatic::SAES::HW::Operation::AbleDButtonState AbleDButtonState;

    public:

        P168ADeviceTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testOpenConnectionFail ()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.open ( "" ) );

            connection->verify();
        }

        void testOpenConnectionSuccess ()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );
            ResponseVector response;

            response.push_back ( 0x1B );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Close_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<unsigned int> ( 100 ) );

            CPPUNIT_ASSERT ( true == device.open ( "" ) );

            connection->verify();
        }

        void testCloseConnectionFail ()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.close() );

            connection->verify();
        }

        void testCloseConnectionSuccess ()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );

            MOCKPP_CHAINER_FOR_EXT ( MockConnection, openConnection, ext ) Open_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, closeConnection ) Close_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Open_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::never() );
            Read_mock.expects ( MOCKPP_NS::never() );
            Close_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == device.close() );

            connection->verify();
        }

        void testGetSerialMachineFail()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( true == device.getSerialMachine().empty() );

            connection->verify();
        }

        void testGetSerialMachineSuccess()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );

            ResponseVector response;

            response.push_back ( 0x1B );
            response.push_back ( 0x1C );
            response.push_back ( 0x80 );
            response.push_back ( 0x00 );
            response.push_back ( 0x10 );
            response.push_back ( 'P' );
            response.push_back ( '5' );
            response.push_back ( '0' );
            response.push_back ( 'V' );
            response.push_back ( 'M' );
            response.push_back ( '3' );
            response.push_back ( 'A' );
            response.push_back ( 'A' );
            response.push_back ( '0' );
            response.push_back ( '0' );
            response.push_back ( '0' );
            response.push_back ( '0' );
            response.push_back ( '7' );
            response.push_back ( '8' );
            response.push_back ( '4' );
            response.push_back ( '3' );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );
            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            TimeOut_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue < unsigned int > ( 0 ) );

            CPPUNIT_ASSERT ( "P50VM3AA00007843" == device.getSerialMachine() );

            connection->verify();
        }

        void testSetSerialMachineFail()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Read_mock.expects ( MOCKPP_NS::never() );
            Send_mock.expects ( MOCKPP_NS::atLeastOnce() ).will ( MOCKPP_NS::returnValue<bool> ( false ) );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            CPPUNIT_ASSERT ( false == device.setSerialMachine ( "P50VM1234" ) );

            connection->verify();
        }

        void testSetSerialMachineSuccess()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );
            ResponseVector response;

            response.push_back ( 0x1B );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            Send_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<bool> ( true ) );
            TimeOut_mock.expects ( MOCKPP_NS::once() ).will ( MOCKPP_NS::returnValue<unsigned int> ( 100 ) );
            Read_mock.expects ( MOCKPP_NS::once() ).will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );

            CPPUNIT_ASSERT ( true == device.setSerialMachine ( "P50VM1234" ) );

            connection->verify();
        }

        void testGetButtonStateResponseFail()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response;

            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );
            response.push_back ( 0x00 );

            Read_mock
            .expects ( MOCKPP_NS::atLeastOnce() )
            .will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );

            Send_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            AbleDButtonState * state;

            state = device.getAbleDButtonState();
            CPPUNIT_ASSERT ( false == state->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::SELECT ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::UP ) );

            connection->verify();
        }

        void testGetButtonStateResponseOneButton()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response;

            response.push_back ( 0x1B );  // Good
            response.push_back ( 0x64 );
            response.push_back ( 0x02 );
            response.push_back ( 0x31 );  // Help
            response.push_back ( 0x01 );  // Press

            Read_mock
            .expects ( MOCKPP_NS::atLeastOnce() )
            .will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );

            Send_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            AbleDButtonState * state;

            state = device.getAbleDButtonState();
            CPPUNIT_ASSERT ( true == state->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::PRESS == state->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::SELECT ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::UP ) );

            connection->verify();
        }

        void testGetButtonStateResponseTwoButton()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response;

            response.push_back ( 0x1B );  // Good
            response.push_back ( 0x64 );
            response.push_back ( 0x02 );
            response.push_back ( 0x31 );  // Help
            response.push_back ( 0x01 );  // Press

            response.push_back ( 0x1B );  // Good
            response.push_back ( 0x64 );
            response.push_back ( 0x02 );
            response.push_back ( 0x32 );  // Select
            response.push_back ( 0x01 );  // Press

            Read_mock
            .expects ( MOCKPP_NS::atLeastOnce() )
            .will ( new MOCKPP_NS::ReturnStub< ResponseVector > ( response ) );

            Send_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            AbleDButtonState * state;

            state = device.getAbleDButtonState();
            CPPUNIT_ASSERT ( true == state->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( AbleDButtonState::PRESS == state->getStatus ( AbleDButtonState::SELECT ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::UP ) );

            connection->verify();
        }

        void testGetButtonState()
        {
            MockConnection * connection = new MockConnection();
            P168ADevice device ( connection );

            MOCKPP_CHAINER_FOR ( MockConnection, readBuffer ) Read_mock ( connection );
            MOCKPP_CHAINER_FOR_EXT ( MockConnection, sendCommand, ext ) Send_mock ( connection );
            MOCKPP_CHAINER_FOR ( MockConnection, getTimeOut ) TimeOut_mock ( connection );

            ResponseVector response1;
            ResponseVector response2;
            ResponseVector response3;
            ResponseVector response4;
            ResponseVector response5;
            ResponseVector response6;
            ResponseVector response7;

            response1.push_back ( 0x00 );
            response1.push_back ( 0x00 );
            response1.push_back ( 0x00 );
            response1.push_back ( 0x00 );

            response2.push_back ( 0x1B );  // Good
            response2.push_back ( 0x64 );
            response2.push_back ( 0x02 );
            response2.push_back ( 0x31 );  // Help
            response2.push_back ( 0x01 );  // Press

            response3.push_back ( 0x1B );  // Good
            response3.push_back ( 0x64 );
            response3.push_back ( 0x02 );
            response3.push_back ( 0x32 );  // Select
            response3.push_back ( 0x01 );  // Press

            response4.push_back ( 0x1C );  // Fail
            response4.push_back ( 0x64 );
            response4.push_back ( 0x02 );
            response4.push_back ( 0x33 );  // Up
            response4.push_back ( 0x01 );  // Press

            response5.push_back ( 0x1B );
            response5.push_back ( 0x63 );  // Fail
            response5.push_back ( 0x02 );
            response5.push_back ( 0x31 );  // Help
            response5.push_back ( 0x02 );  // Release

            response6.push_back ( 0x1B );
            response6.push_back ( 0x64 );
            response6.push_back ( 0x01 );  // Fail
            response6.push_back ( 0x31 );  // Help
            response6.push_back ( 0x01 );  // Press
            response6.push_back ( 0x1B );  // Good
            response6.push_back ( 0x64 );
            response6.push_back ( 0x02 );
            response6.push_back ( 0x32 );  // Select
            response6.push_back ( 0x03 );  // Hold

            response7.push_back ( 0x1B );  // Good
            response7.push_back ( 0x64 );
            response7.push_back ( 0x02 );
            response7.push_back ( 0x33 );  // Up
            response7.push_back ( 0x03 );  // Hold

            Read_mock
            .expects ( MOCKPP_NS::atLeastOnce() )
            .will (
                MOCKPP_NS::onConsecutiveCalls (
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( response1 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( response2 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( response3 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( response4 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( response5 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( response6 ),
                    new MOCKPP_NS::ReturnStub< ResponseVector > ( response7 ) )
            );

            Send_mock.expects ( MOCKPP_NS::never() );
            TimeOut_mock.expects ( MOCKPP_NS::never() );

            AbleDButtonState * state;

            state = device.getAbleDButtonState();
            CPPUNIT_ASSERT ( false == state->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::SELECT ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::UP ) );

            state = device.getAbleDButtonState();
            CPPUNIT_ASSERT ( true == state->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::PRESS == state->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::SELECT ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::UP ) );

            state = device.getAbleDButtonState();
            CPPUNIT_ASSERT ( true == state->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( AbleDButtonState::PRESS == state->getStatus ( AbleDButtonState::SELECT ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::UP ) );

            state = device.getAbleDButtonState();
            CPPUNIT_ASSERT ( false == state->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( AbleDButtonState::PRESS == state->getStatus ( AbleDButtonState::SELECT ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::UP ) );

            state = device.getAbleDButtonState();
            CPPUNIT_ASSERT ( false == state->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( AbleDButtonState::PRESS == state->getStatus ( AbleDButtonState::SELECT ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::UP ) );

            state = device.getAbleDButtonState();
            CPPUNIT_ASSERT ( true == state->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( AbleDButtonState::HOLD == state->getStatus ( AbleDButtonState::SELECT ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::UP ) );

            state = device.getAbleDButtonState();
            CPPUNIT_ASSERT ( true == state->isChanged() );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::HELP ) );
            CPPUNIT_ASSERT ( AbleDButtonState::NONE == state->getStatus ( AbleDButtonState::SELECT ) );
            CPPUNIT_ASSERT ( AbleDButtonState::HOLD == state->getStatus ( AbleDButtonState::UP ) );

            connection->verify();
        }

        CPPUNIT_TEST_SUITE ( P168ADeviceTest );

        CPPUNIT_TEST ( testOpenConnectionFail );
        CPPUNIT_TEST ( testOpenConnectionSuccess );

        CPPUNIT_TEST ( testCloseConnectionFail );
        CPPUNIT_TEST ( testCloseConnectionSuccess );

        CPPUNIT_TEST ( testGetSerialMachineFail );
        CPPUNIT_TEST ( testGetSerialMachineSuccess );

        CPPUNIT_TEST ( testSetSerialMachineFail );
        CPPUNIT_TEST ( testSetSerialMachineSuccess );

        CPPUNIT_TEST ( testGetButtonStateResponseFail );
        CPPUNIT_TEST ( testGetButtonStateResponseOneButton );
        CPPUNIT_TEST ( testGetButtonStateResponseTwoButton );
        CPPUNIT_TEST ( testGetButtonState );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_P168A_DEVICE_TEST */
