#ifndef TEST_SIMULATOR_ALARM_BOX_DEVICE_TEST
#define TEST_SIMULATOR_ALARM_BOX_DEVICE_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Devices/SimulatorAlarmBoxDevice.hxx>
#include <tests/MockFile.hxx>
#include <tests/StoreMockFile.hxx>

class SimulatorAlarmBoxDeviceTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::SAES::HW::Devices::SimulatorAlarmBoxDevice SimulatorAlarmBoxDevice;
        typedef Smartmatic::System::IO::File File;
        typedef Smartmatic::System::SafeBuffer SafeBuffer;

    public:

        SimulatorAlarmBoxDeviceTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testOpenConnectionFail ()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );

            canOpenFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.open ( "" ) );

            mock.verify();
        }

        void testOpenConnectionSuccess ()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );

            canOpenFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.open ( "" ) );

            mock.verify();
        }

        void testCheckOpenFileConnection ()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.canOpenFileReturnValues.push_back ( true );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.open ( "dummy" ) );
            CPPUNIT_ASSERT ( false == mock.canOpenFileList.empty() );
            CPPUNIT_ASSERT ( "dummy" == ( * mock.canOpenFileList.begin() ) );
        }

        void testCloseConnection ()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );
            saveBufferToFile_mock.expects ( MOCKPP_NS::never() );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.close () );

            mock.verify();
        }

        void testSendPingFail()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );

            openFileToBuffer_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.sendPing() );

            mock.verify();
        }

        void testSendPingFailResponseNOK()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer ( "NOK" ), true ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.sendPing() );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "ping" == ( * mock.openFileListValues.begin() ) );
        }

        void testSendPingResponseOK()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer ( "OK" ), true ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.sendPing() );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "ping" == ( * mock.openFileListValues.begin() ) );
        }

        void testOnRedLedFail()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.turnOnRedLed ( 0x01 ) );

            mock.verify();
        }

        void testOnRedLedSuccess()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOnRedLed ( 0x01 ) );

            mock.verify();
        }

        void testCheckSaveFileOnRedLedSuccess()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            SafeBuffer expectedBuffer;

            expectedBuffer.AddData ( "RedLed:ON:1" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "GreenLed:OFF" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "Buzzer:OFF" );
            expectedBuffer.AddData ( "\n" );

            mock.saveReturnValues.push_back ( true );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOnRedLed ( 0x01 ) );
            CPPUNIT_ASSERT ( false == mock.saveBufferValues.empty() );
            CPPUNIT_ASSERT ( "behavior" == ( * mock.saveBufferValues.begin() ).file );
            CPPUNIT_ASSERT ( expectedBuffer == ( * mock.saveBufferValues.begin() ).buffer );
        }

        void testOffRedLedFail()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.turnOffRedLed() );

            mock.verify();
        }

        void testOffRedLedSuccess()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOffRedLed() );

            mock.verify();
        }

        void testCheckSaveFileOffRedLedSuccess()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            SafeBuffer expectedBuffer;

            expectedBuffer.AddData ( "RedLed:OFF" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "GreenLed:OFF" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "Buzzer:OFF" );
            expectedBuffer.AddData ( "\n" );

            mock.saveReturnValues.push_back ( true );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOffRedLed() );
            CPPUNIT_ASSERT ( false == mock.saveBufferValues.empty() );
            CPPUNIT_ASSERT ( "behavior" == ( * mock.saveBufferValues.begin() ).file );
            CPPUNIT_ASSERT ( expectedBuffer == ( * mock.saveBufferValues.begin() ).buffer );
        }

        void testOnGreenLedFail()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.turnOnGreenLed ( 0x02 ) );

            mock.verify();
        }

        void testOnGreenLedSuccess()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOnGreenLed ( 0x02 ) );

            mock.verify();
        }

        void testCheckSaveFileOnGreenLedSuccess()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            SafeBuffer expectedBuffer;

            expectedBuffer.AddData ( "RedLed:OFF" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "GreenLed:ON:2" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "Buzzer:OFF" );
            expectedBuffer.AddData ( "\n" );

            mock.saveReturnValues.push_back ( true );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOnGreenLed ( 0x02 ) );
            CPPUNIT_ASSERT ( false == mock.saveBufferValues.empty() );
            CPPUNIT_ASSERT ( "behavior" == ( * mock.saveBufferValues.begin() ).file );
            CPPUNIT_ASSERT ( expectedBuffer == ( * mock.saveBufferValues.begin() ).buffer );
        }

        void testOffGreenLedFail()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.turnOffGreenLed() );

            mock.verify();
        }

        void testOffGreenLedSuccess()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOffGreenLed() );

            mock.verify();
        }

        void testCheckSaveFileOffGreenLedSuccess()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            SafeBuffer expectedBuffer;

            expectedBuffer.AddData ( "RedLed:OFF" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "GreenLed:OFF" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "Buzzer:OFF" );
            expectedBuffer.AddData ( "\n" );

            mock.saveReturnValues.push_back ( true );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOffGreenLed() );
            CPPUNIT_ASSERT ( false == mock.saveBufferValues.empty() );
            CPPUNIT_ASSERT ( "behavior" == ( * mock.saveBufferValues.begin() ).file );
            CPPUNIT_ASSERT ( expectedBuffer == ( * mock.saveBufferValues.begin() ).buffer );
        }

        void testOnBuzzerFail()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.turnOnBuzzer ( 0x03 ) );

            mock.verify();
        }

        void testOnBuzzerSuccess()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( true ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOnBuzzer ( 0x03 ) );

            mock.verify();
        }

        void testCheckSaveFileOnBuzzerSuccess()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            SafeBuffer expectedBuffer;

            expectedBuffer.AddData ( "RedLed:OFF" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "GreenLed:OFF" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "Buzzer:ON:3" );
            expectedBuffer.AddData ( "\n" );

            mock.saveReturnValues.push_back ( true );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOnBuzzer ( 0x03 ) );
            CPPUNIT_ASSERT ( false == mock.saveBufferValues.empty() );
            CPPUNIT_ASSERT ( "behavior" == ( * mock.saveBufferValues.begin() ).file );
            CPPUNIT_ASSERT ( expectedBuffer == ( * mock.saveBufferValues.begin() ).buffer );
        }

        void testOffBuzzerFail()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.turnOffBuzzer() );

            mock.verify();
        }

        void testOffBuzzerSuccess()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, addBufferToFile, ext ) saveBufferToFile_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );
            openFileToBuffer_mock.expects ( MOCKPP_NS::never() );

            saveBufferToFile_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.turnOffBuzzer() );

            mock.verify();
        }

        void testCheckSaveFileOffBuzzerSuccess()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            SafeBuffer expectedBuffer;

            expectedBuffer.AddData ( "RedLed:OFF" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "GreenLed:OFF" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "Buzzer:OFF" );
            expectedBuffer.AddData ( "\n" );

            mock.saveReturnValues.push_back ( true );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOffBuzzer () );
            CPPUNIT_ASSERT ( false == mock.saveBufferValues.empty() );
            CPPUNIT_ASSERT ( "behavior" == ( * mock.saveBufferValues.begin() ).file );
            CPPUNIT_ASSERT ( expectedBuffer == ( * mock.saveBufferValues.begin() ).buffer );
        }

        void testButtonPressedFileNotFound()
        {
            MockFile mock;
            File::getInstance ( &mock );

            MOCKPP_CHAINER_FOR_EXT ( MockFile, canOpenFile, ext ) canOpenFile_mock ( &mock );
            MOCKPP_CHAINER_FOR_EXT ( MockFile, openFileToBuffer, ext ) openFileToBuffer_mock ( &mock );

            canOpenFile_mock.expects ( MOCKPP_NS::never() );

            openFileToBuffer_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<bool> ( false ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.isButtonPressed() );

            mock.verify();
        }

        void testButtonPressedFailResponseNone()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer ( "NONE" ), true ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( false == device.isButtonPressed() );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "button" == ( * mock.openFileListValues.begin() ) );
        }

        void testButtonPressedResponsePush()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            mock.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer ( "PUSH" ), true ) );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.isButtonPressed() );
            CPPUNIT_ASSERT ( false == mock.openFileListValues.empty() );
            CPPUNIT_ASSERT ( "button" == ( * mock.openFileListValues.begin() ) );
        }

        void testMultiEvent()
        {
            StoreMockFile mock;
            File::getInstance ( &mock );

            SafeBuffer expectedBuffer;

            expectedBuffer.AddData ( "RedLed:ON:1" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "GreenLed:ON:2" );
            expectedBuffer.AddData ( " - " );
            expectedBuffer.AddData ( "Buzzer:ON:3" );
            expectedBuffer.AddData ( "\n" );

            mock.saveReturnValues.push_back ( true );
            mock.saveReturnValues.push_back ( true );
            mock.saveReturnValues.push_back ( true );

            SimulatorAlarmBoxDevice device ( "ping", "button", "behavior" );

            CPPUNIT_ASSERT ( true == device.turnOnRedLed ( 0x01 ) );
            CPPUNIT_ASSERT ( true == device.turnOnGreenLed ( 0x02 ) );
            CPPUNIT_ASSERT ( true == device.turnOnBuzzer ( 0x03 ) );
            CPPUNIT_ASSERT ( 3 == mock.saveBufferValues.size() );

            std::list < StoreMockFile::SafeBufferValues >::iterator it = mock.saveBufferValues.begin();

            ++it;
            ++it;

            CPPUNIT_ASSERT ( "behavior" == ( *it ).file );
            CPPUNIT_ASSERT ( expectedBuffer == ( * it ).buffer );
        }

        CPPUNIT_TEST_SUITE ( SimulatorAlarmBoxDeviceTest );

        CPPUNIT_TEST ( testOpenConnectionFail );
        CPPUNIT_TEST ( testOpenConnectionSuccess );
        CPPUNIT_TEST ( testCheckOpenFileConnection );

        CPPUNIT_TEST ( testCloseConnection );

        CPPUNIT_TEST ( testSendPingFail );
        CPPUNIT_TEST ( testSendPingFailResponseNOK );
        CPPUNIT_TEST ( testSendPingResponseOK );

        CPPUNIT_TEST ( testOnRedLedFail );
        CPPUNIT_TEST ( testOnRedLedSuccess );
        CPPUNIT_TEST ( testCheckSaveFileOnRedLedSuccess );

        CPPUNIT_TEST ( testOffRedLedFail );
        CPPUNIT_TEST ( testOffRedLedSuccess );
        CPPUNIT_TEST ( testCheckSaveFileOffRedLedSuccess );

        CPPUNIT_TEST ( testOnGreenLedFail );
        CPPUNIT_TEST ( testOnGreenLedSuccess );
        CPPUNIT_TEST ( testCheckSaveFileOnGreenLedSuccess );

        CPPUNIT_TEST ( testOffGreenLedFail );
        CPPUNIT_TEST ( testOffGreenLedSuccess );
        CPPUNIT_TEST ( testCheckSaveFileOffGreenLedSuccess );

        CPPUNIT_TEST ( testOnBuzzerFail );
        CPPUNIT_TEST ( testOnBuzzerSuccess );
        CPPUNIT_TEST ( testCheckSaveFileOnBuzzerSuccess );

        CPPUNIT_TEST ( testOffBuzzerFail );
        CPPUNIT_TEST ( testOffBuzzerSuccess );
        CPPUNIT_TEST ( testCheckSaveFileOffBuzzerSuccess );

        CPPUNIT_TEST ( testButtonPressedFileNotFound );
        CPPUNIT_TEST ( testButtonPressedFailResponseNone );
        CPPUNIT_TEST ( testButtonPressedResponsePush );

        CPPUNIT_TEST ( testMultiEvent );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_SIMULATOR_ALARM_BOX_DEVICE_TEST */
