/**
 * @file	MockSerialPortConnection.hxx
 * @brief	Declares the MockSerialPortConnection.
 * @author	Yadickson Soto
 * @date	19/02/2014
 */

#ifndef _MOCK_SERIAL_PORT_CONNECTION_H_
#define _MOCK_SERIAL_PORT_CONNECTION_H_

#include <mockpp/mockpp.h>
#include <mockpp/chaining/ChainableMockObject.h>
#include <mockpp/chaining/ChainingMockObjectSupport.h>
#include <Connections/SerialPortConnection.hxx>

class MockSerialPortConnection : public Smartmatic::SAES::HW::Connections::SerialPortConnection,
    public MOCKPP_NS::ChainableMockObject
{
    public:

        MockSerialPortConnection ( Smartmatic::SAES::HW::Connections::IConnection * connection )
            : SerialPortConnection ( connection ), MOCKPP_NS::ChainableMockObject ( MOCKPP_PCHAR ( "MockSerialPortConnection" ), 0 )
            , MOCKPP_CONSTRUCT_MEMBERS_FOR_CHAINABLE_EXT1 ( openConnection, ext )
            , MOCKPP_CONSTRUCT_MEMBERS_FOR_CHAINABLE_EXT1 ( sendCommand, ext )
            , MOCKPP_CONSTRUCT_MEMBERS_FOR_CHAINABLE0 ( closeConnection )
        {
        }

        virtual ~MockSerialPortConnection()
        {

        }

        MOCKPP_CHAINABLE_EXT1 ( MockSerialPortConnection,
                                bool, openConnection, const std::string &,
                                bool, ext, const std::string * );

        MOCKPP_CHAINABLE_EXT1 ( MockSerialPortConnection,
                                bool, sendCommand, const std::vector<unsigned char> &,
                                bool, ext, const std::vector<unsigned char> * );

        MOCKPP_CHAINABLE0 ( MockSerialPortConnection,
                            bool, closeConnection );

        virtual Smartmatic::System::SafeVector <unsigned char> readBuffer ()
        {
            Smartmatic::System::SafeVector <unsigned char> buffer;

            buffer = this->connection->readBuffer();

            if ( this->clientListener )
            {
                clientListener->peekEvent ( buffer );
            }

            return buffer;
        }
};

#endif // _MOCK_SERIAL_PORT_CONNECTION_H_
