/**
 * @file	configuration-persistence-manager.cc
 *
 * @brief	configuration persistence manager class.
 */

#include "configuration-persistence-manager.h"
#include <System/IO/File.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define CONFIG_FILE "configuration-miscellaneous.xml" ///< config file base

using namespace Smartmatic::Configuration;
using namespace Smartmatic::System;
using namespace Smartmatic::System::IO;

std::string ConfigurationPersistenceManager::filePath = CONFIG_FILE;
ConfigurationPersistenceManager * ConfigurationPersistenceManager::instance = NULL; ///< The configuration persistence manager singleton instance

ConfigurationPersistenceManager::ConfigurationPersistenceManager()
{
    configuration = NULL;
}

ConfigurationPersistenceManager::~ConfigurationPersistenceManager()
{
    if ( configuration )
    {
        delete configuration;
        configuration = NULL;
    }

    instance = NULL;
}

void ConfigurationPersistenceManager::Initialize ( const std::string & filePath )
{
    try
    {
        SafeBuffer buffer;
        File::getInstance()->openFileToBuffer ( filePath, buffer );

        std::string semiFile;
        semiFile.assign ( ( const char * ) buffer.GetData(), buffer.GetSize() );

        std::istringstream ss ( semiFile );
        configuration = new ConfigurationBase ( * parseConfigurationBaseRoot ( ss, ConfigurationTypes::Flags::dont_validate ).get() );
    }
    catch ( ... )
    {

    }
}

ConfigurationPersistenceManager * ConfigurationPersistenceManager::getInstance ( ConfigurationPersistenceManager * externManager )
{
    if ( ! instance )
    {
        instance = ( externManager == NULL ? new ConfigurationPersistenceManager () : externManager );
        instance->Initialize ( filePath );
    }

    return instance;
}

std::string ConfigurationPersistenceManager::GetLibraryConfigFile ( const std::string & nameOfLibrary )
{
    std::string out;

    ConfigurationBase::ConfigurationTypeConstIterator iterator ( getConfiguration()->getConfigurationType().begin() );
    const ConfigurationBase::ConfigurationTypeConstIterator enditerator ( getConfiguration()->getConfigurationType().end() );

    while ( iterator != enditerator )
    {
        const ConfigurationType & ct ( *iterator++ );

        if ( nameOfLibrary.compare ( ct.getName() ) == 0 )
        {
            out.append ( ct.getConfiguration() );
            break;
        }
    }

    return out;
}

void ConfigurationPersistenceManager::SetLibraryConfigFile ( const std::string & nameOfLibrary, const std::string & on )
{
    ConfigurationBase::ConfigurationTypeIterator iterator ( getConfiguration()->getConfigurationType().begin() );
    const ConfigurationBase::ConfigurationTypeIterator enditerator ( getConfiguration()->getConfigurationType().end() );

    while ( iterator != enditerator )
    {
        if ( nameOfLibrary.compare ( iterator->getName() ) == 0 )
        {
            iterator->setConfiguration ( on );
            return;
        }

        iterator++;
    }

    ConfigurationType type;
    type.setConfiguration ( on );
    type.setName ( nameOfLibrary );
    getConfiguration()->getConfigurationType().push_back ( type );
}

bool ConfigurationPersistenceManager::SaveFile()
{
    std::ostringstream str;

    Smartmatic::ConfigurationTypes::NamespaceInfomap map;
    map[""].name = NAMESPACE_CONFIGURATION;
    map[""].schema = "";

    serializeConfigurationBaseRoot ( str, * ( getConfiguration() ), map, "UTF-8" );

    SafeBuffer buffer ( str.str() );
    return File::getInstance()->saveBufferToFile ( buffer, filePath );
}

Smartmatic::Configuration::ConfigurationBase * ConfigurationPersistenceManager::getConfiguration()
{
    if ( configuration == NULL )
    {
        configuration = new ConfigurationBase();
        ConfigurationBase::ConfigurationTypeSequence seq;
        configuration->setConfigurationType ( seq );
    }

    return configuration;
}
