/**
 * @file   AudioPlayer.hxx
 * @brief  Declaration of AudioPlayer class.
 * @author manuel.arguelles
 * @date   Sep 29, 2017
 */

#ifndef AUDIO_PLAYER_HXX
#define AUDIO_PLAYER_HXX

#include "IAudioPlayer.hxx"
#include "Audio.hxx"
#include <memory>
#include <string>

namespace Smartmatic
{
    namespace System
    {
        namespace Audio
        {
            class AudioPlayerImpl;

            /**
             * @class  AudioPlayer
             * @brief  Audio player class.
             * @author manuel.arguelles
             * @date   Sep 29, 2017
             */
            class AudioPlayer : public IAudioPlayer
            {
                public:

                    /**
                     * @brief  Constructs an instance of the class.
                     * @author manuel.arguelles
                     * @date   Sep 29, 2017
                     */
                    AudioPlayer();

                    /**
                     * @brief  Constructs an instance of the class.
                     * @author manuel.arguelles
                     * @date   Jan 23, 2018
                     * @param  cardName The name of the sound card.
                     */
                    explicit AudioPlayer(const std::string& cardName);

                    /**
                     * @brief  Destroys the instance of the class.
                     * @author manuel.arguelles
                     * @date   Sep 29, 2017
                     */
                    virtual ~AudioPlayer();

                public:

                    /**
                     * @brief  Plays the audio.
                     * @author manuel.arguelles
                     * @date   Sep 29, 2017
                     * @throw  AudioException If the device is busy or cannot
                     * be opened.
                     * @param  audio The audio samples to play.
                     */
                    virtual void play(const Audio& audio);

                private:

                    /**
                     * @brief  Disable assignment operator.
                     * @author manuel.arguelles
                     * @date   Oct  5, 2017
                     */
                    AudioPlayer& operator=(const AudioPlayer&);

                    /**
                     * @brief  Disable copy constructor.
                     * @author manuel.arguelles
                     * @date   Oct  5, 2017
                     */
                    AudioPlayer(const AudioPlayer&);

                private:

                    std::auto_ptr<AudioPlayerImpl> m_impl;
            };

        } /* namespace Audio */
    } /* namespace System */
} /* namespace Smartmatic */

#endif /* AUDIO_PLAYER_HXX */
