/**
 * @file   MixerControl.hxx
 * @brief  Declaration of MixerControl class.
 * @author manuel.arguelles
 * @date   Dec 13, 2017
 */

#ifndef MIXER_CONTROL_HXX
#define MIXER_CONTROL_HXX

#include <memory>
#include <string>

namespace Smartmatic
{
    namespace System
    {
        namespace Audio
        {
            class MixerControlImpl;

            /**
             * @class  MixerControl
             * @brief  Controls the audio mixer.
             * @author manuel.arguelles
             * @date   Dec 13, 2017
             */
            class MixerControl
            {
                public:

                    /**
                     * @brief  Create an instance of the class.
                     * @author manuel.arguelles
                     * @date   Dec 15, 2017
                     * @param  cardName The name of the sound card.
                     * @param  defaultVolume Audio voting default volume.
                     */
                    MixerControl(const std::string& cardName, const int defaultVolume = 0);

                    /**
                     * @brief  Destroys an instance of the class.
                     * @author manuel.arguelles
                     * @date   Dec 13, 2017
                     */
                    virtual ~MixerControl();

                public:

                    /**
                     * @brief  Sets the playback volume.
                     * @author manuel.arguelles
                     * @date   Dec 13, 2017
                     * @param  volume The volume value (0 to 255).
                     */
                    void setPlaybackVolume(int volume);

                    /**
                     * @brief  Gets the playback volume.
                     * @author manuel.arguelles
                     * @date   Dec 13, 2017
                     */
                    int getPlaybackVolume();

                    /**
                     * @brief  Increase the playback volume by 5 points.
                     * @author manuel.arguelles
                     * @date   Dec 15, 2017
                     */
                    void increasePlaybackVolume();

                    /**
                     * @brief  Decrease the playback volume by 5 points.
                     * @author manuel.arguelles
                     * @date   Dec 15, 2017
                     */
                    void decreasePlaybackVolume();

                    /**
                     * @brief  Gets the playback device of the card.
                     * @author manuel.arguelles
                     * @date   Jan 31, 2018
                     * @return The device name.
                     */
                    std::string getPlaybackDeviceName() const;

                private:

                    std::auto_ptr<MixerControlImpl> m_impl;
            };

        } /* namespace Audio */
    } /* namespace System */
} /* namespace Smartmatic */

#endif /* MIXER_CONTROL_HXX */
