/**
 * @file	ZipCompression.hxx
 * @brief	Header zip compression class.
 * @author	Yadickson Soto
 * @date	08/11/2012
 */

#ifndef _ZIP_COMPRESION_CLASS_H_
#define _ZIP_COMPRESION_CLASS_H_

#include <System/Compression/ICompression.hxx>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace System
    {
        namespace Compression
        {
            /**
             * @class	ZipCompression
             * @brief	Compression class.
             * @author	Yadickson Soto
             * @date	08/11/2012
             */
            class ZipCompression : public ICompression
            {
                public:

                    /**
                     * @brief	Class constructor
                     * @author	Yadickson Soto
                     * @date	08/11/2012
                     */
                    ZipCompression();

                    /**
                     * @brief	Class destructor
                     * @author	Yadickson Soto
                     * @date	08/11/2012
                     */
                    virtual ~ZipCompression();

                    /**
                     * @fn	virtual bool ZipCompression::Inflate( Smartmatic::System::SafeBuffer & dataIn,
                     *		Smartmatic::System::SafeBuffer & dataOut, int & avail) = 0;
                     * @brief	Inflates.
                     * @author	Yadickson Soto
                     * @date	08/11/2012
                     * @param	dataIn				The data in.
                     * @param	dataOut				The data out result.
                     * @param	avail				availability data.
                     * @return	true if success
                     */
                    virtual bool Inflate ( Smartmatic::System::SafeBuffer & dataIn,
                                           Smartmatic::System::SafeBuffer & dataOut,
                                           int & avail );

                    /**
                     * @fn	virtual bool ZipCompression::Deflate ( Smartmatic::System::SafeBuffer & dataIn,
                     *              Smartmatic::System::SafeBuffer & dataOut ) = 0;
                     * @brief	Deflates.
                     * @author	Yadickson Soto
                     * @date	08/11/2012
                     * @param	dataIn				The data in.
                     * @param	dataOut				The data out result.
                     * @return	true if success
                     */
                    virtual bool Deflate ( Smartmatic::System::SafeBuffer & dataIn,
                                           Smartmatic::System::SafeBuffer & dataOut );

                protected:

                    /**
                     * @fn	void * zipAllocFunc ( void * opaque, unsigned int items, unsigned int size )
                     * @brief	method alloc memory.
                     * @author	Yadickson Soto yadickson.soto@smartmatic.com
                     * @date	08/11/2012
                     * @param	opaque	pointer buf.
                     * @param	items	items.
                     * @param	size	size.
                     * @return  buf pointer
                     */
                    static void * zipAllocFunc ( void * opaque, unsigned int items, unsigned int size );

                    /**
                     * @fn	void zipFreeFunc ( void * opaque, void * address )
                     * @brief	method free memory.
                     * @author	Yadickson Soto yadickson.soto@smartmatic.com
                     * @date	08/11/2012
                     * @param	opaque	buf pointer.
                     * @param	address	buf pointer.
                     */
                    static void zipFreeFunc ( void * opaque, void * address );

                private:

                    static Smartmatic::Log::ISMTTLog * logger; /**<logger*/
            };
        }
    }
}

#endif // _ZIP_COMPRESION_CLASS_H_
