/**
 * @file	compression-class.cc
 * @brief	Body file to the compression class class.
 */

#include "compression-class.h"
#include "ZipCompression.hxx"

using namespace Smartmatic::System::Compression;
using namespace Smartmatic::System;

CompressionClass * CompressionClass::instance = NULL;

CompressionClass::CompressionClass ()
{
    configObject = new ZipCompression();
}

CompressionClass::~CompressionClass()
{
    if ( configObject )
    {
        delete configObject;
        configObject = NULL;
    }

    instance = NULL;
}

CompressionClass * CompressionClass::getInstance ()
{
    if ( instance == NULL )
    {
        instance = new CompressionClass ();
    }

    return instance;
}

bool CompressionClass::Inflate ( Smartmatic::System::SafeBuffer & dataIn,
                                 Smartmatic::System::SafeBuffer & dataOut )
{
    int avail;
    return configObject->Inflate ( dataIn, dataOut, avail );
}

void CompressionClass::Inflate ( Smartmatic::System::SafeBuffer & dataIn,
                                 std::list <Smartmatic::System::SafeBuffer *> & listDataOut )
{
    listDataOut.clear();

    int avail = 0;
    int total = dataIn.GetSize();

    do
    {
        int process = 0;
        int current = 0;

        SafeBuffer data ( ( unsigned char * ) dataIn.GetData() + current, total );
        SafeBuffer buffer;

        SafeBuffer * dataOut = NULL;

        if ( configObject->Inflate ( data, buffer, avail ) )
        {
            dataOut = new SafeBuffer ( buffer );
        }

        process = total - avail;
        total -= process;
        current += process;

        listDataOut.push_back ( dataOut );
    }
    while ( avail != 0 );
}

bool CompressionClass::Deflate ( Smartmatic::System::SafeBuffer & dataIn,
                                 Smartmatic::System::SafeBuffer & dataOut )
{
    return configObject->Deflate ( dataIn, dataOut );
}
