/**
 * @file	compression-class.h
 * @brief	Header file to the compression class class.
 */

#ifndef _COMPRESION_CLASS_H_
#define _COMPRESION_CLASS_H_

#include <System/SafeBuffer.h>
#include <list>

namespace Smartmatic
{
    namespace System
    {
        namespace Compression
        {
            class ICompression;

            /**
             * @class	CompressionClass
             * @brief	Compression class.
             * @author	Yadickson Soto
             * @date	28/04/2011
             */
            class CompressionClass
            {
                private:

                    /**
                     * @fn CompressionClass();
                     * @brief	Class constructor
                     * @author	Yadickson Soto
                     * @date	08/11/2012
                     */
                    CompressionClass ();

                public:

                    /**
                     * @brief	Class destructor
                     * @author	Yadickson Soto
                     * @date	08/11/2012
                     */
                    virtual ~CompressionClass();

                    /**
                     * @fn	bool CompressionClass::Inflate( Smartmatic::System::SafeBuffer & dataIn,
                     * 			Smartmatic::System::SafeBuffer & dataOut );
                     * @brief	Inflate data.
                     * @author	Yadickson Soto yadickson.soto@smartmatic.com
                     * @date	03/06/2011
                     * @param	dataIn 	The data.
                     * @param	dataOut	The result.
                     * @return	true if success.
                     */
                    bool Inflate ( Smartmatic::System::SafeBuffer & dataIn,
                                   Smartmatic::System::SafeBuffer & dataOut );

                    /**
                     * @fn	static void CompressionClass::Inflate( Smartmatic::System::SafeBuffer & dataIn,
                     * 			std::list <Smartmatic::System::SafeBuffer *> & listDataOut );
                     * @brief	Inflate data.
                     * @author	Yadickson Soto yadickson.soto@smartmatic.com
                     * @date	03/06/2011
                     * @param	dataIn		 	The data.
                     * @param	listDataOut	the data out.
                     */
                    void Inflate ( Smartmatic::System::SafeBuffer & dataIn,
                                   std::list <Smartmatic::System::SafeBuffer *> & listDataOut );

                    /**
                     * @fn	static bool CompressionClass::Deflate( Smartmatic::System::SafeBuffer & dataIn,
                     * 			Smartmatic::System::SafeBuffer & dataOut,
                     * 			bool zip = false );
                     * @brief	Deflate data.
                     * @author	Yadickson Soto yadickson.soto@smartmatic.com
                     * @date	03/06/2011
                     * @param	dataIn 	The data.
                     * @param	dataOut	The result.
                     * @return	status.
                     */
                    bool Deflate ( Smartmatic::System::SafeBuffer & dataIn,
                                   Smartmatic::System::SafeBuffer & dataOut );

                    /**
                     * @fn static CompressionClass * getInstance();
                     * @brief	Method getter instance class
                     * @author	Yadickson Soto
                     * @date	08/11/2012
                     * @return instance
                     */
                    static CompressionClass * getInstance ();

                private:

                    /**
                     * @brief  Disable copy constructor.
                     * @author manuel.arguelles
                     * @date   Sep 12, 2017
                     */
                    CompressionClass(const CompressionClass&);

                    /**
                     * @brief  Disable copy.
                     * @author manuel.arguelles
                     * @date   Sep 12, 2017
                     */
                    CompressionClass& operator=(const CompressionClass&);

                private:

                    ICompression * configObject; ///< object compression class
                    static CompressionClass * instance; ///< instance class
            };
        }
    }
}
#endif // _COMPRESION_CLASS_H_
