/**
 * @file B64.hxx
 * @brief Header base 64 encoder/decoder class.
 * @date 30/08/2013
 * @author Yadickson Soto
 */

#ifndef B64_HXX_
#define B64_HXX_

#include <string>

namespace Smartmatic
{
    namespace System
    {
        namespace Encoding
        {
            /**
             * @class B64
             * @brief base 64 encoder/decoder class.
             * @date 30/08/2013
             * @author Yadickson Soto
             */
            class B64
            {
                public:
                    /**
                     * @fn B64();
                     * @brief Class constructor
                     * @date 30/08/2013
                     * @author Yadickson Soto
                     */
                    B64();
                    /**
                     * @fn virtual ~B64();
                     * @brief Class destructor
                     * @date 30/08/2013
                     * @author Yadickson Soto
                     */
                    virtual ~B64();
                    /**
                     * @fn unsigned char * encode ( const unsigned char * data,
                     *                               unsigned int inputLength,
                     *                               unsigned int & outputLength );
                     * @brief Encode input data to base64
                     * @param data input data
                     * @param inputLength input length
                     * @param outputLength result output length
                     * @return output base64 encode, NULL is fail
                     * @date 30/08/2013
                     * @author Yadickson Soto
                     */
                    unsigned char * encode ( const unsigned char * data,
                                             unsigned int inputLength,
                                             unsigned int & outputLength );
                    /**
                     * @fn unsigned char * decode ( const unsigned char * data,
                     *                               unsigned int inputLength,
                     *                               unsigned int & outputLength );
                     * @brief Decode input base64 data
                     * @param data input base64 data
                     * @param inputLength input length
                     * @param outputLength result output length
                     * @return output decode data, NULL is fail
                     * @date 30/08/2013
                     * @author Yadickson Soto
                     */
                    unsigned char * decode ( const char * data,
                                             unsigned int inputLength,
                                             unsigned int & outputLength );

                private:

                    /**
                     * @brief  Disable copy constructor.
                     * @author manuel.arguelles
                     * @date   Sep 12, 2017
                     */
                    B64(const B64&);

                    /**
                     * @brief  Disable copy.
                     * @author manuel.arguelles
                     * @date   Sep 12, 2017
                     */
                    B64& operator=(const B64&);

                private:

                    unsigned char * decodingTable; ///< decoding table
            };

        } /* namespace Encoding */
    } /* namespace System */
} /* namespace Smartmatic */
#endif /* B64_HXX_ */
