/**
 * @file   IDirectory.hxx
 * @brief  Declaration of IDirectory interface.
 * @author manuel.arguelles
 * @date   Aug  8, 2017
 */

#ifndef I_DIRECTORY_HXX
#define I_DIRECTORY_HXX

#include <string>
#include <vector>

namespace Smartmatic
{
    namespace System
    {
        namespace IO
        {
            /**
             * @class  IDrectory
             * @brief  Interface for directory class.
             * @author manuel.arguelles
             * @date   Aug  8, 2017
             */
            class IDirectory
            {
                public:

                    /**
                     * @brief  Finalize an instance of IDirectory.
                     * @author manuel.arguelles
                     * @date   Aug  8, 2017
                     */
                    virtual ~IDirectory() {}

                public:

                    /**
                     * @brief  Deletes a directory.
                     * @author manuel.arguelles
                     * @date   Aug  9, 2017
                     * @param  path The directory to remove.
                     * @return True if the directory was deleted, false if not.
                     */
                    virtual bool Delete(const std::string& path) = 0;

                    /**
                     * @brief  Gets a list with the files in the given path.
                     * @author manuel.arguelles
                     * @date   Aug  9, 2017
                     * @param  path The path to search for files.
                     * @param  list The list of files present in path.
                     */
                    virtual void GetFiles(const std::string& path, std::vector<std::string>& list) = 0;

                    /**
                     * @brief  Gets a list with the directories in the given path.
                     * @author manuel.arguelles
                     * @date   Aug  9, 2017
                     * @param  path The path to search for directories.
                     * @param  list The list of directories present in path.
                     */
                    virtual void GetDirectories(const std::string& path, std::vector<std::string>& list) = 0;

                    /**
                     * @brief  Checks if the given directory exists.
                     * @author manuel.arguelles
                     * @date   Aug  9, 2017
                     * @param  path The path to the directory.
                     * @return True if the directory exists, false if not.
                     */
                    virtual bool DirectoryExists(const std::string& path) = 0;

                    /**
                     * @brief  Creates a directory.
                     * @author manuel.arguelles
                     * @date   Aug  9, 2017
                     * @param  path The path of the directory to create.
                     * @return True if the directory was created successfully, false if not.
                     */
                    virtual bool Mkdir(const std::string& path) = 0;
            };

        } /* namespace IO */
    } /* namespace System */
} /* namespace Smartmatic */

#endif /* I_DIRECTORY_HXX */
