/**
 * @file   IFile.hxx
 * @brief  Declaration of File interface.
 * @author manuel.arguelles
 * @date   Aug  9, 2017
 */

#ifndef I_FILE_HXX
#define I_FILE_HXX

#include <string>

namespace Smartmatic
{
    namespace System
    {
        namespace IO
        {
            /**
             * @class  IFile
             * @brief  Interface for File objects.
             * @author manuel.arguelles
             * @date   Aug  9, 2017
             */
            class IFile
            {
                public:

                    /**
                     * @brief  Finalize an instance of IFile.
                     * @author manuel.arguelles
                     * @date   Aug  9, 2017
                     */
                    virtual ~IFile() {}

                public:

                    /**
                     * @brief  Copy a file.
                     * @author manuel.arguelles
                     * @date   Aug  9, 2017
                     * @param  inputFile The file to copy.
                     * @param  outputFile The destination file.
                     * @return True if the copy was successful, false if not.
                     */
                    virtual bool copyFile(const std::string& inputFile, const std::string& outputFile) = 0;

                    /**
                     * @brief  Compare two files.
                     * @author manuel.arguelles
                     * @date   Aug  9, 2017
                     * @param  fileOne The first file to compare.
                     * @param  fileTwo The second file to which compare the first.
                     * @return True if both files are equal, false if not.
                     */
                    virtual bool compareFiles(const std::string& fileOne, const std::string& fileTwo) = 0;
            };

        } /* namespace IO */
    } /* namespace System */
} /* namespace Smartmatic */

#endif /* I_FILE_HXX */
