/**
 * @file ExitProcess.hxx
 * @brief Class definition to exit process.
 * @date 15/11/2013
 * @author Yadickson Soto
 */

#ifndef _EXIT_PROCESS_HXX_
#define _EXIT_PROCESS_HXX_

#include <stddef.h>

namespace Smartmatic
{
    namespace System
    {
        namespace Runtime
        {
            /**
             * @class	ExitProcess
             * @brief	Class definition to exit process.
             * @author	Yadickson Soto
             * @date	15-11-2013
             */
            class ExitProcess
            {
                protected:
                    /**
                     * @fn ExitProcess();
                     * @brief	Class constructor
                     * @author	Yadickson Soto
                     * @date	15-11-2013
                     */
                    ExitProcess();

                public:

                    /**
                     * @fn virtual ~ExitProcess();
                     * @brief	Destroy
                     * @author	Yadickson Soto
                     * @date	15-11-2013
                     */
                    virtual ~ExitProcess();

                    /**
                     * @fn virtual void exitProcess ();
                     * @brief	Call exit process and finished run application
                     * @author	Yadickson Soto
                     * @date	15-11-2013
                     */
                    virtual void exitProcess ();

                    /**
                     * @fn virtual void exitProcessWithCode ( int exitCode );
                     * @brief	Call exit process with exit code and finished run application
                     * @author	Yadickson Soto
                     * @date	29/05/2014
                     * @param exitCode The exit code value
                     */
                    virtual void exitProcessWithCode ( int exitCode );

                    /**
                     * @fn	static ExitProcess * getInstance( ExitProcess * externProcess = NULL );
                     * @brief	Getter method instance of class.
                     * @author	Yadickson Soto
                     * @date	31/10/2013
                     * @param 	externProcess external launcher to unit test
                     * @return	instance of class.
                     */
                    static ExitProcess * getInstance ( ExitProcess * externProcess = NULL );

                private:

                    static ExitProcess * instance; ///< instance of class
            };
        }
    }
}

#endif /* _EXIT_PROCESS_HXX_ */
