/**
 * @file ProcessLauncher.cpp
 * @brief Body process launcher class
 * @date 04/05/2011
 * @author Freddy Gomez
 */

#include "ProcessLauncher.h"
#include "SystemPipeProcess.hxx"
#include <stdlib.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::System::Runtime;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::Log;

ISMTTLog * ProcessLauncher::logger = SMTTLogManager::GetLogger ( "Smartmatic.System.Runtime.ProcessLauncher", GETTEXT_PACKAGE );
ProcessLauncher * ProcessLauncher::instance = NULL;

ProcessLauncher::ProcessLauncher()
{

}

ProcessLauncher::~ProcessLauncher()
{
    instance = NULL;
}

Smartmatic::System::SafeList < std::string > ProcessLauncher::RunProcessThroughPipe ( const std::string & commandLineWithArguments, PipeFile * pipeFile )
{
    Smartmatic::System::SafeList < std::string > retVal;

    pipeFile = ( pipeFile == NULL ? new SystemPipeProcess() : pipeFile );

    logger->Debug ( "RunProcessThroughPipe : " + commandLineWithArguments );

    if ( pipeFile->open ( commandLineWithArguments ) )
    {
        std::string line;
        bool result = true;

        while ( result )
        {
            line = pipeFile->getLine ( result );

            if ( result )
            {
                retVal.push_back ( line );
            }
            else
            {
                break;
            }
        }

        pipeFile->close();
    }

    delete pipeFile;

    return retVal;
}

int ProcessLauncher::RunProcessThroughSystem ( const std::string & commandLineWithArguments, bool background )
{
    std::string command = getCommand ( commandLineWithArguments, background );
    return runCommand ( command.c_str() );
}

std::string ProcessLauncher::getCommand ( const std::string & command, bool background )
{
    std::string result = command + std::string ( ( background ? " &" : "" ) );
    logger->Debug ( "RunProcessThroughSystem : " + result );
    return result;
}

int ProcessLauncher::runCommand ( const std::string & command )
{
    return system ( command.c_str() );
}

ProcessLauncher * ProcessLauncher::getInstance ( ProcessLauncher * externLauncher )
{
    if ( instance == NULL )
    {
        instance = ( externLauncher == NULL ? new ProcessLauncher() : externLauncher );
    }

    return instance;
}
