/**
 * @file ProcessMonitor.h
 * @brief Header process monitor class
 * @date 04/05/2011
 * @author Freddy Gomez
 */

#ifndef PROCESSMONITOR_H_
#define PROCESSMONITOR_H_

#include <string>

namespace Smartmatic
{

    namespace System
    {

        namespace Runtime
        {
            /**
             * @class	ProcessMonitor
             * @brief	Class definition file.
             * @author	Freddy Gomez &lt;fgomez@smartmatic.com&gt;
             * @date	04-05-2011
             */
            class ProcessMonitor
            {
                public:

                    /**
                     * @fn	static int ProcessMonitor::CountProcessRunning(const std::string & processSearchPattern);
                     * @brief	This method counts the number of process which match the specified pattern.
                     * @author	Freddy Gomez
                     * @date	04/05/2011
                     * @param [in]	processSearchPattern	process search pattern.
                     * @return	The nuber of process which match the pattern.
                     */
                    static int CountProcessRunning ( const std::string & processSearchPattern );

                    /**
                     * @fn	static void ProcessMonitor::KillProcess(int pid);
                     * @brief	This method kill the process specified.
                     * @author	Freddy Gomez
                     * @date	04/05/2011
                     * @param [in]	pid			process identifier.
                     */
                    static void KillProcess ( int pid );

                    /**
                     * @fn	static void ProcessMonitor::KillProcessAndWait(const std::string & processName, int count = 5 );
                     * @brief	This method kill the process and wait.
                     * @author	Yadickson Soto
                     * @date	04/05/2011
                     * @param	processName	process identifier.
                     * @param	count			 	retry count.
                     */
                    static void KillProcessAndWait ( const std::string & processName, int count = 5 );

                    /**
                     * @fn	static void ProcessMonitor::KillProcess( const std::string & processName, bool background = false );
                     * @brief	Kill the process.
                     * @author	Freddy Gomez
                     * @date	04/05/2011
                     * @param [in]	processName	process full name.
                     * @param	background run background command line
                     */
                    static void KillProcess ( const std::string & processName, bool background = false );
            };

        }
    }
}
#endif /* PROCESSMONITOR_H_ */
