/**
 * @file SafeDispatcher.hxx
 * @brief Header class SafeDispatcher
 * @date 22/07/2015
 * @author Yadickson Soto
 */

#ifndef _SAFE_DISPATCHER_H_
#define _SAFE_DISPATCHER_H_

#include <glibmm.h>
#include <list>

namespace Smartmatic
{
    namespace System
    {
        /**
         * @class	SafeDispatcher
         * @brief	SafeDispatcher class.
         * @author	Yadickson Soto
         * @date	22/07/2015
         */
        class SafeDispatcher
        {
            public:

                typedef sigc::signal<void, void *> SyncSignal; ///< Signal definition

                /**
                 * @fn	SafeDispatcher();
                 * @brief	Default constructor.
                 * @author	Yadickson Soto
                 * @date	22/07/2015
                 */
                SafeDispatcher();

                /**
                 * @fn	virtual ~SafeDispatcher();
                 * @brief	Finaliser.
                 * @author	Yadickson Soto
                 * @date	22/07/2015
                 */
                virtual ~SafeDispatcher();

                /**
                 * @fn	void emit( void * object );
                 * @brief	Method to emit object.
                 * @author	Yadickson Soto
                 * @date	22/07/2015
                 * @param object The object to emit
                 */
                virtual void emit ( void * object );

                /**
                 * @fn	SyncSignal getSyncSignal();
                 * @brief	Method get signal.
                 * @author	Yadickson Soto
                 * @date	23/06/2012
                 * @return signal
                 */
                SyncSignal getSyncSignal();

                /**
                 * @fn	unsigned int getQueueSize();
                 * @brief	Method get size of the queue.
                 * @author	Yadickson Soto
                 * @date	27/07/2015
                 * @return 	The size of the queue
                 */
                unsigned int getQueueSize();

            private:

                std::list < void * > currentList; ///< Current object list to process

                Glib::Dispatcher popPrivDispatcher; ///< pop dispatcher
                SyncSignal popDispatcher; ///< signal pop dispatcher
                Glib::Mutex syncProcessing_mutex; ///< mutex sync processing

                /**
                 * @fn	void handleDispatch();
                 * @brief	Method handle dispatch.
                 * @author	Yadickson Soto
                 * @date	22/07/2015
                 */
                void handleDispatch();
        };
    }
}

#endif /* _SAFE_DISPATCHER_H_ */
