/**
 * @file CertificateExtensionDER.cxx
 * @brief Body class certificate DER extension.
 * @date 18/12/2013
 * @author Beatriz Avila
 */

#include "CertificateExtensionDER.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <openssl/evp.h>
#include <openssl/x509.h>
#include <openssl/safestack.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::Log;
using namespace Smartmatic::System::Security::Cryptography;

ISMTTLog * CertificateExtensionDER::logger = SMTTLogManager::GetLogger ( "Smartmatic.System.Security.Cryptography.CertificateExtensionBase", GETTEXT_PACKAGE );

CertificateExtensionDER::CertificateExtensionDER ( const Smartmatic::System::SafeBuffer & certificateBuffer ) :
    CertificateExtensionBase::CertificateExtensionBase ( certificateBuffer )
{

}

CertificateExtensionDER::~CertificateExtensionDER ( )
{

}

CertificateExtensionDER * CertificateExtensionDER::clone() const
{
    CertificateExtensionDER* cloned = new CertificateExtensionDER(certificateBuffer);

    if (x509 != NULL)
        cloned->x509 = X509_dup(x509);

    if (privateKey != NULL)
    {
        CRYPTO_add(&privateKey->references, 1, CRYPTO_LOCK_EVP_PKEY);
        cloned->privateKey = privateKey;
    }

    if (publicKey != NULL)
    {
        CRYPTO_add(&publicKey->references, 1, CRYPTO_LOCK_EVP_PKEY);
        cloned->publicKey = publicKey;
    }

    return cloned;
}

X509 * CertificateExtensionDER::LoadCertifiedX509FromBIO ( )
{
    return d2i_X509_bio ( memoryBIO, NULL );
}

EVP_PKEY * CertificateExtensionDER::LoadCertifiedPrivateKeyFromBIO ( )
{
    return d2i_PrivateKey_bio ( memoryBIO, NULL );
}

STACK_OF ( X509 ) * CertificateExtensionDER::getCertificateAuthoritiesFromBIO ( )
{
    return certificateAuthorities;
}
