/**
 * @file CertificateExtensionPEM.cxx
 * @brief Body class certificate PEM extension.
 * @date 18/12/2013
 * @author Beatriz Avila
 */

#include "CertificateExtensionPEM.hxx"
#include <openssl/pem.h>
#include <string.h>
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::Log;
using namespace Smartmatic::System::Security::Cryptography;

ISMTTLog * CertificateExtensionPEM::logger = SMTTLogManager::GetLogger ( "Smartmatic.System.Security.Cryptography.CertificateExtensionBase", GETTEXT_PACKAGE );

CertificateExtensionPEM::CertificateExtensionPEM ( const Smartmatic::System::SafeBuffer & certificateBuffer, const std::string & certPassword ) :
    CertificateExtensionBase::CertificateExtensionBase ( certificateBuffer, certPassword )
{

}

CertificateExtensionPEM::~CertificateExtensionPEM ( )
{

}

CertificateExtensionPEM * CertificateExtensionPEM::clone() const
{
    CertificateExtensionPEM* cloned = new CertificateExtensionPEM(certificateBuffer, certPassword);

    if (x509 != NULL)
        cloned->x509 = X509_dup(x509);

    if (privateKey != NULL)
    {
        CRYPTO_add(&privateKey->references, 1, CRYPTO_LOCK_EVP_PKEY);
        cloned->privateKey = privateKey;
    }

    if (publicKey != NULL)
    {
        CRYPTO_add(&publicKey->references, 1, CRYPTO_LOCK_EVP_PKEY);
        cloned->publicKey = publicKey;
    }

    return cloned;
}

X509 * CertificateExtensionPEM::LoadCertifiedX509FromBIO ( )
{
    return PEM_read_bio_X509_AUX ( memoryBIO, NULL, ( pem_password_cb * ) passw_callback, NULL );
}

EVP_PKEY * CertificateExtensionPEM::LoadCertifiedPrivateKeyFromBIO ( )
{
    return PEM_read_bio_PrivateKey ( memoryBIO, NULL, ( pem_password_cb * ) passw_callback, ( char * ) certPassword.c_str() );
}

STACK_OF ( X509 ) * CertificateExtensionPEM::getCertificateAuthoritiesFromBIO ( )
{
    STACK_OF ( X509_INFO ) * xis = PEM_X509_INFO_read_bio ( memoryBIO, NULL, ( pem_password_cb * ) passw_callback, NULL );

    if ( xis )
    {
        certificateAuthorities = sk_X509_new_null();

        X509_INFO * xi = NULL;

        while ( ( xi = sk_X509_INFO_pop ( xis ) ) )
        {
            if ( xi->x509 )
            {
                sk_X509_push ( certificateAuthorities, xi->x509 );
                xi->x509 = NULL;
                X509_INFO_free(xi);
            }
        }

        sk_X509_INFO_pop_free ( xis, X509_INFO_free );
    }

    return certificateAuthorities;
}

int CertificateExtensionPEM::passw_callback ( char * buf, int bufsiz, int verify, char * password )
{
    int res = 0;

    if ( password )
    {
        res = strlen ( password );
        res = ( res > bufsiz  ? bufsiz : res );
        memcpy ( buf, password, res );
    }

    return res;
}
