/**
 * @file DigestAlgorithmLookup.h
 * @brief Header digest algorithm lookup class
 * @date 05/04/2011
 * @author Freddy Gomez
 */

#ifndef DIGESTALGORITHMDEFINITION_H_
#define DIGESTALGORITHMDEFINITION_H_

#include <openssl/evp.h>
#include "MsgDigestUtil.h"

namespace Smartmatic
{
    namespace System
    {
        namespace Security
        {
            namespace Cryptography
            {
                /**
                 * @class	DigestAlgorithmLookup
                 * @brief	Digest algorithm lookup class.
                 * @author	freddyg
                 * @date	28/04/2011
                 */
                class DigestAlgorithmLookup
                {

                    public:

                        /**
                         * @fn	DigestAlgorithmLookup::DigestAlgorithmLookup()
                         * @brief	Default constructor.
                         * @author	freddyg
                         * @date	28/04/2011
                         */
                        DigestAlgorithmLookup() {}

                        /**
                         * @fn	static const EVP_MD * DigestAlgorithmLookup::LookupDigest(DigestAlgType alg);
                         * @brief	Looks up a given key to find its associated digest.
                         * @author	freddyg
                         * @date	28/04/2011
                         * @param	alg	The algorithm.
                         * @return	null if it fails, else.
                         */
                        static const EVP_MD * LookupDigest ( MsgDigestUtil::DigestAlgType alg );
                };
            }
        }
    }
}
#endif /* DIGESTALGORITHMDEFINITION_H_ */
