/**
 * @file SecurityBase.hxx
 * @brief Header class security base
 * @date 21/03/2012
 * @author Yadickson Soto
 */

#ifndef SECURITYBASE_HXX_
#define SECURITYBASE_HXX_

#include <System/Security/Cryptography/CertUtil.h>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace System
    {
        namespace Security
        {
            /**
             * @class	SecurityBase
             * @brief	Class utils for crypto and signed.
             * @author	Yadickson Soto &lt;yadickson.soto@smartmatic.com&gt;
             * @date	21/03/2012
             */
            class SecurityBase
            {
                public:
                    /**
                     * @fn	SecurityBase();
                     * @brief	Class constructor.
                     * @author	Yadickson Soto
                     * @date	21/03/2012
                     */
                    SecurityBase();

                    /**
                     * @fn	virtual ~SecurityBase();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	21/03/2012
                     */
                    virtual ~SecurityBase();

                    /**
                     * @fn	void SetCertificate ( const std::string & certPath, Smartmatic::System::Security::Cryptography::CertUtil::CertFileFormat format, const std::string & certPass = "" );
                     * @brief	Loads the private key and public key to signed by certPath.
                     * @author	Yadickson Soto
                     * @date	20/01/2014
                     * @param	certPath	path file.
                     * @param	format		format certified.
                     * @param	certPass	password.
                     */
                    void SetCertificate ( const std::string & certPath, Smartmatic::System::Security::Cryptography::CertUtil::CertFileFormat format, const std::string & certPass = "" );

                    /**
                     * @fn	void SetCertificate( Smartmatic::System::Security::Cryptography::CertificateExtensionBase * certificate );
                     * @brief	Loads the private key and public key to signed.
                     * @author	Yadickson Soto
                     * @date	20/01/2014
                     * @param certificate certificate to load private key and public key.
                     */
                    void SetCertificate ( Smartmatic::System::Security::Cryptography::CertificateExtensionBase * certificate );

                protected:

                    Smartmatic::System::Security::Cryptography::CertificateExtensionBase * certificate; ///<certificate manager
            };
        }
    }
}

#endif /* SECURITYBASE_HXX_ */
