/**
 * @file Signed.cxx
 * @brief Body class for Signed file
 */

#include "Signed.hxx"

#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>
#include <System/Security/XmlDigitalSignature/XmlEnvelopedSignature.hxx>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///< macro for gettext
#else
#define _(String) (String) ///< macro without gettext
#endif

#define N_(String) (String) ///< macro not translate

using namespace Smartmatic::System::Security;
using namespace Smartmatic::System::Security::Cryptography;
using namespace Smartmatic::System::Exception;
using namespace Smartmatic::System;
using namespace Smartmatic::Log;

ISMTTLog * Signed::logger = SMTTLogManager::GetLogger ( "Smartmatic.System.Security.Signed", GETTEXT_PACKAGE );

Signed::Signed()
    : SecurityBase()
{

}

Signed::~Signed()
{

}

void Signed::signBuffer(const SafeBuffer& bufferIn, SafeBuffer& bufferOut, Signed::SignedType signedType) throw (SignedException)
{
    bufferOut.Clear();

    if (signedType == Signed::NOT_SIGNED)
    {
        bufferOut.AddData(bufferIn);
        return;
    }

    if (certificate == NULL)
    {
        logger->Debug("Error - Sign Dom - certificate NULL");
        throw SignedException(
            _("Smartmatic.System.Security.Signed.ErrorSignedCert"),
            N_("Smartmatic.System.Security.Signed.ErrorSignedCert"), logger);
    }

    XmlEnvelopedSignature envelopedSignature;

    if (envelopedSignature.sign(bufferIn, bufferOut, signedType, certificate) == false)
    {
        throw SignedException(
            _("Smartmatic.System.Security.Signed.ErrorSignedCert"),
            N_("Smartmatic.System.Security.Signed.ErrorSignedCert"),
            logger);
    }
}

bool Signed::verifyBuffer(const SafeBuffer& buffer) throw (SignedException)
{
    XmlEnvelopedSignature envelopedSignature;
    const bool validate = envelopedSignature.verify(buffer, certificate ? certificate->LoadCertifiedX509() : NULL);

    if (validate == false)
    {
        throw SignedException(
            _("Smartmatic.System.Security.Signed.ErrorValidatingDigitalXmlSignature"),
            N_("Smartmatic.System.Security.Signed.ErrorValidatingDigitalXmlSignature"),
            logger);
    }

    return validate;
}
