/**
 * @file XmlSignature.cxx
 * @brief Body class for XmlSignature file.
 * @author  Eduardo Fernández
 * @date    10/10/2018
 */

#include "XmlSignature.hxx"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///< macro for gettext
#else
#define _(String) (String) ///< macro without gettext
#endif

#define N_(String) (String) ///< macro not translate

#define DSIGNS_PREFIX "" ///< prefix signed node

using namespace Smartmatic::System;
using namespace Smartmatic::System::Security;
using namespace Smartmatic::System::Security::Cryptography;

XmlSignature::XmlSignature()
{
}

XmlSignature::~XmlSignature()
{
}

bool
XmlSignature::sign(
    const SafeBuffer& bufferToSign,
    SafeBuffer& signature,
    const Signed::SignedType& signatureType,
    CertificateExtensionBase * const certificate,
    const hashMethod& hash,
    const std::string& basePath)
{
    return m_xmlSignatureAlgorithm->signBuffer(bufferToSign, signature, signatureType, certificate, hash, basePath);
}

bool
XmlSignature::verify(
    const SafeBuffer& bufferToVerify,
    X509 * const certificate,
    const std::string& basePath)
{
    return m_xmlSignatureAlgorithm->verifyBuffer(bufferToVerify, certificate, basePath);
}
