/**
 * @file	smartmatic-sounds-manager.h
 *
 * @brief	Header file to the  sounds manager class.
 */

#include "System/Sounds/beep-descriptor.h"
#include "System/Sounds/beep-manager.h"

#ifndef _SMTT_SOUNDS_MANAGER_H_
#define _SMTT_SOUNDS_MANAGER_H_

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace System
    {
        namespace Sounds
        {
            /**
             * @class	SMTTSoundsManager
             * @brief	Manager for smtt sounds class.
             * @author	Rafael.gasperi
             * @date	28/04/2011
             */
            class SMTTSoundsManager
            {
                public:

                    /**
                     * @fn	SMTTSoundsManager::SMTTSoundsManager();
                     * @brief	Default constructor.
                     * @author	Rafael.gasperi
                     * @date	28/04/2011
                     */
                    SMTTSoundsManager();

                    /**
                     * @fn	virtual ~SMTTSoundsManager();
                     * @brief	Default destructorer
                     * @author	Yadickson Soto
                     * @date	06/02/2014
                     */
                    virtual ~SMTTSoundsManager();

                    /**
                     * @fn	static SMTTSoundsManager* SMTTSoundsManager::getInstance();
                     * @brief	Gets the current SMTT Sounds Manager.
                     * @author	Rafael.gasperi
                     * @date	28/04/2011
                     * @return	null if it fails, else.
                     */
                    static SMTTSoundsManager * getInstance(SMTTSoundsManager * externManager = NULL);

                    /**
                     * @fn	void SMTTSoundsManager::Sound(const std::string & sound);
                     * @brief	Sounds.
                     * @author	Yadickson Soto
                     * @date	06/02/2014
                     * @param	sound	The sound.
                     */
                    virtual void Sound ( const std::string & sound );

                    /**
                     * @fn	void Stop ();
                     * @brief	Stop service sounds.
                     * @author	Yadickson Soto
                     * @date	20/06/2013
                     */
                    void Stop ();

                protected:

                    static SMTTSoundsManager * singleton_instance; ///< The singleton instance
                    Smartmatic::System::Sounds::BeepManager beepManager; ///< Manager for beep
                    static Smartmatic::Log::ISMTTLog * logger;  ///< The logger
            };
        }
    }
}

#endif // _SMTT_SOUNDS_MANAGER_H_
