/**
 * @file StackTraceManager.hxx
 * @brief Header stack trace manager
 * @date 28/02/2013
 * @author Yadickson Soto
 */

#ifndef STACKTRACEMANAGER_HXX_
#define STACKTRACEMANAGER_HXX_

#include <glibmm.h>
#include <string>
#include <list>

namespace Smartmatic
{
    namespace System
    {

        /**
         * @class StackTraceManager
         * @brief Class stack trace manager
         * @date 28/02/2013
         * @author Yadickson Soto
         */
        class StackTraceManager
        {

            protected:
                /**
                 * @fn StackTraceManager();
                 * @brief Class constructor
                 * @date 28/02/2013
                 * @author Yadickson Soto
                 */
                StackTraceManager();

            public:
                /**
                 * @fn virtual ~StackTraceManager();
                 * @brief Class destructor
                 * @date 28/02/2013
                 * @author Yadickson Soto
                 */
                virtual ~StackTraceManager();

                /**
                 * @fn void start();
                 * @brief Method register signal
                 * @date 28/02/2013
                 * @author Yadickson Soto
                 */
                void start();

                /**
                 * @fn void stop();
                 * @brief Method stop register signal
                 * @date 28/02/2013
                 * @author Yadickson Soto
                 */
                void stop();

                /**
                 * @fn static StackTraceManager * getInstance( StackTraceManager * externStackTrace = NULL );
                 * @brief Method getter instance class
                 * @date 28/02/2013
                 * @author Yadickson Soto
                 * @param 	externStackTrace external StackTraceManager to unit test
                 * @return instance class
                 */
                static StackTraceManager * getInstance ( StackTraceManager * externStackTrace = NULL );

            protected:

                /**
                 * @fn virtual void getStack ( std::list < std::string > & list );
                 * @brief Method getter stack trace
                 * @date 28/02/2013
                 * @author Yadickson Soto
                 * @param list result list
                 */
                virtual void getStack ( std::list < std::string > & list );

                /**
                 * @fn virtual std::string getStack ();
                 * @brief Method getter stack trace
                 * @date 28/02/2013
                 * @author Yadickson Soto
                 * @return str
                 */
                virtual std::string getStackString ();

                /**
                 * @fn virtual void showSigSegvError();
                 * @brief Method show error messages to sigsegv
                 * @date 17/11/2013
                 * @author Yadickson Soto
                 */
                virtual void showSigSegvError();

                /**
                 * @fn virtual void showSigSegvError();
                 * @brief Method show error messages to sigabrt
                 * @date 17/11/2013
                 * @author Yadickson Soto
                 */
                virtual void showSigAbortError();

                /**
                 * @fn static void signalHandler ( int sig );
                 * @brief Method callback register signal
                 * @date 28/02/2013
                 * @author Yadickson Soto
                 * @param sig signal
                 */
                static void signalHandler ( int sig );

            private:

                static StackTraceManager * instance; ///< instance class
                Glib::Mutex mutexSignal; ///< The mutex signal
        };
    }
}

#endif /* STACKTRACEMANAGER_HXX_ */
