/**
 * @file DateTimeUtils.hxx
 * @brief Defines the date time util class.
 * @date 15/07/2013
 * @author Yadickson Soto
 */

#ifndef DATETIMEUTILS_HXX_
#define DATETIMEUTILS_HXX_

#include <string>
#include <ctime>

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace System
    {
        namespace Utils
        {
            /**
             * @class DateTimeUtils
             * @brief The date time util class
             * @author Yadickson Soto
             * @date 28/04/2014
             */
            class DateTimeUtils
            {
                public:

                    /**
                     * @fn DateTimeUtils ( const std::string & year, const std::string & month, const std::string & day );
                     * @brief Class constructor
                     * @author Yadickson Soto
                     * @date 28/04/2014
                     * @param day the day
                     * @param month the month
                     * @param year the year
                     */
                    DateTimeUtils ( const std::string & day, const std::string & month, const std::string & year );

                    /**
                     * @fn DateTimeUtils ( const std::string & stringTime = "" );
                     * @brief Class constructor
                     * @author Yadickson Soto
                     * @date 28/04/2014
                     * @param stringTime the data time
                     */
                    explicit DateTimeUtils ( const std::string & stringTime = "" );

                    /**
                     * @fn virtual ~DateTimeUtils();
                     * @brief Class destructor
                     * @author Yadickson Soto
                     * @date 28/04/2014
                     */
                    virtual ~DateTimeUtils();

                    /**
                     * @fn std::string getDate();
                     * @brief Gets date string (yyyy/mm/dd)
                     * @author Yadickson Soto
                     * @date 28/04/2014
                     * @return the date string
                     */
                    std::string getDate();

                    /**
                     * @fn std::string getTime();
                     * @brief Gets time string (H:M:S)
                     * @author Yadickson Soto
                     * @date 28/04/2014
                     * @return the time string
                     */
                    std::string getTime();

                    /**
                     * @fn std::string getDay();
                     * @brief Gets day
                     * @author Yadickson Soto
                     * @date 28/04/2014
                     * @return the day
                     */
                    std::string getDay();

                    /**
                     * @fn std::string getMonth();
                     * @brief Gets month
                     * @author Yadickson Soto
                     * @date 28/04/2014
                     * @return the month
                     */
                    std::string getMonth();

                    /**
                     * @fn std::string getYear();
                     * @brief Gets year
                     * @author Yadickson Soto
                     * @date 28/04/2014
                     * @return the year
                     */
                    std::string getYear();

                    /**
                     * @fn bool validate();
                     * @brief Getter date time if valid
                     * @return true if data time is valid
                     * @date 15/07/2013
                     * @author Yadickson Soto
                     */
                    bool validate();

                    /**
                     * @fn	static std::string getCurrentDateTime();
                     * @brief	Gets current datetime as iso8601 format string
                     * @author	Yadickson Soto
                     * @date	03/04/2013
                     * @return current datetime
                     */
                    static std::string getCurrentDateTime();

                private:

                    /**
                     * @fn void parse ( const std::string & stringTime );
                     * @brief Parser string time to validate
                     * @author Yadickson Soto
                     * @date 28/04/2014
                     * @param stringTime the data time
                     */
                    void parse ( const std::string & stringTime );

                    std::string input; ///< copy input date time
                    std::tm _time; ///< the input time

                    static Smartmatic::Log::ISMTTLog * logger; ///<logger
            };
        }
    } /* namespace System */
} /* namespace Smartmatic */
#endif /* DATETIMEUTILS_HXX_ */
