/**
 * @file SafeBufferUtils.cxx
 * @brief Body of the utility to split and find elements over any buffer.
 * @date 06/02/2014
 * @date Yadickson Soto
 */

#include "SafeBufferUtils.hxx"
#include <string.h>
#include <vector>
#include <algorithm>

#define CR 0x0D /*CR */
#define LF 0x0A /*LF */

using namespace Smartmatic::System::Utils;
using namespace Smartmatic::System;

SafeBufferUtils::SafeBufferUtils ( const SafeBuffer & buffer )
    : m_buffer(buffer.GetVector())
{
}

SafeBufferUtils::~SafeBufferUtils ()
{

}

std::vector < SafeBuffer > SafeBufferUtils::splitByEndLine ()
{
    std::vector < SafeBuffer > list;

    SafeBuffer endlineWindows;

    endlineWindows.push_back ( CR );
    endlineWindows.push_back ( LF );

    list = splitByBuffer ( endlineWindows );

    if ( list.empty () )
    {
        SafeBuffer endLineUnix;

        endLineUnix.push_back ( LF );

        list = splitByBuffer ( endLineUnix );
    }

    if ( list.empty () )
    {
        SafeBuffer endLineMac;

        endLineMac.push_back ( CR );

        list = splitByBuffer ( endLineMac );
    }

    if ( list.empty () )
    {
        SafeBuffer buffer(&m_buffer[0], m_buffer.size());
        list.push_back ( buffer );
    }

    return list;
}

std::vector < SafeBuffer > SafeBufferUtils::splitByBuffer ( const SafeBuffer & findBuffer )
{
    std::vector < SafeBuffer > list;
    unsigned long index     = 0;
    unsigned long posResult = 0;

    while ( findData ( index, findBuffer, posResult ) )
    {
        SafeBuffer b ( ( &m_buffer[0] + index ) , posResult - index );
        index = posResult + findBuffer.GetSize ();
        list.push_back ( b );
    }

    if ( !list.empty () && index < m_buffer.size () )
    {
        SafeBuffer b ( ( &m_buffer[0] + index ) , m_buffer.size () - index );
        list.push_back ( b );
    }

    return list;
}

bool SafeBufferUtils::findData ( unsigned long index, const Smartmatic::System::SafeBuffer & findBuffer, unsigned long & postResult )
{
    bool found = false;

    postResult = 0;

    if (findBuffer.GetSize() > 0 && index < m_buffer.size())
    {
        std::vector<unsigned char>::const_iterator it;

        it = std::search(m_buffer.begin() + index,
                         m_buffer.end(),
                         findBuffer.GetData(),
                         findBuffer.GetData() + findBuffer.GetSize());

        if (it != m_buffer.end())
        {
            found = true;
            postResult = (it - m_buffer.begin());
        }
    }

    return found;
}
