/**
 * @file ExtractCertificate.cxx
 * @brief Body class utils for extract certificate
 * @date 09/02/2013
 * @author Yadickson Soto
 */

#include "ExtractCertificate.hxx"
#include "DomXml.hxx"
#include <Log/ISMTTLog.h>
#include <Log/SMTTLogManager.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

using namespace Smartmatic::System::XML;
using namespace Smartmatic::Log;

ISMTTLog * ExtractCertificate::logger = SMTTLogManager::GetLogger ( "Smartmatic.System.XML.ExtractCertificate", GETTEXT_PACKAGE );

ExtractCertificate::ExtractCertificate ( const Smartmatic::System::SafeBuffer & buffer )
    : buffer ( buffer )
{

}

ExtractCertificate::~ExtractCertificate()
{

}

bool ExtractCertificate::getBase64Certificate ( Smartmatic::System::SafeBuffer & certificate )
{
    bool validate = false;

    certificate.Clear();

    Smartmatic::System::XML::DomXml domXml;
    xercesc::DOMDocument * dom = domXml.bufferToDom ( buffer );

    xercesc::DOMNode * elementX509Certificate = ( xercesc::DOMNode * ) dom->getDocumentElement();
    elementX509Certificate = domXml.getNode ( elementX509Certificate, "Signature" );
    elementX509Certificate = domXml.getNode ( elementX509Certificate, "KeyInfo" );
    elementX509Certificate = domXml.getNode ( elementX509Certificate, "X509Data" );
    elementX509Certificate = domXml.getNode ( elementX509Certificate, "X509Certificate" );

    if ( elementX509Certificate != NULL )
    {
        elementX509Certificate = elementX509Certificate->getFirstChild();
    }

    if ( elementX509Certificate != NULL && elementX509Certificate->getNodeType() == xercesc::DOMNode::TEXT_NODE )
    {
        char * msg = xercesc::XMLString::transcode ( elementX509Certificate->getTextContent() );
        certificate.AddData ( ( const unsigned char * ) msg, strlen ( msg ) );
        xercesc::XMLString::release ( &msg );
        validate = true;
    }
    else
    {
        logger->Debug ( "ERROR - X509Certificate XML" );
    }

    return validate;
}
