/**
 * @file   Xslt.hxx
 * @brief  Declaration of XSLT functions.
 * @author manuel.arguelles
 * @date   Mar 13, 2018
 */

#ifndef XSLT_HXX
#define XSLT_HXX

#include <string>

namespace Smartmatic
{
    namespace System
    {
        namespace XML
        {
            namespace Xslt
            {
                /**
                 * @brief  Transform and XML file using an xslt.
                 * @author manuel.arguelles
                 * @date   Mar 13, 2018
                 *
                 * @param  fileName   The path and name of the XML file to transform.
                 * @param  styleSheet The XSLT data.
                 *
                 * @throws xmlpp::exception      If error during the process occurs.
                 * @throws xmlpp::internal_error If error during the process occurs.
                 * @throws xmlpp::parse_error    If error during the parsing occurs.
                 *
                 * @return A string with the transformed XML file.
                 */
                std::string transformFile(const std::string& fileName, const std::string& styleSheet);
            }
        }
    }
}

#endif /* XSLT_HXX */
