/**
 * @file FOPTransformer.hxx
 * @brief Header class FOPTransformer, xml to pdf runtime
 * @date 27/10/2011
 * @author Yadickson Soto
 */

#ifndef FOPTRANSFORMER_HXX_
#define FOPTRANSFORMER_HXX_

#include <string>
#include "XSLFOTransformer.h"

namespace Smartmatic
{
    namespace Log
    {
        class ISMTTLog;
    }

    namespace System
    {
        namespace XSLFO
        {
            /**
             * @class	FOPTransformer
             * @brief	Class transformer xml to pdf runtime.
             * @author	Yadickson Soto
             * @see XSLFOTransformer
             * @date	27/10/2011
             */
            class FOPTransformer : public XSLFOTransformer
            {
                public:

                    /**
                     * @fn	FOPTransformer::FOPTransformer();
                     * @brief	Constructor.
                     * @author	Yadickson Soto
                     * @date	27/10/2011
                     */
                    FOPTransformer();
                    /**
                     * @fn	virtual FOPTransformer::~FOPTransformer();
                     * @brief	Destroy.
                     * @author	Yadickson Soto
                     * @date	27/10/2011
                     */
                    virtual ~FOPTransformer();
                    /**
                     * @fn	static void FOPTransformer::setConfigFile(const std::string & configFile);
                     * @brief	Method setter path config file runtine.
                     * @author	Yadickson Soto
                     * @date	27/10/2011
                     * @param	configFile	path config file fop runtime.
                     */
                    static void setConfigFile ( const std::string & configFile );
                    /**
                     * @fn	static std::string getConfigFile ();
                     * @brief	Gets path config file runtine.
                     * @author	Yadickson Soto
                     * @date	16/11/2013
                     * @return	path config file fop runtime.
                     */
                    static std::string getConfigFile ();
                    /**
                     * @fn	virtual bool FOPTransformer::transformFile(std::string outputFile, std::string inputFile,
                     * 			std::string templateFile);
                     * @brief	Method transformer xml to pdf fop runtine.
                     * @author	Yadickson Soto
                     * @date	27/10/2011
                     * @param	outputFile		path output pdf file.
                     * @param	inputFile			path input xml file.
                     * @param	templateFile	path input xlst file.
                     * @return	true is success transformation.
                     */
                    virtual bool transformFile ( std::string outputFile, std::string inputFile, std::string templateFile );

                private:

                    /**
                     * @fn	bool FOPTransformer::transformToFile( const std::string& outputFile, const std::string& inputFile, const std::string& templateFile, const std::string& outputFormat );
                     * @brief	Method transformer xml to file.
                     * @author	Yadickson Soto
                     * @date	05/12/2012
                     * @param	outputFile		path output pdf file.
                     * @param	inputFile			path input xml file.
                     * @param	templateFile	path input xlst file.
                     * @param outputFormat output format
                     * @return	true is success transformation.
                     */
                    bool transformToFile ( const std::string& outputFile, const std::string& inputFile, const std::string& templateFile, const std::string& outputFormat );

                    static std::string configFile; ///< path config file fop runtime
                    static Smartmatic::Log::ISMTTLog * logger; ///<logger
            };
        }
    }
}

#endif /* FOPTRANSFORMER_HXX_ */
