#ifndef TEST_SMTT_LANGUAGE_CONTROLLER_TEST
#define TEST_SMTT_LANGUAGE_CONTROLLER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Configuration/SmartmaticLanguageController.hxx>
#include <System/OptParser.hxx>

class SmartmaticLanguageControllerTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::Configuration::SmartmaticLanguageController SmartmaticLanguageController;
        typedef Smartmatic::System::OptParser OptParser;

        OptParser * parser;

    public:

        SmartmaticLanguageControllerTest ()
        {
            parser = NULL;
        }

        void setUp()
        {
            parser = OptParser::getInstance();
        }

        void tearDown()
        {
            delete parser;
        }

        void testDefaultValues()
        {
            SmartmaticLanguageController controller;

            CPPUNIT_ASSERT ( GETTEXT_PACKAGE == controller.getPackageName() );
            CPPUNIT_ASSERT ( GNOMELOCALEDIR == controller.getLocaleDir() );
        }

        void testChangeLocalePath()
        {
            SmartmaticLanguageController controller;

            const char * argv [] = { "app", "--localedir", "locale-path" };
            int argc = 3;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( GETTEXT_PACKAGE == controller.getPackageName() );
            CPPUNIT_ASSERT ( "locale-path" == controller.getLocaleDir() );
        }

        CPPUNIT_TEST_SUITE ( SmartmaticLanguageControllerTest );

        CPPUNIT_TEST ( testDefaultValues );
        CPPUNIT_TEST ( testChangeLocalePath );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_SMTT_LANGUAGE_CONTROLLER_TEST */
