/*
 * StoreMockFile.hxx
 *
 *  Created on: 06/11/2013
 *      Author: soto
 */

#ifndef STORE_MOCK_FILE_HXX
#define STORE_MOCK_FILE_HXX

#include <list>
#include <System/IO/File.h>

class StoreMockFile : public Smartmatic::System::IO::File
{
    public:

        StoreMockFile ()
        {

        }

        virtual ~StoreMockFile ()
        {
            clearAll();
        }

        struct OpenFileValues
        {
            OpenFileValues ( Smartmatic::System::SafeBuffer buffer, bool returValue )
                : buffer ( buffer ), returValue ( returValue ) { }

            Smartmatic::System::SafeBuffer buffer;
            bool returValue;
        };

        struct SafeBufferValues
        {
            SafeBufferValues ( Smartmatic::System::SafeBuffer buffer, const std::string & file )
                : buffer ( buffer ), file ( file ) { }

            Smartmatic::System::SafeBuffer buffer;
            std::string file;
        };

        std::list < std::string > canOpenFileList;
        std::list < bool > canOpenFileReturnValues;
        std::list < OpenFileValues > openFileValues;
        std::list < std::string > openFileListValues;
        std::list < SafeBufferValues > saveBufferValues;
        std::list < bool > saveReturnValues;
        Smartmatic::System::SafeBuffer addBufferFile;
        std::list < std::string > deleteFileListValues;
        std::list < bool > deleteFileReturnValues;

        virtual bool canOpenFile ( const std::string & file )
        {
            bool value = false;

            if ( !canOpenFileReturnValues.empty() )
            {
                value = canOpenFileReturnValues.front();

                canOpenFileReturnValues.pop_front();
                canOpenFileList.push_back ( file );
            }

            return value;
        }

        virtual bool openFileToBuffer ( const std::string & file, Smartmatic::System::SafeBuffer & out )
        {
            bool value = false;
            out.Clear();

            if ( !openFileValues.empty() )
            {
                OpenFileValues & obj ( openFileValues.front() );
                value = obj.returValue;
                out.AddData ( obj.buffer );

                openFileValues.pop_front();
                openFileListValues.push_back ( file );
            }

            return value;
        }

        virtual bool saveBufferToFile ( const Smartmatic::System::SafeBuffer & buffer, const std::string & file )
        {
            bool value = false;

            if ( !saveReturnValues.empty() )
            {
                value = saveReturnValues.front();
                saveReturnValues.pop_front();
                saveBufferValues.push_back ( SafeBufferValues ( buffer, file ) );
            }

            return value;
        }

        virtual bool addBufferToFile ( const Smartmatic::System::SafeBuffer & buffer, const std::string & file )
        {
            bool value = false;

            if ( !saveReturnValues.empty() )
            {
                value = saveReturnValues.front();
                saveReturnValues.pop_front();
                saveBufferValues.push_back ( SafeBufferValues ( buffer, file ) );
                addBufferFile.AddData ( buffer );
            }

            return value;
        }

        virtual bool DeleteFile ( const std::string & file )
        {
            bool value = false;

            if ( !deleteFileReturnValues.empty() )
            {
                value = deleteFileReturnValues.front();

                deleteFileReturnValues.pop_front();
                deleteFileListValues.push_back ( file );
            }

            return value;
        }

        void clearAll()
        {
            openFileValues.clear();
            openFileListValues.clear();
            saveBufferValues.clear();
            saveReturnValues.clear();
            addBufferFile.Clear();
            deleteFileReturnValues.clear();
            deleteFileListValues.clear();
        }
};

#endif /* STORE_MOCK_FILE_HXX */

