#ifndef TEST_ZIPCOMPRESSIONTEST
#define TEST_ZIPCOMPRESSIONTEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Compression/ZipCompression.hxx>

class ZipCompressionTest : public CPPUNIT_NS::TestFixture
{
    private:

        Smartmatic::System::Compression::ICompression * object;

    public:

        ZipCompressionTest()
        {
            object = NULL;
        }

        void setUp()
        {
            object = new Smartmatic::System::Compression::ZipCompression();
        }

        void tearDown()
        {
            delete object;
        }

        void testInflateNull()
        {
            Smartmatic::System::SafeBuffer dataIn;
            Smartmatic::System::SafeBuffer dataOut;
            int avail;

            CPPUNIT_ASSERT ( false == object->Inflate ( dataIn, dataOut, avail ) );
            CPPUNIT_ASSERT ( 0 == avail );
        }

        void testInflateNoZip()
        {
            Smartmatic::System::SafeBuffer dataIn ( "abcdf" );
            Smartmatic::System::SafeBuffer dataOut;
            int avail;

            CPPUNIT_ASSERT ( false == object->Inflate ( dataIn, dataOut, avail ) );
            CPPUNIT_ASSERT ( 0 == avail );
        }

        void testInflate()
        {
            unsigned char data[] = { 0x78, 0xda, 0x73, 0x74, 0x72, 0x76, 0x71, 0x75, 0x03, 0x00, 0x05, 0x7e, 0x01, 0x96 };
            unsigned int size = sizeof ( data ) / sizeof ( unsigned char );

            Smartmatic::System::SafeBuffer dataIn ( data, size );
            Smartmatic::System::SafeBuffer dataOut;
            int avail;

            CPPUNIT_ASSERT ( true == object->Inflate ( dataIn, dataOut, avail ) );
            CPPUNIT_ASSERT ( 0 == avail );
        }

        void testDeflateNull()
        {
            Smartmatic::System::SafeBuffer dataIn;
            Smartmatic::System::SafeBuffer dataOut;

            CPPUNIT_ASSERT ( false == object->Deflate ( dataIn, dataOut ) );
        }

        void testDeflateString()
        {
            Smartmatic::System::SafeBuffer dataIn ( "String" );
            Smartmatic::System::SafeBuffer dataOut;

            CPPUNIT_ASSERT ( true == object->Deflate ( dataIn, dataOut ) );
        }

        void testDeflate()
        {
            Smartmatic::System::SafeBuffer dataIn ( "ABCDEF" );
            Smartmatic::System::SafeBuffer dataOut;

            CPPUNIT_ASSERT ( true == object->Deflate ( dataIn, dataOut ) );
            CPPUNIT_ASSERT ( "eNpzdHJ2cXUDAAV+AZY=" == dataOut.GetBase64Data() );
        }

        void testRegretion()
        {
            std::string input = "ABCDEF";
            std::string output;

            Smartmatic::System::SafeBuffer dataIn ( input );
            Smartmatic::System::SafeBuffer dataZip;
            Smartmatic::System::SafeBuffer dataOut;
            int avail;

            CPPUNIT_ASSERT ( true == object->Deflate ( dataIn, dataZip ) );
            CPPUNIT_ASSERT ( true == object->Inflate ( dataZip, dataOut, avail ) );

            output.assign ( ( const char * ) dataOut.GetData(), dataOut.GetSize() );

            CPPUNIT_ASSERT ( input == output );
            CPPUNIT_ASSERT ( 0 == avail );
        }

        CPPUNIT_TEST_SUITE ( ZipCompressionTest );
        CPPUNIT_TEST ( testInflateNull );
        CPPUNIT_TEST ( testInflateNoZip );
        CPPUNIT_TEST ( testInflate );
        CPPUNIT_TEST ( testDeflateNull );
        CPPUNIT_TEST ( testDeflateString );
        CPPUNIT_TEST ( testDeflate );
        CPPUNIT_TEST ( testRegretion );
        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_ZIPCOMPRESSIONTEST */
