/**
 * @file   FatFileManagerStubs.hxx
 * @brief  Declaration of stubs required for FatFileManagerTests.
 * @author manuel.arguelles
 * @date   Aug  9, 2017
 */

#ifndef FAT_FILE_MANAGER_STUBS_HXX
#define FAT_FILE_MANAGER_STUBS_HXX

#include <System/IO/IDirectory.hxx>
#include <System/IO/IFile.hxx>
#include <string>
#include <vector>

class OneFile : public Smartmatic::System::IO::IDirectory
{
    public:
        OneFile() {}
        virtual ~OneFile() {}
        virtual bool Delete(const std::string& path) { return true; }
        virtual void GetFiles(const std::string& path, std::vector<std::string>& list)
            {
                list.push_back("File.txt");
            }
        virtual void GetDirectories(const std::string& path, std::vector<std::string>& list)
            {
            }
        virtual bool Mkdir(const std::string& path) { return true; }
        virtual bool DirectoryExists(const std::string& path)
            {
                if (path.rfind(".txt") == std::string::npos)
                    return true;
                return false;
            }

};

class OneFilePerOneDirectory : public Smartmatic::System::IO::IDirectory
{
    public:
        OneFilePerOneDirectory() : m_firstTime(true) {}
        virtual ~OneFilePerOneDirectory() {}
        virtual bool Delete(const std::string& path) { return true; }
        virtual void GetFiles(const std::string& path, std::vector<std::string>& list)
            {
                list.push_back("File.txt");
            }
        virtual void GetDirectories(const std::string& path, std::vector<std::string>& list)
            {
                if (m_firstTime)
                {
                    list.push_back("Directory");
                    m_firstTime = false;
                }
            }
        virtual bool Mkdir(const std::string& path) { return true; }
        virtual bool DirectoryExists(const std::string& path)
            {
                if (path.rfind(".txt") == std::string::npos)
                    return true;
                return false;
            }
    private:
        bool m_firstTime;
};

class EmptyDirectory : public Smartmatic::System::IO::IDirectory
{
    public:
        EmptyDirectory() {}
        virtual ~EmptyDirectory() {}
        virtual bool Delete(const std::string& path) { return true; }
        virtual void GetFiles(const std::string& path, std::vector<std::string>& list)
            {
                list.clear();
            }
        virtual void GetDirectories(const std::string& path, std::vector<std::string>& list)
            {
                list.clear();
                list.push_back(".");
                list.push_back("..");
                for (std::string::size_type i = 0; i < m_structure.size(); ++i)
                {
                    std::string directory;
                    std::string::size_type pos = m_structure[i].rfind('/');
                    if (pos != m_structure[i].size() - 1)
                    {
                        directory = m_structure[i].substr(pos);
                        list.push_back(m_structure[i]);
                    }
                    else if ((pos = m_structure[i].rfind('/', m_structure[i].size() - 2)) != std::string::npos)
                    {
                        directory = m_structure[i].substr(pos+1, (m_structure[i].size() - (pos + 2)));
                        if (path.rfind(directory) == std::string::npos)
                            list.push_back(directory);
                    }
                }
            }
        virtual bool Mkdir(const std::string& path)
            {
                m_structure.push_back(path);
                return true;
            }
        virtual bool DirectoryExists(const std::string& path) { return true; }
    public:
        std::vector<std::string> getStructure() { return m_structure; }
    private:
        std::vector<std::string> m_structure;
};

#endif /* FAT_FILE_MANAGER_STUBS_HXX */
