#ifndef TEST_OPT_PARSER_TEST_
#define TEST_OPT_PARSER_TEST_

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Runtime/ProcessLauncher.h>
#include <Configuration/configuration-persistence-manager.h>
#include <System/XSLFO/FOPTransformer.hxx>
#include <Log/SMTTLogManager.h>
#include <System/OptParser.hxx>
#include "MockExitProcess.hxx"
#include "MockDirectory.hxx"
#include "MockProcessLauncher.hxx"

class OptParserTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Runtime::ProcessLauncher ProcessLauncher;
        typedef Smartmatic::System::OptParser OptParser;
        typedef Smartmatic::System::Runtime::ExitProcess ExitProcess;
        typedef Smartmatic::System::IO::Directory Directory;
        typedef Smartmatic::Configuration::ConfigurationPersistenceManager ConfigurationPersistenceManager;
        typedef Smartmatic::Log::SMTTLogManager SMTTLogManager;
        typedef Smartmatic::System::XSLFO::FOPTransformer FOPTransformer;

        OptParser * parser;

    public:

        OptParserTest ()
        {
            parser = NULL;
        }

        void setUp()
        {
            parser = OptParser::getInstance();
        }

        void tearDown()
        {
            delete parser;
        }

        void testInitializeWithoutInitializer()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MockDirectory directory;
            Directory::getInstance ( &directory );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockDirectory, FileExists, ext ) FileExists_mock ( &directory );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            FileExists_mock
            .expects ( MOCKPP_NS::never() );

            std::string result;

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::SHARE_DIR ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOCALE_DIR ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::SHARE_DIR, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOCALE_DIR, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            launcher.verify();
            exitProcess.verify();
            directory.verify();
        }

        void testInitializeWithoutParameters()
        {
            const char * argv [] = { "app" };
            int argc = 1;

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MockDirectory directory;
            Directory::getInstance ( &directory );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockDirectory, FileExists, ext ) FileExists_mock ( &directory );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            FileExists_mock
            .expects ( MOCKPP_NS::never() );

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            launcher.verify();
            exitProcess.verify();
            directory.verify();
        }

        void testInitializeWithWrongParameter()
        {
            const char * argv [] = { "app", "wrong", "abcd" };
            int argc = 3;

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MockDirectory directory;
            Directory::getInstance ( &directory );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockDirectory, FileExists, ext ) FileExists_mock ( &directory );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            FileExists_mock
            .expects ( MOCKPP_NS::never() );

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            launcher.verify();
            exitProcess.verify();
            directory.verify();
        }

        void testInitializeWithEmptyConfigParameter()
        {
            const char * argv [] = { "app", "--config" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithConfigParameter()
        {
            const char * argv [] = { "app", "--config", "configFile" };
            int argc = 3;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;
            std::string expected = "configFile";

            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expected == result );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithConfigShortParameter()
        {
            const char * argv [] = { "app", "-c", "configFile", "other" };
            int argc = 4;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;
            std::string expected = "configFile";

            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expected == result );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithEmptyLoggerParameter()
        {
            const char * argv [] = { "app", "--logger" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            std::string result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithLoggerParameter()
        {
            const char * argv [] = { "app", "--logger", "loggerFile", "abcd" };
            int argc = 4;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;
            std::string expected = "loggerFile";

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expected == result );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithLoggerShortParameter()
        {
            const char * argv [] = { "app", "-g", "loggerFile", "opqr", "xyz" };
            int argc = 5;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;
            std::string expected = "loggerFile";

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expected == result );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithEmptyXslfoParameter()
        {
            const char * argv [] = { "app", "--xslfo" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithXslfoParameter()
        {
            const char * argv [] = { "app", "--xslfo", "XslfoFile" };
            int argc = 3;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;
            std::string expected = "XslfoFile";

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expected == result );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithXslfoShortParameter()
        {
            const char * argv [] = { "app", "-x", "XslfoFile" };
            int argc = 3;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;
            std::string expected = "XslfoFile";

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expected == result );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithDisableValidationParameter()
        {
            const char * argv [] = { "app", "--disable-bid-sid-validation" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );
        }

        void testInitializeWithDisableValidationShortParameter()
        {
            const char * argv [] = { "app", "-d" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );
        }

        void testInitializeWithDisableSaveVote()
        {
            const char * argv [] = { "app", "--disable-save-vote" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );
        }

        void testInitializeWithDisableSaveVoteShortParameter()
        {
            const char * argv [] = { "app", "-e" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );
        }

        void testInitializeWithDbusInfoParameter()
        {
            const char * argv [] = { "app", "--dbus-info" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );
        }

        void testInitializeWithDbusInfoShortParameter()
        {
            const char * argv [] = { "app", "-i" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );
        }

        void testInitializeWithHelpParameter()
        {
            const char * argv [] = { "app", "--help" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );
        }

        void testInitializeWithHelpShortParameter()
        {
            const char * argv [] = { "app", "-h" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );
        }

        void testInitializeWithVersionParameter()
        {
            const char * argv [] = { "app", "--version" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );
        }

        void testInitializeWithVersionShortParameter()
        {
            const char * argv [] = { "app", "-v" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );
        }

        void testInitializeWithAllLongParameters()
        {
            const char * argv [] = { "app",
                                     "--config", "cf",
                                     "--sharedir", "dd",
                                     "--localedir", "ld",
                                     "--logger", "lf",
                                     "--xslfo", "xf",
                                     "--mode", "mp",
                                     "--login", "lgn",
                                     "--password", "pass",
                                     "--disable-bid-sid-validation", "x",
                                     "--dbus-info", "x",
                                     "--help", "x",
                                     "--version", "x",
                                     "--disable-save-vote", "x"
                                   };
            int argc = 26;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            std::string expectedConfig = "cf";
            std::string expectedShareDir = "dd";
            std::string expectedLocaleDir = "ld";
            std::string expectedLogger = "lf";
            std::string expectedXslfo = "xf";
            std::string expectedMode = "mp";
            std::string expectedLogin = "lgn";
            std::string expectedPass = "pass";

            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::SHARE_DIR ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::LOCALE_DIR ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedConfig == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::SHARE_DIR, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedShareDir == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::LOCALE_DIR, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedLocaleDir == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedLogger == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedXslfo == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedMode == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedLogin == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedPass == result );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithAllShortParameters()
        {
            const char * argv [] = { "app",
                                     "-c", "cf",
                                     "-s", "dd",
                                     "-o", "ld",
                                     "-g", "lf",
                                     "-x", "xf",
                                     "-m", "mp",
                                     "-l", "lgn",
                                     "-p", "pass",
                                     "-d", "x",
                                     "-i", "x",
                                     "-h", "x",
                                     "-v", "x",
                                     "-e", "x"
                                   };
            int argc = 26;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            std::string expectedConfig = "cf";
            std::string expectedShareDir = "dd";
            std::string expectedLocaleDir = "ld";
            std::string expectedLogger = "lf";
            std::string expectedXslfo = "xf";
            std::string expectedMode = "mp";
            std::string expectedLogin = "lgn";
            std::string expectedPass = "pass";

            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::SHARE_DIR ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::LOCALE_DIR ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedConfig == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::SHARE_DIR, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedShareDir == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::LOCALE_DIR, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedLocaleDir == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedLogger == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedXslfo == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedMode == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedLogin == result );

            result = "value";
            CPPUNIT_ASSERT ( true == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expectedPass == result );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithAllEmptyLongParameters()
        {
            const char * argv [] = { "app",
                                     "--disable-bid-sid-validation",
                                     "--dbus-info",
                                     "--help",
                                     "--version",
                                     "--disable-save-vote"
                                   };
            int argc = 6;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testInitializeWithAllEmptyShortParameters()
        {
            const char * argv [] = { "app",
                                     "-d",
                                     "-i",
                                     "-h",
                                     "-v",
                                     "-e"
                                   };
            int argc = 6;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::CONFIG ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGGER ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::XSLFO ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::MODE ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::LOGIN ) );
            CPPUNIT_ASSERT ( false == parser->isSet ( OptParser::PASSWORD ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_BID_SID_VALIDATE ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DBUS_INFO ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::HELP ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::VERS ) );
            CPPUNIT_ASSERT ( true == parser->isSet ( OptParser::DISABLE_SAVE_VOTE ) );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::CONFIG, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGGER, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::XSLFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::MODE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::LOGIN, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::PASSWORD, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_BID_SID_VALIDATE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DBUS_INFO, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::HELP, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::VERS, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );

            result = "value";
            CPPUNIT_ASSERT ( false == parser->getArg ( OptParser::DISABLE_SAVE_VOTE, result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testGetHelpStringWithParameters()
        {
            const char * argv [] = { "app", "-h" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            CPPUNIT_ASSERT ( true == parser->getHelpOption ( result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
        }

        void testGetHelpStringWithoutParameters()
        {
            const char * argv [] = { "app" };
            int argc = 1;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            CPPUNIT_ASSERT ( false == parser->getHelpOption ( result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testGetLoginStringWithParameters()
        {
            const char * argv [] = { "app", "-l", "login" };
            int argc = 3;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;
            std::string expected = "login";

            CPPUNIT_ASSERT ( true == parser->getLoginOption ( result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expected == result );
        }

        void testGetLoginStringWithoutParameters()
        {
            const char * argv [] = { "app" };
            int argc = 1;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            CPPUNIT_ASSERT ( false == parser->getLoginOption ( result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testGetPasswordStringWithParameters()
        {
            const char * argv [] = { "app", "-p", "pass" };
            int argc = 3;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;
            std::string expected = "pass";

            CPPUNIT_ASSERT ( true == parser->getPasswordOption ( result ) );
            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expected == result );
        }

        void testGetPasswordStringWithoutParameters()
        {
            const char * argv [] = { "app" };
            int argc = 1;

            parser->initialize ( argc, ( char ** ) argv );

            std::string result;

            CPPUNIT_ASSERT ( false == parser->getPasswordOption ( result ) );
            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testRunApplicationProcessOnlyHelp()
        {
            const char * argv [] = { "app", "-h" };
            int argc = 2;

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MockDirectory directory;
            Directory::getInstance ( &directory );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockExitProcess, exitProcessWithCode, ext ) exitProcessWithCode_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockDirectory, FileExists, ext ) FileExists_mock ( &directory );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            exitProcessWithCode_mock
            .expects ( MOCKPP_NS::once() );

            FileExists_mock
            .expects ( MOCKPP_NS::never() );

            parser->initialize ( argc, ( char ** ) argv );
            parser->runApplicationProcess ( "package", "basepath" );

            launcher.verify();
            exitProcess.verify();
            directory.verify();
        }

        void testRunApplicationProcessOnlyVersion()
        {
            const char * argv [] = { "app", "-v" };
            int argc = 2;

            parser->initialize ( argc, ( char ** ) argv );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MockDirectory directory;
            Directory::getInstance ( &directory );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockExitProcess, exitProcessWithCode, ext ) exitProcessWithCode_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockDirectory, FileExists, ext ) FileExists_mock ( &directory );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            exitProcessWithCode_mock
            .expects ( MOCKPP_NS::once() );

            FileExists_mock
            .expects ( MOCKPP_NS::never() )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue<bool> ( false ),
                        MOCKPP_NS::returnValue<bool> ( false ),
                        MOCKPP_NS::returnValue<bool> ( false ) ) );

            parser->runApplicationProcess ( "package", "basepath" );

            launcher.verify();
            exitProcess.verify();
            directory.verify();
        }

        void testRunApplicationProcessLoadDefault()
        {
            const char * argv [] = { "app" };
            int argc = 1;

            parser->initialize ( argc, ( char ** ) argv );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MockDirectory directory;
            Directory::getInstance ( &directory );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockDirectory, FileExists, ext ) FileExists_mock ( &directory );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            FileExists_mock
            .expects ( MOCKPP_NS::exactly ( 3 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue<bool> ( true ),
                        MOCKPP_NS::returnValue<bool> ( true ),
                        MOCKPP_NS::returnValue<bool> ( true ) ) );

            parser->runApplicationProcess ( "package", "basepath" );

            std::string expectedConfig = "configuration-miscellaneous.xml";
            std::string expectedLogger = "log4-configuration.xml";
            std::string expectedCofigFop = "fop.xconf";

            CPPUNIT_ASSERT ( expectedConfig == ConfigurationPersistenceManager::filePath );
            CPPUNIT_ASSERT ( expectedLogger == SMTTLogManager::getInstance()->getConfigFile() );
            CPPUNIT_ASSERT ( expectedCofigFop == FOPTransformer::getConfigFile() );

            launcher.verify();
            exitProcess.verify();
            directory.verify();
        }

        void testRunApplicationProcessLoadParameters()
        {
            const char * argv [] = { "app",
                                     "-c", "config",
                                     "-g", "logger",
                                     "-x", "xslfo"
                                   };
            int argc = 7;

            parser->initialize ( argc, ( char ** ) argv );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MockDirectory directory;
            Directory::getInstance ( &directory );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockDirectory, FileExists, ext ) FileExists_mock ( &directory );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            FileExists_mock
            .expects ( MOCKPP_NS::exactly ( 6 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue<bool> ( false ),
                        MOCKPP_NS::returnValue<bool> ( true ),
                        MOCKPP_NS::returnValue<bool> ( false ),
                        MOCKPP_NS::returnValue<bool> ( true ),
                        MOCKPP_NS::returnValue<bool> ( false ),
                        MOCKPP_NS::returnValue<bool> ( true ) ) );

            parser->runApplicationProcess ( "package", "basepath" );

            std::string expectedConfig = "config";
            std::string expectedLogger = "logger";
            std::string expectedCofigFop = "xslfo";

            CPPUNIT_ASSERT ( expectedConfig == ConfigurationPersistenceManager::filePath );
            CPPUNIT_ASSERT ( expectedLogger == SMTTLogManager::getInstance()->getConfigFile() );
            CPPUNIT_ASSERT ( expectedCofigFop == FOPTransformer::getConfigFile() );

            launcher.verify();
            exitProcess.verify();
            directory.verify();
        }

        void testRunApplicationProcessWithModeConfigFileNotFound()
        {
            const char * argv [] = { "app", "-m", "mp" };
            int argc = 3;

            parser->initialize ( argc, ( char ** ) argv );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MockDirectory directory;
            Directory::getInstance ( &directory );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockDirectory, FileExists, ext ) FileExists_mock ( &directory );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() );

            exitProcess_mock
            .expects ( MOCKPP_NS::once() );

            FileExists_mock
            .expects ( MOCKPP_NS::exactly ( 2 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue<bool> ( false ),
                        MOCKPP_NS::returnValue<bool> ( false ) ) );

            parser->runApplicationProcess ( "package", "basepath" );

            launcher.verify();
            exitProcess.verify();
            directory.verify();
        }

        void testRunApplicationProcessWithModeConfigFileFoundLoggerFileNotFound()
        {
            const char * argv [] = { "app", "-m", "mp" };
            int argc = 3;

            parser->initialize ( argc, ( char ** ) argv );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MockDirectory directory;
            Directory::getInstance ( &directory );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockDirectory, FileExists, ext ) FileExists_mock ( &directory );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() );

            exitProcess_mock
            .expects ( MOCKPP_NS::once() );

            FileExists_mock
            .expects ( MOCKPP_NS::exactly ( 4 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue<bool> ( false ),
                        MOCKPP_NS::returnValue<bool> ( true ),
                        MOCKPP_NS::returnValue<bool> ( false ),
                        MOCKPP_NS::returnValue<bool> ( false ) ) );

            parser->runApplicationProcess ( "package", "basepath" );

            std::string expectedConfig = "basepath/MP/configuration-miscellaneous.xml";

            CPPUNIT_ASSERT ( expectedConfig == ConfigurationPersistenceManager::filePath );

            launcher.verify();
            exitProcess.verify();
            directory.verify();
        }

        void testRunApplicationProcessWithModeConfigAndLoggerFilesFoundXslfoFirstOption()
        {
            const char * argv [] = { "app", "-m", "mp" };
            int argc = 3;

            parser->initialize ( argc, ( char ** ) argv );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MockDirectory directory;
            Directory::getInstance ( &directory );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockDirectory, FileExists, ext ) FileExists_mock ( &directory );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            FileExists_mock
            .expects ( MOCKPP_NS::exactly ( 4 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue<bool> ( true ),
                        MOCKPP_NS::returnValue<bool> ( false ),
                        MOCKPP_NS::returnValue<bool> ( true ),
                        MOCKPP_NS::returnValue<bool> ( true ) ) );

            parser->runApplicationProcess ( "package", "basepath" );

            std::string expectedConfig = "configuration-miscellaneous.xml";
            std::string expectedLogger = "basepath/MP/log4-configuration.xml";
            std::string expectedCofigFop = "fop.xconf";

            CPPUNIT_ASSERT ( expectedConfig == ConfigurationPersistenceManager::filePath );
            CPPUNIT_ASSERT ( expectedLogger == SMTTLogManager::getInstance()->getConfigFile() );
            CPPUNIT_ASSERT ( expectedCofigFop == FOPTransformer::getConfigFile() );

            launcher.verify();
            exitProcess.verify();
            directory.verify();
        }

        void testRunApplicationProcessWithModeConfigAndLoggerFilesFoundXslfoSecondOption()
        {
            const char * argv [] = { "app", "-m", "mp" };
            int argc = 3;

            parser->initialize ( argc, ( char ** ) argv );

            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MockExitProcess exitProcess;
            ExitProcess::getInstance ( &exitProcess );

            MockDirectory directory;
            Directory::getInstance ( &directory );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );
            MOCKPP_CHAINER_FOR ( MockExitProcess, exitProcess ) exitProcess_mock ( &exitProcess );
            MOCKPP_CHAINER_FOR_EXT ( MockDirectory, FileExists, ext ) FileExists_mock ( &directory );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::never() );

            exitProcess_mock
            .expects ( MOCKPP_NS::never() );

            FileExists_mock
            .expects ( MOCKPP_NS::exactly ( 4 ) )
            .will ( MOCKPP_NS::onConsecutiveCalls (
                        MOCKPP_NS::returnValue<bool> ( true ),
                        MOCKPP_NS::returnValue<bool> ( true ),
                        MOCKPP_NS::returnValue<bool> ( false ),
                        MOCKPP_NS::returnValue<bool> ( true ) ) );

            parser->runApplicationProcess ( "package", "basepath" );

            std::string expectedConfig = "configuration-miscellaneous.xml";
            std::string expectedLogger = "log4-configuration.xml";
            std::string expectedCofigFop = "basepath/MP/fop.xconf";

            CPPUNIT_ASSERT ( expectedConfig == ConfigurationPersistenceManager::filePath );
            CPPUNIT_ASSERT ( expectedLogger == SMTTLogManager::getInstance()->getConfigFile() );
            CPPUNIT_ASSERT ( expectedCofigFop == FOPTransformer::getConfigFile() );

            launcher.verify();
            exitProcess.verify();
            directory.verify();
        }

        CPPUNIT_TEST_SUITE ( OptParserTest );

        CPPUNIT_TEST ( testInitializeWithoutInitializer );
        CPPUNIT_TEST ( testInitializeWithoutParameters );
        CPPUNIT_TEST ( testInitializeWithWrongParameter );

        CPPUNIT_TEST ( testInitializeWithEmptyConfigParameter );
        CPPUNIT_TEST ( testInitializeWithConfigParameter );
        CPPUNIT_TEST ( testInitializeWithConfigShortParameter );

        CPPUNIT_TEST ( testInitializeWithEmptyLoggerParameter );
        CPPUNIT_TEST ( testInitializeWithLoggerParameter );
        CPPUNIT_TEST ( testInitializeWithLoggerShortParameter );

        CPPUNIT_TEST ( testInitializeWithEmptyXslfoParameter );
        CPPUNIT_TEST ( testInitializeWithXslfoParameter );
        CPPUNIT_TEST ( testInitializeWithXslfoShortParameter );

        CPPUNIT_TEST ( testInitializeWithDisableValidationParameter );
        CPPUNIT_TEST ( testInitializeWithDisableValidationShortParameter );

        CPPUNIT_TEST ( testInitializeWithDisableSaveVote );
        CPPUNIT_TEST ( testInitializeWithDisableSaveVoteShortParameter );

        CPPUNIT_TEST ( testInitializeWithDbusInfoParameter );
        CPPUNIT_TEST ( testInitializeWithDbusInfoShortParameter );

        CPPUNIT_TEST ( testInitializeWithHelpParameter );
        CPPUNIT_TEST ( testInitializeWithHelpShortParameter );

        CPPUNIT_TEST ( testInitializeWithVersionParameter );
        CPPUNIT_TEST ( testInitializeWithVersionShortParameter );

        CPPUNIT_TEST ( testInitializeWithAllLongParameters );
        CPPUNIT_TEST ( testInitializeWithAllShortParameters );

        CPPUNIT_TEST ( testInitializeWithAllEmptyLongParameters );
        CPPUNIT_TEST ( testInitializeWithAllEmptyShortParameters );

        CPPUNIT_TEST ( testGetHelpStringWithParameters );
        CPPUNIT_TEST ( testGetHelpStringWithoutParameters );

        CPPUNIT_TEST ( testGetLoginStringWithParameters );
        CPPUNIT_TEST ( testGetLoginStringWithoutParameters );

        CPPUNIT_TEST ( testGetPasswordStringWithParameters );
        CPPUNIT_TEST ( testGetPasswordStringWithoutParameters );

        CPPUNIT_TEST ( testRunApplicationProcessOnlyHelp );
        CPPUNIT_TEST ( testRunApplicationProcessOnlyVersion );

        CPPUNIT_TEST ( testRunApplicationProcessLoadDefault );
        CPPUNIT_TEST ( testRunApplicationProcessLoadParameters );

        CPPUNIT_TEST ( testRunApplicationProcessWithModeConfigFileNotFound );
        CPPUNIT_TEST ( testRunApplicationProcessWithModeConfigFileFoundLoggerFileNotFound );
        CPPUNIT_TEST ( testRunApplicationProcessWithModeConfigAndLoggerFilesFoundXslfoFirstOption );
        CPPUNIT_TEST ( testRunApplicationProcessWithModeConfigAndLoggerFilesFoundXslfoSecondOption );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_OPT_PARSER_TEST_ */
