#ifndef TEST_PROCESS_LAUNCHER_TEST_
#define TEST_PROCESS_LAUNCHER_TEST_

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Runtime/PowerDown.hxx>
#include <System/Runtime/ProcessLauncher.h>
#include "MockCommandLauncher.hxx"
#include "MockRunProcessLauncher.hxx"
#include <tests/MockPipeFile.hxx>

class ProcessLauncherTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Runtime::ProcessLauncher ProcessLauncher;

    public:

        ProcessLauncherTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testCallRunProcessThroughSystem()
        {
            MockCommandLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            int result;
            int expected = 1;

            MOCKPP_CHAINER_FOR_EXT ( MockCommandLauncher, getCommand, ext ) getCommand_mock ( &launcher );
            MOCKPP_CHAINER_FOR_EXT ( MockCommandLauncher, runCommand, ext ) runCommand_mock ( &launcher );

            getCommand_mock
            .expects ( MOCKPP_NS::once() )
            .before ( "run" )
            .will ( new MOCKPP_NS::ReturnStub<std::string> ( "null" ) )
            .id ( "command" );

            runCommand_mock
            .expects ( MOCKPP_NS::once() )
            .after ( "command" )
            .will ( MOCKPP_NS::returnValue <int> ( 1 ) )
            .id ( "run" );

            result = ProcessLauncher::getInstance()->RunProcessThroughSystem ( "null", false );

            CPPUNIT_ASSERT ( expected == result );

            launcher.verify();
        }

        void testCommandDefault()
        {
            MockRunProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            int result;
            int expected = 0;

            std::string expectedCommandValue = "command";

            MOCKPP_CHAINER_FOR_EXT ( MockRunProcessLauncher, runCommand, ext ) runCommand_mock ( &launcher );

            runCommand_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 0 ) );

            result = ProcessLauncher::getInstance()->RunProcessThroughSystem ( "command" );

            CPPUNIT_ASSERT ( expected == result );
            CPPUNIT_ASSERT ( expectedCommandValue == launcher.commandValue );

            launcher.verify();
        }

        void testCommandWithBackground()
        {
            MockRunProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            int result;
            int expected = 0;

            std::string expectedCommandValue = "command &";

            MOCKPP_CHAINER_FOR_EXT ( MockRunProcessLauncher, runCommand, ext ) runCommand_mock ( &launcher );

            runCommand_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 0 ) );

            result = ProcessLauncher::getInstance()->RunProcessThroughSystem ( "command", true );

            CPPUNIT_ASSERT ( expected == result );
            CPPUNIT_ASSERT ( expectedCommandValue == launcher.commandValue );

            launcher.verify();
        }

        void testCommandWithoutBackground()
        {
            MockRunProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            int result;
            int expected = 0;

            std::string expectedCommandValue = "command";

            MOCKPP_CHAINER_FOR_EXT ( MockRunProcessLauncher, runCommand, ext ) runCommand_mock ( &launcher );

            runCommand_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue <int> ( 0 ) );

            result = ProcessLauncher::getInstance()->RunProcessThroughSystem ( "command", false );

            CPPUNIT_ASSERT ( expected == result );
            CPPUNIT_ASSERT ( expectedCommandValue == launcher.commandValue );

            launcher.verify();
        }

        void testRunProcessThroughPipeOpenFail()
        {
            MockPipeFile * launcher = new MockPipeFile();

            std::list < std::string > result;
            result.push_back ( "Hello World" );

            result = ProcessLauncher::getInstance()->RunProcessThroughPipe ( "command", launcher );

            CPPUNIT_ASSERT ( true == result.empty() );
        }

        void testRunProcessThroughPipeOpenOneLine()
        {
            MockPipeFile * launcher = new MockPipeFile();

            std::list < std::string > result;

            std::stringstream ss;
            ss << "Hello" << std::endl;

            launcher->buffer.AddData ( ss.str() );

            result = ProcessLauncher::getInstance()->RunProcessThroughPipe ( "command", launcher );

            CPPUNIT_ASSERT ( 1 == result.size() );
            CPPUNIT_ASSERT ( "Hello" == ( * ( result.begin() ) ) );
        }

        void testRunProcessThroughPipeOpenTwoLine()
        {
            MockPipeFile * launcher = new MockPipeFile();
            std::list < std::string > result;

            {
                std::stringstream ss;
                ss << "Hello" << std::endl;
                launcher->buffer.AddData ( ss.str() );
            }

            {
                std::stringstream ss;
                ss << "World" << std::endl;
                launcher->buffer.AddData ( ss.str() );
            }

            result = ProcessLauncher::getInstance()->RunProcessThroughPipe ( "command", launcher );

            CPPUNIT_ASSERT ( 2 == result.size() );

            std::list < std::string >::iterator it = result.begin();

            CPPUNIT_ASSERT ( "Hello" == ( *it ) );

            ++it;

            CPPUNIT_ASSERT ( "World" == ( *it ) );
        }

        CPPUNIT_TEST_SUITE ( ProcessLauncherTest );

        CPPUNIT_TEST ( testCallRunProcessThroughSystem );
        CPPUNIT_TEST ( testCommandDefault );
        CPPUNIT_TEST ( testCommandWithBackground );
        CPPUNIT_TEST ( testCommandWithoutBackground );

        CPPUNIT_TEST ( testRunProcessThroughPipeOpenFail );
        CPPUNIT_TEST ( testRunProcessThroughPipeOpenOneLine );
        CPPUNIT_TEST ( testRunProcessThroughPipeOpenTwoLine );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_PROCESS_LAUNCHER_TEST_ */
