#ifndef TEST_SAFE_BUFFER_TEST
#define TEST_SAFE_BUFFER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/SafeBuffer.h>
#include <cstring>

class SafeBufferTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::System::SafeBuffer SafeBuffer;

        SafeBufferTest()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testEmptyConstructor()
        {
            SafeBuffer buffer;

            CPPUNIT_ASSERT ( NULL == buffer.GetData() );
            CPPUNIT_ASSERT ( 0 == buffer.GetSize() );
        }

        void testConstructorWithPointerParam()
        {
            const char * data = { "abcd" };
            unsigned int leng = sizeof ( data ) / sizeof ( unsigned char );

            SafeBuffer buffer ( ( unsigned char * ) data, leng );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( leng == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'd' == buffer.GetData() [3] );
        }

        void testConstructorWithStringParam()
        {
            std::string input = "Hello";
            SafeBuffer buffer ( input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( input.length() == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'H' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'e' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'l' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'l' == buffer.GetData() [3] );
            CPPUNIT_ASSERT ( 'o' == buffer.GetData() [4] );
        }

        void testConstructorWithLongParam()
        {
            unsigned long input = 0xfcda5423;
            unsigned int size = 4;

            SafeBuffer buffer ( input, size );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( size == buffer.GetSize() );

            CPPUNIT_ASSERT ( 0x23 == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 0x54 == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 0xda == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 0xfc == buffer.GetData() [3] );
        }

        void testConstructorWithOtherBufferParam()
        {
            SafeBuffer input ( "Hello" );
            SafeBuffer buffer ( input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( input.GetSize() == buffer.GetSize() );
        }

        void testOperatorEqualWithEmptyBuffer()
        {
            SafeBuffer buffer1;
            SafeBuffer buffer2;

            bool expected = true;
            bool result = buffer1 == buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testOperatorEqualWithDiferentBuffer()
        {
            SafeBuffer buffer1 ( "one" );
            SafeBuffer buffer2 ( "two" );

            bool expected = false;
            bool result = buffer1 == buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testOperatorEqualWithDiferentBufferTwo()
        {
            SafeBuffer buffer1 ( "xyz" );
            SafeBuffer buffer2 ( "abcd" );

            bool expected = false;
            bool result = buffer1 == buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testOperatorEqualWithSameBuffer()
        {
            SafeBuffer buffer1 ( "one" );
            SafeBuffer buffer2 ( "one" );

            bool expected = true;
            bool result = buffer1 == buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testOperatorNotEqualWithEmptyBuffer()
        {
            SafeBuffer buffer1;
            SafeBuffer buffer2;

            bool expected = false;
            bool result = buffer1 != buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testOperatorNotEqualWithDiferentBuffer()
        {
            SafeBuffer buffer1 ( "one" );
            SafeBuffer buffer2 ( "two" );

            bool expected = true;
            bool result = buffer1 != buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testOperatorNotEqualWithDiferentBufferTwo()
        {
            SafeBuffer buffer1 ( "xyz" );
            SafeBuffer buffer2 ( "abcd" );

            bool expected = true;
            bool result = buffer1 != buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testOperatorNotEqualWithSameBuffer()
        {
            SafeBuffer buffer1 ( "one" );
            SafeBuffer buffer2 ( "one" );

            bool expected = false;
            bool result = buffer1 != buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testConstructorWithOtherBuffer()
        {
            SafeBuffer buffer1 ( "Hello" );
            SafeBuffer buffer2 ( buffer1 );

            bool expected = true;
            bool result = buffer1 == buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testOperatorAssignmentToEmptyBuffer()
        {
            SafeBuffer buffer1 ( "Hello" );
            SafeBuffer buffer2 = buffer1;

            bool expected = true;
            bool result = buffer1 == buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testOperatorAssignmentFromEmptyBuffer()
        {
            SafeBuffer buffer1;
            SafeBuffer buffer2 = buffer1;

            bool expected = true;
            bool result = buffer1 == buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testOperatorAssignmentToBuffer()
        {
            SafeBuffer buffer1 ( "Hello" );
            SafeBuffer buffer2 ( "Bye" );

            buffer2 = buffer1;

            bool expected = true;
            bool result = buffer1 == buffer2;

            CPPUNIT_ASSERT ( expected == result );
        }

        void testAddEmptyBufferToEmptyBuffer()
        {
            SafeBuffer input;
            SafeBuffer buffer;

            buffer.AddData ( input );

            CPPUNIT_ASSERT ( NULL == buffer.GetData() );
            CPPUNIT_ASSERT ( 0 == buffer.GetSize() );
        }

        void testAddBufferToEmptyBuffer()
        {
            SafeBuffer input ( "abc" );
            SafeBuffer buffer;

            buffer.AddData ( input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( 3 == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [2] );
        }

        void testAddBufferToBuffer()
        {
            SafeBuffer input ( "abc" );
            SafeBuffer buffer ( "xy" );

            buffer.AddData ( input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( 5 == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'x' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'y' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [3] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [4] );
        }

        void testAddPointerToBuffer()
        {
            const char * data = { "abc" };
            unsigned int leng = sizeof ( data ) / sizeof ( unsigned char );

            SafeBuffer buffer ( "xy" );
            unsigned lengExpected = buffer.GetSize() + leng;

            buffer.AddData ( ( const unsigned char * ) data, leng );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( lengExpected == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'x' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'y' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [3] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [4] );
        }

        void testAddStringToBuffer()
        {
            std::string input = "abc";
            SafeBuffer buffer ( "xy" );

            buffer.AddData ( input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( 5 == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'x' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'y' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [3] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [4] );
        }

        void testPushBackToBuffer()
        {
            char input = 'a';
            SafeBuffer buffer ( "xy" );

            buffer.push_back ( input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( 3 == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'x' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'y' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [2] );
        }

        void testPushBackToEmptyBuffer()
        {
            char input = 'a';
            SafeBuffer buffer;

            buffer.push_back ( input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( 1 == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
        }

        void testConsecutivePushBackToBuffer()
        {
            SafeBuffer buffer;

            buffer.push_back ( 'a' );
            buffer.push_back ( 'b' );
            buffer.push_back ( 'c' );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( 3 == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [2] );
        }

        void testBase64FromEmptyBuffer()
        {
            SafeBuffer buffer;

            CPPUNIT_ASSERT ( true == buffer.GetBase64Data().empty() );
        }

        void testBase64FromBuffer()
        {
            SafeBuffer buffer ( "abcdf" );
            std::string expected = "YWJjZGY=";

            std::string result = buffer.GetBase64Data();

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( expected == result );
        }

        void testClearEmptyBuffer()
        {
            SafeBuffer buffer;
            buffer.Clear ();

            CPPUNIT_ASSERT ( NULL == buffer.GetData() );
            CPPUNIT_ASSERT ( 0 == buffer.GetSize() );
        }

        void testClearBuffer()
        {
            SafeBuffer buffer ( "abcd" );
            const unsigned char * initial_data = buffer.GetData();
            const char * ref_chars = { "abcd" };
            // Simple confirmation
            // Initial data contains the same first 4 chars as our ref_chars.
            CPPUNIT_ASSERT ( 0 == memcmp ( initial_data, ref_chars, 4 ) );

            buffer.Clear ();

            CPPUNIT_ASSERT ( NULL == buffer.GetData() );
            CPPUNIT_ASSERT ( 0 == buffer.GetSize() );
        }

        void testInsertEmptyDataToEmptyBuffer()
        {
            unsigned long index = 0;
            std::string input;

            SafeBuffer buffer;
            buffer.insertData ( index, input );

            CPPUNIT_ASSERT ( NULL == buffer.GetData() );
            CPPUNIT_ASSERT ( 0 == buffer.GetSize() );
        }

        void testInsertDataToEmptyBuffer()
        {
            unsigned long index = 0;
            std::string input = "abcd";

            SafeBuffer buffer;
            buffer.insertData ( index, input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( input.length() == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'd' == buffer.GetData() [3] );
        }

        void testInsertDataWithIndexOutSizeToEmptyBuffer()
        {
            unsigned long index = 1000;
            std::string input = "abcd";

            SafeBuffer buffer;
            buffer.insertData ( index, input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( input.length() == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'd' == buffer.GetData() [3] );
        }

        void testInsertDataToFirst()
        {
            unsigned long index = 0;
            std::string input = "x";
            unsigned int expectedSize = 5;

            SafeBuffer buffer ( "abcd" );
            buffer.insertData ( index, input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( expectedSize == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'x' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [3] );
            CPPUNIT_ASSERT ( 'd' == buffer.GetData() [4] );
        }

        void testInsertDataToEnd()
        {
            unsigned long index = 4;
            std::string input = "x";
            unsigned int expectedSize = 5;

            SafeBuffer buffer ( "abcd" );
            buffer.insertData ( index, input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( expectedSize == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'd' == buffer.GetData() [3] );
            CPPUNIT_ASSERT ( 'x' == buffer.GetData() [4] );
        }

        void testInsertEmptyDataToBuffer()
        {
            unsigned long index = 2;
            std::string input;
            unsigned int expectedSize = 4;

            SafeBuffer buffer ( "abcd" );
            buffer.insertData ( index, input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( expectedSize == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'd' == buffer.GetData() [3] );
        }

        void testInsertDataToCenter()
        {
            unsigned long index = 2;
            std::string input = "-.-";

            SafeBuffer buffer ( "abcd" );
            unsigned int expectedSize = buffer.GetSize() + input.length();

            buffer.insertData ( index, input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( expectedSize == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( '-' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( '.' == buffer.GetData() [3] );
            CPPUNIT_ASSERT ( '-' == buffer.GetData() [4] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [5] );
            CPPUNIT_ASSERT ( 'd' == buffer.GetData() [6] );
        }

        void testInsertPointerToBuffer()
        {
            unsigned long index = 2;

            const char * data = { ".-." };
            unsigned int leng = 3;

            SafeBuffer buffer ( "abcd" );
            unsigned int expectedSize = buffer.GetSize() + leng;

            buffer.insertData ( index, ( unsigned char * ) data, leng );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( expectedSize == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( '.' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( '-' == buffer.GetData() [3] );
            CPPUNIT_ASSERT ( '.' == buffer.GetData() [4] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [5] );
            CPPUNIT_ASSERT ( 'd' == buffer.GetData() [6] );
        }

        void testInsertBufferToBuffer()
        {
            unsigned long index = 2;
            unsigned int expectedSize = 7;

            SafeBuffer input ( "wxy" );

            SafeBuffer buffer ( "abcd" );
            buffer.insertData ( index, input );

            CPPUNIT_ASSERT ( NULL != buffer.GetData() );
            CPPUNIT_ASSERT ( expectedSize == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'w' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'x' == buffer.GetData() [3] );
            CPPUNIT_ASSERT ( 'y' == buffer.GetData() [4] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [5] );
            CPPUNIT_ASSERT ( 'd' == buffer.GetData() [6] );
        }

        void testRemoveDataFromEmptyBuffer()
        {
            unsigned long index = 2;
            unsigned long size = 10;

            unsigned long posExpected = 0;

            SafeBuffer buffer;

            buffer.removeData ( index, size );

            CPPUNIT_ASSERT ( posExpected == buffer.GetSize() );
        }

        void testNotRemoveDataFromBuffer()
        {
            unsigned long index = 2;
            unsigned long size = 0;

            unsigned long posExpected = 4;

            SafeBuffer buffer ( "abcd" );

            buffer.removeData ( index, size );

            CPPUNIT_ASSERT ( posExpected == buffer.GetSize() );
        }

        void testRemoveFirstDataFromBuffer()
        {
            unsigned long index = 0;
            unsigned long size = 1;

            unsigned long posExpected = 3;

            SafeBuffer buffer ( "abcd" );

            buffer.removeData ( index, size );

            CPPUNIT_ASSERT ( posExpected == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'd' == buffer.GetData() [2] );
        }

        void testRemoveCenterDataFromBuffer()
        {
            unsigned long index = 3;
            unsigned long size = 3;

            unsigned long posExpected = 6;

            SafeBuffer buffer ( "abc-y-def" );

            buffer.removeData ( index, size );

            CPPUNIT_ASSERT ( posExpected == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [2] );
            CPPUNIT_ASSERT ( 'd' == buffer.GetData() [3] );
            CPPUNIT_ASSERT ( 'e' == buffer.GetData() [4] );
            CPPUNIT_ASSERT ( 'f' == buffer.GetData() [5] );
        }

        void testRemoveEndDataFromBuffer()
        {
            unsigned long index = 3;
            unsigned long size = 1;

            unsigned long posExpected = 3;

            SafeBuffer buffer ( "abcd" );

            buffer.removeData ( index, size );

            CPPUNIT_ASSERT ( posExpected == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [2] );
        }

        void testRemoveEndDataFromBufferSizeMoreSizeBuffer()
        {
            unsigned long index = 3;
            unsigned long size = 10;

            unsigned long posExpected = 3;

            SafeBuffer buffer ( "abcd" );

            buffer.removeData ( index, size );

            CPPUNIT_ASSERT ( posExpected == buffer.GetSize() );

            CPPUNIT_ASSERT ( 'a' == buffer.GetData() [0] );
            CPPUNIT_ASSERT ( 'b' == buffer.GetData() [1] );
            CPPUNIT_ASSERT ( 'c' == buffer.GetData() [2] );
        }

        void testOperatorOutputStreamWithSafeBufferNull()
        {
            SafeBuffer buffer;
            std::stringstream ss;

            ss << buffer;

            CPPUNIT_ASSERT ( "SafeBuffer(0)" == ss.str() );
        }

        void testOperatorOutputStreamWithSafeBuffer()
        {
            SafeBuffer buffer ( "abcd" );
            std::stringstream ss;

            ss << buffer;

            CPPUNIT_ASSERT ( "SafeBuffer(4)" == ss.str() );
        }

        void testOperatorStringWithSafeBufferNull()
        {
            SafeBuffer buffer;
            std::string ss;

            ss << buffer;

            CPPUNIT_ASSERT ( "SafeBuffer(0)" == ss );
        }

        void testOperatorStringWithSafeBuffer()
        {
            SafeBuffer buffer ( "abcd" );
            std::string ss;

            ss << buffer;

            CPPUNIT_ASSERT ( "SafeBuffer(4)" == ss );
        }

        CPPUNIT_TEST_SUITE ( SafeBufferTest );

        CPPUNIT_TEST ( testEmptyConstructor );
        CPPUNIT_TEST ( testConstructorWithPointerParam );
        CPPUNIT_TEST ( testConstructorWithStringParam );
        CPPUNIT_TEST ( testConstructorWithLongParam );
        CPPUNIT_TEST ( testConstructorWithOtherBufferParam );

        CPPUNIT_TEST ( testOperatorEqualWithEmptyBuffer );
        CPPUNIT_TEST ( testOperatorEqualWithDiferentBuffer );
        CPPUNIT_TEST ( testOperatorEqualWithDiferentBufferTwo );
        CPPUNIT_TEST ( testOperatorEqualWithSameBuffer );

        CPPUNIT_TEST ( testOperatorNotEqualWithEmptyBuffer );
        CPPUNIT_TEST ( testOperatorNotEqualWithDiferentBuffer );
        CPPUNIT_TEST ( testOperatorNotEqualWithDiferentBufferTwo );
        CPPUNIT_TEST ( testOperatorNotEqualWithSameBuffer );

        CPPUNIT_TEST ( testConstructorWithOtherBuffer );
        CPPUNIT_TEST ( testOperatorAssignmentToEmptyBuffer );
        CPPUNIT_TEST ( testOperatorAssignmentFromEmptyBuffer );
        CPPUNIT_TEST ( testOperatorAssignmentToBuffer );

        CPPUNIT_TEST ( testAddEmptyBufferToEmptyBuffer );
        CPPUNIT_TEST ( testAddBufferToEmptyBuffer );
        CPPUNIT_TEST ( testAddBufferToBuffer );
        CPPUNIT_TEST ( testAddPointerToBuffer );
        CPPUNIT_TEST ( testAddStringToBuffer );

        CPPUNIT_TEST ( testPushBackToBuffer );
        CPPUNIT_TEST ( testPushBackToEmptyBuffer );
        CPPUNIT_TEST ( testConsecutivePushBackToBuffer );

        CPPUNIT_TEST ( testBase64FromEmptyBuffer );
        CPPUNIT_TEST ( testBase64FromBuffer );

        CPPUNIT_TEST ( testClearEmptyBuffer );
        CPPUNIT_TEST ( testClearBuffer );

        CPPUNIT_TEST ( testInsertEmptyDataToEmptyBuffer );
        CPPUNIT_TEST ( testInsertDataToEmptyBuffer );
        CPPUNIT_TEST ( testInsertDataWithIndexOutSizeToEmptyBuffer );
        CPPUNIT_TEST ( testInsertDataToFirst );
        CPPUNIT_TEST ( testInsertDataToEnd );
        CPPUNIT_TEST ( testInsertEmptyDataToBuffer );
        CPPUNIT_TEST ( testInsertDataToCenter );
        CPPUNIT_TEST ( testInsertPointerToBuffer );
        CPPUNIT_TEST ( testInsertBufferToBuffer );

        CPPUNIT_TEST ( testRemoveDataFromEmptyBuffer );
        CPPUNIT_TEST ( testNotRemoveDataFromBuffer );
        CPPUNIT_TEST ( testRemoveFirstDataFromBuffer );
        CPPUNIT_TEST ( testRemoveCenterDataFromBuffer );
        CPPUNIT_TEST ( testRemoveEndDataFromBuffer );
        CPPUNIT_TEST ( testRemoveEndDataFromBufferSizeMoreSizeBuffer );

        CPPUNIT_TEST ( testOperatorOutputStreamWithSafeBufferNull );
        CPPUNIT_TEST ( testOperatorOutputStreamWithSafeBuffer );

        CPPUNIT_TEST ( testOperatorStringWithSafeBufferNull );
        CPPUNIT_TEST ( testOperatorStringWithSafeBuffer );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_SAFE_BUFFER_TEST */
