#ifndef TEST_COMPOSEKEYTEST
#define TEST_COMPOSEKEYTEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Security/ComposeKey.hxx>
#include <System/Security/OpenSSLSecurity.hxx>

class ComposeKeyTest : public CPPUNIT_NS::TestFixture
{
    private:

        Smartmatic::System::Security::ComposeKey * object;

    public:

        ComposeKeyTest()
        {
            object = NULL;
        }

        void setUp()
        {
            Smartmatic::System::Security::OpenSSLSecurity::init();
            object = new Smartmatic::System::Security::ComposeKey ();
        }

        void tearDown()
        {
            Smartmatic::System::Security::OpenSSLSecurity::clear();
            delete object;
        }

        void testComposeNullCharPointer()
        {
            unsigned char * key = NULL;
            Smartmatic::System::SafeBuffer result;

            object->setKey ( key, 0 );
            object->getCompose ( 16, result );

            CPPUNIT_ASSERT ( NULL == result.GetData() );
            CPPUNIT_ASSERT ( 0 == result.GetSize() );
        }

        void testComposeNullSafeBuffer()
        {
            Smartmatic::System::SafeBuffer key;
            Smartmatic::System::SafeBuffer result;

            object->setKey ( key );
            object->getCompose ( 16, result );

            CPPUNIT_ASSERT ( NULL == result.GetData() );
            CPPUNIT_ASSERT ( 0 == result.GetSize() );
        }

        void testComposeCharPointer16()
        {
            unsigned char key [] = {0x7a, 0x20, 0xa5, 0x3d, 0x46, 0x0f, 0xc9, 0xce, 0x04, 0x23, 0xa7, 0xa0, 0x76, 0x4c, 0x6c, 0xf2};
            Smartmatic::System::SafeBuffer result;

            object->setKey ( key, sizeof ( key ) / sizeof ( unsigned char ) );
            object->getCompose ( 16, result );

            CPPUNIT_ASSERT ( NULL != result.GetData() );
            CPPUNIT_ASSERT ( 16 == result.GetSize() );
            CPPUNIT_ASSERT ( "p1ycPEGNMmsHQmdT7E4OTQ==" == result.GetBase64Data() );
        }

        void testComposeCharPointer32()
        {
            unsigned char key [] = {0x35, 0x2b, 0x2f, 0x33, 0x62, 0x34, 0x44, 0x31, 0x68, 0x69, 0x39, 0x37, 0x50, 0x4e, 0x4b, 0x6a, 0x6b, 0x39, 0x72, 0x4f, 0x45, 0x44, 0x31, 0x36, 0x72, 0x4a, 0x77, 0x35, 0x43, 0x69, 0x6d, 0x45};
            Smartmatic::System::SafeBuffer result;

            object->setKey ( key, sizeof ( key ) / sizeof ( unsigned char ) );
            object->getCompose ( 16, result );

            CPPUNIT_ASSERT ( NULL != result.GetData() );
            CPPUNIT_ASSERT ( 16 == result.GetSize() );
            CPPUNIT_ASSERT ( "mh9uQc+EGykhbP6XtS5gbg==" == result.GetBase64Data() );
        }

        void testComposeSafeBuffer()
        {
            Smartmatic::System::SafeBuffer key ( "abcdefghijklmnop" );
            Smartmatic::System::SafeBuffer result;

            object->setKey ( key );
            object->getCompose ( 16, result );

            CPPUNIT_ASSERT ( NULL != result.GetData() );
            CPPUNIT_ASSERT ( 16 == result.GetSize() );
            CPPUNIT_ASSERT ( "Bda9vnZWoJUEZ/V+Ian2Lg==" == result.GetBase64Data() );
        }

        void testComposeSafeBufferConstructor()
        {
            Smartmatic::System::SafeBuffer key ( "abcdefghijklmnop" );
            Smartmatic::System::SafeBuffer result;

            Smartmatic::System::Security::ComposeKey object ( key );
            object.getCompose ( 16, result );

            CPPUNIT_ASSERT ( NULL != result.GetData() );
            CPPUNIT_ASSERT ( 16 == result.GetSize() );
            CPPUNIT_ASSERT ( "Bda9vnZWoJUEZ/V+Ian2Lg==" == result.GetBase64Data() );
        }

        void testComposeSafeBufferFixSize64()
        {
            Smartmatic::System::SafeBuffer key ( "abcdefghijklmnop" );
            Smartmatic::System::SafeBuffer result;

            object->setKey ( key );
            object->getCompose ( 64, result );

            CPPUNIT_ASSERT ( NULL != result.GetData() );
            CPPUNIT_ASSERT ( 64 == result.GetSize() );
            CPPUNIT_ASSERT ( "Bda9vnZWoJUEZ/V+Ian2LotR8vSEIG6968grXO7Wm5kF1r2+dlaglQRn9X4hqfYui1Hy9IQgbr3ryCtc7tabmQ==" == result.GetBase64Data() );
        }

        CPPUNIT_TEST_SUITE ( ComposeKeyTest );

        CPPUNIT_TEST ( testComposeNullCharPointer );
        CPPUNIT_TEST ( testComposeNullSafeBuffer );
        CPPUNIT_TEST ( testComposeCharPointer16 );
        CPPUNIT_TEST ( testComposeCharPointer32 );
        CPPUNIT_TEST ( testComposeSafeBuffer );
        CPPUNIT_TEST ( testComposeSafeBufferConstructor );
        CPPUNIT_TEST ( testComposeSafeBufferFixSize64 );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_COMPOSEKEYTEST */
