#ifndef TEST_CERTUTILTEST
#define TEST_CERTUTILTEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Security/Cryptography/CertUtil.h>
#include <System/Security/OpenSSLSecurity.hxx>
#include <System/Encoding/Base64Encoder.h>
#include <System/SafeBuffer.h>
#include <System/IO/File.h>
#include <tests/StoreMockFile.hxx>
#include <openssl/evp.h>
#include <openssl/x509.h>
#include <openssl/safestack.h>

using namespace Smartmatic::System;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Security;
using namespace Smartmatic::System::Encoding;
using namespace Smartmatic::System::Security::Cryptography;

static std::string wrongCertificate_PEM = "-----BEGIN CERTIFICATE-----\n"
        "MIIC9DCCAl2gAwIBAgICEAAwDQYJKoZIhvcNAQEFBQAweTELMAkGA1UEBhMCQkUx\n"
        "ETAPBgNVBAgMCEJydXNzZWxzMRIwEAYDVQQHDAlFdHRlcmJlZWsxEzARBgNVBAoM\n"
        "ClNtYXJ0bWF0aWMxHDAaBgNVBAsME0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNV\n"
        "BAMMB1JPT1QgQ0EwHhcNMTMxMjI2MTAzNjM0WhcNMTQxMjI2MTAzNjM0WjCBiDEL\n"
        "MAkGA1UEBhMCQkUxETAPBgNVBAgMCEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1h\n"
        "dGljMRwwGgYDVQQLDBNFbGVjdG9yYWwgU29sdXRpb25zMQ4wDAYDVQQDDAVVc2Vy\n"
        "MTEjMCEGCSqGSIb3DQEJARYUdXNlcjFAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZI\n"
        "hvcNAQEBBQADgY0AMIGJAoGBALkfis573u0A27LW+n1q9URLy6fFoJ8XIAn1bYrw\n"
        "-----END CERTIFICATE-----";

static std::string validCertificate_PEM = "-----BEGIN CERTIFICATE-----\n"
        "MIIC9DCCAl2gAwIBAgICEAAwDQYJKoZIhvcNAQEFBQAweTELMAkGA1UEBhMCQkUx\n"
        "ETAPBgNVBAgMCEJydXNzZWxzMRIwEAYDVQQHDAlFdHRlcmJlZWsxEzARBgNVBAoM\n"
        "ClNtYXJ0bWF0aWMxHDAaBgNVBAsME0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNV\n"
        "BAMMB1JPT1QgQ0EwHhcNMTMxMjI2MTAzNjM0WhcNMTQxMjI2MTAzNjM0WjCBiDEL\n"
        "MAkGA1UEBhMCQkUxETAPBgNVBAgMCEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1h\n"
        "dGljMRwwGgYDVQQLDBNFbGVjdG9yYWwgU29sdXRpb25zMQ4wDAYDVQQDDAVVc2Vy\n"
        "MTEjMCEGCSqGSIb3DQEJARYUdXNlcjFAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZI\n"
        "hvcNAQEBBQADgY0AMIGJAoGBALkfis573u0A27LW+n1q9URLy6fFoJ8XIAn1bYrw\n"
        "YQgZPfuLGk0fSFzPf3skMKhvueWgNg9IbOi29Ta8/y4T55SYdTCjumezcjo5kXfP\n"
        "J5dUFNMSnACwP+xH8MGrCaUBn9WEGO4IE0dbiTK4koH0kCrnbOqR+IaNW/TDFJvH\n"
        "mWQ5AgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wg\n"
        "R2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBQb0Vt+kvOcMX8GKNS2Nrp6\n"
        "fJ8RWTAfBgNVHSMEGDAWgBR7ieRpADfz3zAXXjayYT4sn4hRCjANBgkqhkiG9w0B\n"
        "AQUFAAOBgQARS2/N2ySflGKV4bbNgcu9RJspQ7P6wTFgLivsjcLKgJvLgJQUNdsr\n"
        "eoY4T0Jjm3yg+tN6y8831u4JUgZOuvjWmHmIkYFPqqkzEHkPyslBZFHBhE/60xNn\n"
        "p+xjtpQJ/RB9eC4OeaXpgaCLYP5jQPxN00A8HEdLNjqz6sIvWyCzjg==\n"
        "-----END CERTIFICATE-----\n";

static std::string wrongPrivateKey_PEM = "-----BEGIN ENCRYPTED PRIVATE KEY-----\n"
        "MIICxjBABgkqhkiG9w0BBQ0wMzAbBgkqhkiG9w0BBQwwDgQIiV8C9Nv/IOcCAggA\n"
        "MBQGCCqGSIb3DQMHBAggVWwspYiQfgSCAoCnX7fmbIA4YMDX+2F26injvxB8Vwz5\n"
        "en5MomnpXGiPFKcVaZgj/vaHo7qPHh3/Xvpj9SboRwrNkO0iY+KCJjaE5GezbJ6z\n"
        "nvElXO3Gs6/mzqFnIc2ApK6ShxZ1mVJEGtUP/D5996kiQZ3/+ks/Ne94B0AxQ6Jt\n"
        "Koi28hdW9YH7lp0iwFfIBrV+0Y7+I/IXYV0fNPWCrI6gaval89XZPfoF8wvK4sO0\n"
        "KDbMMv59X+L07KD5RLBIxLbcq0GVzYsC53MU6aU2UkrSCPEPi39tdzkvF0tPEBbY\n"
        "vME6TrJONkSxaV8nzID/BO+ZNvl0RVUhePbpf/CQhxZZUTWY5mgdZ7Ru0hdl9jJ+\n"
        "-----END RSA PRIVATE KEY-----";

static std::string validPrivateKey_PEM = "-----BEGIN ENCRYPTED PRIVATE KEY-----\n"
        "MIICxjBABgkqhkiG9w0BBQ0wMzAbBgkqhkiG9w0BBQwwDgQIiV8C9Nv/IOcCAggA\n"
        "MBQGCCqGSIb3DQMHBAggVWwspYiQfgSCAoCnX7fmbIA4YMDX+2F26injvxB8Vwz5\n"
        "en5MomnpXGiPFKcVaZgj/vaHo7qPHh3/Xvpj9SboRwrNkO0iY+KCJjaE5GezbJ6z\n"
        "nvElXO3Gs6/mzqFnIc2ApK6ShxZ1mVJEGtUP/D5996kiQZ3/+ks/Ne94B0AxQ6Jt\n"
        "Koi28hdW9YH7lp0iwFfIBrV+0Y7+I/IXYV0fNPWCrI6gaval89XZPfoF8wvK4sO0\n"
        "KDbMMv59X+L07KD5RLBIxLbcq0GVzYsC53MU6aU2UkrSCPEPi39tdzkvF0tPEBbY\n"
        "vME6TrJONkSxaV8nzID/BO+ZNvl0RVUhePbpf/CQhxZZUTWY5mgdZ7Ru0hdl9jJ+\n"
        "zyddWAg24Te56rpsyjhfAJhRYZK1UwQUOLhRaaUvZpBM2QYHA9NSHOGv9IU6krP+\n"
        "iTFOKw2XbGMZkuCJz1Jn8h4jfGHfw2SMZvRcmqNW2OuQQn40kMlOoKp1xcZ2pTR4\n"
        "B0dl1Y4tLe7s4zC9JdyGsYiwlAwHwDSgATg+G6c1cUbxHwlPBAl8fNpmNdp7OGZk\n"
        "DhHoC2rldV3D04HwukarR82OP8VUj7H3ykSEKTEnUX8vGpkruPPXpe3lF9pZrqX5\n"
        "QAvdZuz+jDWy+OOt3NNLR7pEUK96geuDNJegWracsUB2/DwRKhWOWjxG3nko0H+n\n"
        "y1P4TG0xeT/59oJOLvscHpO+IW3p3rjiTvN8hgFt1bLSi+ZKJOxtJNNsQCMokgV9\n"
        "UiB3/sJnLM0f+yRODsR0iscy51rssuSs8P8XjsyEiG+qep8VfGrCAwIw4dMxyZ/P\n"
        "jtuZe1bhjON3Zva27eF47FKRpwiU5KBFBwbSx92lGZ6Gin5dYP045LOf\n"
        "-----END ENCRYPTED PRIVATE KEY-----\n";

static std::string wrongCertificate_DER = "MIIC9DCCAl2gAwIBAgICEAAwDQYJKoZIhvcNAQEFBQAweTELMAkGA1UEBhMCQkUx"
        "ETAPBgNVBAgMCEJydXNzZWxzMRIwEAYDVQQHDAlFdHRlcmJlZWsxEzARBgNVBAoM"
        "ClNtYXJ0bWF0aWMxHDAaBgNVBAsME0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNV"
        "BAMMB1JPT1QgQ0EwHhcNMTMxMjI2MTAzNjM0WhcNMTQxMjI2MTAzNjM0WjCBiDEL"
        "MAkGA1UEBhMCQkUxETAPBgNVBAgMCEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1h"
        "dGljMRwwGgYDVQQLDBNFbGVjdG9yYWwgU29sdXRpb25zMQ4wDAYDVQQDDAVVc2Vy"
        "MTEjMCEGCSqGSIb3DQEJARYUdXNlcjFAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZI";

static std::string validCertificate_DER = "MIIC9DCCAl2gAwIBAgICEAAwDQYJKoZIhvcNAQEFBQAweTELMAkGA1UEBhMCQkUx"
        "ETAPBgNVBAgMCEJydXNzZWxzMRIwEAYDVQQHDAlFdHRlcmJlZWsxEzARBgNVBAoM"
        "ClNtYXJ0bWF0aWMxHDAaBgNVBAsME0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNV"
        "BAMMB1JPT1QgQ0EwHhcNMTMxMjI2MTAzNjM0WhcNMTQxMjI2MTAzNjM0WjCBiDEL"
        "MAkGA1UEBhMCQkUxETAPBgNVBAgMCEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1h"
        "dGljMRwwGgYDVQQLDBNFbGVjdG9yYWwgU29sdXRpb25zMQ4wDAYDVQQDDAVVc2Vy"
        "MTEjMCEGCSqGSIb3DQEJARYUdXNlcjFAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZI"
        "hvcNAQEBBQADgY0AMIGJAoGBALkfis573u0A27LW+n1q9URLy6fFoJ8XIAn1bYrw"
        "YQgZPfuLGk0fSFzPf3skMKhvueWgNg9IbOi29Ta8/y4T55SYdTCjumezcjo5kXfP"
        "J5dUFNMSnACwP+xH8MGrCaUBn9WEGO4IE0dbiTK4koH0kCrnbOqR+IaNW/TDFJvH"
        "mWQ5AgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wg"
        "R2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBQb0Vt+kvOcMX8GKNS2Nrp6"
        "fJ8RWTAfBgNVHSMEGDAWgBR7ieRpADfz3zAXXjayYT4sn4hRCjANBgkqhkiG9w0B"
        "AQUFAAOBgQARS2/N2ySflGKV4bbNgcu9RJspQ7P6wTFgLivsjcLKgJvLgJQUNdsr"
        "eoY4T0Jjm3yg+tN6y8831u4JUgZOuvjWmHmIkYFPqqkzEHkPyslBZFHBhE/60xNn"
        "p+xjtpQJ/RB9eC4OeaXpgaCLYP5jQPxN00A8HEdLNjqz6sIvWyCzjg==";

static std::string wrongPrivateKey_DER = "MIICXQIBAAKBgQC5H4rOe97tANuy1vp9avVES8unxaCfFyAJ9W2K8GEIGT37ixpN"
        "H0hcz397JDCob7nloDYPSGzotvU2vP8uE+eUmHUwo7pns3I6OZF3zyeXVBTTEpwA"
        "sD/sR/DBqwmlAZ/VhBjuCBNHW4kyuJKB9JAq52zqkfiGjVv0wxSbx5lkOQIDAQAB"
        "AoGBAII7BlMsIS9poyS0x5LjY5egGqz0AoLoqclXtrA/WoNv/oKu4NnQX/+qmWvv"
        "katsrcI0atNlh/hOfUL8wieQKSDUJfgQ22wZQ8vM7JlJUi209rQJwaC8L343A0YQ"
        "SEJjBg3j7nlcbqgbv5NX/+ekLDNb8ugp7gHVXs5rk6NvzuQBAkEA8MdUSeBUQ34Z";

static std::string validPrivateKey_DER = "MIICXQIBAAKBgQC5H4rOe97tANuy1vp9avVES8unxaCfFyAJ9W2K8GEIGT37ixpN"
        "H0hcz397JDCob7nloDYPSGzotvU2vP8uE+eUmHUwo7pns3I6OZF3zyeXVBTTEpwA"
        "sD/sR/DBqwmlAZ/VhBjuCBNHW4kyuJKB9JAq52zqkfiGjVv0wxSbx5lkOQIDAQAB"
        "AoGBAII7BlMsIS9poyS0x5LjY5egGqz0AoLoqclXtrA/WoNv/oKu4NnQX/+qmWvv"
        "katsrcI0atNlh/hOfUL8wieQKSDUJfgQ22wZQ8vM7JlJUi209rQJwaC8L343A0YQ"
        "SEJjBg3j7nlcbqgbv5NX/+ekLDNb8ugp7gHVXs5rk6NvzuQBAkEA8MdUSeBUQ34Z"
        "mjaAii3CSaJa2hq40E4FrD6SUtarNDqJzW8zC2ecnYy+jzyltGo1aQEiF7c9jRll"
        "8skzGmJQiQJBAMTTgbGQh/kJ0kJhGyEFE4B+l1AmbOPO7YvUURXBEJJ9ltGlnUDE"
        "sgONOlPIvGC7cHOAxYTWYvf+e75hoAGlqjECQD6z+ixfAjKtZSd26BSUBBO+9x/z"
        "c4uzteB8TwjJpL4uPHLGcamXqv6Qh5OvvIt2WUBmLiW074+OPLF0Wh2V2tkCQGF0"
        "G9YQKtLqwvls3SLXQZWwmDjuHaIZ9dHzGQa9ZfgySLea2aaU/VL23TdYv7Theccm"
        "riWchLonfZuA+Nl37jECQQCTNkShflb+dfi8uVXhB59ufx0aHVxGFLQFIgkcR/3L"
        "HWv2Oor8tQmdNamU02NOIxt2SPku+iXgK6cLP5xJIcd4";

static std::string wrongCertificate_PKCS12 = "MIIJ4QIBAzCCCacGCSqGSIb3DQEHAaCCCZgEggmUMIIJkDCCBo8GCSqGSIb3DQEH"
        "BqCCBoAwggZ8AgEAMIIGdQYJKoZIhvcNAQcBMBwGCiqGSIb3DQEMAQYwDgQIsyAM"
        "Tby61EMCAggAgIIGSNA54zRywSYK7JFdm8Gzfmib0u4oCdZf05yZp/guiXXou7N4"
        "GslmIdVhxtzIiv3XniG3kxWZccv6fs9S77VjyhS+HYi1OsR6TrGWc/sQ+vX+Xa2m"
        "LW2WuZLfjPonKLlY4pmT1saXv46xxgg9PFHiKZ54ao6F0g+24BGP/hXTGYLo9rDy"
        "3/Z6W8E1FX2BuEk1M79zTMMwDkbg5ivO8P9W6tOoMwgOqTnVKuZPmdqjF/BN58By"
        "PiFkBjMuDkRi5RlwhzbQqmd1Fgfq59JTcGrY8uDCcYCzAO7lBZS/bcZy1k9eY1eU"
        "XwUqmlzyszuly2x/0TP+Ycrws/p4hUHKbHeqN+3orxlcJsr/EMwnyipV/VASPjEM"
        "aZ+BKV8Pfr7PlZGyahhfSyHvx3EBFx4ONHTLsg5lzXYCquP41CZRhopgU41Nbu1K"
        "9dz4zC9uUkmA7zloJIbClWigRETS3cqbVUzgbr4wiIfbwdW2XnycAvh8v0GBMcu1"
        "GmWu0hXEEYGXnm30Wr8vxoXoZvfx/Euu0erU+Eo2QH7UL6FfMOYGbKSMzeaRcvnx"
        "gIg1dQkIUThyOYiJ34WELh9QQikJ7iY1uu0nxvWN/X+tH3ufVOIMZ7FFcXH2yLKZ"
        "/f4qFj5JOzKRfbxjB660ccUVXCHJYWeS3eWuRFYEUry6mfmcmXtT2ly2dMBjop2j"
        "t7GFlZBbKelazk9Zn/urrcusZZgaWDZns85ojMqBP9kbnZwBj+LvN3BLSbVhjU5N"
        "Tb2biKaAKhkf2gMO/F/REEs+uzB3vZOg1un0tBcC0enfqynq3wpQV6QDw4n7QIU+"
        "yz9zyif2PQ1IVexau4Me7N9Ot958OSlkVnSwx6rUz5NmAT4wzO7y4HQaJwmp/JDw";

static std::string validCertificate_PKCS12 = "MIIJ4QIBAzCCCacGCSqGSIb3DQEHAaCCCZgEggmUMIIJkDCCBo8GCSqGSIb3DQEH"
        "BqCCBoAwggZ8AgEAMIIGdQYJKoZIhvcNAQcBMBwGCiqGSIb3DQEMAQYwDgQIsyAM"
        "Tby61EMCAggAgIIGSNA54zRywSYK7JFdm8Gzfmib0u4oCdZf05yZp/guiXXou7N4"
        "GslmIdVhxtzIiv3XniG3kxWZccv6fs9S77VjyhS+HYi1OsR6TrGWc/sQ+vX+Xa2m"
        "LW2WuZLfjPonKLlY4pmT1saXv46xxgg9PFHiKZ54ao6F0g+24BGP/hXTGYLo9rDy"
        "3/Z6W8E1FX2BuEk1M79zTMMwDkbg5ivO8P9W6tOoMwgOqTnVKuZPmdqjF/BN58By"
        "PiFkBjMuDkRi5RlwhzbQqmd1Fgfq59JTcGrY8uDCcYCzAO7lBZS/bcZy1k9eY1eU"
        "XwUqmlzyszuly2x/0TP+Ycrws/p4hUHKbHeqN+3orxlcJsr/EMwnyipV/VASPjEM"
        "aZ+BKV8Pfr7PlZGyahhfSyHvx3EBFx4ONHTLsg5lzXYCquP41CZRhopgU41Nbu1K"
        "9dz4zC9uUkmA7zloJIbClWigRETS3cqbVUzgbr4wiIfbwdW2XnycAvh8v0GBMcu1"
        "GmWu0hXEEYGXnm30Wr8vxoXoZvfx/Euu0erU+Eo2QH7UL6FfMOYGbKSMzeaRcvnx"
        "gIg1dQkIUThyOYiJ34WELh9QQikJ7iY1uu0nxvWN/X+tH3ufVOIMZ7FFcXH2yLKZ"
        "/f4qFj5JOzKRfbxjB660ccUVXCHJYWeS3eWuRFYEUry6mfmcmXtT2ly2dMBjop2j"
        "t7GFlZBbKelazk9Zn/urrcusZZgaWDZns85ojMqBP9kbnZwBj+LvN3BLSbVhjU5N"
        "Tb2biKaAKhkf2gMO/F/REEs+uzB3vZOg1un0tBcC0enfqynq3wpQV6QDw4n7QIU+"
        "yz9zyif2PQ1IVexau4Me7N9Ot958OSlkVnSwx6rUz5NmAT4wzO7y4HQaJwmp/JDw"
        "EJHMXi5cvekN2ek75a4imk057pNQo4+HuMH1BUZxAIBZ+ylbe8+NjBNzbWDMu6gg"
        "UXTz0B4454ZzJnGO1Qr6neBGGpFQ5DKmmzSZUDCC9TzZG4JuxRzkKPgae66Uugin"
        "xi7F3MnWSI+YAjCow6UGZv/PmCCBVFVxM6ASvS+Y6rPNYOWkn0NfZH+Xb+t/aSAj"
        "3SVs9lPSFZ7q3ng5H0SsXe6cSmAu3UXOt2htM+lypmNduRD18HBaINz6DApu9kQ9"
        "5Q+Q6b27X178VP2ymnStfw0VLAQGFD/LaSpeLU3tW0p+se1jgkL3GEyJ7OhvyeWy"
        "JWTbm3WwtpmUaBTJRyC4AZu/76Uyk72EXYdVSpQXrKFWd3k2ykxyOKFnUOWxtlyX"
        "0AwdUIVooRwTewXzs5+RRtrPd41aTjPhMv7HDIjSHpdhDy5DGj67gWYdKSzJ6Zig"
        "SDCxqqUod5h7paXUFMbPGCPakmIBPdgfraLkK20NXBIzCOrZmBw2EE2oIqQtJ/f6"
        "l1jUUe85iWEVStxlQhgxF1Z9HOjgaWKm8LNjBaq0pPEWHFngIANefHkiibRTA882"
        "MKHuco1bQXYpKat4bKTT6hid1IDojLRo+6FWQptE7qX0WfriUA4Qsr7hmMT10/Kf"
        "bziAHlMIMhCUZvRt7JqR4wyhUq0AWkFA8/aH0FQNs0n6gWO4bUG7KT831XZvr21C"
        "cknButntjTOg0GV8K0EicT90jgY1OawsR4/lRFrMcT+1R9YecCdzpIzqbmLodZG+"
        "ZDrs9XHRNfXpcnz1X6P/8U3aa/x26/ER6bmezznWF60NVrA3u8ACUcymjh2mC+6/"
        "4uQeca8K7v+jvlrjK9jpXEsNPaWfDsTm5Nf39BnmE8WrJTc5BU8GlvarZdWzblSY"
        "JXzi6BlAc/e7u3+NCIlXXlow86upuKxAnGBu142lRe1s2ZnCT/cL2ubab9nHJUUe"
        "CpsW6egPL+rXSVagOHD9d55X8r2USzhTGyVTq6G/wkY1VPAjMfH0+SZ7rbgkCg6z"
        "7wrRuQYWqG5QgtqJ4vXhIZffpyd3TWZhF+iFaXkCZNM48K4CmkpzecmgfgYkIvya"
        "Zqcw8aA0aQARVREnP58xrb2SrdLygpx12jMu6mZiTwxy3BfHmUJUeC15X7Nn7gxH"
        "jXPFsJmuHGKZIa1Wrq3GeImQgFGts/DuynFmV+H/5U6UD9hS4tHvbIbO6cmnyMZ7"
        "x4OkKFvp13nusDiyuzCdQllYx0G06kFzxFuchui23ms0zAp0LjCCAvkGCSqGSIb3"
        "DQEHAaCCAuoEggLmMIIC4jCCAt4GCyqGSIb3DQEMCgECoIICpjCCAqIwHAYKKoZI"
        "hvcNAQwBAzAOBAiwRsjl2i/JBgICCAAEggKAo67L/gzuTYIVlwuVsUF63kISwQ2d"
        "MRwlFQQc5VD9O+lnIksCyZfpcHcSYJGl4AeOy9glAeOn0o13ynkA5oCe1DlemadM"
        "njui44MSLivmNTJleGNqCtoUT88/ADGcGoeOneMCl4yTP42klGZaF2hXoT7tAZkE"
        "vurLAw7VBK7JWT/8tXXFBN2CvNGkyhSQWasfzQUyc44nABsOAprbwGzj7LpOJ4jb"
        "J7FvPcn3lJXR3xPdDNWTg8nLxiALpJMoB0vPFanyxDmhG8LdhxA8E0kOBacF9c9v"
        "165RxCIA/9M1ri1/H7iDpeCwjSPb+yyZTPGEsyuQQdjBiph6YXPQcBs17TkGgjIm"
        "TjKJnnubyKSf2CryfOHlvBTHN84XUzasqkRNMPyk4mhboJCBZ0sduxYnLmbcwBAW"
        "aXdxiGGnhenfnHYZ9NWDeiYXofHn+UZrqjfE3xWxg70h//Nj6ISu9s6u6YR343vB"
        "ivi8UFJu3kpwXkm1yZLtgZb64QH4VvGXE5H/vLVtedRThqq6kSGwKcKJCl31VrF9"
        "Xy+7u4t9amQVpVDIq9IEpwGzqpGxNSpVavUSmzfTbiAwZtkdCgPd2W0lrXSbznxo"
        "RqpQmnejBwy5jUkM6IPn3DovMUWpoxZt2klj286ZqJM7iF11y9H9S0aOt3W88Ulp"
        "sqvA9C0Jp6N3+OftZg4+pJX/MZrfBt0Yk27tA5AzT4AbxmOtKdLtnjMiK0UteTsu"
        "SeriPybTxXJyExR5WAhHU5K5MuURZGpn+dN2viwEwSdMbPGxJijCpnCqdf0iaJWI"
        "DbP8L+x7QUH81sIBZpDXC13hQMjnBOyru71H5tYzPhrvisuxLudqqwi8wzElMCMG"
        "CSqGSIb3DQEJFTEWBBS2X3q5lo9YxXfYjtyJLisz+f5mKTAxMCEwCQYFKw4DAhoF"
        "AAQUd9qIdcVDXDs3XI/8DniFdZhZKpYECGXJksfazXjZAgIIAA==";

static std::string correctPrivateKeyPassword = "passworduser1";
static std::string wrongPassword = "wrong";
static std::string correctPasswordPKCS12 = "passwordpkcs12";
static std::string filePath = "filePath";

class CertUtilTest : public CPPUNIT_NS::TestFixture
{
    private:
        X509 * certifiedX509;
        EVP_PKEY * certifiedPKEY;
        STACK_OF ( X509 ) * certificateAuthorities;

    public:

        CertUtilTest()
        {
            certifiedX509 = NULL;
            certifiedPKEY = NULL;
            certificateAuthorities = NULL;
        }

        void setUp()
        {
            Smartmatic::System::Security::OpenSSLSecurity::init();
            certifiedX509 = NULL;
            certifiedPKEY = NULL;
            certificateAuthorities = NULL;
        }

        void tearDown()
        {
            Smartmatic::System::Security::OpenSSLSecurity::clear();

            if ( certifiedX509 != NULL )
            {
                X509_free ( certifiedX509 );
                certifiedX509 = NULL;
            }

            if ( certifiedPKEY != NULL )
            {
                EVP_PKEY_free ( certifiedPKEY );
                certifiedPKEY = NULL;
            }

            if ( certificateAuthorities )
            {
                sk_X509_pop_free ( certificateAuthorities, X509_free );
                certificateAuthorities = NULL;
            }
        }

        void testLoadCertifiedX509_PEM_NullSafeBuffer()
        {
            SafeBuffer certificateBuffer;
            certifiedX509 = CertUtil::LoadCertifiedX509 ( certificateBuffer, Cryptography::CertUtil::CertFormat_PEM );

            CPPUNIT_ASSERT ( certifiedX509 == NULL );
        }

        void testLoadCertifiedX509_PEM_WrongContent()
        {
            SafeBuffer certificateBuffer ( wrongCertificate_PEM );
            certifiedX509 = CertUtil::LoadCertifiedX509 ( certificateBuffer, Cryptography::CertUtil::CertFormat_PEM );

            CPPUNIT_ASSERT ( certifiedX509 == NULL );
        }

        void testLoadCertifiedX509_PEM()
        {
            SafeBuffer certificateBuffer ( validCertificate_PEM );
            certifiedX509 = CertUtil::LoadCertifiedX509 ( certificateBuffer, Cryptography::CertUtil::CertFormat_PEM );

            CPPUNIT_ASSERT ( certifiedX509 != NULL );
        }

        void testLoadCertifiedPrivateKey_PEM_NullSafeBuffer()
        {
            SafeBuffer certificateBuffer;
            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_PEM, correctPrivateKeyPassword );

            CPPUNIT_ASSERT ( certifiedPKEY == NULL );
        }

        void testLoadCertifiedPrivateKey_PEM_WrongContent()
        {
            SafeBuffer certificateBuffer ( wrongPrivateKey_PEM );
            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_PEM, correctPrivateKeyPassword );

            CPPUNIT_ASSERT ( certifiedPKEY == NULL );
        }

        void testLoadCertifiedPrivateKey_PEM_EmptyPassphrase()
        {
            SafeBuffer certificateBuffer ( validPrivateKey_PEM );
            std::string emptyPassword;

            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_PEM, emptyPassword );

            CPPUNIT_ASSERT ( certifiedPKEY == NULL );
        }

        void testLoadCertifiedPrivateKey_PEM_WrongPassphrase()
        {
            SafeBuffer certificateBuffer ( validPrivateKey_PEM );
            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_PEM, wrongPassword );

            CPPUNIT_ASSERT ( certifiedPKEY == NULL );
        }

        void testLoadCertifiedPrivateKey_PEM()
        {
            SafeBuffer certificateBuffer ( validPrivateKey_PEM );
            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_PEM, correctPrivateKeyPassword );

            CPPUNIT_ASSERT ( certifiedPKEY != NULL );
        }

        void testLoadCertificateAuthorities_PEM_NullSafeBuffer()
        {
            SafeBuffer certificateBuffer;
            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( certificateBuffer, Cryptography::CertUtil::CertFormat_PEM );

            CPPUNIT_ASSERT ( certificateAuthorities == NULL );
        }

        void testLoadCertificateAuthorities_PEM_WrongContent()
        {
            SafeBuffer certificateBuffer ( wrongCertificate_PEM );
            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( certificateBuffer, Cryptography::CertUtil::CertFormat_PEM );

            CPPUNIT_ASSERT ( certificateAuthorities == NULL );
        }

        void testLoadCertificateAuthorities_PEM()
        {
            SafeBuffer certificateBuffer ( validCertificate_PEM );
            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( certificateBuffer, Cryptography::CertUtil::CertFormat_PEM );

            CPPUNIT_ASSERT ( certificateAuthorities != NULL );
        }

        void testLoadCertifiedX509_DER_NullSafeBuffer()
        {
            SafeBuffer certificateBuffer;
            certifiedX509 = CertUtil::LoadCertifiedX509 ( certificateBuffer, Cryptography::CertUtil::CertFormat_DER );

            if ( certifiedX509 != NULL )
            {
                X509_free ( certifiedX509 );
                certifiedX509 = NULL;
            }

            CPPUNIT_ASSERT ( certifiedX509 == NULL );
        }

        void testLoadCertifiedX509_DER_WrongContent ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( wrongCertificate_DER, certificateBuffer );

            certifiedX509 = CertUtil::LoadCertifiedX509 ( certificateBuffer, Cryptography::CertUtil::CertFormat_DER );

            CPPUNIT_ASSERT ( certifiedX509 == NULL );
        }

        void testLoadCertifiedX509_DER ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_DER, certificateBuffer );

            certifiedX509 = CertUtil::LoadCertifiedX509 ( certificateBuffer, Cryptography::CertUtil::CertFormat_DER );

            CPPUNIT_ASSERT ( certifiedX509 != NULL );
        }

        void testLoadCertifiedPrivateKey_DER_NullSafeBuffer()
        {
            SafeBuffer certificateBuffer;
            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_DER );

            CPPUNIT_ASSERT ( certifiedPKEY == NULL );
        }

        void testLoadCertifiedPrivateKey_DER_WrongContent ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( wrongPrivateKey_DER, certificateBuffer );

            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_DER );

            CPPUNIT_ASSERT ( certifiedPKEY == NULL );
        }

        void testLoadCertifiedPrivateKey_DER ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validPrivateKey_DER, certificateBuffer );

            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_DER );

            CPPUNIT_ASSERT ( certifiedPKEY != NULL );
        }

        void testLoadCertificateAuthorities_DER_NullSafeBuffer()
        {
            SafeBuffer certificateBuffer;
            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( certificateBuffer, Cryptography::CertUtil::CertFormat_DER );

            CPPUNIT_ASSERT ( certificateAuthorities == NULL );
        }

        void testLoadCertificateAuthorities_DER_WrongContent ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( wrongCertificate_DER, certificateBuffer );

            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( certificateBuffer, Cryptography::CertUtil::CertFormat_DER );

            CPPUNIT_ASSERT ( certificateAuthorities == NULL );
        }

        void testLoadCertificateAuthorities_DER ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_DER, certificateBuffer );

            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( certificateBuffer, Cryptography::CertUtil::CertFormat_DER );

            CPPUNIT_ASSERT ( certificateAuthorities == NULL );
        }

        void testLoadCertifiedX509_PKCS12_NullSafeBuffer()
        {
            SafeBuffer certificateBuffer;
            certifiedX509 = CertUtil::LoadCertifiedX509 ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( certifiedX509 == NULL );
        }

        void testLoadCertifiedX509_PKCS12_WrongContent()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( wrongCertificate_PKCS12, certificateBuffer );

            certifiedX509 = CertUtil::LoadCertifiedX509 ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( certifiedX509 == NULL );
        }

        void testLoadCertifiedX509_PKCS12_EmptyPassphrase()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );
            std::string emptyPassword;

            certifiedX509 = CertUtil::LoadCertifiedX509 ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, emptyPassword );

            CPPUNIT_ASSERT ( certifiedX509 == NULL );
        }

        void testLoadCertifiedX509_PKCS12_WrongPassphrase()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            certifiedX509 = CertUtil::LoadCertifiedX509 ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, wrongPassword );

            CPPUNIT_ASSERT ( certifiedX509 == NULL );
        }

        void testLoadCertifiedX509_PKCS12 ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            certifiedX509 = CertUtil::LoadCertifiedX509 ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( certifiedX509 != NULL );
        }

        void testLoadCertifiedPrivateKey_PKCS12_NullSafeBuffer()
        {
            SafeBuffer certificateBuffer;
            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( certifiedPKEY == NULL );
        }

        void testLoadCertifiedPrivateKey_PKCS12_WrongContent()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( wrongCertificate_PKCS12, certificateBuffer );

            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( certifiedPKEY == NULL );
        }

        void testLoadCertifiedPrivateKey_PKCS12_EmptyPassphrase()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );
            std::string emptyPassword;

            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, emptyPassword );

            CPPUNIT_ASSERT ( certifiedPKEY == NULL );
        }

        void testLoadCertifiedPrivateKey_PKCS12_WrongPassphrase()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, wrongPassword );

            CPPUNIT_ASSERT ( certifiedPKEY == NULL );
        }

        void testLoadCertifiedPrivateKey_PKCS12 ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( certifiedPKEY != NULL );
        }

        void testLoadCertificateAuthorities_PKCS12_NullSafeBuffer()
        {
            SafeBuffer certificateBuffer;
            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( certificateAuthorities == NULL );
        }

        void testLoadCertificateAuthorities_PKCS12_WrongContent()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( wrongCertificate_PKCS12, certificateBuffer );

            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( certificateAuthorities == NULL );
        }

        void testLoadCertificateAuthorities_PKCS12_EmptyPassphrase()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );
            std::string emptyPassword;

            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, emptyPassword );

            CPPUNIT_ASSERT ( certificateAuthorities == NULL );
        }

        void testLoadCertificateAuthorities_PKCS12_WrongPassphrase()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, wrongPassword );

            CPPUNIT_ASSERT ( certificateAuthorities == NULL );
        }

        void testLoadCertificateAuthorities_PKCS12 ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( certificateBuffer, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( certificateAuthorities != NULL );
        }

        void testLoadCertificate_X509_FileNotFound ()
        {
            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer(), false ) );

            certifiedX509 = CertUtil::LoadCertifiedX509 ( filePath, Cryptography::CertUtil::CertFormat_DER );

            CPPUNIT_ASSERT ( certifiedX509 == NULL );
        }

        void testLoadCertificate_X509_FileFound ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_DER, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            certifiedX509 = CertUtil::LoadCertifiedX509 ( filePath, Cryptography::CertUtil::CertFormat_DER );

            CPPUNIT_ASSERT ( certifiedX509 != NULL );
        }

        void testLoadCertificate_PrivateKey_FileNotFound ()
        {
            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer(), false ) );

            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( filePath, Cryptography::CertUtil::CertFormat_PEM, correctPrivateKeyPassword );

            CPPUNIT_ASSERT ( certifiedPKEY == NULL );
        }

        void testLoadCertificate_PrivateKey_FileFound ()
        {
            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer ( validPrivateKey_PEM ), true ) );

            certifiedPKEY = CertUtil::LoadCertifiedPrivateKey ( filePath, Cryptography::CertUtil::CertFormat_PEM, correctPrivateKeyPassword );

            CPPUNIT_ASSERT ( certifiedPKEY != NULL );
        }

        void testLoadCertificate_PKCS12_FileNotFound ()
        {
            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer(), false ) );

            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( filePath, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( certificateAuthorities == NULL );
        }

        void testLoadCertificate_PKCS12_FileFound ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            certificateAuthorities = CertUtil::LoadCertificateAuthorities ( filePath, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( certificateAuthorities != NULL );
        }

        void testGetCertificateExtensionBaseByFile ()
        {
            SafeBuffer certificateBuffer;
            Base64Encoder::ConvertFromBase64 ( validCertificate_PKCS12, certificateBuffer );

            StoreMockFile file;
            File::getInstance ( &file );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( certificateBuffer, true ) );

            CertificateExtensionBase * certBase = CertUtil::getCertificateExtensionBase ( filePath, Cryptography::CertUtil::CertFormat_PKCS12, correctPasswordPKCS12 );

            CPPUNIT_ASSERT ( NULL != certBase );
            CPPUNIT_ASSERT ( NULL != certBase->LoadCertifiedX509() );
            CPPUNIT_ASSERT ( NULL != certBase->LoadCertifiedPrivateKey() );
            CPPUNIT_ASSERT ( NULL != certBase->getCertificateAuthorities() );

            certBase->releaseAll();
            delete certBase;
        }

        CPPUNIT_TEST_SUITE ( CertUtilTest );
        CPPUNIT_TEST ( testLoadCertifiedX509_PEM_NullSafeBuffer );
        CPPUNIT_TEST ( testLoadCertifiedX509_PEM_WrongContent );
        CPPUNIT_TEST ( testLoadCertifiedX509_PEM );

        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_PEM_NullSafeBuffer );
        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_PEM_WrongContent );
        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_PEM_EmptyPassphrase );
        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_PEM_WrongPassphrase );
        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_PEM );

        CPPUNIT_TEST ( testLoadCertificateAuthorities_PEM_NullSafeBuffer );
        CPPUNIT_TEST ( testLoadCertificateAuthorities_PEM_WrongContent );
        CPPUNIT_TEST ( testLoadCertificateAuthorities_PEM );

        CPPUNIT_TEST ( testLoadCertifiedX509_DER_NullSafeBuffer );
        CPPUNIT_TEST ( testLoadCertifiedX509_DER_WrongContent );
        CPPUNIT_TEST ( testLoadCertifiedX509_DER );

        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_DER_NullSafeBuffer );
        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_DER_WrongContent );
        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_DER );

        CPPUNIT_TEST ( testLoadCertificateAuthorities_DER_NullSafeBuffer );
        CPPUNIT_TEST ( testLoadCertificateAuthorities_DER_WrongContent );
        CPPUNIT_TEST ( testLoadCertificateAuthorities_DER );

        CPPUNIT_TEST ( testLoadCertifiedX509_PKCS12_NullSafeBuffer );
        CPPUNIT_TEST ( testLoadCertifiedX509_PKCS12_WrongContent );
        CPPUNIT_TEST ( testLoadCertifiedX509_PKCS12_EmptyPassphrase );
        CPPUNIT_TEST ( testLoadCertifiedX509_PKCS12_WrongPassphrase );
        CPPUNIT_TEST ( testLoadCertifiedX509_PKCS12 );

        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_PKCS12_NullSafeBuffer );
        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_PKCS12_WrongContent );
        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_PKCS12_EmptyPassphrase );
        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_PKCS12_WrongPassphrase );
        CPPUNIT_TEST ( testLoadCertifiedPrivateKey_PKCS12 );

        CPPUNIT_TEST ( testLoadCertificateAuthorities_PKCS12_NullSafeBuffer );
        CPPUNIT_TEST ( testLoadCertificateAuthorities_PKCS12_WrongContent );
        CPPUNIT_TEST ( testLoadCertificateAuthorities_PKCS12_EmptyPassphrase );
        CPPUNIT_TEST ( testLoadCertificateAuthorities_PKCS12_WrongPassphrase );
        CPPUNIT_TEST ( testLoadCertificateAuthorities_PKCS12 );

        CPPUNIT_TEST ( testLoadCertificate_X509_FileNotFound );
        CPPUNIT_TEST ( testLoadCertificate_X509_FileFound );
        CPPUNIT_TEST ( testLoadCertificate_PrivateKey_FileNotFound );
        CPPUNIT_TEST ( testLoadCertificate_PrivateKey_FileFound );
        CPPUNIT_TEST ( testLoadCertificate_PKCS12_FileNotFound );
        CPPUNIT_TEST ( testLoadCertificate_PKCS12_FileFound );

        CPPUNIT_TEST ( testGetCertificateExtensionBaseByFile );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_TEST_CERTUTILTEST */
