#ifndef TEST_DETACHED_TEST
#define TEST_XMLSIGNEDTEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/Security/Cryptography/CertificateExtensionBase.hxx>
#include <System/Security/Cryptography/CertUtil.h>
#include <System/Security/OpenSSLSecurity.hxx>
#include <System/Security/XmlDigitalSignature/XmlDetachedSignature.hxx>
#include <System/Security/XmlSecurityC.hxx>
#include <System/Encoding/Base64Encoder.h>
#include <System/IO/File.h>
#include <System/Security/URILocalResolver.hxx>
#include <System/XML/DomXml.hxx>
#include <tests/StoreMockFile.hxx>
#include <tests/MockFile.hxx>
#include <xercesc/dom/DOMDocument.hpp>
#include <xsec/dsig/DSIGReference.hpp>
#include <xsec/enc/OpenSSL/OpenSSLCryptoX509.hpp>
#include <xsec/enc/XSECCryptoException.hpp>
#include <xsec/framework/XSECException.hpp>
#include <xsec/framework/XSECProvider.hpp>

#include <openssl/ec.h>
#include <openssl/bn.h>
#include <openssl/evp.h>

using namespace Smartmatic::System;
using namespace Smartmatic::System::IO;
using namespace Smartmatic::System::Encoding;
using namespace Smartmatic::System::Security;
using namespace Smartmatic::System::XML;

static std::string correctDetachedFile = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\"><SignedInfo><CanonicalizationMethod Algorithm=\"http://www.w3.org/2001/10/xml-exc-c14n#WithComments\"/><SignatureMethod Algorithm=\"http://www.w3.org/2001/04/xmldsig-more#rsa-sha256\"/><Reference URI=\"uno\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>Q1WkaxnTSNwvV8BG+O9j1FOOu5NgAPPJ7pVKJ0YN2GU=</DigestValue></Reference><Reference URI=\"dos\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>/O3+5KI/XLWDoOvqdilXEa1QTEiOfgb3IBHPeNiTRFk=</DigestValue></Reference><Reference URI=\"key\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>X8Kw8w74F8acQR7WTF9F+l8SsvwTGsZbRdo49xvPI9I=</DigestValue></Reference><Reference URI=\"UserCert2.p12\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>kbBZ8C4LYcPP0IGQwK+2dB+VbnES83R2vtaDKe7YEUk=</DigestValue></Reference>" \
        "</SignedInfo><SignatureValue>mKerOLtkcta6CSaWrw3Y0Ox7uUFGcUV3uusCLwtE1kPsjMkGMQeNlU4Z7nkCDGTVGc8gD7eo/mOehLjR01xHpAXA2v2uQzqQYTkWu1ngF1orrtof5kHH2KzDJGFNg189EYmYLl8dLD2uHOumLk+OIDTdyuFmOePhByyAh+CbYWE=</SignatureValue><KeyInfo><X509Data><X509SubjectName>1.2.840.113549.1.9.1=#1614757365723240736d6172746d617469632e636f6d,CN=User 2,OU=Electoral Solutions,O=Smartmatic,ST=Brussels,C=BE</X509SubjectName><X509Certificate>" \
        "MIIDQzCCAiugAwIBAgICEAMwDQYJKoZIhvcNAQELBQAwZTELMAkGA1UEBhMCQkUxETAPBgNVBAgM" \
        "CEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1hdGljMRwwGgYDVQQLDBNFbGVjdG9yYWwgU29sdXRp" \
        "b25zMRAwDgYDVQQDDAdST09UIENBMCAXDTIyMDcxNDEzMTUyN1oYDzMwMjExMTE0MTMxNTI3WjCB" \
        "iTELMAkGA1UEBhMCQkUxETAPBgNVBAgMCEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1hdGljMRww" \
        "GgYDVQQLDBNFbGVjdG9yYWwgU29sdXRpb25zMQ8wDQYDVQQDDAZVc2VyIDIxIzAhBgkqhkiG9w0B" \
        "CQEWFHVzZXIyQHNtYXJ0bWF0aWMuY29tMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQC1bX3b" \
        "oEiretroFKER/nDxBuqqJgouc9JR2eC+xhxHNBMf+RebMzj19gum14+GMYhea9Ax4V9ICEqI2Ijp" \
        "+i9m4wl19zZflndc48Glr+66JYOU5+6pg8j8dz+OsZcUV3sdFVTMrzujsXlDwFsNifOl1r3WoJOM" \
        "shc4UtvXa3SvpwIDAQABo1owWDAfBgNVHSMEGDAWgBRrNy+HTBW6OKzrcP0BUfprP4tRsTAdBgNV" \
        "HQ4EFgQUSlIKpFtNa4SlNhsYtXqd5WnUOKAwCQYDVR0TBAIwADALBgNVHQ8EBAMCBPAwDQYJKoZI" \
        "hvcNAQELBQADggEBAG2q3s9Gjf1tjojBYSceMfcU3xHkF9V6sQM/xmJdd/DqkpQiKP96T4o4rZAQ" \
        "3IWc8B5KO/xpbd46VUfJziqn05IE7GRsWRSlsyZM7Y6obpTGoHDxclcuomYAJeb8HXoH6JcpAkmg" \
        "i+cOrk7XUzKoSR3B7JBXHfAYVAXWgRm9Z4iDSYfuGVRpQigJbkED+SToUn4AN/bPVlHeWEWgap4Z" \
        "avp+0QcQ3TPe1bjv8/quiAkyRY492kj6s4OVBp7LWQfHmcFKBFmV9h7rK7/f6kD05ryzLTByh4oL" \
        "LWlD+kAAhw1VlSe/0tbz4hL2U7GnqTzqFAbjjWcqstm5dlMkvEBI/qI=</X509Certificate></X509Data></KeyInfo></Signature>";

static std::string incorrectDetachedFile = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\"><SignedInfo><CanonicalizationMethod Algorithm=\"http://www.w3.org/2001/10/xml-exc-c14n#WithComments\"/><SignatureMethod Algorithm=\"http://www.w3.org/2001/04/xmldsig-more#rsa-sha256\"/><Reference URI=\"uno\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>Q1WkaxnTSNwvV8BG+O9j1FOOu5NgAPPJ7pVKJ0YN2GU=</DigestValue></Reference><Reference URI=\"dos\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>/O3+5KI/XLWDoOvqdilXEa1QTEiOfgb3IBHPeNiTRFk=</DigestValue></Reference><Reference URI=\"key\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>X8Kw8w74F8acQR7WTF9F+l8SsvwTGsZbRdo49xvPI9I=</DigestValue></Reference><Reference URI=\"UserCert2.p12\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>kbBZ8C4LYcPP0IGQwK+2dB+VbnES83R2vtaDKe7YEUk=</DigestValue></Reference>" \
        "</SignedInfo><SignatureValue>mKerOLtkcta6CSaWrw3Y0Ox7uUFGcUV3uusCLwtE1kPsjMkGMQeNlU4Z7nkCDGTVGc8gD7eo/mOehLjR01xHpAXA2v2uQzqQYTkWu1ngF1orrtof5kHH2KzDJGFNg189EYmYLl8dLD2uHOumLk+OIDTdyuFmOePhByyAh+CbYWE=</SignatureValue><KeyInfo></KeyInfo><KeyInfo><X509Data><X509SubjectName>1.2.840.113549.1.9.1=#1614757365723240736d6172746d617469632e636f6d,CN=User 2,OU=Electoral Solutions,O=Smartmatic,ST=Brussels,C=BE</X509SubjectName><X509Certificate>" \
        "MIIDQzCCAiugAwIBAgICEAMwDQYJKoZIhvcNAQELBQAwZTELMAkGA1UEBhMCQkUxETAPBgNVBAgM" \
        "CEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1hdGljMRwwGgYDVQQLDBNFbGVjdG9yYWwgU29sdXRp" \
        "b25zMRAwDgYDVQQDDAdST09UIENBMCAXDTIyMDcxNDEzMTUyN1oYDzMwMjExMTE0MTMxNTI3WjCB" \
        "iTELMAkGA1UEBhMCQkUxETAPBgNVBAgMCEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1hdGljMRww" \
        "GgYDVQQLDBNFbGVjdG9yYWwgU29sdXRpb25zMQ8wDQYDVQQDDAZVc2VyIDIxIzAhBgkqhkiG9w0B" \
        "CQEWFHVzZXIyQHNtYXJ0bWF0aWMuY29tMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQC1bX3b" \
        "oEiretroFKER/nDxBuqqJgouc9JR2eC+xhxHNBMf+RebMzj19gum14+GMYhea9Ax4V9ICEqI2Ijp" \
        "+i9m4wl19zZflndc48Glr+66JYOU5+6pg8j8dz+OsZcUV3sdFVTMrzujsXlDwFsNifOl1r3WoJOM" \
        "shc4UtvXa3SvpwIDAQABo1owWDAfBgNVHSMEGDAWgBRrNy+HTBW6OKzrcP0BUfprP4tRsTAdBgNV" \
        "HQ4EFgQUSlIKpFtNa4SlNhsYtXqd5WnUOKAwCQYDVR0TBAIwADALBgNVHQ8EBAMCBPAwDQYJKoZI" \
        "hvcNAQELBQADggEBAG2q3s9Gjf1tjojBYSceMfcU3xHkF9V6sQM/xmJdd/DqkpQiKP96T4o4rZAQ" \
        "3IWc8B5KO/xpbd46VUfJziqn05IE7GRsWRSlsyZM7Y6obpTGoHDxclcuomYAJeb8HXoH6JcpAkmg" \
        "i+cOrk7XUzKoSR3B7JBXHfAYVAXWgRm9Z4iDSYfuGVRpQigJbkED+SToUn4AN/bPVlHeWEWgap4Z" \
        "avp+0QcQ3TPe1bjv8/quiAkyRY492kj6s4OVBp7LWQfHmcFKBFmV9h7rK7/f6kD05ryzLTByh4oL" \
        "LWlD+kAAhw1VlSe/0tbz4hL2U7GnqTzqFAbjjWcqstm5dlMkvEBI/qI=</X509Certificate></X509Data></KeyInfo></Signature>";

static std::string changeDigestValueDetachedFile = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\"><SignedInfo><CanonicalizationMethod Algorithm=\"http://www.w3.org/2001/10/xml-exc-c14n#WithComments\"/><SignatureMethod Algorithm=\"http://www.w3.org/2001/04/xmldsig-more#rsa-sha256\"/><Reference URI=\"uno\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>Q2WkaxnTSNwvV8BG+O9j1FOOu5NgAPPJ7pVKJ0YN2GU=</DigestValue></Reference><Reference URI=\"dos\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>/O3+5KI/XLWDoOvqdilXEa1QTEiOfgb3IBHPeNiTRFk=</DigestValue></Reference><Reference URI=\"key\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>X8Kw8w74F8acQR7WTF9F+l8SsvwTGsZbRdo49xvPI9I=</DigestValue></Reference><Reference URI=\"UserCert2.p12\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>kbBZ8C4LYcPP0IGQwK+2dB+VbnES83R2vtaDKe7YEUk=</DigestValue></Reference>" \
        "</SignedInfo><SignatureValue>mKerOLtkcta6CSaWrw3Y0Ox7uUFGcUV3uusCLwtE1kPsjMkGMQeNlU4Z7nkCDGTVGc8gD7eo/mOehLjR01xHpAXA2v2uQzqQYTkWu1ngF1orrtof5kHH2KzDJGFNg189EYmYLl8dLD2uHOumLk+OIDTdyuFmOePhByyAh+CbYWE=</SignatureValue><KeyInfo></KeyInfo><KeyInfo><X509Data><X509SubjectName>1.2.840.113549.1.9.1=#1614757365723240736d6172746d617469632e636f6d,CN=User 2,OU=Electoral Solutions,O=Smartmatic,ST=Brussels,C=BE</X509SubjectName><X509Certificate>" \
        "MIIDQzCCAiugAwIBAgICEAMwDQYJKoZIhvcNAQELBQAwZTELMAkGA1UEBhMCQkUxETAPBgNVBAgM" \
        "CEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1hdGljMRwwGgYDVQQLDBNFbGVjdG9yYWwgU29sdXRp" \
        "b25zMRAwDgYDVQQDDAdST09UIENBMCAXDTIyMDcxNDEzMTUyN1oYDzMwMjExMTE0MTMxNTI3WjCB" \
        "iTELMAkGA1UEBhMCQkUxETAPBgNVBAgMCEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1hdGljMRww" \
        "GgYDVQQLDBNFbGVjdG9yYWwgU29sdXRpb25zMQ8wDQYDVQQDDAZVc2VyIDIxIzAhBgkqhkiG9w0B" \
        "CQEWFHVzZXIyQHNtYXJ0bWF0aWMuY29tMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQC1bX3b" \
        "oEiretroFKER/nDxBuqqJgouc9JR2eC+xhxHNBMf+RebMzj19gum14+GMYhea9Ax4V9ICEqI2Ijp" \
        "+i9m4wl19zZflndc48Glr+66JYOU5+6pg8j8dz+OsZcUV3sdFVTMrzujsXlDwFsNifOl1r3WoJOM" \
        "shc4UtvXa3SvpwIDAQABo1owWDAfBgNVHSMEGDAWgBRrNy+HTBW6OKzrcP0BUfprP4tRsTAdBgNV" \
        "HQ4EFgQUSlIKpFtNa4SlNhsYtXqd5WnUOKAwCQYDVR0TBAIwADALBgNVHQ8EBAMCBPAwDQYJKoZI" \
        "hvcNAQELBQADggEBAG2q3s9Gjf1tjojBYSceMfcU3xHkF9V6sQM/xmJdd/DqkpQiKP96T4o4rZAQ" \
        "3IWc8B5KO/xpbd46VUfJziqn05IE7GRsWRSlsyZM7Y6obpTGoHDxclcuomYAJeb8HXoH6JcpAkmg" \
        "i+cOrk7XUzKoSR3B7JBXHfAYVAXWgRm9Z4iDSYfuGVRpQigJbkED+SToUn4AN/bPVlHeWEWgap4Z" \
        "avp+0QcQ3TPe1bjv8/quiAkyRY492kj6s4OVBp7LWQfHmcFKBFmV9h7rK7/f6kD05ryzLTByh4oL" \
        "LWlD+kAAhw1VlSe/0tbz4hL2U7GnqTzqFAbjjWcqstm5dlMkvEBI/qI=</X509Certificate></X509Data></KeyInfo></Signature>";

static std::string changueSignatureValueDetachedFile = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\"><SignedInfo><CanonicalizationMethod Algorithm=\"http://www.w3.org/2001/10/xml-exc-c14n#WithComments\"/><SignatureMethod Algorithm=\"http://www.w3.org/2001/04/xmldsig-more#rsa-sha256\"/><Reference URI=\"uno\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>Q2WkaxnTSNwvV8BG+O9j1FOOu5NgAPPJ7pVKJ0YN2GU=</DigestValue></Reference><Reference URI=\"dos\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>/O3+5KI/XLWDoOvqdilXEa1QTEiOfgb3IBHPeNiTRFk=</DigestValue></Reference><Reference URI=\"key\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>X8Kw8w74F8acQR7WTF9F+l8SsvwTGsZbRdo49xvPI9I=</DigestValue></Reference><Reference URI=\"UserCert2.p12\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>kbBZ8C4LYcPP0IGQwK+2dB+VbnES83R2vtaDKe7YEUk=</DigestValue></Reference>" \
        "</SignedInfo><SignatureValue>mkerOLtkcta6CSaWrw3Y0Ox7uUFGcUV3uusCLwtE1kPsjMkGMQeNlU4Z7nkCDGTVGc8gD7eo/mOehLjR01xHpAXA2v2uQzqQYTkWu1ngF1orrtof5kHH2KzDJGFNg189EYmYLl8dLD2uHOumLk+OIDTdyuFmOePhByyAh+CbYWE=</SignatureValue><KeyInfo></KeyInfo><KeyInfo><X509Data><X509SubjectName>1.2.840.113549.1.9.1=#1614757365723240736d6172746d617469632e636f6d,CN=User 2,OU=Electoral Solutions,O=Smartmatic,ST=Brussels,C=BE</X509SubjectName><X509Certificate>" \
        "MIIDQzCCAiugAwIBAgICEAMwDQYJKoZIhvcNAQELBQAwZTELMAkGA1UEBhMCQkUxETAPBgNVBAgM" \
        "CEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1hdGljMRwwGgYDVQQLDBNFbGVjdG9yYWwgU29sdXRp" \
        "b25zMRAwDgYDVQQDDAdST09UIENBMCAXDTIyMDcxNDEzMTUyN1oYDzMwMjExMTE0MTMxNTI3WjCB" \
        "iTELMAkGA1UEBhMCQkUxETAPBgNVBAgMCEJydXNzZWxzMRMwEQYDVQQKDApTbWFydG1hdGljMRww" \
        "GgYDVQQLDBNFbGVjdG9yYWwgU29sdXRpb25zMQ8wDQYDVQQDDAZVc2VyIDIxIzAhBgkqhkiG9w0B" \
        "CQEWFHVzZXIyQHNtYXJ0bWF0aWMuY29tMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQC1bX3b" \
        "oEiretroFKER/nDxBuqqJgouc9JR2eC+xhxHNBMf+RebMzj19gum14+GMYhea9Ax4V9ICEqI2Ijp" \
        "+i9m4wl19zZflndc48Glr+66JYOU5+6pg8j8dz+OsZcUV3sdFVTMrzujsXlDwFsNifOl1r3WoJOM" \
        "shc4UtvXa3SvpwIDAQABo1owWDAfBgNVHSMEGDAWgBRrNy+HTBW6OKzrcP0BUfprP4tRsTAdBgNV" \
        "HQ4EFgQUSlIKpFtNa4SlNhsYtXqd5WnUOKAwCQYDVR0TBAIwADALBgNVHQ8EBAMCBPAwDQYJKoZI" \
        "hvcNAQELBQADggEBAG2q3s9Gjf1tjojBYSceMfcU3xHkF9V6sQM/xmJdd/DqkpQiKP96T4o4rZAQ" \
        "3IWc8B5KO/xpbd46VUfJziqn05IE7GRsWRSlsyZM7Y6obpTGoHDxclcuomYAJeb8HXoH6JcpAkmg" \
        "i+cOrk7XUzKoSR3B7JBXHfAYVAXWgRm9Z4iDSYfuGVRpQigJbkED+SToUn4AN/bPVlHeWEWgap4Z" \
        "avp+0QcQ3TPe1bjv8/quiAkyRY492kj6s4OVBp7LWQfHmcFKBFmV9h7rK7/f6kD05ryzLTByh4oL" \
        "LWlD+kAAhw1VlSe/0tbz4hL2U7GnqTzqFAbjjWcqstm5dlMkvEBI/qI=</X509Certificate></X509Data></KeyInfo></Signature>";

static std::string changueCertificateDetachedFile = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?><Signature xmlns=\"http://www.w3.org/2000/09/xmldsig#\"><SignedInfo><CanonicalizationMethod Algorithm=\"http://www.w3.org/2001/10/xml-exc-c14n#WithComments\"/><SignatureMethod Algorithm=\"http://www.w3.org/2001/04/xmldsig-more#rsa-sha256\"/><Reference URI=\"uno\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>Q2WkaxnTSNwvV8BG+O9j1FOOu5NgAPPJ7pVKJ0YN2GU=</DigestValue></Reference><Reference URI=\"dos\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>/O3+5KI/XLWDoOvqdilXEa1QTEiOfgb3IBHPeNiTRFk=</DigestValue></Reference><Reference URI=\"key\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>X8Kw8w74F8acQR7WTF9F+l8SsvwTGsZbRdo49xvPI9I=</DigestValue></Reference><Reference URI=\"UserCert2.p12\"><DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/><DigestValue>kbBZ8C4LYcPP0IGQwK+2dB+VbnES83R2vtaDKe7YEUk=</DigestValue></Reference>" \
        "</SignedInfo><SignatureValue>mkerOLtkcta6CSaWrw3Y0Ox7uUFGcUV3uusCLwtE1kPsjMkGMQeNlU4Z7nkCDGTVGc8gD7eo/mOehLjR01xHpAXA2v2uQzqQYTkWu1ngF1orrtof5kHH2KzDJGFNg189EYmYLl8dLD2uHOumLk+OIDTdyuFmOePhByyAh+CbYWE=</SignatureValue><KeyInfo></KeyInfo><KeyInfo><X509Data><X509SubjectName>1.2.840.113549.1.9.1=#1614757365723240736d6172746d617469632e636f6d,CN=User 2,OU=Electoral Solutions,O=Smartmatic,ST=Brussels,C=BE</X509SubjectName><X509Certificate>" \
        "MIIC9zCCAmCgAwIBAgICEAMwDQYJKoZIhvcNAQEEBQAweTELMAkGA1UEBhMCQkUxETAPBgNVBAgT" \
        "XEJydXNzZWxzMRIwEAYDVQQHEwlFdHRlcmJlZWsxEzARBgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNV" \
        "BAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxEDAOBgNVBAMTB1JPT1QgQ0EwIBcNMTMxMjMwMTUxMjUz" \
        "WhgPMjExMjA3MjQxNTEyNTNaMIGJMQswCQYDVQQGEwJCRTERMA8GA1UECBMIQnJ1c3NlbHMxEzAR" \
        "BgNVBAoTClNtYXJ0bWF0aWMxHDAaBgNVBAsTE0VsZWN0b3JhbCBTb2x1dGlvbnMxDzANBgNVBAMT" \
        "BlVzZXIgMjEjMCEGCSqGSIb3DQEJARYUdXNlcjJAc21hcnRtYXRpYy5jb20wgZ8wDQYJKoZIhvcN" \
        "AQEBBQADgY0AMIGJAoGBAM2ew78JzhX3GocanVAxqiv0pPcKjUPhtFpDS2uI12SNIyNQqszPXF51" \
        "euV5g8If308PVhM59Vpk+APR1vqfjrYvVuMJCBFI5IFuHFh0uhqArqL6LoKc2zs5xTbrl+ueyzZk" \
        "COLdmoolgaSzas+qbLGeO86ub5qXROTwxj6ijfmNAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZI" \
        "AYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBTSCgQsgLAe" \
        "jEx7mR5gIRy6irmcBDAfBgNVHSMEGDAWgBSkK16P6n6Mm/Bx4DBAW81buzO8pzANBgkqhkiG9w0B" \
        "AQQFAAOBgQCG6JPAyVrFc5/mTYIlY9/aIitOET7N14WoArAApwql7rwzPwgwslWSXI+SnVtiKPOS" \
        "W75H01o0a1FjmA6jnc0fnoS/miCNPwPZCUw01VJK5+UTCz4+xjiljHFMKWIshq9FCYPoYzhAhW+d" \
        "X9zsW+hUppJ8LLHIlTgXOPgP3NCFGA==</X509Certificate></X509Data></KeyInfo></Signature>";

static std::string b64fileOne = "MQo=";

static std::string b64fileTwo = "ZG9zCg==";

static std::string b64fileThree = "cGFzc3dvcmRwa2NzMTIK";

static std::string b64fileFour = "MIIKcQIBAzCCCjcGCSqGSIb3DQEHAaCCCigEggokMIIKIDCCBx8GCSqGSIb3DQEH" \
                                 "BqCCBxAwggcMAgEAMIIHBQYJKoZIhvcNAQcBMBwGCiqGSIb3DQEMAQYwDgQI1DfW" \
                                 "c2iuUWECAggAgIIG2Gtew4WNTrGALpGtMr+FcKaqpfreGmx3AmIlHXIMdb4GoPXr" \
                                 "aGg4+ocpxetpGMw5TUkvCziQpXQ/8DPZFzzf0R4rWDKTdrb9Z7o8gD9tOsQD1JRT" \
                                 "tnexdfL7aCTlOcDbaVP3u3ZpwDuTgKyLmO0ReXsOmTOBmv3v9aZQ88KxM9QcIf65" \
                                 "Y3x+6usRE42OLWOxg2Tjm5DxrxLIB/nAZCSkRcnOEBgBQHr1BShNyqqn81ESmYlj" \
                                 "/XjTlaRMtCFsAiJKVuzke9sVaISrqNN038jMFlRlH3BRabdYwrJXu6uyOfPUl9cS" \
                                 "FE/cZ5ivANwierLwMDRC/UDQkSSdIqc3YBtbUr03xxpD3bIYWDdzdBqaNGVjXto8" \
                                 "ZpTBknyb4GKqHqGLvN7y6xRS48JR/Z4VlA52vGTsJQy+gwK/ti5nhGY2ex0hmrLe" \
                                 "hC7vi3s+WUkUBII9UQpebRTaVnagS0kC8/DJCn8R0W2/07m5LXFhVrDw5GCFF6xY" \
                                 "b+59LGhVK/RnIDgOevLg4eTAAmGmthlTm1TxVtsBNblXjNbLLte93Eb83Qr3Kvzy" \
                                 "Q/2KJcEUkCEnRaYHYcN3ItZUMRcDMOPGe3BzsM4A7qDfJCNOn8mWghS4fV3Wfqjg" \
                                 "d0TYrj2wMvoooG9v2n6z4nFmbEhXVq5AQPdeb/vQWdZabzOSyDf2oUmU8IpDsnCj" \
                                 "SgOt1Uuh31CyNM2nY3mWUEkAqOYeL4QcLVeSzxkubEA6OKeMCK69fpjvW0/YdCyA" \
                                 "aliuhV9N3iiAQsFv8eje+GK9AZtf6DHoUaJtlIrsIKvrIk4SFjPKz6AkwUKBvp2c" \
                                 "V0lGxqdSmgiJ8JMfmgazQV6gi6ZqiYVl1B4dHjXZ/YornJmWgtZiVRQcDq2tRX8x" \
                                 "FEW6oYEG/Emy8IieeaBxQ88XYL1xEW0UUsRe1mtw5FaiH5WHCG1jUaVMaed7LOC1" \
                                 "ap0O7arxIqz7DFQE7e+wBxGisTpvutM0Xs8DXI6R63fBepBBidLWTeFQSTLEFW01" \
                                 "JKZ+fJUwASA5q6wgdl/bf1yrFzl1pld+JEWzkd2eCu9ubezdVn2OhY9MlwB64aCx" \
                                 "PooOp9eZmt+bYD38fIVCjDomsqLvoHm6T6bCHj4Y8I/nl67wX99q36U6c0WHGKpY" \
                                 "71o4DW77ejtiVA59K4j8QklVZpTM+FmjuyrTUHiOF8Lb37GZL8hdI/zCHoUrIG15" \
                                 "Xvr/9Bm3nkjPc6IY1i9qwHeUtXaxFDFXzAjzqcaEvIx56O6EvAuyrT6rcdnVV98P" \
                                 "BvCcxW65fxW9Yq7KsbpB/DasF1TD8ENWowW914qfblyVglYGi8sxo5M8atTxmL2k" \
                                 "lGwsL9iEJzwbXBmp12dHdjkKKwMI01HW73tQsDtVeE76gWe0WLObsxfQIDG2Bol8" \
                                 "zc+SW356ayEOQ04QZNQQ0A3mCVtNBcEKZpHdY+JxNcb+j47nxmEvbB00M/KR6QXd" \
                                 "DcGhOPQSDLvrGl9iC79hQuWBUoxVuAX2J8adKlKl5i+elBbw4Ow5oDpirdQERdZW" \
                                 "oqk6ioiJbvvf6FvdLiQnYS/tTEiO/+6dz+Lpu6Nv2bG9i6bgWHWk++PEWRlUutKl" \
                                 "sGItFpmQUYZ5/sH1bExedgLfvFIJ+UKBrOLNLgmTmIvFoxoMcRg5zacJhyOOvuZC" \
                                 "4Tv19spKku2cHEeLXNl42ZQWOwoBQvVtKcFWPxm4ZY9l+j6Z4QdlRDoePRt6CyGO" \
                                 "3C2qexsJ6y2bffFkIxiEc8/I48FSo4ilVNrS3hVIT8pwLZbCviBmTug4DsS617kb" \
                                 "UHp4vznGosCi+ZrOwR/rL+5WtRrXbCWnqwrVImAClF8fCehJ6QAxOKrOioKXT0C5" \
                                 "OKxWXmOR9eADSG+wPD88DBDxSgLkZtlsWBTkSoW3E5+ZxI2i/JuKrPohYtWEyUK5" \
                                 "5/fBOA1nuiCHQjw90tNwtynFQzOtDZtMO2F062c3iun7bCP+0f82SfGTI/y1r9Bm" \
                                 "XwoT1NKMY5cUlnlg69jy0prxYi+92/A6uSYMNV8V+gikGp+ItTzmWqIktxGz54Yt" \
                                 "nQDtg0ncqko59pjf294rFAaHAS8iug4vt2ZwoG8nbK0Jq1GJuscsuJhWG69Fh2XO" \
                                 "OWAQYfRa+IIXiC61woRytU9kKrmKAdW8xuWONtdjNKOh88wvvYLypPB7H/5ueD8c" \
                                 "6qfuJy07YDXhlf+WTv9CpsUGKTBeBPTgOj+LGig70SZopOTeyL6m6fjkFFK2DZD6" \
                                 "MKPrAu0CVDzA3+o0QPdZox1rfd0oYcIl+5oKA9nYl1rG13pullDdy93KNGZZhiky" \
                                 "dKOtrGt7WTY7o8/BRNxAzAGlI8t77A22KqSHAAXCy0rkkTwRGjCCAvkGCSqGSIb3" \
                                 "DQEHAaCCAuoEggLmMIIC4jCCAt4GCyqGSIb3DQEMCgECoIICpjCCAqIwHAYKKoZI" \
                                 "hvcNAQwBAzAOBAh/liYliUlRvwICCAAEggKAZDhx2m31ZDk0xsQGXbS7qrx7DFkM" \
                                 "xbbgK9agDLJ0zQ3StaGo05DLdqmD6y3erCgrT4FxLxwvjxr9q08bSOu5ZvANYlBC" \
                                 "p8GUcRhDmswhkGPBmLh7bbVU6mFck02pr1kntm1qFr05JYZ+DFIYS+hwoPv0DU8m" \
                                 "C7VCYV/crUHrfjBow5i8XKngd6q9UwxbrkLlDhRgmHwlAlWXg767C+Ds8TYe5wgr" \
                                 "ln5wft7R757vITytvQC0Ul3ELdAj+7jyiifsuLwG/BgJT82BU6M5NtMG9pJKafpj" \
                                 "3RSIqqfrDz9TppG4AcoisFjUj67ZES2Y1uUEhW7V1M8elbVl1zsv9GQFr90IP82o" \
                                 "rb+UVpmUoR49f25Eqw9HO48cHvqnjHwFDc+0AQiDmQNQHanp+H98hmQA0Z6qvaEE" \
                                 "fKT8ITn8daUC7yP7zLefAauTnLlOw12G6YUIHD0CKt3uR3+OwifkHd2nVRKtjBqG" \
                                 "7oXZiX5xaJ159ieiKZ+wXQGWXjyIIowHWhOnAuzMKV5uEm44KPKRWyQDNceR66mq" \
                                 "tPPLiYXHX7WIJJh/ubazZ0Lh9zp5wTAefcDHhOjAlJr4K6Blb3fBOhtlqMQNK3A+" \
                                 "IJqHJgcEvL2HN4n4CysVFrw+YG76snA2V1GttwUl95wpw1sgne5p5MR6s8XtYWf3" \
                                 "Vbx6tELh8ivEWhqy0qHV+Yq2P6WmpTX0QBSieWJ4uCeTcEWiko1jvdTAIb1W1M8N" \
                                 "oPStPiOBHFQ2r/wzo7co/30Z7e1F2ZSqMWfzXGx9cXzEu4RipIjiYTRxl0galgXM" \
                                 "T42xlJp8Ut/36k0DYFU12Uzkj3Mw1Z89d5GbpmyIDmaSitIJ4w+2gM7cFzElMCMG" \
                                 "CSqGSIb3DQEJFTEWBBQJ8cvFVKweYsoJq7FTQU2QoxBKaTAxMCEwCQYFKw4DAhoF" \
                                 "AAQULiJWJiOVenea6+yEhex0GcuehmgECHH2ajsukIsvAgIIAA==";

static const std::string correctCertificatePkcs12 = \
    "MIIFtgIBAzCCBXAGCSqGSIb3DQEHAaCCBWEEggVdMIIFWTCCAaYGCSqGSIb3DQEHAaCCAZcEggGT"
    "MIIBjzCCAYsGCyqGSIb3DQEMCgECoIIBMjCCAS4wKAYKKoZIhvcNAQwBAzAaBBT3hx/JLAHFSFRE"
    "zfS/wS55m8cR3wICBAAEggEARe7Zm4KtWkDP92UcCV9VdNRtSEHABMgxQ/0tNHO+gI+efhtpXJN1"
    "ze4AKS+D+3JWYIiRykuHWxRxrJjLNZ+JAzqCx3dSkpAuVYmBYyMw/omnBChr/WDpt1hyh840h8tv"
    "mTOXxFL0bidqHS2X8FY20Qgz8UkL/DHHRZbVPKo+hqez7Qo59KTzU0xQonAJBbXl+r8V9b+9uWP2"
    "UJ/sBpuIEyA6ifMCocQmI0Za0Z34ZAmlOpUPs/ZkcVoGaicblBuogGwNBUpsSrCT3+BHr+uK0zM4"
    "W/ly47BBar+oMUNC5SPtnOFsZQwxl2/pwZ/lVXxVLAsNJY319LxvJqW1pS3ObDFGMB8GCSqGSIb3"
    "DQEJFDESHhAAYQBuAHkAQQBsAGkAYQBzMCMGCSqGSIb3DQEJFTEWBBQ+BNOR/4EGCTH/CW80zAIH"
    "BsqI/zCCA6sGCSqGSIb3DQEHBqCCA5wwggOYAgEAMIIDkQYJKoZIhvcNAQcBMCgGCiqGSIb3DQEM"
    "AQYwGgQUP1aCnx4+t10r85ntQin81t8IoVMCAgQAgIIDWHG1zHyRK1piFiMNPGiwSZoaVBEDqIon"
    "VLqM57TW0jlqkEuCSjWGMI7fYOwkvMn3/e7ad1Grfy0D+3URksG0nyfeq2aRHm24zLolFtS1vB1J"
    "/mOEuOMeaGx3p8ctegsZRObzeiAbZ6ZEokRpbg1Qb2mtBPLm2IyjKBktZa9bP/xnBjqXfjaYO5GY"
    "s/myheXw2ej+I8Kw6ijuGqA4dE/1JIvFSTy3XoLcAeJe0fXHc9NL8xBbw3062VYrMCmnRC3Qat6f"
    "ZHDMlnY5UdOmMGHlwBDtcnJiO+NUWcrOJSWuVk0qdolCky7Oqc1aIoYbMNe+6aOOPYumAbkkL+nB"
    "xPno0rraOPYX6xu/YUJJa1Fortg0Le2oB2N4oWz/fhhzrtMiHSsHOD9il18SCdV1X0CzYhwaN/mB"
    "69hiTvBia6SL0xO3tIjMyQB4w0ypa5QoHMYKAjc/r2kQza6s77N2TU/KSZzBn31YTGL1jBOHs5Rj"
    "maj3YxXLYcdTsBx+TG4nVZPQ5G7JdylJWMy7jtgJfqFPvBJmwmbh1b4j7jPeMok5i3403+0o9T+n"
    "Z7ORtup/GADYDljxAunJLXEaOs8bQtkQElf6PT3/T3UolDeHqUGNMD3dZLKXRIlzQMYZ9RSWg3vm"
    "q2HdnM0PfflinqokYfz9cHZyWKXwJ+2AqGE2BR5C3TfnHQnYGAARmvCUhG/dJtlf8DN46p2YcpbO"
    "8h07BPUQ6cteazNGr2bKS0CwZ5Hi6bcYx0K7zOfXsjWknjry2iqc44kYih8keMOmJ2Z8aLUx42hl"
    "4IACL37Urch4jR4+CrrnFylduoz6HvOCxdLHcbVvymMToaizlL5tDU6zQVt5i2rjly29DHnYtu9K"
    "tGPfjExmXn1EG13NyVn0ZwADic9JsNlSzAnIoBF1KfCo9VMWpBWzUSgAv1DiJkedf94/uTf92q6p"
    "saGKngD97TFFsfE5gjjrTMR25AqN/0JGlOUG1/t+j8yt98G0sPaNokGXEim6sZyHRd72kLyoSFu/"
    "HAbRohT3H1MVM9ETT4+aPlNm3yXny74OQIHz9LynQqraFcSUBNkEU5dD63/HBfYhrAO6sbPjSfsV"
    "CAswbW2gXJOx9+6ZdHASds7GpYumdbbCPRlm9kVpOvF0h9wwPTAhMAkGBSsOAwIaBQAEFPqw6frp"
    "ESC3dyt0JCFx+xZJojsnBBS+d2pPC5If7Yzma8nqACdcLOXxcwICBAA=";

static const std::string correctCertificatePassPhrase = \
    "gQnN6L1GSLgN/Bzt0sWtz+ZAlB5JQPJP03aILQ9oS1Q=";

static const std::string incorrectCertificatePkcs12 = \
    "MIIFrgIBAzCCBWgGCSqGSIb3DQEHAaCCBVkEggVVMIIFUTCCAaYGCSqGSIb3DQEHAaCCAZcEggGT"
    "MIIBjzCCAYsGCyqGSIb3DQEMCgECoIIBMjCCAS4wKAYKKoZIhvcNAQwBAzAaBBTDYZDrdGLpPwZB"
    "U/yaPGDbjxOz/wICBAAEggEAiAEXb3EbX7EqKjV7IusiApUVmArBmYhWzoE9IZoUj+Rfy16bFgsw"
    "lq0R2o3HOGSPGUvr1jxi7OzNOZaqTb3S12fnNy2c00dXUIQsU502lgJG+FKpko13Ukx9xP3+lAvS"
    "MmbTToRD456MDi0Xbp1wKmc22Z1hTNrvHt+sQYRbxsvLLorHwFLm3RvzNl4cx7qGNiwAG3Y/2pIR"
    "d0Za4MlypIJx2t+BGnD/ob3gYcXDfshh/Z1buFVIpfcFfrgdJzfuOlRYfx7RaV+IFyXpgaD2q2CD"
    "Xu6DrqK46T+E864UL/iVB67wiSPuQlKGtcPXl1SiXRmDE0rFO5akz0ySjijFBTFGMB8GCSqGSIb3"
    "DQEJFDESHhAAYQBuAHkAQQBsAGkAYQBzMCMGCSqGSIb3DQEJFTEWBBRwUDPGv27JJnQYn2L4TxgN"
    "qiMi+TCCA6MGCSqGSIb3DQEHBqCCA5QwggOQAgEAMIIDiQYJKoZIhvcNAQcBMCgGCiqGSIb3DQEM"
    "AQYwGgQUDiLtqbGA1oNcTrp+eU4QIlGvnaICAgQAgIIDUEtSuOktTUBb1HhSE6oz7x4D1owxmXjl"
    "J/cx7VKn3SYxmn6nb5vFaudsONWfW/nr5847dgWleHcHHB0BZM8pHKmsHIM8igG4Gsh3o0L2PVGP"
    "Jba8kWVkIr3t+Ls+dxqX8zK1P+xKcfe26B2RQPI3t/7BPXv3aNj9+HLmkRMIqW+biWMX8tXzYyOV"
    "NqDXTjy6+WjH40Bfg877uKgxC2qoWPHyLfUR/9hW3At47JJ01h8e9td/o4FjFQ9myHNORzfKCquY"
    "ZFqA8KZCIpmnt+aqq0igUf1ijLl0hF0MVCut2p2e3ybZ54QW+bCg9os18gewYV34YPoVjxjpkQ+7"
    "JWNtjCZ/M4lzk044VJcndRVgk0EtJ7WESUAyfaVLzj5ZYAIDoyLHjs3rXuP96kJZa8GJLDA3y1uC"
    "i/BRNVMIPz7CvV2hifNDpM52EAG+qShQ37If8Fj0H0MZb1hKZQCP6PBNVT+h4tcfhELNz21zsAxj"
    "4Howij0H8AVQK8RLpDBWhw3h74LlgzKPNYfDsaZr2hyQuyWSD6DMFOzK6psiO77VUm3k+cj/1Uau"
    "f8zjH8BgyB3rVxcpi5oioPfps6hd5TK1SknGsTKmamvJDi1C9r8YJLgYSce3JzQX7qJ368qr956M"
    "DW817RwD2jq7jBPk0CDAfeopD9OA6bHNVwc4xpUEyQZ9y4NhDAQNdVDel6RvOdBSq04YPsApR20U"
    "UivLpR8i9rODp4J/4e5q0eJcg0mgzlTORJv9lHXcy7jDt38CW7F6VqO43dD7Z6xj/8mwAkYfiMob"
    "6AsSOz8vivXXd+UstYCZ6MDXOrmIuLF9/fRQxZ07yWI6yXWEle9MawNv2NEwX1ZcshClSKvpxeOS"
    "jc5T2mBr+5+WFiGonLyF6MBlxGXuH0Q5Kyo3kGxgz4QRVVqgmY00KwmkYDYkuHf/IZU3OrYeeEfe"
    "U7ppyy/cIEjuPNRiE9eSjGqJy/Do2ruhCsSe8IypROBUCz9IQfChxOL6MliqGzjHX5EiTO62c2ph"
    "mceEume1Nln9H/7Tuzp/f9xk2M/BC2DlxsX38EMftFsyLL7j7y6BQ/71IvamfskZ/bBWExBpvlfp"
    "RBLNzdu+dtMmCf++MD11edqo9SmjWoC0TXz0MD0wITAJBgUrDgMCGgUABBSajUJc3MUt7nesr/FM"
    "uds74rvfnAQUrNUEO5Qqv4C5B2l6K4dqP6yyLv4CAgQA";

static const std::string incorrectCertificatePassPhrase = \
    "9qxmq+q2UjhSYiAzgN/GgjLbCIG7FbEqsWyR5SGXOYw=";

static const std::string filePath = "filePath";

using namespace Smartmatic::System::Security::Cryptography;

class XmlDetachedSignatureAlgorithmTest : public CPPUNIT_NS::TestFixture
{
    private:

        XmlDetachedSignature detachedSignature;

    public:

        XmlDetachedSignatureAlgorithmTest()
        {
        }

        void setUp()
        {
            Smartmatic::System::Security::OpenSSLSecurity::init();
            Smartmatic::System::Security::XmlSecurityC::init();
        }

        void tearDown()
        {
            Smartmatic::System::Security::OpenSSLSecurity::clear();
            Smartmatic::System::Security::XmlSecurityC::clear();
        }

        void testVerifyBuffer ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            const bool result = detachedSignature.verify(buffer);

            CPPUNIT_ASSERT ( true == result );
        }

        void testVerifyBufferWithIncorrectInputFile ()
        {
            SafeBuffer buffer ( incorrectDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            const bool result = detachedSignature.verify(buffer);

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferWithEmptyInputFile ()
        {
            SafeBuffer buffer;

            const bool result = detachedSignature.verify(buffer);

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferChangeDigestValue ()
        {
            SafeBuffer buffer ( changeDigestValueDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            const bool result = detachedSignature.verify(buffer);

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferChangeSignatureValue ()
        {
            SafeBuffer buffer ( changueSignatureValueDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            const bool result = detachedSignature.verify(buffer);

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferChangeCertificateValue ()
        {
            SafeBuffer buffer ( changueCertificateDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            const bool result = detachedSignature.verify(buffer);

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferFirstEmpty ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer(), true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            const bool result = detachedSignature.verify(buffer);

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferLastEmpty ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( SafeBuffer (), true ) );

            const bool result = detachedSignature.verify(buffer);

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferFirstChangue ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            fileOne.push_back ( 0x00 );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            const bool result = detachedSignature.verify(buffer);

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferLastChangue ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            fileFour.push_back ( 0x00 );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, true ) );

            const bool result = detachedSignature.verify(buffer);

            CPPUNIT_ASSERT ( false == result );
        }

        void testVerifyBufferMissingFile ()
        {
            SafeBuffer buffer ( correctDetachedFile );

            StoreMockFile file;
            File::getInstance ( &file );

            SafeBuffer fileOne;
            SafeBuffer fileTwo;
            SafeBuffer fileThree;
            SafeBuffer fileFour;

            Base64Encoder::ConvertFromBase64 ( b64fileOne, fileOne );
            Base64Encoder::ConvertFromBase64 ( b64fileTwo, fileTwo );
            Base64Encoder::ConvertFromBase64 ( b64fileThree, fileThree );
            Base64Encoder::ConvertFromBase64 ( b64fileFour, fileFour );

            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileOne, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileTwo, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileThree, true ) );
            file.openFileValues.push_back ( StoreMockFile::OpenFileValues ( fileFour, false ) );

            const bool result = detachedSignature.verify(buffer);

            CPPUNIT_ASSERT ( false == result );
        }

        void testSignAndVerifyBufferWithCorrectCertificate()
        {
            StoreMockFile file;
            SafeBuffer    p12;
            SafeBuffer    bufferIn;
            SafeBuffer    bufferOut;

            Base64Encoder::ConvertFromBase64(correctCertificatePkcs12, p12);
            Base64Encoder::ConvertFromBase64(b64fileFour, bufferIn);

            File::getInstance(&file);

            file.openFileValues.push_back(StoreMockFile::OpenFileValues(p12, true));
            file.openFileValues.push_back(StoreMockFile::OpenFileValues(bufferIn, true));

            CertificateExtensionBase *cert =
                CertUtil::getCertificateExtensionBase(filePath, Cryptography::CertUtil::CertFormat_PKCS12, correctCertificatePassPhrase);

            bool validate = detachedSignature.sign(bufferIn, bufferOut, Signed::FULL_SIGNED, cert, HASH_SHA256, filePath);

            CPPUNIT_ASSERT(true == validate);

            file.openFileValues.push_back(StoreMockFile::OpenFileValues(bufferIn, true));

            validate = detachedSignature.verify(bufferOut, cert->LoadCertifiedX509());

            CPPUNIT_ASSERT(true == validate);
        }

        void testSignAndVerifyBufferWithIncorrectCertificate()
        {
            StoreMockFile file;
            SafeBuffer    correctP12;
            SafeBuffer    incorrectP12;
            SafeBuffer    bufferIn;
            SafeBuffer    bufferOut;

            File::getInstance(&file);

            Base64Encoder::ConvertFromBase64(correctCertificatePkcs12, correctP12);
            Base64Encoder::ConvertFromBase64(b64fileFour, bufferIn);

            file.openFileValues.push_back(StoreMockFile::OpenFileValues(correctP12, true));
            file.openFileValues.push_back(StoreMockFile::OpenFileValues(bufferIn, true));

            CertificateExtensionBase *cert =
                CertUtil::getCertificateExtensionBase(filePath, Cryptography::CertUtil::CertFormat_PKCS12, correctCertificatePassPhrase);

            bool validate = detachedSignature.sign(bufferIn, bufferOut, Signed::FULL_SIGNED, cert, HASH_SHA256, filePath);

            CPPUNIT_ASSERT(true == validate);

            Base64Encoder::ConvertFromBase64(incorrectCertificatePkcs12, incorrectP12);

            file.openFileValues.push_back(StoreMockFile::OpenFileValues(incorrectP12, true));
            file.openFileValues.push_back(StoreMockFile::OpenFileValues(bufferIn, true));

            cert = CertUtil::getCertificateExtensionBase(filePath, Cryptography::CertUtil::CertFormat_PKCS12, incorrectCertificatePassPhrase);

            validate = detachedSignature.verify(bufferOut, cert->LoadCertifiedX509());

            CPPUNIT_ASSERT(false == validate);
        }

        CPPUNIT_TEST_SUITE ( XmlDetachedSignatureAlgorithmTest );
        CPPUNIT_TEST ( testVerifyBuffer );
        CPPUNIT_TEST ( testVerifyBufferWithIncorrectInputFile );
        CPPUNIT_TEST ( testVerifyBufferWithEmptyInputFile );
        CPPUNIT_TEST ( testVerifyBufferChangeDigestValue );
        CPPUNIT_TEST ( testVerifyBufferChangeSignatureValue );
        CPPUNIT_TEST ( testVerifyBufferChangeCertificateValue );
        CPPUNIT_TEST ( testVerifyBufferFirstEmpty );
        CPPUNIT_TEST ( testVerifyBufferLastEmpty );
        CPPUNIT_TEST ( testVerifyBufferFirstChangue );
        CPPUNIT_TEST ( testVerifyBufferLastChangue );
        CPPUNIT_TEST ( testVerifyBufferMissingFile );
        CPPUNIT_TEST ( testSignAndVerifyBufferWithCorrectCertificate );
        CPPUNIT_TEST ( testSignAndVerifyBufferWithIncorrectCertificate );
        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_DETACHED_TEST */
