#ifndef TEST_UUID_TEST
#define TEST_UUID_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/guid-class.h>

class UUIDTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::System::GuidClass GuidClass;
        typedef Smartmatic::System::Exception::GuIdException GuIdException;

        UUIDTest()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testCreateBasicUUId()
        {
            GuidClass obj;
            std::string result;

            obj = GuidClass::NewGuid ();
            result = obj.ToString();

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( 36 == result.size() );
        }

        void testCreateStrongestUUId( )
        {
            GuidClass obj;
            std::string result;

            obj = GuidClass::NewGuid ( true );
            result = obj.ToString();

            CPPUNIT_ASSERT ( false == result.empty() );
            CPPUNIT_ASSERT ( 36 == result.size() );
        }

        void testCreateTwoUUId()
        {
            GuidClass obj1;
            GuidClass obj2;
            std::string result1;
            std::string result2;

            obj1 = GuidClass::NewGuid ();
            obj2 = GuidClass::NewGuid ();

            result1 = obj1.ToString();
            result2 = obj2.ToString();

            CPPUNIT_ASSERT ( false == result1.empty() );
            CPPUNIT_ASSERT ( false == result2.empty() );
            CPPUNIT_ASSERT ( false == ( result1.compare ( result2 ) == 0 ) );
            CPPUNIT_ASSERT ( true == ( obj1 != obj2 ) );
        }

        void testParseEmptyUUId( )
        {
            std::string uuid;

            CPPUNIT_ASSERT_THROW ( GuidClass::Parse ( uuid ), GuIdException );
        }

        void testParseNotUUId( )
        {
            std::string uuid = "550e8400-e29b-41d4-a716-44665544000";

            CPPUNIT_ASSERT_THROW ( GuidClass::Parse ( uuid ), GuIdException );
        }

        void testParseKnowUUId( )
        {
            GuidClass newObj;
            std::string uuid = "550e8400-e29b-41d4-a716-446655440000";

            newObj = GuidClass::Parse ( uuid );

            CPPUNIT_ASSERT ( true == ( uuid.compare ( newObj.ToString() ) == 0 ) );
        }

        void testCreateTwoSameUUId()
        {
            GuidClass obj1;
            GuidClass obj2;
            std::string uuid = "550e8400-e29b-41d4-a716-446655440000";
            std::string result1;
            std::string result2;

            obj1 = GuidClass::Parse ( uuid );
            obj2 = GuidClass::Parse ( uuid );

            result1 = obj1.ToString();
            result2 = obj2.ToString();

            CPPUNIT_ASSERT ( false == result1.empty() );
            CPPUNIT_ASSERT ( false == result2.empty() );
            CPPUNIT_ASSERT ( true == ( result1.compare ( result2 ) == 0 ) );
            CPPUNIT_ASSERT ( true == ( obj1 == obj2 ) );
        }

        void testCreateTwoSameUUIdByConstructor()
        {
            GuidClass obj1;
            GuidClass obj2;
            std::string uuid = "550e8400-e29b-41d4-a716-446655440000";
            std::string result1;
            std::string result2;

            obj1 = GuidClass::Parse ( uuid );
            obj2 = GuidClass ( obj1 );

            result1 = obj1.ToString();
            result2 = obj2.ToString();

            CPPUNIT_ASSERT ( false == result1.empty() );
            CPPUNIT_ASSERT ( false == result2.empty() );
            CPPUNIT_ASSERT ( true == ( result1.compare ( result2 ) == 0 ) );
            CPPUNIT_ASSERT ( true == ( obj1 == obj2 ) );
        }

        void testParseKnowUUIdToSafeBuffer( )
        {
            GuidClass newObj;
            std::string uuid = "550e8400-e29b-41d4-a716-446655440000";

            newObj = GuidClass::Parse ( uuid );

            CPPUNIT_ASSERT ( 16 == newObj.toSafeBuffer().GetSize() );
        }

        void testParseKnowUUIdToBase64( )
        {
            GuidClass newObj;
            std::string uuid = "550e8400-e29b-41d4-a716-446655440000";
            std::string expected = "VQ6EAOKbQdSnFkRmVUQAAA==";

            newObj = GuidClass::Parse ( uuid );

            CPPUNIT_ASSERT ( true == ( newObj.ToBase64String().compare ( expected ) == 0 ) );
        }

        void testParseBasicUUId( )
        {
            GuidClass obj;
            GuidClass newObj;

            obj = GuidClass::NewGuid ();
            std::string uuid = obj.ToString();

            newObj = GuidClass::Parse ( uuid );

            CPPUNIT_ASSERT ( true == ( uuid.compare ( newObj.ToString() ) == 0 ) );
        }

        void testParseStrongestUUId( )
        {
            GuidClass obj;
            GuidClass newObj;

            obj = GuidClass::NewGuid ( true );
            std::string uuid = obj.ToString();

            newObj = GuidClass::Parse ( uuid );

            CPPUNIT_ASSERT ( true == ( uuid.compare ( newObj.ToString() ) == 0 ) );
        }

        CPPUNIT_TEST_SUITE ( UUIDTest );

        CPPUNIT_TEST ( testCreateBasicUUId );
        CPPUNIT_TEST ( testCreateStrongestUUId );
        CPPUNIT_TEST ( testCreateTwoUUId );
        CPPUNIT_TEST ( testParseEmptyUUId );
        CPPUNIT_TEST ( testParseNotUUId );
        CPPUNIT_TEST ( testParseKnowUUId );
        CPPUNIT_TEST ( testCreateTwoSameUUId );
        CPPUNIT_TEST ( testCreateTwoSameUUIdByConstructor );
        CPPUNIT_TEST ( testParseKnowUUIdToSafeBuffer );
        CPPUNIT_TEST ( testParseKnowUUIdToBase64 );
        CPPUNIT_TEST ( testParseBasicUUId );
        CPPUNIT_TEST ( testParseStrongestUUId );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_UUID_TEST */
