#ifndef TEST_ZENITY_WRAPPER_TEST
#define TEST_ZENITY_WRAPPER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <System/ZenityWrapper.hxx>
#include <System/Runtime/ProcessLauncher.h>
#include "MockProcessLauncher.hxx"
#include "StoreMockProcessLauncher.hxx"

class ZenityWrapperTest : public CPPUNIT_NS::TestFixture
{
    private:

        typedef Smartmatic::System::Runtime::ProcessLauncher ProcessLauncher;
        typedef Smartmatic::System::ZenityWrapper ZenityWrapper;

    public:

        ZenityWrapperTest ()
        {

        }

        void setUp()
        {

        }

        void tearDown()
        {

        }

        void testZenityShowError()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            ZenityWrapper::showError ( "message", "title" );

            RunProcessThroughSystem_mock.verify();
        }

        void testZenityShowWarning()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            ZenityWrapper::showWarning ( "message", "title" );

            RunProcessThroughSystem_mock.verify();
        }

        void testZenityShowInfo()
        {
            MockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );

            MOCKPP_CHAINER_FOR_EXT ( MockProcessLauncher, RunProcessThroughSystem, ext ) RunProcessThroughSystem_mock ( &launcher );

            RunProcessThroughSystem_mock
            .expects ( MOCKPP_NS::once() )
            .will ( MOCKPP_NS::returnValue<int> ( 0 ) );

            ZenityWrapper::showInfo ( "message", "title" );

            RunProcessThroughSystem_mock.verify();
        }

        void testZenityShowErrorStoreParameters()
        {
            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );
            std::string expected = "zenity --error --text=\"message\" --title=\"title\" --no-wrap";

            ZenityWrapper::showError ( "message", "title" );

            CPPUNIT_ASSERT ( 0 == expected.compare ( launcher.RunProcessThroughSystemCommandLine ) );
            CPPUNIT_ASSERT ( true == launcher.RunProcessThroughSystemBackground );
        }

        void testZenityShowWarningStoreParametersDefaultTimeout()
        {
            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );
            std::string expected = "zenity --warning --text=\"message\" --title=\"title\" --timeout 0";

            ZenityWrapper::showWarning ( "message", "title" );

            CPPUNIT_ASSERT ( 0 == expected.compare ( launcher.RunProcessThroughSystemCommandLine ) );
            CPPUNIT_ASSERT ( true == launcher.RunProcessThroughSystemBackground );
        }

        void testZenityShowInfoStoreParametersDefaultTimeout()
        {
            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );
            std::string expected = "zenity --info --text=\"message\" --title=\"title\" --timeout 0";

            ZenityWrapper::showInfo ( "message", "title" );

            CPPUNIT_ASSERT ( 0 == expected.compare ( launcher.RunProcessThroughSystemCommandLine ) );
            CPPUNIT_ASSERT ( true == launcher.RunProcessThroughSystemBackground );
        }

        void testZenityShowWarningStoreParameters()
        {
            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );
            std::string expected = "zenity --warning --text=\"message\" --title=\"title\" --timeout 10";

            ZenityWrapper::showWarning ( "message", "title", 10 );

            CPPUNIT_ASSERT ( 0 == expected.compare ( launcher.RunProcessThroughSystemCommandLine ) );
            CPPUNIT_ASSERT ( true == launcher.RunProcessThroughSystemBackground );
        }

        void testZenityShowInfoStoreParameters()
        {
            StoreMockProcessLauncher launcher;
            ProcessLauncher::getInstance ( &launcher );
            std::string expected = "zenity --info --text=\"message\" --title=\"title\" --timeout 15";

            ZenityWrapper::showInfo ( "message", "title", 15 );

            CPPUNIT_ASSERT ( 0 == expected.compare ( launcher.RunProcessThroughSystemCommandLine ) );
            CPPUNIT_ASSERT ( true == launcher.RunProcessThroughSystemBackground );
        }

        CPPUNIT_TEST_SUITE ( ZenityWrapperTest );

        CPPUNIT_TEST ( testZenityShowError );
        CPPUNIT_TEST ( testZenityShowWarning );
        CPPUNIT_TEST ( testZenityShowInfo );

        CPPUNIT_TEST ( testZenityShowErrorStoreParameters );
        CPPUNIT_TEST ( testZenityShowWarningStoreParametersDefaultTimeout );
        CPPUNIT_TEST ( testZenityShowInfoStoreParametersDefaultTimeout );
        CPPUNIT_TEST ( testZenityShowWarningStoreParameters );
        CPPUNIT_TEST ( testZenityShowInfoStoreParameters );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_ZENITY_WRAPPER_TEST */
