/**
 * @file	BasicWindowConfManager.hxx
 * @brief	Declares the smartmatic GUI basic window configurations class.
 * @author	Yadickson Soto
 * @date	27/02/2014
 */

#ifndef _BASIC_WINDOW_CONFIGURATION_MANAGER_H_
#define _BASIC_WINDOW_CONFIGURATION_MANAGER_H_

#include <string>
#include <Configuration/SmartmaticGUIConfiguration-schema.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Configuration
        {
            /**
             * @class	BasicWindowConfManager
             * @brief	Manager for smartmatic GUI basic window configurations class.
             * @author	Yadickson Soto
             * @date	27/02/2014
             */
            class BasicWindowConfManager
            {
                public:

                    /**
                     * @fn	static BasicWindowConfManager * getInstance ( BasicWindowConfManager * externManager = NULL );
                     * @brief	Gets the current Smartmatic Sound Configuration Manager.
                     * @author	Yadickson Soto
                     * @date	27/02/2014
                     * @param 	externManager external manager to unit test
                     * @return	instance of the class
                     */
                    static BasicWindowConfManager * getInstance ( BasicWindowConfManager * externManager = NULL );
                    /**
                     * @fn	std::string getWindowTitle ();
                     * @brief	Gets the window title.
                     * @author	Yadickson Soto
                     * @date	27/02/2014
                     * @return	The window title.
                     */
                    std::string getWindowTitle ();
                    /**
                     * @fn	std::string getWinwdoTitle ();
                     * @brief	Gets if show border window.
                     * @author	Yadickson Soto
                     * @date	27/02/2014
                     * @return	true if show border window is enabled.
                     */
                    bool isShowBorderWindow ();
                    /**
                     * @fn	virtual ~BasicWindowConfManager();
                     * @brief	Class destructorer
                     * @author	Yadickson Soto
                     * @date	27/02/2014
                     */
                    virtual ~BasicWindowConfManager();

                protected:

                    /**
                     * @fn	virtual Smartmatic::GUI::Configuration::BasicWindowConfigurations & getBasicWindowConfigurations();
                     * @brief	Gets basic window configurations
                     * @author	Yadickson Soto
                     * @date	27/02/2014
                     * @return	basic window configuration.
                     */
                    virtual Smartmatic::GUI::Configuration::BasicWindowConfigurations & getBasicWindowConfigurations();

                    /**
                     * @fn	BasicWindowConfManager();
                     * @brief	Default constructor.
                     * @author	Yadickson Soto
                     * @date	27/02/2014
                     */
                    BasicWindowConfManager();

                    static BasicWindowConfManager * instance; ///< The singleton instance
            };
        }
    }
}

#endif // _BASIC_WINDOW_CONFIGURATION_MANAGER_H_
