/**
 * @file SmartmaticBasicHBox.hxx
 * @brief Header basic hbox widget class
 * @date 25/04/2013
 * @author Yadickson Soto
 */

#ifndef _SMARTMATIC_BASICHBOX_H_
#define _SMARTMATIC_BASICHBOX_H_

#include <gtkmm.h>
#include <Operation/AccessibleNameWidget.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class	SmartmaticBasicHBox
             * @brief	Smartmatic basic hbox.
             * @date 25/04/2013
             * @author Yadickson Soto
             */
            class SmartmaticBasicHBox: public Gtk::HBox, public Smartmatic::GUI::Operation::AccessibleNameWidget
            {

                public:

                    /**
                     * @fn	SmartmaticBasicHBox( bool homogeneous = false, int spacing = 0 );
                     * @brief	Default constructor.
                     * @date 25/04/2013
                     * @author Yadickson Soto
                     * @param homogeneous Whether each widget in the VBox should have the same
                     * height.  If set, a PACK_SHRINK argument to pack_start() or pack_end() is ignored.
                     * @param spacing Determines the space in pixels between child widgets.
                     */
                    SmartmaticBasicHBox ( bool homogeneous = false, int spacing = 0 );

                    /**
                     * @fn	SmartmaticBasicHBox(BaseObjectType* cobject,
                     * 			const Glib::RefPtr<Gtk::Builder>& refBuilder=Gtk::Builder::create());
                     * @brief	Constructor.
                     * @date 25/04/2013
                     * @author Yadickson Soto
                     * @param	cobject			If non-null, the cobject.
                     * @param	refBuilder	(optional) the reference builder.
                     */
                    SmartmaticBasicHBox ( BaseObjectType * cobject, const Glib::RefPtr<Gtk::Builder> & refBuilder = Gtk::Builder::create() );

                    /**
                     * @fn	virtual ~SmartmaticBasicHBox();
                     * @brief	Class destructor.
                     * @date 25/04/2013
                     * @author Yadickson Soto
                     */
                    virtual ~SmartmaticBasicHBox();
            };
        }
    }
}

#endif // _SMARTMATIC_BASICHBOX_H_
