/**
 * @file SmartmaticBasicLabel.hxx
 * @brief Header basic label widget class
 * @date 24/04/2013
 * @author Yadickson Soto
 */

#ifndef _SMARTMATIC_BASICLABEL_H_
#define _SMARTMATIC_BASICLABEL_H_

#include <gtkmm.h>
#include <Operation/AccessibleNameWidget.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class	SmartmaticBasicLabel
             * @brief	Smartmatic label.
             * @date 24/04/2013
             * @author Yadickson Soto
             */
            class SmartmaticBasicLabel: public Gtk::Label, public Smartmatic::GUI::Operation::AccessibleNameWidget
            {

                public:

                    /**
                     * @fn	SmartmaticBasicLabel();
                     * @brief	Default constructor.
                     * @date 24/04/2013
                     * @author Yadickson Soto
                     */
                    SmartmaticBasicLabel();

                    /**
                     * @fn	SmartmaticBasicLabel(const Glib::ustring& label, bool mnemonic=false);
                     * @brief	Constructor.
                     * @date 24/04/2013
                     * @author Yadickson Soto
                     * @param	label			The label.
                     * @param	mnemonic	true to mnemonic.
                     */
                    SmartmaticBasicLabel ( const Glib::ustring & label, bool mnemonic = false );

                    /**
                     * @fn	SmartmaticBasicLabel(const Glib::ustring& label, float xalign, float yalign,
                     * 			bool mnemonic=false);
                     * @brief	Constructor.
                     * @date 24/04/2013
                     * @author Yadickson Soto
                     * @param	label			The label.
                     * @param	xalign		The xalign.
                     * @param	yalign		The yalign.
                     * @param	mnemonic	true to mnemonic.
                     */
                    SmartmaticBasicLabel ( const Glib::ustring & label, float xalign, float yalign, bool mnemonic = false );

                    /**
                     * @fn	SmartmaticBasicLabel(const Glib::ustring& label, Gtk::AlignmentEnum xalign,
                     * 			Gtk::AlignmentEnum yalign=Gtk::ALIGN_CENTER, bool mnemonic=false);
                     * @brief	Constructor.
                     * @date 24/04/2013
                     * @author Yadickson Soto
                     * @param	label			The label.
                     * @param	xalign		The xalign.
                     * @param	yalign		The yalign.
                     * @param	mnemonic	true to mnemonic.
                     */
                    SmartmaticBasicLabel ( const Glib::ustring & label, Gtk::AlignmentEnum xalign, Gtk::AlignmentEnum yalign = Gtk::ALIGN_CENTER, bool mnemonic = false );

                    /**
                     * @fn	SmartmaticBasicLabel(BaseObjectType* cobject,
                     * 			const Glib::RefPtr<Gtk::Builder>& refBuilder=Gtk::Builder::create());
                     * @brief	Constructor.
                     * @date 24/04/2013
                     * @author Yadickson Soto
                     * @param	cobject			If non-null, the cobject.
                     * @param	refBuilder	(optional) the reference builder.
                     */
                    SmartmaticBasicLabel ( BaseObjectType * cobject, const Glib::RefPtr<Gtk::Builder> & refBuilder = Gtk::Builder::create() );

                    /**
                     * @fn	virtual ~SmartmaticBasicLabel();
                     * @brief	Class destructor.
                     * @date 24/04/2013
                     * @author Yadickson Soto
                     */
                    virtual ~SmartmaticBasicLabel();
            };
        }
    }
}

#endif // _SMARTMATIC_BASICLABEL_H_
