/**
 * @file SmartmaticBasicRadioButton.hxx
 * @brief Header basic radio button widget class
 * @date 10/10/2013
 * @author Yadickson Soto
 */

#ifndef _SMARTMATIC_BASICRADIOBUTTON_H_
#define _SMARTMATIC_BASICRADIOBUTTON_H_

#include <gtkmm.h>
#include <Operation/AccessibleNameWidget.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class	SmartmaticBasicRadioButton
             * @brief	Smartmatic button.
             * @author	Yadickson Soto
             * @date	10/10/2013
             */
            class SmartmaticBasicRadioButton : public Gtk::RadioButton, public Smartmatic::GUI::Operation::AccessibleNameWidget
            {
                public:
                    /**
                     * @fn	SmartmaticBasicRadioButton::SmartmaticBasicRadioButton( const Glib::ustring& label, bool mnemonic = false );
                     * @brief	constructors.
                     * @author	Yadickson Soto
                     * @date	10/10/2013
                     * @param	label visual label
                     * @param	mnemonic optional parameter
                     */
                    SmartmaticBasicRadioButton ( const Glib::ustring & label, bool mnemonic = false );

                    /**
                     * @fn	SmartmaticBasicRadioButton(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& refBuilder=Gtk::Builder::create());
                     * @brief	Constructor.
                     * @date 10/10/2013
                     * @author Yadickson Soto
                     * @param	cobject			If non-null, the cobject.
                     * @param	refBuilder	(optional) the reference builder.
                     */
                    SmartmaticBasicRadioButton ( BaseObjectType * cobject, const Glib::RefPtr<Gtk::Builder> & refBuilder = Gtk::Builder::create() );

                    /**
                     * @fn	virtual ~SmartmaticBasicRadioButton();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	10/10/2013
                     */
                    virtual ~SmartmaticBasicRadioButton();

                protected:

                    /**
                     * @fn	virtual std::string getThemeConfiguration();
                     * @brief	Getter name gtk theme configuration.
                     * @author	Yadickson Soto
                     * @date	10/10/2013
                     * @return	gtk name theme configuration
                     */
                    virtual std::string getThemeConfiguration();
            };
        }
    }
}

#endif // _SMARTMATIC_BASICRADIOBUTTON_H_
