/**
 * @file SmartmaticBasicSpinButton.hxx
 * @brief Header basic spin button widget class
 * @date 02/09/2013
 * @author Yadickson Soto
 */

#ifndef _SMARTMATIC_BASICSPINBUTTON_H_
#define _SMARTMATIC_BASICSPINBUTTON_H_

#include <gtkmm.h>
#include <Operation/AccessibleNameWidget.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class	SmartmaticBasicSpinButton
             * @brief	Smartmatic spin button widget class.
             * @author	Yadickson Soto
             * @date	02/09/2013
             */
            class SmartmaticBasicSpinButton : public Gtk::SpinButton, public Smartmatic::GUI::Operation::AccessibleNameWidget
            {
                public:
                    /**
                     * @fn	SmartmaticBasicSpinButton::SmartmaticBasicSpinButton();
                     * @brief	constructors.
                     * @author	Yadickson Soto
                     * @date	02/09/2013
                     */
                    SmartmaticBasicSpinButton();

                    /**
                     * @fn	SmartmaticBasicSpinButton(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& refBuilder=Gtk::Builder::create());
                     * @brief	Constructor.
                     * @date 02/09/2013
                     * @author Yadickson Soto
                     * @param	cobject			If non-null, the cobject.
                     * @param	refBuilder	(optional) the reference builder.
                     */
                    SmartmaticBasicSpinButton ( BaseObjectType * cobject, const Glib::RefPtr<Gtk::Builder> & refBuilder = Gtk::Builder::create() );

                    /**
                     * @fn	virtual ~SmartmaticBasicSpinButton();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	02/09/2013
                     */
                    virtual ~SmartmaticBasicSpinButton();

                protected:

                    /**
                     * @fn	virtual std::string getThemeConfiguration();
                     * @brief	Getter name gtk theme configuration.
                     * @author	Yadickson Soto
                     * @date	10/10/2013
                     * @return	gtk name theme configuration
                     */
                    virtual std::string getThemeConfiguration();
            };
        }
    }
}

#endif // _SMARTMATIC_BASICSPINBUTTON_H_
