/**
 * @file SmartmaticSpinButton.hxx
 * @brief Header smartmatic spin button widget class
 * @date 02/09/2013
 * @author Yadickson Soto
 */

#ifndef _SMARTMATIC_SPINBUTTON_H_
#define _SMARTMATIC_SPINBUTTON_H_

#include <Widgets/SmartmaticBasicSpinButton.hxx>
#include <Widgets/ISmartmaticText.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class	SmartmaticSpinButton
             * @brief	Smartmatic button.
             * @author	Yadickson Soto
             * @date	02/09/2013
             */
            class SmartmaticSpinButton : public Smartmatic::GUI::Widgets::SmartmaticBasicSpinButton,
                public ISmartmaticText
            {
                public:
                    /**
                     * @fn	SmartmaticSpinButton::SmartmaticSpinButton();
                     * @brief	constructors.
                     * @author	Yadickson Soto
                     * @date	02/09/2013
                     */
                    SmartmaticSpinButton();

                    /**
                     * @fn	SmartmaticSpinButton(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& refBuilder=Gtk::Builder::create());
                     * @brief	Constructor.
                     * @date 02/09/2013
                     * @author Yadickson Soto
                     * @param	cobject			If non-null, the cobject.
                     * @param	refBuilder	(optional) the reference builder.
                     */
                    SmartmaticSpinButton ( BaseObjectType * cobject, const Glib::RefPtr<Gtk::Builder> & refBuilder = Gtk::Builder::create() );

                    /**
                     * @fn	virtual ~SmartmaticSpinButton();
                     * @brief	Class destructor.
                     * @author	Yadickson Soto
                     * @date	02/09/2013
                     */
                    virtual ~SmartmaticSpinButton();
                    /**
                     * @fn	virtual void setText(std::string text);
                     * @brief	Method setter text.
                     * @author	Yadickson Soto
                     * @date	02/09/2013
                     * @param	text	text.
                     */
                    virtual void setText ( std::string text );
                    /**
                     * @fn	virtual std::string getText();
                     * @brief	Method getter text.
                     * @author	Yadickson Soto
                     * @date	02/09/2013
                     * @return	text.
                     */
                    virtual std::string getText();
                    /**
                     * @fn	virtual void SmartmaticEntry::setMax(int max);
                     * @brief	Set entry max elements.
                     * @author	Yadickson Soto
                     * @date	02/09/2013
                     * @param	max	max.
                     */
                    virtual void setMax ( int max );
                    /**
                     * @fn	virtual void setBGError();
                     * @brief	method set bg error.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     */
                    virtual void setBGError();
                    /**
                     * @fn	virtual void setBGNormal();
                     * @brief	method set bg normal.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     */
                    virtual void setBGNormal();
            };
        }
    }
}

#endif // _SMARTMATIC_SPINBUTTON_H_
