/**
 * @file SmartmaticTextView.h
 * @brief Header class text view
 * @date 23/07/2011
 * @author Juan Delgado
 */

#ifndef SMARTMATICTEXTVIEW_H_
#define SMARTMATICTEXTVIEW_H_

#include <gtkmm.h>
#include <Widgets/SmartmaticBasicScrollContainer.hxx>
#include <Widgets/ISmartmaticText.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {

            /**
             * @class	SmartmaticTextView
             * @brief	Smartmatic text view.
             * @author	Youssef.tourkmani
             * @date	25/10/2012
             */
            class SmartmaticTextView: public SmartmaticBasicScrollContainer, public ISmartmaticText
            {
                public:

                    /**
                     * @fn	SmartmaticTextView::SmartmaticTextView();
                     * @brief	Constructor.
                     * @author	Juan.Delgado
                     * @date	23/07s/2011
                     */
                    SmartmaticTextView();

                    /**
                     * @fn	SmartmaticTextView::SmartmaticTextView(BaseObjectType* cobject,
                     * 			const Glib::RefPtr<Gtk::Builder>& refBuilder=Gtk::Builder::create());
                     * @brief	Constructor.
                     * @author	Juan.Delgado
                     * @date	23/07s/2011
                     * @param	cobject			If non-null, the cobject.
                     * @param	refBuilder	The reference builder.
                     */
                    SmartmaticTextView ( BaseObjectType * cobject, const Glib::RefPtr<Gtk::Builder> & refBuilder = Gtk::Builder::create() );

                    /**
                     * @fn	virtual SmartmaticTextView::~SmartmaticTextView();
                     * @brief	Finalizer.
                     * @author	Juan.Delgado
                     * @date	23/07s/2011
                     */
                    virtual ~SmartmaticTextView();

                    /**
                     * @fn	virtual void SmartmaticTextView::setText(std::string text);
                     * @brief	Method setter text.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     * @param	text	text.
                     */
                    virtual void setText ( std::string text );
                    /**
                     * @fn	virtual std::string SmartmaticTextView::getText();
                     * @brief	Method getter text.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     * @return	text.
                     */
                    virtual std::string getText();
                    /**
                     * @fn	virtual void SmartmaticTextView::setBGError();
                     * @brief	Method set background error.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     */
                    virtual void setBGError();
                    /**
                     * @fn	virtual void SmartmaticTextView::setBGNormal();
                     * @brief	method set bg normal.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     */
                    virtual void setBGNormal();
                    /**
                     * @fn	virtual void focus();
                     * @brief	Focus component
                     * @author	Yadickson Soto
                     * @date	13/09/2013
                     */
                    virtual void focus();
                    /**
                     * @fn	virtual void vadjustment();
                     * @brief	Focus component to scroll window
                     * @author	Yadickson Soto
                     * @date	03/10/2013
                     */
                    void vadjustment();
                    /**
                     * @fn	void insert( const std::string & text );
                     * @brief	insert text to offset position
                     * @author	Yadickson Soto
                     * @date	03/10/2013
                     * @param	text text to insert
                     */
                    void insert ( const std::string & text );
                    /**
                     * @fn	void deleted();
                     * @brief	delete one caracter to offset position
                     * @author	Yadickson Soto
                     * @date	03/10/2013
                     */
                    void deleted();
                    /**
                     * @fn	void up();
                     * @brief	Move cursor to up
                     * @author	Yadickson Soto
                     * @date	03/10/2013
                     */
                    void up();
                    /**
                     * @fn	void down();
                     * @brief	Move cursor to down
                     * @author	Yadickson Soto
                     * @date	03/10/2013
                     */
                    void down();
                    /**
                     * @fn	void left();
                     * @brief	Move cursor to left
                     * @author	Yadickson Soto
                     * @date	03/10/2013
                     */
                    void left();
                    /**
                     * @fn	void right();
                     * @brief	Move cursor to right
                     * @author	Yadickson Soto
                     * @date	03/10/2013
                     */
                    void right();

                protected:

                    Gtk::TextView * textView; ///< text view
                    Glib::RefPtr<Gtk::TextBuffer> textBuffer; ///< text buffer
                    unsigned int offset; ///< offset from text
                    unsigned int tempOffset; ///< temporary offset value

                    /**
                     * @fn	void SmartmaticTextView::initialize();
                     * @brief	Method initialize.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     */
                    void initialize();
                    void focusCursor();

                    /**
                     * @fn	virtual bool SmartmaticTextView::on_button_press_event(GdkEventButton* event);
                     * @brief	Handles on button press event.
                     * @author	Juan.Delgado
                     * @date	23/07/2011
                     * @param	event	The event.
                     * @return	true if it succeeds, false if it fails.
                     */
                    virtual bool on_button_press_event ( GdkEventButton * event );

                    /**
                     * @fn	virtual bool SmartmaticTextView::on_key_press_event(GdkEventKey* event);
                     * @brief	Executes the key press event action.
                     * @author	Youssef.tourkmani
                     * @date	25/10/2012
                     * @param	event	If non-null, the event.
                     * @return	true if it succeeds, false if it fails.
                     */
                    virtual bool on_key_press_event ( GdkEventKey * event );

                    /**
                     * @fn	void SmartmaticTextView::changeText();
                     * @brief	method validate change text.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     */
                    void changeText();

                    /**
                     * @fn	void SmartmaticTextView::insertText(const Gtk::TextBuffer::iterator& a,
                     * 			const Glib::ustring& b, int c);
                     * @brief	method validate insert text.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     * @param	a	iterator.
                     * @param	b	string.
                     * @param	c	position.
                     */
                    void insertText ( const Gtk::TextBuffer::iterator & a, const Glib::ustring & b, int c );

                    /**
                     * @fn	void SmartmaticTextView::deleteText(const Gtk::TextBuffer::iterator& a,
                     * 			const Gtk::TextBuffer::iterator& b);
                     * @brief	method validate delete text.
                     * @author	Yadickson Soto
                     * @date	03/06/2012
                     * @param	a	iterator.
                     * @param	b	iterator.
                     */
                    void deleteText ( const Gtk::TextBuffer::iterator & a, const Gtk::TextBuffer::iterator & b );

                    void changeMark ( const Gtk::TextBuffer::iterator & a, const Glib::RefPtr<Gtk::TextBuffer::Mark> & mark );

                    void changeMarkOffset ( const Glib::RefPtr<Gtk::TextBuffer::Mark> & mark );
            };
        }
    }
}

#endif /* SMARTMATICTEXTVIEW_H_ */
