/**
 * @file StatisticWidget.h
 * @brief Header statistic widget class
 * @date 06/09/2011
 * @author Juan Delgado
 */

#ifndef STATISTICWIDGET_H_
#define STATISTICWIDGET_H_

#include <gtkmm.h>
#include <Configuration/label-configuration.h>
#include <Widgets/SmartmaticBasicVBox.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {

            /**
             * @class	StatisticWidget
             * @brief	Statistic widget.
             * @author	Youssef.tourkmani
             * @date	25/10/2012
             */
            class StatisticWidget : public SmartmaticBasicVBox
            {
                public:

                    /**
                     * @fn	StatisticWidget::StatisticWidget(std::map<std::string, std::map< std::string, std::string > > statisticMap);
                     * @brief	Constructor.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @param	statisticMap	The statistic map.
                     */
                    StatisticWidget ( std::map<std::string, std::map< std::string, std::string > > statisticMap, std::string titleAccessibleName );

                    /**
                     * @fn	virtual StatisticWidget::~StatisticWidget();
                     * @brief	Destructor.
                     * @author	Juan Delgado
                     * @date	30/10/2012
                     */
                    virtual ~StatisticWidget();

                    /**
                     * @fn	void StatisticWidget::SetValue(std::string codeStat, std::string value);
                     * @brief	Sets a value.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @param	codeStat	The code stat.
                     * @param	value			The value.
                     */
                    void SetValue ( std::string codeStat, std::string value );

                    /**
                     * @fn	std::string StatisticWidget::GetValue(std::string codeStat);
                     * @brief	Gets a value.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @param	codeStat	The code stat.
                     * @return	The value.
                     */
                    std::string GetValue ( std::string codeStat );

                    /**
                     * @fn	void StatisticWidget::SetStatsLabelConfiguration(Smartmatic::GUI::Configuration::LabelConfiguration& labelConfiguration);
                     * @brief	Sets stats label configuration.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @param	labelConfiguration	The label configuration.
                     */
                    void SetStatsLabelConfiguration ( Smartmatic::GUI::Configuration::LabelConfiguration & labelConfiguration );

                    /**
                     * @fn	void StatisticWidget::SetTitlesLabelConfiguration(Smartmatic::GUI::Configuration::LabelConfiguration& labelConfiguration);
                     * @brief	Sets titles label configuration.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @param	labelConfiguration	The label configuration.
                     */
                    void SetTitlesLabelConfiguration ( Smartmatic::GUI::Configuration::LabelConfiguration & labelConfiguration );

                    /**
                     * @fn	void StatisticWidget::SetTitlesSizeRequest(int width, int height);
                     * @brief	Set titles size request.
                     * @author	Juan Delgado
                     * @date	29/10/2012
                     * @param	width 	titles height.
                     * @param	height	titles width.
                     */
                    void SetTitlesSizeRequest ( int width, int height );

                    /**
                     * @fn	void StatisticWidget::SetValuesWidth(int width);
                     * @brief	Sets values width.
                     * @author	Youssef.tourkmani
                     * @date	29/10/2012
                     * @param	width	The width.
                     */
                    void SetValuesWidth ( int width );

                protected:
                    std::map < std::string, Gtk::Label * > valuesMap;	///< the values map
                    std::map < std::string, std::map < std::string, std::string > > statisticMap;	///< the statistic map

                    std::list <Gtk::Label * > titleLabelList;	///< the title label list
                    std::list <Gtk::Label * > statsLabelList;	///< the stats label list
            };
        }
    }
}

#endif /* STATISTICWIDGET_H_ */
