/**
 * @file TableBoxSelectionWidget.cxx
 * @brief Header table box selection widget class
 * @date 14/11/2012
 * @author Yadickson Soto
 */

#include "TableBoxSelectionWidget.hxx"

using namespace Smartmatic::GUI::Widgets;

TableBoxSelectionWidget::TableBoxSelectionWidget ( bool multiple, bool homogeneous, bool verticalCenter )
    : TableCenterWidget ( homogeneous, verticalCenter )
{
    this->multiple = multiple;
    this->minSelection = 0;
    this->maxSelection = 0;
}

TableBoxSelectionWidget::~TableBoxSelectionWidget()
{
    elementList.clear();
}

void TableBoxSelectionWidget::put ( void * widget, int row, int column )
{
    BoxSelectionWidget * boxWidget = static_cast < BoxSelectionWidget * > ( widget );

    elementList.push_back ( boxWidget );

    boxWidget->clear();
    boxWidget->getSignalClick().connect ( sigc::mem_fun ( *this, &TableBoxSelectionWidget::onSignalClick ) );
    TableCenterWidget::put ( boxWidget, row, column );
}

void TableBoxSelectionWidget::forceClick ( unsigned int index )
{
    if ( index < elementList.size() )
    {
        std::list <BoxSelectionWidget * >::iterator it = elementList.begin();
        std::advance ( it, index );
        ( *it )->forceClick();
    }
}

int TableBoxSelectionWidget::getCount()
{
    return elementList.size();
}

std::list <BoxSelectionWidget * > TableBoxSelectionWidget::getSelected ()
{
    std::list <BoxSelectionWidget * > list;
    std::list < BoxSelectionWidget * >::iterator it;

    for ( it = elementList.begin();
            it != elementList.end();
            ++it )
    {
        if ( ( *it )->getStatus() )
        {
            list.push_back ( *it );
        }
    }

    return list;
}

void TableBoxSelectionWidget::clear()
{
    std::list < BoxSelectionWidget * >::iterator it;

    for ( it = elementList.begin();
            it != elementList.end();
            ++it )
    {
        ( *it )->clear();
    }
}

sigc::signal<void, std::list <BoxSelectionWidget * > & > TableBoxSelectionWidget::getSignalClick()
{
    return signalClick;
}

sigc::signal<void, BoxSelectionWidget *> TableBoxSelectionWidget::getBoxSignalClick()
{
    return boxSignalClick;
}

void TableBoxSelectionWidget::onSignalClick ( BoxSelectionWidget * widget )
{
    if ( !multiple && widget->getStatus() )
    {
        std::list < BoxSelectionWidget * >::iterator it;

        for ( it = elementList.begin();
                it != elementList.end();
                ++it )
        {
            if ( ( *it )->getStatus() && ( *it )->getCode() != widget->getCode() )
            {
                ( *it )->clear();
                break;
            }
        }
    }

    std::list <BoxSelectionWidget * > list = getSelected ();
    unsigned int size = list.size();

    if ( minSelection != 0 && size < minSelection )
    {
        boxSignalClick.emit ( widget );
        minimumSignal.emit ( minSelection, size );
    }
    else if ( maxSelection != 0 && size > maxSelection )
    {
        widget->clear();
        list = getSelected ();
        maximumSignal.emit ( maxSelection );
    }
    else
    {
        boxSignalClick.emit ( widget );
        signalClick.emit ( list );
    }
}

void TableBoxSelectionWidget::setSelectionQuantitiesBoundaries ( unsigned int minSelection, unsigned int maxSelection )
{
    this->minSelection = minSelection;
    this->maxSelection = maxSelection;
}

TableBoxSelectionWidget::WarningMinSignal TableBoxSelectionWidget::getMinSignal()
{
    return minimumSignal;
}

TableBoxSelectionWidget::WarningMaxSignal TableBoxSelectionWidget::getMaxSignal()
{
    return maximumSignal;
}

unsigned int TableBoxSelectionWidget::getMin()
{
    return minSelection;
}

unsigned int TableBoxSelectionWidget::getMax()
{
    return maxSelection;
}
