/**
 * @file TableWidget.cxx
 * @brief Body class table widget
 * @date 13/03/2012
 * @author Yadickson Soto
 */

#include "TableWidget.hxx"

using namespace Smartmatic::GUI::Widgets;

TableWidget::TableWidget ( Gtk::AttachOptions xAlign, Gtk::AttachOptions yAlign )
    : SmartmaticBasicEventBox()
{
    this->table = NULL;
    this->xAlign = xAlign;
    this->yAlign = yAlign;
    initialize();
    add ( *table );
    show_all_children();
}

TableWidget::TableWidget ( SmartmaticBasicTable * table, Gtk::AttachOptions xAlign, Gtk::AttachOptions yAlign )
    : SmartmaticBasicEventBox()
{
    this->table = NULL;
    this->xAlign = xAlign;
    this->yAlign = yAlign;
    add ( *table );
    show_all_children();
}

TableWidget::~TableWidget()
{
    dispose();
}

void TableWidget::initialize()
{
    dispose();
    table = new SmartmaticBasicTable();
}

void TableWidget::dispose()
{
    remove();

    if ( table )
    {
        delete table;
        table = NULL;
    }
}

void TableWidget::put ( void * widget, int row, int column )
{
    Gtk::Widget * w = static_cast < Gtk::Widget * > ( widget );
    put ( w, row, column, xAlign, yAlign );
}

void TableWidget::put ( Gtk::Widget * widget, int row, int column, Gtk::AttachOptions xAlign, Gtk::AttachOptions yAlign )
{
    put ( widget, row, row + 1, column, column + 1, xAlign, yAlign );
}

void TableWidget::put ( Gtk::Widget * widget, int rowInit, int rowEnd, int colInit, int colEnd, Gtk::AttachOptions xAlign, Gtk::AttachOptions yAlign )
{
    table->attach ( *widget, colInit, colEnd, rowInit, rowEnd, xAlign, yAlign );
}

SmartmaticBasicTable * TableWidget::getTable()
{
    return table;
}

void TableWidget::clear()
{
    table->foreach(sigc::mem_fun(*table, &Gtk::Table::remove));
}

void TableWidget::resize ( unsigned int row, unsigned int column )
{
    if ( table )
    {
        table->resize ( row, column );
    }
}

unsigned int TableWidget::getCountElements()
{
    return table->get_children().size();
}

void TableWidget::setSpacings ( int row, int column )
{
    table->set_row_spacings ( row );
    table->set_col_spacings ( column );
}
