/**
 * @file WizardManager.hxx
 * @brief Declarations of the wizard manager class.
 * @date 08/04/2014
 * @author Yadickson Soto
 */

#ifndef _WIZARD_MANAGER_HXX_
#define _WIZARD_MANAGER_HXX_

#include <Widgets/wizard-widget-manager.h>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {
            /**
             * @class WizardManager
             * @brief The wizard manager class.
             * @date 08/04/2014
             * @author Yadickson Soto
             */
            class WizardManager : public WizardWidgetBase
            {
                public:
                    /**
                     * @fn WizardManager();
                     * @brief Class constructor
                     * @date 08/04/2014
                     * @author Yadickson Soto
                     */
                    WizardManager();
                    /**
                     * @fn virtual ~WizardManager();
                     * @brief Class destructor
                     * @date 08/04/2014
                     * @author Yadickson Soto
                     */
                    virtual ~WizardManager();
                    /**
                     * @fn virtual void initialize();
                     * @brief Start running wizard widget
                     * @date 08/04/2014
                     * @author Yadickson Soto
                     */
                    virtual void initialize();
                    /**
                     * @fn void add( WizardWidgetBase * widget );
                     * @brief Add new widget to running wizard widget
                     * @date 08/04/2014
                     * @author Yadickson Soto
                     * @param widget New widget to running
                     */
                    void add ( WizardWidgetBase * widget );

                protected:

                    /**
                     * @fn	void error();
                     * @brief	Callback if any stop signal is emitted, this will cause the wizard to fail.
                     * @author	Yadickson Soto
                     * @date	06/09/2013
                     */
                    void error();

                    /**
                     * @fn	void cancel();
                     * @brief	Callback if any cancel signal is emitted. (user action, not a failure).
                     * @author	Yadickson Soto
                     * @date	08/04/2014
                     */
                    void cancel();

                private:

                    std::vector < Smartmatic::GUI::Widgets::WizardWidgetBase * > wizardVector; ///< The wizard vector
                    Smartmatic::GUI::Widgets::WizardWidgetManager * manager; ///< The wizard manager

                    sigc::connection connectionManager; ///< The connection manager
                    std::vector < sigc::connection > connections; ///< The pool connections
            };

        } /* namespace Widgets */
    } /* namespace GUI */
} /* namespace Smartmatic */

#endif /* _WIZARD_MANAGER_HXX_ */
