/**
 * @file message-widget.cc
 * @brief Body message widget class
 * @date 29/10/2012
 * @author Juan Delgado, Yadickson Soto
 */

#include "message-widget.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) dgettext (GETTEXT_PACKAGE, String) ///<macro for gettext
#else
#define _(String) (String) ///<macro without gettext
#endif

#define N_(String) (String) ///<macro for gettext not translate

using namespace Gtk;
using namespace Smartmatic::GUI::Widgets;
using namespace Smartmatic::GUI::Configuration;

MessageWidget::MessageWidget ( Gtk::Widget * widgetChild )
    : SmartmaticBasicFrame()
{
    vertBox = NULL;
    totalAlignment = NULL;
    buttonAlignment = NULL;
    closeButton = NULL;

    add ( *widgetChild );
}

MessageWidget::MessageWidget ( Gtk::Widget * widgetChild, bool showButton, int timerToClose, std::string buttonText )
    : SmartmaticBasicFrame()
{
    vertBox = manage ( new VBox() );
    closeButton = manage ( new SmartmaticButton() );
    closeButton = manage ( new SmartmaticButton() );
    closeButton->set_size_request ( 100, 90 ); //TODO: configuration

    if ( buttonText.empty() )
    {
        closeButton->SetLabel ( _ ( "Smartmatic.GUI.Widgets.MessageWidget.OK" ) );
    }
    else
    {
        closeButton->SetLabel ( _ ( buttonText.c_str() ) );
    }

    closeButton->WidgetsPosition ( 5, 0, 0 );
    closeButton->signal_clicked().connect ( sigc::mem_fun ( this, &MessageWidget::on_closeButton_clicked ) );

    if ( !showButton )
    {
        closeButton->set_no_show_all();
    }

    if ( widgetChild )
    {
        vertBox->pack_start ( *widgetChild );
    }

    buttonAlignment = manage ( new Gtk::Alignment() );
    buttonAlignment->set_padding ( 0, 0, 200, 200 );
    buttonAlignment->add ( *closeButton );
    vertBox->pack_start ( *buttonAlignment, false, false );
    totalAlignment = manage ( new Gtk::Alignment() );
    totalAlignment->add ( *vertBox );
    totalAlignment->set_padding ( 0, 100, 0, 0 );
    add ( *totalAlignment );
    show_all_children();
    connector_close = Glib::signal_timeout().connect ( sigc::bind ( sigc::mem_fun ( *this, &MessageWidget::on_timeout ), 0 ), timerToClose );
}

MessageWidget::~MessageWidget()
{
    connector_close.disconnect();
}

bool MessageWidget::on_timeout ( int timer )
{
    m_close_clicked.emit();
    return false;
}

void MessageWidget::on_closeButton_clicked()
{
    connector_close.disconnect();
    m_close_clicked.emit();
}

MessageWidget::type_close_clicked MessageWidget::close_clicked()
{
    return m_close_clicked;
}

void MessageWidget::closeButtonSetName ( std::string name )
{
    closeButton->set_name ( name );
}
