/**
 * @file message-widget.h
 * @brief Header message widget class
 * @date 29/10/2012
 * @author Juan Delgado, Yadickson Soto
 */

#ifndef _MESSAGE_WIDGET_H_
#define _MESSAGE_WIDGET_H_

#include <gtkmm.h>
#include "Widgets/smartmatic-button.h"
#include "Configuration/label-configuration.h"
#include <Widgets/SmartmaticBasicFrame.hxx>

namespace Smartmatic
{
    namespace GUI
    {
        namespace Widgets
        {

            /**
             * @class	MessageWidget
             * @brief	Message widget.
             * @author	Youssef.tourkmani
             * @date	25/10/2012
             */
            class MessageWidget: public SmartmaticBasicFrame
            {
                public:

                    /**
                     * @fn	MessageWidget::MessageWidget(Gtk::Widget* widgetChild);
                     * @brief	Constructor.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	widgetChild	If non-null, the widget child.
                     */
                    explicit MessageWidget ( Gtk::Widget * widgetChild );

                    /**
                     * @fn	MessageWidget::MessageWidget(Gtk::Widget* widgetChild, bool showButton, int timerToClose,
                     * 			std::string buttonText = "");
                     * @brief	Constructor.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	widgetChild 	If non-null, the widget child.
                     * @param	showButton		true to show, false to hide the button.
                     * @param	timerToClose	The timer to close.
                     * @param	buttonText		The button text.
                     */
                    MessageWidget ( Gtk::Widget * widgetChild, bool showButton, int timerToClose, std::string buttonText = "" );

                    /**
                     * @fn	virtual MessageWidget::~MessageWidget();
                     * @brief	Finaliser.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     */
                    virtual ~MessageWidget();

                    /**
                     * @typedef	sigc::signal<void> type_close_clicked
                     * @brief	signals definitions.
                     */
                    typedef sigc::signal<void> type_close_clicked;

                    /**
                     * @fn	type_close_clicked MessageWidget::close_clicked();
                     * @brief	signals connect methods.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @return	.
                     */
                    type_close_clicked close_clicked();

                    /**
                     * @fn	void MessageWidget::closeButtonSetName(std::string name);
                     * @brief	Closes a button set name.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	name	The name.
                     */
                    void closeButtonSetName ( std::string name );

                protected:
                    /**
                     * @brief signals declaration
                     */
                    type_close_clicked m_close_clicked; ///< The close clicked


                    sigc::connection connector_close;   ///< The connector close

                    /**
                     * @fn	bool MessageWidget::on_timeout(int timer);
                     * @brief	Executes the timeout action.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     * @param	timer	The timer.
                     * @return	true if it succeeds, false if it fails.
                     */
                    bool on_timeout ( int timer );

                    /**
                     * @fn	void MessageWidget::on_closeButton_clicked();
                     * @brief	Handles close button clicked signals.
                     * @author	Luiggi.mendez
                     * @date	27/04/2011
                     */
                    void on_closeButton_clicked();

                private:
                    Gtk::VBox * vertBox; ///< The vertical box
                    Gtk::Alignment * totalAlignment; ///< The total alignment
                    Gtk::Alignment * buttonAlignment;	///< The button alignment
                    Smartmatic::GUI::Widgets::SmartmaticButton * closeButton;	///< The close button

            };
        }
    }
}

#endif // _MESSAGE_WIDGET_H_
