#ifndef TEST_BASIC_WINDOW_CONF_MANAGER_TEST
#define TEST_BASIC_WINDOW_CONF_MANAGER_TEST

#ifdef ECUT_MAIN

#include <cppunit/extensions/HelperMacros.h>
#include <Configuration/BasicWindowConfManager.hxx>
#include <tests/MockSmttGuiConfigurationManager.hxx>
#include <tests/MockConfigurationPersistenceManager.hxx>

class BasicWindowConfManagerTest : public CPPUNIT_NS::TestFixture
{
    public:

        typedef Smartmatic::GUI::Configuration::BasicWindowConfManager BasicWindowConfManager;
        typedef Smartmatic::GUI::Configuration::SMTTGUIConfigurationManager SMTTGUIConfigurationManager;
        typedef Smartmatic::GUI::Configuration::BasicWindowConfigurations BasicWindowConfigurations;
        typedef Smartmatic::Configuration::ConfigurationPersistenceManager ConfigurationPersistenceManager;

        BasicWindowConfManager * basicWindowManager;

        BasicWindowConfManagerTest()
        {
            basicWindowManager = NULL;
        }

        void setUp()
        {
            basicWindowManager = BasicWindowConfManager::getInstance();
        }

        void tearDown()
        {
            delete basicWindowManager;
            basicWindowManager = NULL;
        }

        void testBasicWindowValuesWithoutValues()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttGuiConfigurationManager confManager;
            SMTTGUIConfigurationManager::getInstance ( &confManager );

            BasicWindowConfigurations & basicWindowConfigurations ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getBasicWindowConfigurations() );

            basicWindowConfigurations.setWindowTitle ( "" );
            basicWindowConfigurations.setShowBorder ( false );

            CPPUNIT_ASSERT ( true == basicWindowManager->getWindowTitle().empty() );
            CPPUNIT_ASSERT ( false == basicWindowManager->isShowBorderWindow() );

            persistenceManager.verify();
        }

        void testBasicWindowValuesWithValues()
        {
            MockConfigurationPersistenceManager persistenceManager;

            MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

            Initialize_mock
            .expects ( MOCKPP_NS::once() );

            ConfigurationPersistenceManager::getInstance ( &persistenceManager );

            MockSmttGuiConfigurationManager confManager;
            SMTTGUIConfigurationManager::getInstance ( &confManager );

            BasicWindowConfigurations & basicWindowConfigurations ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getBasicWindowConfigurations() );

            basicWindowConfigurations.setWindowTitle ( "one_title" );
            basicWindowConfigurations.setShowBorder ( true );

            std::string title = basicWindowManager->getWindowTitle();

            CPPUNIT_ASSERT ( false == title.empty() );
            CPPUNIT_ASSERT ( "one_title" == title );

            CPPUNIT_ASSERT ( true == basicWindowManager->isShowBorderWindow() );

            persistenceManager.verify();
        }

        void testGetAppSound_IfEmpty()
        {
            /*            MockConfigurationPersistenceManager persistenceManager;

                        MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

                        Initialize_mock
                        .expects ( MOCKPP_NS::once() );

                        ConfigurationPersistenceManager::getInstance ( &persistenceManager );

                        MockSmttGuiConfigurationManager confManager;
                        SMTTGUIConfigurationManager::getInstance ( &confManager );

                        SoundOutput & sound ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSoundOutput() );
                        sound.setAppSound ( "" );

                        std::string result;
                        result = basicWindowManager->getAppSound();

                        CPPUNIT_ASSERT ( true == result.empty() );

                        persistenceManager.verify();
                    }

                    void testGetAppSound()
                    {
                        MockConfigurationPersistenceManager persistenceManager;

                        MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

                        Initialize_mock
                        .expects ( MOCKPP_NS::once() );

                        ConfigurationPersistenceManager::getInstance ( &persistenceManager );

                        MockSmttGuiConfigurationManager confManager;
                        SMTTGUIConfigurationManager::getInstance ( &confManager );

                        SoundOutput & sound ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSoundOutput() );
                        sound.setAppSound ( "aplay" );

                        std::string result;
                        result = basicWindowManager->getAppSound();

                        CPPUNIT_ASSERT ( false == result.empty() );
                        CPPUNIT_ASSERT ( "aplay" == result );

                        persistenceManager.verify();
                    }

                    void testGetUsingBeepTrue()
                    {
                        MockConfigurationPersistenceManager persistenceManager;

                        MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

                        Initialize_mock
                        .expects ( MOCKPP_NS::once() );

                        ConfigurationPersistenceManager::getInstance ( &persistenceManager );

                        MockSmttGuiConfigurationManager confManager;
                        SMTTGUIConfigurationManager::getInstance ( &confManager );

                        SoundOutput & sound ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSoundOutput() );
                        sound.getSoundConfigurations().clear();
                        sound.setUseBeep ( true );

                        CPPUNIT_ASSERT ( true == basicWindowManager->isUsingBeep() );

                        persistenceManager.verify();
                    }

                    void testGetUsingBeepFalse()
                    {
                        MockConfigurationPersistenceManager persistenceManager;

                        MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

                        Initialize_mock
                        .expects ( MOCKPP_NS::once() );

                        ConfigurationPersistenceManager::getInstance ( &persistenceManager );

                        MockSmttGuiConfigurationManager confManager;
                        SMTTGUIConfigurationManager::getInstance ( &confManager );

                        SoundOutput & sound ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSoundOutput() );
                        sound.getSoundConfigurations().clear();
                        sound.setUseBeep ( false );

                        CPPUNIT_ASSERT ( false == basicWindowManager->isUsingBeep() );

                        persistenceManager.verify();
                    }

                    void testGetSoundFile_SoundOutputConfigExist_SoundFileNotFound()
                    {
                        MockConfigurationPersistenceManager persistenceManager;

                        MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

                        Initialize_mock
                        .expects ( MOCKPP_NS::once() );

                        ConfigurationPersistenceManager::getInstance ( &persistenceManager );

                        MockSmttGuiConfigurationManager confManager;
                        SMTTGUIConfigurationManager::getInstance ( &confManager );

                        SoundOutput & sound ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSoundOutput() );
                        sound.getSoundConfigurations().clear();

                        SoundConfigurations confSeq ( "ConfigName" );

                        sound.getSoundConfigurations().push_back ( confSeq );

                        std::string result;
                        result = basicWindowManager->getSoundFile ( "ConfigName" );

                        CPPUNIT_ASSERT ( true == result.empty() );

                        persistenceManager.verify();
                    }

                    void testGetSoundFile_SoundOutputConfigExist_SoundFileFound()
                    {
                        MockConfigurationPersistenceManager persistenceManager;

                        MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

                        Initialize_mock
                        .expects ( MOCKPP_NS::once() );

                        ConfigurationPersistenceManager::getInstance ( &persistenceManager );

                        MockSmttGuiConfigurationManager confManager;
                        SMTTGUIConfigurationManager::getInstance ( &confManager );

                        SoundOutput & sound ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSoundOutput() );
                        sound.getSoundConfigurations().clear();

                        SoundConfigurations confSeq ( "ConfigName" );
                        confSeq.setSoundFile ( "file.wav" );

                        sound.getSoundConfigurations().push_back ( confSeq );

                        std::string result;
                        result = basicWindowManager->getSoundFile ( "ConfigName" );

                        CPPUNIT_ASSERT ( false == result.empty() );
                        CPPUNIT_ASSERT ( "file.wav" == result );

                        persistenceManager.verify();
                    }

                    void testGetSoundFile_SoundOutputConfigExist_SoundNameNotFound()
                    {
                        MockConfigurationPersistenceManager persistenceManager;

                        MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

                        Initialize_mock
                        .expects ( MOCKPP_NS::once() );

                        ConfigurationPersistenceManager::getInstance ( &persistenceManager );

                        MockSmttGuiConfigurationManager confManager;
                        SMTTGUIConfigurationManager::getInstance ( &confManager );

                        SoundOutput & sound ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSoundOutput() );
                        sound.getSoundConfigurations().clear();

                        SoundConfigurations confSeq ( "ConfigName" );
                        confSeq.setSoundFile ( "file.wav" );

                        sound.getSoundConfigurations().push_back ( confSeq );

                        std::string result;
                        result = basicWindowManager->getSoundFile ( "OtherName" );

                        CPPUNIT_ASSERT ( true == result.empty() );

                        persistenceManager.verify();
                    }

                    void testGetSoundConfiguration_SoundOutputConfigNotExist()
                    {
                        MockConfigurationPersistenceManager persistenceManager;

                        MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

                        Initialize_mock
                        .expects ( MOCKPP_NS::once() );

                        ConfigurationPersistenceManager::getInstance ( &persistenceManager );

                        MockSmttGuiConfigurationManager confManager;
                        SMTTGUIConfigurationManager::getInstance ( &confManager );

                        SoundOutput & sound ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSoundOutput() );
                        sound.getSoundConfigurations().clear();

                        std::vector<BeepDescriptor> result = basicWindowManager->getSoundConfiguration ( "ConfigName" );

                        CPPUNIT_ASSERT ( true == result.empty() );

                        persistenceManager.verify();
                    }

                    void testGetSoundConfiguration_SoundOutputConfigExist()
                    {
                        MockConfigurationPersistenceManager persistenceManager;

                        MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

                        Initialize_mock
                        .expects ( MOCKPP_NS::once() );

                        ConfigurationPersistenceManager::getInstance ( &persistenceManager );

                        MockSmttGuiConfigurationManager confManager;
                        SMTTGUIConfigurationManager::getInstance ( &confManager );

                        SoundOutput & sound ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSoundOutput() );
                        sound.getSoundConfigurations().clear();


                        SoundConfigurations confSeq ( "ConfigName" );
                        confSeq.setSoundFile ( "file.wav" );

                        SoundConfigurations::SoundConfigurationSequence soundSeq;
                        soundSeq.push_back ( SoundDescriptorConfiguration ( 10, 20, 30, 40 ) );

                        confSeq.setSoundConfiguration ( soundSeq );
                        sound.getSoundConfigurations().push_back ( confSeq );

                        std::vector<BeepDescriptor> result = basicWindowManager->getSoundConfiguration ( "ConfigName" );

                        CPPUNIT_ASSERT ( 1 == result.size() );
                        CPPUNIT_ASSERT ( " -f 10 -l 20 -r 30 -d 40" == ( * ( result.begin() ) ).GetBeepLine() );

                        persistenceManager.verify();
                    }

                    void testGetSoundConfiguration_SoundOutputConfigExist_OtherSoundName()
                    {
                        MockConfigurationPersistenceManager persistenceManager;

                        MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

                        Initialize_mock
                        .expects ( MOCKPP_NS::once() );

                        ConfigurationPersistenceManager::getInstance ( &persistenceManager );

                        MockSmttGuiConfigurationManager confManager;
                        SMTTGUIConfigurationManager::getInstance ( &confManager );

                        SoundOutput & sound ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSoundOutput() );
                        sound.getSoundConfigurations().clear();


                        SoundConfigurations confSeq ( "ConfigName" );
                        confSeq.setSoundFile ( "file.wav" );

                        SoundConfigurations::SoundConfigurationSequence soundSeq;
                        soundSeq.push_back ( SoundDescriptorConfiguration ( 10, 20, 30, 40 ) );

                        confSeq.setSoundConfiguration ( soundSeq );
                        sound.getSoundConfigurations().push_back ( confSeq );

                        std::vector<BeepDescriptor> result = basicWindowManager->getSoundConfiguration ( "OtherName" );

                        CPPUNIT_ASSERT ( true == result.empty() );

                        persistenceManager.verify();
                    }

                    void testGetSoundConfiguration_TwoBeep_SoundOutputConfigExist()
                    {
                        MockConfigurationPersistenceManager persistenceManager;

                        MOCKPP_CHAINER_FOR_EXT ( MockConfigurationPersistenceManager, Initialize, ext ) Initialize_mock ( &persistenceManager );

                        Initialize_mock
                        .expects ( MOCKPP_NS::once() );

                        ConfigurationPersistenceManager::getInstance ( &persistenceManager );

                        MockSmttGuiConfigurationManager confManager;
                        SMTTGUIConfigurationManager::getInstance ( &confManager );

                        SoundOutput & sound ( SMTTGUIConfigurationManager::getInstance()->getConfiguration()->getSoundOutput() );
                        sound.getSoundConfigurations().clear();


                        SoundConfigurations confSeq ( "ConfigName" );
                        confSeq.setSoundFile ( "file.wav" );

                        SoundConfigurations::SoundConfigurationSequence soundSeq;
                        soundSeq.push_back ( SoundDescriptorConfiguration ( 10, 20, 30, 40 ) );
                        soundSeq.push_back ( SoundDescriptorConfiguration ( 1, 2, 3, 4 ) );

                        confSeq.setSoundConfiguration ( soundSeq );
                        sound.getSoundConfigurations().push_back ( confSeq );

                        std::vector<BeepDescriptor> result = basicWindowManager->getSoundConfiguration ( "ConfigName" );

                        CPPUNIT_ASSERT ( 2 == result.size() );

                        std::vector<BeepDescriptor>::iterator it = result.begin();

                        CPPUNIT_ASSERT ( " -f 10 -l 20 -r 30 -d 40" == ( *it ).GetBeepLine() );

                        ++it;

                        CPPUNIT_ASSERT ( " -f 1 -l 2 -r 3 -d 4" == ( *it ).GetBeepLine() );

                        persistenceManager.verify();
                        */
        }

        CPPUNIT_TEST_SUITE ( BasicWindowConfManagerTest );

        CPPUNIT_TEST ( testBasicWindowValuesWithoutValues );
        CPPUNIT_TEST ( testBasicWindowValuesWithValues );

        CPPUNIT_TEST_SUITE_END();
};

#endif /* ECUT_MAIN */

#endif /* TEST_BASIC_WINDOW_CONF_MANAGER_TEST */
