/**
 * @file BasePathInterface.hxx
 * @brief Declaration of the interface that abstracts to the base path provider.
 * @author Yadickson Soto
 * @date 18/07/2011
 */

#ifndef BASEPATHINTERFACE_HXX_
#define BASEPATHINTERFACE_HXX_

#include <Log/LogInterface.hxx>

namespace Smartmatic
{
    namespace Log
    {
        /**
         * @class   BasePathInterface
         * @brief   Interface that abstracts which exposes the methods of the base path provider.
         * @see LogInterface.
         * @author  Yadickson Soto
         * @date    18/07/2011
         */
        class BasePathInterface : public LogInterface
        {
            public:
                /**
                 * @fn  BasePathInterface::BasePathInterface ( const std::string & code );
                 * @brief   Constructor initializes an instance of the BasePathInterface class.
                 * @author  Yadickson Soto
                 * @date    18/07/2011
                 * @param   code The code that identifies the instance.
                 */
                explicit BasePathInterface ( const std::string & code );

                /**
                 * @fn  virtual BasePathInterface::~BasePathInterface ();
                 * @brief   Finalizes the instance of the BasePathInterface Class.
                 * @author  Yadickson Soto
                 * @date    18/07/2011
                 */
                virtual ~BasePathInterface ();

                /**
                 * @fn  virtual std::string BasePathInterface::getFileFullPath ( std::string & file ) = 0;
                 * @brief  Gets full path.
                 * @author  Yadickson Soto
                 * @date    18/07/2011
                 * @param   file The file name.
                 * @return  file The full path of the merge between base directory and relative path of the file.
                 */
                virtual std::string getFileFullPath ( std::string & file ) = 0;

                /**
                 * @fn  virtual bool BasePathInterface::canWriter () = 0;
                 * @brief   Gets whether exists the directory.
                 * @author  Yadickson Soto
                 * @date    18/07/2011
                 * @return	true if exists successful; otherwise false.
                 */
                virtual bool canWriter () = 0;
        };
    }
}

#endif /* BASEPATHINTERFACE_HXX_ */
