/**
 * @file LogImpl.cpp
 * @brief Body file class LogImpl, declares the log implementation class.
 * @date 08-03-2011
 * @author gerardohernandez
 */

#include "LogImpl.h"
#include <stdio.h>

using namespace Smartmatic::Log;
using namespace log4cxx::helpers;
using namespace log4cxx::spi;
using namespace log4cxx;

LogImpl::LogImpl ( log4cxx::LoggerPtr loggerInfoArg,
                   log4cxx::LoggerPtr loggerErrorArg,
                   log4cxx::LoggerPtr loggerWarnArg,
                   log4cxx::helpers::Pool & pool,
                   const log4cxx::LogString & name,
                   std::string domain )
    : Logger ( pool, name ) ,
      loggerError ( loggerErrorArg ) ,
      loggerInfo ( loggerInfoArg ) ,
      loggerWarn ( loggerWarnArg ) ,
      currentName ( name ) ,
      domain ( domain )
{
}

void LogImpl::doLog ( const log4cxx::LevelPtr & level, const std::string & messageCode )
{
    if ( messageCode.empty () )
    {
        return;
    }

    try
    {
        LoggingEventPtr loggingEvent = new LoggingEvent ( LOG4CXX_STR ( currentName ) , level,
                LOG4CXX_STR ( messageCode ) , LocationInfo::getLocationUnavailable () );
        loggingEvent->setProperty ( LOG4CXX_STR ( "SMTTMessageCode" ) , LOG4CXX_STR ( messageCode ) );

        if ( level == Level::getDebug () )
        {
            LOG4CXX_DEBUG ( loggerInfo, messageCode );
        }

        if ( level == Level::getWarn () )
        {
            LOG4CXX_WARN ( loggerWarn, messageCode );
        }

        if ( level == Level::getError () )
        {
            LOG4CXX_ERROR ( loggerWarn, messageCode );
        }
    }
    catch ( ... )
    {
        printf ( " LogImpl: FATAL ERROR \n" );
    }
}

void LogImpl::Debug ( const std::string & messageCode )
{
    doLog ( Level::getDebug () , messageCode );
}

void LogImpl::Audit ( const std::string & messageCode )
{
    if ( domain != "" )
    {
        doLog ( Level::getWarn () , domain + "#" + messageCode );
    }
    else
    {
        doLog ( Level::getWarn () , messageCode );
    }
}

void LogImpl::Error ( const std::string & messageCode )
{
    if ( domain != "" )
    {
        doLog ( Level::getError () , domain + "#" + messageCode );
    }
    else
    {
        doLog ( Level::getError () , messageCode );
    }
}

